@@ -10,10 +10,10 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
+#include <cstdlib>
 #include <iostream>
 #include <string>
 
-#include "H5private.h" // for HDfree
 #include "H5Include.h"
 #include "H5Exception.h"
 #include "H5IdComponent.h"
@@ -267,8 +267,10 @@ DataSet::getInMemDataSize() const
     }
 
     // Calculate and return the size of the data
-    size_t data_size = type_size * num_elements;
-    return (data_size);
+    // Note that large datasets can overflow a size_t
+    size_t data_size = type_size * static_cast<size_t>(num_elements);
+
+    return data_size;
 }
 
 //--------------------------------------------------------------------------
@@ -364,9 +366,9 @@ DataSet::vlenReclaim(const DataType &type, const DataSpace &space, const DSetMem
     hid_t space_id      = space.getId();
     hid_t xfer_plist_id = xfer_plist.getId();
 
-    herr_t ret_value = H5Dvlen_reclaim(type_id, space_id, xfer_plist_id, buf);
+    herr_t ret_value = H5Treclaim(type_id, space_id, xfer_plist_id, buf);
     if (ret_value < 0) {
-        throw DataSetIException("DataSet::vlenReclaim", "H5Dvlen_reclaim failed");
+        throw DataSetIException("DataSet::vlenReclaim", "H5Treclaim failed");
     }
 }
 
@@ -392,9 +394,9 @@ DataSet::vlenReclaim(void *buf, const DataType &type, const DataSpace &space,
     hid_t space_id      = space.getId();
     hid_t xfer_plist_id = xfer_plist.getId();
 
-    herr_t ret_value = H5Dvlen_reclaim(type_id, space_id, xfer_plist_id, buf);
+    herr_t ret_value = H5Treclaim(type_id, space_id, xfer_plist_id, buf);
     if (ret_value < 0) {
-        throw DataSetIException("DataSet::vlenReclaim", "H5Dvlen_reclaim failed");
+        throw DataSetIException("DataSet::vlenReclaim", "H5Treclaim failed");
     }
 }
 
@@ -716,8 +718,8 @@ DataSet::p_read_fixed_len(const hid_t mem_type_id, const hid_t mem_space_id, con
 
     // If there is data, allocate buffer and read it.
     if (data_size > 0) {
-        char *strg_C = new char[data_size + 1];
-        HDmemset(strg_C, 0, data_size + 1); // clear buffer
+        // Create buffer for C string
+        char *strg_C = new char[data_size + 1]();
 
         herr_t ret_value = H5Dread(id, mem_type_id, mem_space_id, file_space_id, xfer_plist_id, strg_C);
 
@@ -727,7 +729,7 @@ DataSet::p_read_fixed_len(const hid_t mem_type_id, const hid_t mem_space_id, con
         }
 
         // Get string from the C char* and release resource allocated locally
-        strg = strg_C;
+        strg = H5std_string(strg_C, data_size);
         delete[] strg_C;
     }
 }
@@ -758,7 +760,7 @@ DataSet::p_read_variable_len(const hid_t mem_type_id, const hid_t mem_space_id,
 
     // Get string from the C char* and release resource allocated by C API
     strg = strg_C;
-    HDfree(strg_C);
+    free(strg_C);
 }
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
