@@ -22,9 +22,8 @@ const char Exception::DEFAULT_MSG[] = "No detailed information provided";
 //--------------------------------------------------------------------------
 // Function:    Exception default constructor
 ///\brief       Default constructor.
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-Exception::Exception()
+Exception::Exception() : detail_message{""}, func_name{""}
 {
 }
 
@@ -34,7 +33,6 @@ Exception::Exception()
 ///             in which the failure occurs, and an optional detailed message.
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 Exception::Exception(const H5std_string &func, const H5std_string &message)
     : detail_message(message), func_name(func)
@@ -45,7 +43,6 @@ Exception::Exception(const H5std_string &func, const H5std_string &message)
 // Function:    Exception copy constructor
 ///\brief       Copy constructor: same HDF5 object as \a original
 ///\param       orig - IN: Exception instance to copy
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 Exception::Exception(const Exception &orig) : detail_message(orig.detail_message), func_name(orig.func_name)
 {
@@ -60,7 +57,6 @@ Exception::Exception(const Exception &orig) : detail_message(orig.detail_message
 ///\par Description
 ///             In the failure case, the string "Invalid major error number"
 ///             will be returned.
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 H5std_string
 Exception::getMajorString(hid_t err_major) const
@@ -72,9 +68,14 @@ Exception::getMajorString(hid_t err_major) const
     if (mesg_size < 0)
         throw IdComponentException("Exception::getMajorString", "H5Eget_msg failed");
 
+    // The actual message size is the cast value + 1 for the terminal ASCII NUL
+    // (unfortunate in/out type sign mismatch)
+    size_t actual_mesg_size = static_cast<size_t>(mesg_size) + 1;
+
     // Call H5Eget_msg again to get the actual message
-    char *mesg_C = new char[mesg_size + 1]; // temporary C-string for C API
-    mesg_size    = H5Eget_msg(err_major, NULL, mesg_C, mesg_size + 1);
+    char *mesg_C = new char[actual_mesg_size]; // temporary C-string for C API
+
+    mesg_size = H5Eget_msg(err_major, NULL, mesg_C, actual_mesg_size);
 
     // Check for failure again
     if (mesg_size < 0) {
@@ -97,7 +98,6 @@ Exception::getMajorString(hid_t err_major) const
 ///\par Description
 ///             In the failure case, the string "Invalid minor error number"
 ///             will be returned.
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 H5std_string
 Exception::getMinorString(hid_t err_minor) const
@@ -109,9 +109,14 @@ Exception::getMinorString(hid_t err_minor) const
     if (mesg_size < 0)
         throw IdComponentException("Exception::getMinorString", "H5Eget_msg failed");
 
+    // The actual message size is the cast value + 1 for the terminal ASCII NUL
+    // (unfortunate in/out type sign mismatch)
+    size_t actual_mesg_size = static_cast<size_t>(mesg_size) + 1;
+
     // Call H5Eget_msg again to get the actual message
-    char *mesg_C = new char[mesg_size + 1]; // temporary C-string for C API
-    mesg_size    = H5Eget_msg(err_minor, NULL, mesg_C, mesg_size + 1);
+    char *mesg_C = new char[actual_mesg_size]; // temporary C-string for C API
+
+    mesg_size = H5Eget_msg(err_minor, NULL, mesg_C, actual_mesg_size);
 
     // Check for failure again
     if (mesg_size < 0) {
@@ -139,7 +144,6 @@ Exception::getMinorString(hid_t err_minor) const
 ///\par
 ///             Users are encouraged to write their own more specific error
 ///             handlers
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 Exception::setAutoPrint(H5E_auto2_t &func, void *client_data)
@@ -154,7 +158,6 @@ Exception::setAutoPrint(H5E_auto2_t &func, void *client_data)
 //--------------------------------------------------------------------------
 // Function:    Exception::dontPrint
 ///\brief       Turns off the automatic error printing from the C library.
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 Exception::dontPrint()
@@ -174,7 +177,6 @@ Exception::dontPrint()
 ///                                called upon an error condition
 ///\param       client_data - OUT: Current setting for the data passed to
 ///                                the error function
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 Exception::getAutoPrint(H5E_auto2_t &func, void **client_data)
@@ -192,7 +194,6 @@ Exception::getAutoPrint(H5E_auto2_t &func, void **client_data)
 ///\par Description
 ///             The stack is also cleared whenever a C API function is
 ///             called, with certain exceptions (for instance, \c H5Eprint).
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 Exception::clearErrorStack()
@@ -242,7 +243,6 @@ Exception::clearErrorStack()
 ///     const char  *desc;          //optional supplied description
 /// } H5E_error2_t;
 ///\endcode
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 Exception::walkErrorStack(H5E_direction_t direction, H5E_walk2_t func, void *client_data)
@@ -258,7 +258,6 @@ Exception::walkErrorStack(H5E_direction_t direction, H5E_walk2_t func, void *cli
 ///\brief       Returns the detailed message set at the time the exception
 ///             is thrown.
 ///\return      Text message - \c H5std_string
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 H5std_string
 Exception::getDetailMsg() const
@@ -271,7 +270,6 @@ Exception::getDetailMsg() const
 ///\brief       Returns the detailed message set at the time the exception
 ///             is thrown.
 ///\return      Text message - \c char pointer
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 const char *
 Exception::getCDetailMsg() const
@@ -283,7 +281,6 @@ Exception::getCDetailMsg() const
 // Function:    Exception::getFuncName
 ///\brief       Returns the name of the function, where the exception is thrown.
 ///\return      Text message - \c H5std_string
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 H5std_string
 Exception::getFuncName() const
@@ -295,7 +292,6 @@ Exception::getFuncName() const
 // Function:    Exception::getCFuncName
 ///\brief       Returns the name of the function, where the exception is thrown.
 ///\return      Text message - \c char pointer
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 const char *
 Exception::getCFuncName() const
@@ -308,7 +304,6 @@ Exception::getCFuncName() const
 ///\brief       Prints the error stack in a default manner.
 ///\param       stream    - IN: File pointer, default to stderr
 ///\param       err_stack - IN: Error stack ID, default to H5E_DEFAULT(0)
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 Exception::printErrorStack(FILE *stream, hid_t err_stack)
@@ -324,7 +319,6 @@ Exception::printErrorStack(FILE *stream, hid_t err_stack)
 //              function is replaced by the static function printErrorStack
 //              and will be removed from the next major release.
 // Parameter    stream - IN: File pointer
-// Programmer   Binh-Minh Ribler - 2000
 // Description:
 //              This function can be removed in next major release.
 //              -BMR, 2014/04/24
@@ -336,18 +330,8 @@ Exception::printErrorStack(FILE *stream, hid_t err_stack)
 //    Exception::printErrorStack(stream, H5E_DEFAULT);
 //}
 
-//--------------------------------------------------------------------------
-// Function:    Exception destructor
-///\brief       Noop destructor
-// Programmer   Binh-Minh Ribler - 2000
-//--------------------------------------------------------------------------
-Exception::~Exception() throw()
-{
-}
-
 //--------------------------------------------------------------------------
 // Subclass:    FileIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    FileIException default constructor
@@ -367,17 +351,9 @@ FileIException::FileIException(const H5std_string &func, const H5std_string &mes
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    FileIException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-FileIException::~FileIException() throw()
-{
-}
 
 //--------------------------------------------------------------------------
 // Subclass:    GroupIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    GroupIException default constructor
@@ -397,17 +373,8 @@ GroupIException::GroupIException(const H5std_string &func, const H5std_string &m
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    GroupIException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-GroupIException::~GroupIException() throw()
-{
-}
-
 //--------------------------------------------------------------------------
 // Subclass:    DataSpaceIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    DataSpaceIException default constructor
@@ -427,17 +394,9 @@ DataSpaceIException::DataSpaceIException(const H5std_string &func, const H5std_s
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    DataSpaceIException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-DataSpaceIException::~DataSpaceIException() throw()
-{
-}
 
 //--------------------------------------------------------------------------
 // Subclass:    DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    DataTypeIException default constructor
@@ -457,17 +416,9 @@ DataTypeIException::DataTypeIException(const H5std_string &func, const H5std_str
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    DataTypeIException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-DataTypeIException::~DataTypeIException() throw()
-{
-}
 
 //--------------------------------------------------------------------------
 // Subclass:    ObjHeaderIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    ObjHeaderIException default constructor
@@ -487,17 +438,9 @@ ObjHeaderIException::ObjHeaderIException(const H5std_string &func, const H5std_s
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    ObjHeaderIException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-ObjHeaderIException::~ObjHeaderIException() throw()
-{
-}
 
 //--------------------------------------------------------------------------
 // Subclass:    PropListIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    PropListIException default constructor
@@ -517,17 +460,9 @@ PropListIException::PropListIException(const H5std_string &func, const H5std_str
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    PropListIException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-PropListIException::~PropListIException() throw()
-{
-}
 
 //--------------------------------------------------------------------------
 // Subclass:    DataSetIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    DataSetIException default constructor
@@ -547,17 +482,9 @@ DataSetIException::DataSetIException(const H5std_string &func, const H5std_strin
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    DataSetIException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-DataSetIException::~DataSetIException() throw()
-{
-}
 
 //--------------------------------------------------------------------------
 // Subclass:    AttributeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    AttributeIException default constructor
@@ -577,17 +504,9 @@ AttributeIException::AttributeIException(const H5std_string &func, const H5std_s
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    AttributeIException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-AttributeIException::~AttributeIException() throw()
-{
-}
 
 //--------------------------------------------------------------------------
 // Subclass:    ReferenceException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    ReferenceException default constructor
@@ -607,17 +526,9 @@ ReferenceException::ReferenceException(const H5std_string &func, const H5std_str
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    ReferenceException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-ReferenceException::~ReferenceException() throw()
-{
-}
 
 //--------------------------------------------------------------------------
 // Subclass:    LibraryIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    LibraryIException default constructor
@@ -637,17 +548,9 @@ LibraryIException::LibraryIException(const H5std_string &func, const H5std_strin
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    LibraryIException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-LibraryIException::~LibraryIException() throw()
-{
-}
 
 //--------------------------------------------------------------------------
 // Subclass:    LocationException
-// Programmer   Binh-Minh Ribler - 2014
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    LocationException default constructor
@@ -667,17 +570,9 @@ LocationException::LocationException(const H5std_string &func, const H5std_strin
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    LocationException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-LocationException::~LocationException() throw()
-{
-}
 
 //--------------------------------------------------------------------------
 // Subclass:    IdComponentException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
 // Function:    IdComponentException default constructor
@@ -697,12 +592,5 @@ IdComponentException::IdComponentException(const H5std_string &func, const H5std
     : Exception(func, message)
 {
 }
-//--------------------------------------------------------------------------
-// Function:    IdComponentException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-IdComponentException::~IdComponentException() throw()
-{
-}
 
 } // namespace H5
