@@ -118,6 +118,52 @@ H5File::H5File(const H5std_string &name, unsigned int flags, const FileCreatProp
     }
 }
 
+//--------------------------------------------------------------------------
+// Function:    H5File overloaded constructor
+///\brief       Opens an HDF5 file using a non-default access property list
+///\param       name         - IN: Name of the file
+///\param       flags        - IN: File access flags
+///\param       access_plist - IN: File access property list.
+///\par Description
+///             Valid values of \a flags include:
+///             \li \c H5F_ACC_RDONLY - Open file as read-only, if it already
+///                             exists, and fail, otherwise
+///             \li \c H5F_ACC_RDWR - Open file for read/write, if it already
+///                             exists, and fail, otherwise
+// Notes        With a PGI compiler (~2012-2013,) the exception thrown by
+//              p_get_file could not be caught in the applications.  Added try
+//              block here to catch then re-throw it. -BMR 2013/03/21
+//--------------------------------------------------------------------------
+H5File::H5File(const char *name, unsigned int flags, const FileAccPropList &access_plist)
+    : Group(), id(H5I_INVALID_HID)
+{
+    try {
+        p_get_file(name, flags, FileCreatPropList::DEFAULT, access_plist);
+    }
+    catch (FileIException &open_file) {
+        throw open_file;
+    }
+}
+
+//--------------------------------------------------------------------------
+// Function:    H5File overloaded constructor
+///\brief       This is another overloaded constructor.  It differs from the
+///             above constructor only in the type of the \a name argument.
+///\param       name - IN: Name of the file - \c H5std_string
+///\param       flags - IN: File access flags
+///\param       access_plist - IN: File access property list
+//--------------------------------------------------------------------------
+H5File::H5File(const H5std_string &name, unsigned int flags, const FileAccPropList &access_plist)
+    : Group(), id(H5I_INVALID_HID)
+{
+    try {
+        p_get_file(name.c_str(), flags, FileCreatPropList::DEFAULT, access_plist);
+    }
+    catch (FileIException &open_file) {
+        throw open_file;
+    }
+}
+
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 //--------------------------------------------------------------------------
 // This function is private and contains common code between the
@@ -164,9 +210,8 @@ H5File::p_get_file(const char *name, unsigned int flags, const FileCreatPropList
 //              constructor is needed by the library in order to return
 //              an object, H5File doesn't need it. -BMR (HDFFV-8766 partially)
 //--------------------------------------------------------------------------
-H5File::H5File(hid_t existing_id) : Group()
+H5File::H5File(hid_t existing_id) : Group(), id{existing_id}
 {
-    id = existing_id;
     incRefCount(); // increment number of references to this id
 }
 
@@ -179,9 +224,8 @@ H5File::H5File(hid_t existing_id) : Group()
 ///\param       original - IN: H5File instance to copy
 // December 2000
 //--------------------------------------------------------------------------
-H5File::H5File(const H5File &original) : Group(original)
+H5File::H5File(const H5File &original) : Group(original), id{original.getId()}
 {
-    id = original.getId();
     incRefCount(); // increment number of references to this id
 }
 
@@ -196,16 +240,17 @@ H5File::H5File(const H5File &original) : Group(original)
 bool
 H5File::isHdf5(const char *name)
 {
-    // Calls C routine H5Fis_hdf5 to determine whether the file is in
+    // Calls C routine H5Fis_accessible to determine whether the file is in
     // HDF5 format.  It returns positive value, 0, or negative value
-    htri_t ret_value = H5Fis_hdf5(name);
+    htri_t ret_value = H5Fis_accessible(name, H5P_DEFAULT);
+
     if (ret_value > 0)
         return true;
     else if (ret_value == 0)
         return false;
-    else // Raise exception when H5Fis_hdf5 returns a negative value
+    else // Raise exception when H5Fis_accessible returns a negative value
     {
-        throw FileIException("H5File::isHdf5", "H5Fis_hdf5 returned negative value");
+        throw FileIException("H5File::isHdf5", "H5Fis_accessible returned negative value");
     }
 }
 
@@ -222,6 +267,48 @@ H5File::isHdf5(const H5std_string &name)
     return (isHdf5(name.c_str()));
 }
 
+//--------------------------------------------------------------------------
+// Function:    H5File::isAccessible (static)
+///\brief       Determines whether a file can be accessed as HDF5. (Static)
+///\param       name - IN: Name of the file
+///\param       access_plist - IN: File access property list.  Default to
+///             FileAccPropList::DEFAULT
+///\return      true if the file can be accessed as HDF5, and false, otherwise
+///\exception   H5::FileIException
+// September 2018
+//--------------------------------------------------------------------------
+bool
+H5File::isAccessible(const char *name, const FileAccPropList &access_plist)
+{
+    // Calls C routine H5Fis_accessible to determine whether the file is in
+    // HDF5 format.  It returns positive value, 0, or negative value
+    hid_t  access_plist_id = access_plist.getId();
+    htri_t ret_value       = H5Fis_accessible(name, access_plist_id);
+    if (ret_value > 0)
+        return true;
+    else if (ret_value == 0)
+        return false;
+    else // Raise exception when H5Fis_accessible returns a negative value
+    {
+        throw FileIException("H5File::isAccessible", "H5Fis_accessible returned negative value");
+    }
+}
+
+//--------------------------------------------------------------------------
+// Function:    H5File::isAccessible (static)
+///\brief       This is an overloaded member function, provided for convenience.
+///             It takes an \c H5std_string for \a name. (Static)
+///\param       name - IN: Name of the file - \c H5std_string
+///\param       access_plist - IN: File access property list.  Default to
+///             FileAccPropList::DEFAULT
+// September 2018
+//--------------------------------------------------------------------------
+bool
+H5File::isAccessible(const H5std_string &name, const FileAccPropList &access_plist)
+{
+    return (isAccessible(name.c_str(), access_plist));
+}
+
 //--------------------------------------------------------------------------
 // Function:    openFile
 ///\brief       Opens an HDF5 file
@@ -531,7 +618,6 @@ H5File::getVFDHandle(void **file_handle) const
 ///\par Description
 ///             This function is called after an existing file is opened in
 ///             order to learn the true size of the underlying file.
-// Programmer   Raymond Lu - June 24, 2004
 //--------------------------------------------------------------------------
 hsize_t
 H5File::getFileSize() const
@@ -544,6 +630,26 @@ H5File::getFileSize() const
     return (file_size);
 }
 
+//--------------------------------------------------------------------------
+// Function:    H5File::getFileNum
+///\brief       Returns the file number of the HDF5 file.
+///\return      File number
+///\exception   H5::FileIException
+///\par Description
+///             This function is called after an existing file is opened in
+///             order to retrieve the unique 'file number' for the file.
+//--------------------------------------------------------------------------
+unsigned long
+H5File::getFileNum() const
+{
+    unsigned long fileno    = 0;
+    herr_t        ret_value = H5Fget_fileno(id, &fileno);
+    if (ret_value < 0) {
+        throw FileIException("H5File::getFileNum", "H5Fget_fileno failed");
+    }
+    return (fileno);
+}
+
 //--------------------------------------------------------------------------
 // Function:    H5File::getId
 ///\brief       Get the id of this file
