@@ -12,7 +12,6 @@
 
 #include <string>
 
-#include "H5private.h" // for HDmemset
 #include "H5Include.h"
 #include "H5Exception.h"
 #include "H5IdComponent.h"
@@ -44,9 +43,12 @@ namespace H5 {
 extern "C" {
 
 static herr_t
-userAttrOpWrpr(H5_ATTR_UNUSED hid_t loc_id, const char *attr_name, H5_ATTR_UNUSED const H5A_info_t *ainfo,
-               void *op_data)
+userAttrOpWrpr(hid_t loc_id, const char *attr_name, const H5A_info_t *ainfo, void *op_data)
 {
+    // Unused
+    (void)loc_id;
+    (void)ainfo;
+
     H5std_string       s_attr_name = H5std_string(attr_name);
     UserData4Aiterate *myData      = reinterpret_cast<UserData4Aiterate *>(op_data);
     myData->op(*myData->location, s_attr_name, myData->opData);
@@ -56,8 +58,11 @@ userAttrOpWrpr(H5_ATTR_UNUSED hid_t loc_id, const char *attr_name, H5_ATTR_UNUSE
 // userVisitOpWrpr interfaces between the user's function and the
 // C library function H5Ovisit3
 static herr_t
-userVisitOpWrpr(H5_ATTR_UNUSED hid_t obj_id, const char *attr_name, const H5O_info_t *obj_info, void *op_data)
+userVisitOpWrpr(hid_t obj_id, const char *attr_name, const H5O_info2_t *obj_info, void *op_data)
 {
+    // Unused
+    (void)obj_id;
+
     H5std_string    s_attr_name = H5std_string(attr_name);
     UserData4Visit *myData      = reinterpret_cast<UserData4Visit *>(op_data);
     int             status      = myData->op(*myData->obj, s_attr_name, obj_info, myData->opData);
@@ -68,7 +73,6 @@ userVisitOpWrpr(H5_ATTR_UNUSED hid_t obj_id, const char *attr_name, const H5O_in
 
 //--------------------------------------------------------------------------
 // Function:    H5Object default constructor (protected)
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 H5Object::H5Object() : H5Location()
 {
@@ -82,7 +86,6 @@ H5Object::H5Object() : H5Location()
 //              Applications shouldn't need to use it.
 // param        attr   - IN/OUT: Attribute object to be changed
 // param        new_id - IN: New id to set
-// Programmer   Binh-Minh Ribler - 2015
 //--------------------------------------------------------------------------
 void
 f_Attribute_setId(Attribute *attr, hid_t new_id)
@@ -110,7 +113,6 @@ f_Attribute_setId(Attribute *attr, hid_t new_id)
 ///             attribute with a new attribute of the same name, first
 ///             delete the existing one with \c H5Object::removeAttr, then
 ///             recreate it with this function.
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 Attribute
 H5Object::createAttribute(const char *name, const DataType &data_type, const DataSpace &data_space,
@@ -136,7 +138,6 @@ H5Object::createAttribute(const char *name, const DataType &data_type, const Dat
 ///\brief       This is an overloaded member function, provided for convenience.
 ///             It differs from the above function in that it takes
 ///             a reference to an \c H5std_string for \a name.
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 Attribute
 H5Object::createAttribute(const H5std_string &name, const DataType &data_type, const DataSpace &data_space,
@@ -151,7 +152,6 @@ H5Object::createAttribute(const H5std_string &name, const DataType &data_type, c
 ///\param       name - IN: Name of the attribute
 ///\return      Attribute instance
 ///\exception   H5::AttributeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 Attribute
 H5Object::openAttribute(const char *name) const
@@ -172,7 +172,6 @@ H5Object::openAttribute(const char *name) const
 ///\brief       This is an overloaded member function, provided for convenience.
 ///             It differs from the above function in that it takes
 ///             a reference to an \c H5std_string for \a name.
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 Attribute
 H5Object::openAttribute(const H5std_string &name) const
@@ -186,7 +185,6 @@ H5Object::openAttribute(const H5std_string &name) const
 ///\param       idx - IN: Index of the attribute, a 0-based, non-negative integer
 ///\return      Attribute instance
 ///\exception   H5::AttributeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 Attribute
 H5Object::openAttribute(const unsigned int idx) const
@@ -216,7 +214,6 @@ H5Object::openAttribute(const unsigned int idx) const
 ///\par Description
 ///             The signature of user_op is
 ///             void (*)(H5::H5Location&, H5std_string, void*).
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 int
 H5Object::iterateAttrs(attr_operator_t user_op, unsigned *_idx, void *op_data)
@@ -260,14 +257,11 @@ H5Object::iterateAttrs(attr_operator_t user_op, unsigned *_idx, void *op_data)
 ///\param       *op_data - IN: User-defined pointer to data required by the
 ///                            application for its processing of the object
 ///\param       fields   - IN: Flags specifying the fields to be retrieved
-///                            to the callback op via the H5O_info_t argument.
+///                            to the callback op via the H5O_info2_t argument.
 ///             \li \c H5O_INFO_BASIC      fileno, addr, type, and rc fields
 ///             \li \c H5O_INFO_TIME       atime, mtime, ctime, and btime fields
 ///             \li \c H5O_INFO_NUM_ATTRS  num_attrs field
-///             \li \c H5O_INFO_HDR        hdr field
-///             \li \c H5O_INFO_META_SIZE  meta_size field
-///             \li \c H5O_INFO_ALL        H5O_INFO_BASIC | H5O_INFO_TIME | H5O_INFO_NUM_ATTRS | H5O_INFO_HDR
-///             | H5O_INFO_META_SIZE
+///             \li \c H5O_INFO_ALL        H5O_INFO_BASIC | H5O_INFO_TIME | H5O_INFO_NUM_ATTRS
 ///\return
 ///             \li On success:
 ///                 \li the return value of the first operator that returns a positive value
@@ -277,9 +271,8 @@ H5Object::iterateAttrs(attr_operator_t user_op, unsigned *_idx, void *op_data)
 ///                     wrong within the library or the operator failed
 ///\exception   H5::Exception
 ///\par Description
-///             For information, please refer to the H5Ovisit2 API in the HDF5
+///             For information, please refer to the H5Ovisit3 API in the HDF5
 ///             C Reference Manual.
-// Programmer   Binh-Minh Ribler - Feb, 2019
 //--------------------------------------------------------------------------
 void
 H5Object::visit(H5_index_t idx_type, H5_iter_order_t order, visit_operator_t user_op, void *op_data,
@@ -293,15 +286,15 @@ H5Object::visit(H5_index_t idx_type, H5_iter_order_t order, visit_operator_t use
 
     // Call the C API passing in op wrapper and info
     herr_t ret_value =
-        H5Ovisit2(getId(), idx_type, order, userVisitOpWrpr, static_cast<void *>(userData), fields);
+        H5Ovisit3(getId(), idx_type, order, userVisitOpWrpr, static_cast<void *>(userData), fields);
 
     // Release memory
     delete userData;
 
-    // Throw exception if H5Ovisit2 failed, which could be a failure in
+    // Throw exception if H5Ovisit3 failed, which could be a failure in
     // the library or in the call back operator
     if (ret_value < 0)
-        throw Exception(inMemFunc("visit"), "H5Ovisit2 failed");
+        throw Exception(inMemFunc("visit"), "H5Ovisit3 failed");
 }
 
 //--------------------------------------------------------------------------
@@ -314,20 +307,19 @@ H5Object::visit(H5_index_t idx_type, H5_iter_order_t order, visit_operator_t use
 ///             Exception will be thrown when:
 ///             - an error returned by the C API
 ///             - version number is not one of the valid values above
-// Programmer   Binh-Minh Ribler - December, 2016
 //--------------------------------------------------------------------------
 unsigned
 H5Object::objVersion() const
 {
-    H5O_info_t objinfo;
-    unsigned   version = 0;
+    H5O_native_info_t objinfo;
+    unsigned          version = 0;
 
     // Use C API to get information of the object
-    herr_t ret_value = H5Oget_info2(getId(), &objinfo, H5O_INFO_HDR);
+    herr_t ret_value = H5Oget_native_info(getId(), &objinfo, H5O_NATIVE_INFO_HDR);
 
     // Throw exception if C API returns failure
     if (ret_value < 0)
-        throw Exception(inMemFunc("objVersion"), "H5Oget_info failed");
+        throw Exception(inMemFunc("objVersion"), "H5Oget_native_info failed");
     // Return a valid version or throw an exception for invalid value
     else {
         version = objinfo.hdr.version;
@@ -342,14 +334,13 @@ H5Object::objVersion() const
 ///\brief       Returns the number of attributes attached to this HDF5 object.
 ///\return      Number of attributes
 ///\exception   H5::AttributeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 int
 H5Object::getNumAttrs() const
 {
-    H5O_info_t oinfo; /* Object info */
+    H5O_info2_t oinfo; /* Object info */
 
-    if (H5Oget_info2(getId(), &oinfo, H5O_INFO_NUM_ATTRS) < 0)
+    if (H5Oget_info3(getId(), &oinfo, H5O_INFO_NUM_ATTRS) < 0)
         throw AttributeIException(inMemFunc("getNumAttrs"), "H5Oget_info failed");
     else
         return (static_cast<int>(oinfo.num_attrs));
@@ -360,7 +351,6 @@ H5Object::getNumAttrs() const
 ///\brief       Checks whether the named attribute exists at this location.
 ///\param       name - IN: Name of the attribute to be queried
 ///\exception   H5::AttributeIException
-// Programmer   Binh-Minh Ribler - 2013
 //--------------------------------------------------------------------------
 bool
 H5Object::attrExists(const char *name) const
@@ -382,7 +372,6 @@ H5Object::attrExists(const char *name) const
 ///\brief       This is an overloaded member function, provided for convenience.
 ///             It differs from the above function in that it takes
 ///             a reference to an \c H5std_string for \a name.
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 bool
 H5Object::attrExists(const H5std_string &name) const
@@ -395,7 +384,6 @@ H5Object::attrExists(const H5std_string &name) const
 ///\brief       Removes the named attribute from this object.
 ///\param       name - IN: Name of the attribute to be removed
 ///\exception   H5::AttributeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 H5Object::removeAttr(const char *name) const
@@ -410,7 +398,6 @@ H5Object::removeAttr(const char *name) const
 ///\brief       This is an overloaded member function, provided for convenience.
 ///             It differs from the above function in that it takes
 ///             a reference to an \c H5std_string for \a name.
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 H5Object::removeAttr(const H5std_string &name) const
@@ -424,7 +411,6 @@ H5Object::removeAttr(const H5std_string &name) const
 ///\param       oldname - IN: Name of the attribute to be renamed
 ///\param       newname - IN: New name ame of the attribute
 ///\exception   H5::AttributeIException
-// Programmer   Binh-Minh Ribler - Mar, 2005
 //--------------------------------------------------------------------------
 void
 H5Object::renameAttr(const char *oldname, const char *newname) const
@@ -439,7 +425,6 @@ H5Object::renameAttr(const char *oldname, const char *newname) const
 ///\brief       This is an overloaded member function, provided for convenience.
 ///             It differs from the above function in that it takes
 ///             a reference to an \c H5std_string for the names.
-// Programmer   Binh-Minh Ribler - Mar, 2005
 //--------------------------------------------------------------------------
 void
 H5Object::renameAttr(const H5std_string &oldname, const H5std_string &newname) const
@@ -451,7 +436,6 @@ H5Object::renameAttr(const H5std_string &oldname, const H5std_string &newname) c
 // Function:    getObjName
 ///\brief       Given an id, returns the type of the object.
 ///\return      The name of the object
-// Programmer   Binh-Minh Ribler - Mar, 2014
 //--------------------------------------------------------------------------
 ssize_t
 H5Object::getObjName(char *obj_name, size_t buf_size) const
@@ -475,7 +459,6 @@ H5Object::getObjName(char *obj_name, size_t buf_size) const
 ///\brief       Returns the name of this object as an \a H5std_string.
 ///\return      Name of the object
 ///\exception   H5::Exception
-// Programmer   Binh-Minh Ribler - Mar, 2014
 //--------------------------------------------------------------------------
 H5std_string
 H5Object::getObjName() const
@@ -483,7 +466,7 @@ H5Object::getObjName() const
     H5std_string obj_name; // object name to return
 
     // Preliminary call to get the size of the object name
-    ssize_t name_size = H5Iget_name(getId(), NULL, static_cast<size_t>(0));
+    ssize_t name_size = H5Iget_name(getId(), NULL, 0);
 
     // If H5Iget_name failed, throw exception
     if (name_size < 0) {
@@ -494,11 +477,16 @@ H5Object::getObjName() const
     }
     // Object's name exists, retrieve it
     else if (name_size > 0) {
-        char *name_C = new char[name_size + 1]; // temporary C-string
-        HDmemset(name_C, 0, name_size + 1);     // clear buffer
+
+        // The actual size is the cast value + 1 for the terminal ASCII NUL
+        // (unfortunate in/out type sign mismatch)
+        size_t actual_name_size = static_cast<size_t>(name_size) + 1;
+
+        // Create buffer for C string
+        char *name_C = new char[actual_name_size]();
 
         // Use overloaded function
-        name_size = getObjName(name_C, name_size + 1);
+        name_size = getObjName(name_C, actual_name_size);
 
         // Convert the C object name to return
         obj_name = name_C;
@@ -506,8 +494,9 @@ H5Object::getObjName() const
         // Clean up resource
         delete[] name_C;
     }
+
     // Return object's name
-    return (obj_name);
+    return obj_name;
 }
 
 //--------------------------------------------------------------------------
@@ -521,7 +510,6 @@ H5Object::getObjName() const
 ///             This function retrieves the object's name as an std string.
 ///             buf_size can specify a specific length or default to 0, in
 ///             which case the entire name will be retrieved.
-// Programmer   Binh-Minh Ribler - Mar, 2014
 //--------------------------------------------------------------------------
 ssize_t
 H5Object::getObjName(H5std_string &obj_name, size_t len) const
@@ -531,12 +519,12 @@ H5Object::getObjName(H5std_string &obj_name, size_t len) const
     // If no length is provided, get the entire object name
     if (len == 0) {
         obj_name  = getObjName();
-        name_size = obj_name.length();
+        name_size = static_cast<ssize_t>(obj_name.length());
     }
     // If length is provided, get that number of characters in name
     else {
-        char *name_C = new char[len + 1]; // temporary C-string
-        HDmemset(name_C, 0, len + 1);     // clear buffer
+        // Create buffer for C string
+        char *name_C = new char[len + 1]();
 
         // Use overloaded function
         name_size = getObjName(name_C, len + 1);
@@ -550,18 +538,7 @@ H5Object::getObjName(H5std_string &obj_name, size_t len) const
     // Otherwise, keep obj_name intact
 
     // Return name size
-    return (name_size);
+    return name_size;
 }
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-//--------------------------------------------------------------------------
-// Function:    H5Object destructor
-///\brief       Noop destructor.
-// Programmer   Binh-Minh Ribler - 2000
-//--------------------------------------------------------------------------
-H5Object::~H5Object()
-{
-}
-#endif // DOXYGEN_SHOULD_SKIP_THIS
-
 } // namespace H5
