@@ -31,14 +31,12 @@
 #include "H5StrType.h"
 #include "H5DataSet.h"
 #include "H5PredType.h"
-#include "H5private.h"
 
 namespace H5 {
 
 //--------------------------------------------------------------------------
 // Function:    StrType default constructor
 ///\brief       Default constructor: Creates a stub string datatype
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 StrType::StrType() : AtomType()
 {
@@ -49,7 +47,6 @@ StrType::StrType() : AtomType()
 ///\brief       Creates a string datatype using a predefined type.
 ///\param       pred_type - IN: Predefined datatype
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 StrType::StrType(const PredType &pred_type) : AtomType()
 {
@@ -75,7 +72,6 @@ StrType::StrType(const PredType &pred_type) : AtomType()
 // Note
 //              The use of this constructor can be shortened by using
 //              its overloaded below as StrType(0, size).
-// Programmer   Binh-Minh Ribler - 2000
 // Modification
 //              Planned for removal. -BMR, 2005/12/02
 //              Removed from documentation. -BMR, 2016/03/07
@@ -102,10 +98,12 @@ StrType::StrType(const PredType &pred_type, const size_t &size) : AtomType()
 ///             StrType atype(PredType::C_S1, size)
 // Note
 //              This constructor replaced the previous one.
-// Programmer   Binh-Minh Ribler - Nov 28, 2005
 //--------------------------------------------------------------------------
-StrType::StrType(H5_ATTR_UNUSED const int dummy, const size_t &size) : AtomType()
+StrType::StrType(const int dummy, const size_t &size) : AtomType()
 {
+    // Unused
+    (void)dummy;
+
     // use DataType::copy to make a copy of the string predefined type
     // then set its length
     copy(PredType::C_S1);
@@ -117,7 +115,6 @@ StrType::StrType(H5_ATTR_UNUSED const int dummy, const size_t &size) : AtomType(
 ///\brief       Creates an StrType object using the id of an existing datatype.
 ///\param       existing_id - IN: Id of an existing datatype
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 StrType::StrType(const hid_t existing_id) : AtomType(existing_id)
 {
@@ -126,7 +123,6 @@ StrType::StrType(const hid_t existing_id) : AtomType(existing_id)
 //--------------------------------------------------------------------------
 // Function:    StrType copy constructor
 ///\brief       Copy constructor: same HDF5 object as \a original
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 StrType::StrType(const StrType &original) : AtomType(original)
 {
@@ -137,7 +133,6 @@ StrType::StrType(const StrType &original) : AtomType(original)
 ///\brief       Gets the string datatype of the specified dataset
 ///\param       dataset - IN: Dataset that this string datatype associates with
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 StrType::StrType(const DataSet &dataset) : AtomType()
 {
@@ -156,7 +151,6 @@ StrType::StrType(const DataSet &dataset) : AtomType()
 ///\param       loc        - IN: Location of the type
 ///\param       dtype_name - IN: String type name
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - Dec 2016
 // Description
 //              In 1.10.1, this constructor was introduced and may replace the
 //              existing function CommonFG::openStrType(const char*) to
@@ -175,7 +169,6 @@ StrType::StrType(const H5Location &loc, const char *dtype_name) : AtomType()
 ///\param       loc        - IN: Location of the type
 ///\param       dtype_name - IN: String type name
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - Dec 2016
 // Description
 //              In 1.10.1, this constructor was introduced and may replace the
 //              existing function CommonFG::openStrType(const H5std_string&)
@@ -193,7 +186,6 @@ StrType::StrType(const H5Location &loc, const H5std_string &dtype_name) : AtomTy
 ///             binary object description of this type.
 ///
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - Aug 2017
 //--------------------------------------------------------------------------
 DataType *
 StrType::decode() const
@@ -223,7 +215,6 @@ StrType::decode() const
 ///     and usability problems. See the C API entry H5Pset_char_encoding for
 ///     more information.
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 H5T_cset_t
 StrType::getCset() const
@@ -250,7 +241,6 @@ StrType::getCset() const
 ///     and usability problems. See the C API entry H5Pset_char_encoding for
 ///     more information.
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 StrType::setCset(H5T_cset_t cset) const
@@ -269,7 +259,6 @@ StrType::setCset(H5T_cset_t cset) const
 ///             \li \c H5T_STR_NULLPAD (0) - Pad with zeros
 ///             \li \c H5T_STR_SPACEPAD (0) - pad with spaces (as FORTRAN does)
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 H5T_str_t
 StrType::getStrpad() const
@@ -291,7 +280,6 @@ StrType::getStrpad() const
 ///\par Description
 ///             For information, please refer to the H5Tset_strpad API in
 ///             the HDF5 C Reference Manual.
-// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 StrType::setStrpad(H5T_str_t strpad) const
@@ -302,13 +290,4 @@ StrType::setStrpad(H5T_str_t strpad) const
     }
 }
 
-//--------------------------------------------------------------------------
-// Function:    StrType destructor
-///\brief       Properly terminates access to this string datatype.
-// Programmer   Binh-Minh Ribler - 2000
-//--------------------------------------------------------------------------
-StrType::~StrType()
-{
-}
-
 } // namespace H5
