@@ -30,17 +30,17 @@ using namespace H5;
 #define NDATASETS 50
 
 /* Number of attributes for attribute iteration test */
-//#define NATTR 50
+// #define NATTR 50
 
 /* Number of groups for second group iteration test */
-//#define ITER_NGROUPS 150
+// #define ITER_NGROUPS 150
 
 /* General maximum length of names used */
 #define NAMELEN 80
 
 /* 1-D dataset with fixed dimensions */
-//#define SPACE1_RANK     1
-//#define SPACE1_DIM1     4
+// #define SPACE1_RANK     1
+// #define SPACE1_DIM1     4
 
 const H5std_string FILE_ITERATE("titerate.h5");
 const H5std_string GROUP1("Top Group");
@@ -78,7 +78,7 @@ static void printelems(const Group &group, const H5std_string &dsname, const H5s
 static int
 iter_strcmp(const void *s1, const void *s2)
 {
-    return (HDstrcmp(*(const char *const *)s1, *(const char *const *)s2));
+    return (strcmp(*reinterpret_cast<const char *const *>(s1), *reinterpret_cast<const char *const *>(s2)));
 }
 
 /*-------------------------------------------------------------------------
@@ -88,14 +88,14 @@ iter_strcmp(const void *s1, const void *s2)
  *-------------------------------------------------------------------------
  */
 static herr_t
-liter_cb(hid_t H5_ATTR_UNUSED group, const char *name, const H5L_info_t H5_ATTR_UNUSED *link_info,
+liter_cb(hid_t H5_ATTR_UNUSED group, const char *name, const H5L_info2_t H5_ATTR_UNUSED *link_info,
          void *op_data)
 {
-    iter_info *info   = (iter_info *)op_data;
+    iter_info *info   = static_cast<iter_info *>(op_data);
     static int count  = 0;
     static int count2 = 0;
 
-    HDstrcpy(info->name, name);
+    strcpy(info->name, name);
 
     switch (info->command) {
         case RET_ZERO:
@@ -125,15 +125,11 @@ liter_cb(hid_t H5_ATTR_UNUSED group, const char *name, const H5L_info_t H5_ATTR_
  *
  * Return       Success: 0
  *              Failure: -1
- *
- * Programmer   Binh-Minh Ribler
- *              Friday, September 9, 2016
  *-------------------------------------------------------------------------
  */
 static void
 test_iter_group(FileAccPropList &fapl)
 {
-    int       i;                     /* counting variable */
     hsize_t   idx;                   /* Index in the group */
     char      name[NAMELEN];         /* temporary name buffer */
     char     *lnames[NDATASETS + 2]; /* Names of the links created */
@@ -151,7 +147,7 @@ test_iter_group(FileAccPropList &fapl)
         /* Test iterating over empty group */
         info.command = RET_ZERO;
         idx          = 0;
-        ret          = H5Literate(file.getId(), H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info);
+        ret          = H5Literate2(file.getId(), H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info);
         verify_val(ret, SUCCEED, "H5Literate", __LINE__, __FILE__);
 
         DataType datatype(PredType::NATIVE_INT);
@@ -159,28 +155,28 @@ test_iter_group(FileAccPropList &fapl)
         // Create a scalar file space
         DataSpace filespace;
 
-        for (i = 0; i < NDATASETS; i++) {
-            sprintf(name, "Dataset %d", i);
+        for (int i = 0; i < NDATASETS; i++) {
+            snprintf(name, sizeof(name), "Dataset %d", i);
 
             // Create a dataset in the file
             DataSet dataset = file.createDataSet(name, datatype, filespace);
 
             /* Keep a copy of the dataset names */
-            lnames[i] = HDstrdup(name);
-            check_values(lnames[i], "HDstrdup returns NULL", __LINE__, __FILE__);
+            lnames[i] = strdup(name);
+            check_values(lnames[i], "strdup returns NULL", __LINE__, __FILE__);
         }
 
         /* Create a group and named datatype under root group for testing */
         Group grp(file.createGroup(GROUP1, 0));
-        lnames[NDATASETS] = HDstrdup("grp");
-        check_values(lnames[NDATASETS], "HDstrdup returns NULL", __LINE__, __FILE__);
+        lnames[NDATASETS] = strdup("grp");
+        check_values(lnames[NDATASETS], "strdup returns NULL", __LINE__, __FILE__);
 
         datatype.commit(file, "dtype");
-        lnames[NDATASETS + 1] = HDstrdup("dtype");
-        check_values(lnames[NDATASETS], "HDstrdup returns NULL", __LINE__, __FILE__);
+        lnames[NDATASETS + 1] = strdup("dtype");
+        check_values(lnames[NDATASETS], "strdup returns NULL", __LINE__, __FILE__);
 
         /* Sort the dataset names */
-        HDqsort(lnames, (size_t)(NDATASETS + 2), sizeof(char *), iter_strcmp);
+        qsort(lnames, NDATASETS + 2, sizeof(char *), iter_strcmp);
 
         /* Iterate through the datasets in the root group in various ways */
 
@@ -192,11 +188,11 @@ test_iter_group(FileAccPropList &fapl)
 
         // Get the number of object in the root group
         hsize_t nobjs = root_group.getNumObjs();
-        verify_val(nobjs, (hsize_t)(NDATASETS + 2), "H5Gget_info", __LINE__, __FILE__);
+        verify_val(static_cast<long>(nobjs), NDATASETS + 2, "H5Gget_info", __LINE__, __FILE__);
 
         H5std_string obj_name;
-        for (i = 0; i < nobjs; i++) {
-            // H5O_info_t oinfo;                /* Object info */
+        for (hsize_t i = 0; i < nobjs; i++) {
+            // H5O_info2_t oinfo;                /* Object info */
 
             obj_name = root_group.getObjnameByIdx(i);
             // ret = (herr_t)H5Lget_name_by_idx(root_group, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i,
@@ -221,7 +217,7 @@ test_iter_group(FileAccPropList &fapl)
         // Attempted to iterate with negative index, should fail
         try {
             info.command = RET_ZERO;
-            idx          = (hsize_t)-1;
+            idx          = HSIZE_UNDEF;
             obj_name     = root_group.getObjnameByIdx(idx);
 
             // Should FAIL but didn't, so throw an invalid action exception
@@ -267,8 +263,8 @@ test_iter_group(FileAccPropList &fapl)
         } // do nothing, exception expected
 
         /* Free the dataset names */
-        for (i = 0; i < (NDATASETS + 2); i++)
-            HDfree(lnames[i]);
+        for (int i = 0; i < NDATASETS + 2; i++)
+            free(lnames[i]);
 
         // Everything will be closed as they go out of scope
 
@@ -284,7 +280,7 @@ test_iter_group(FileAccPropList &fapl)
     /* Test all objects in group, when callback always returns 0 */
     info.command = RET_ZERO;
     idx = 0;
-    if((ret = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) > 0)
+    if((ret = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) > 0)
         TestErrPrintf("Group iteration function didn't return zero correctly!\n");
 
     /* Test all objects in group, when callback always returns 1 */
@@ -292,7 +288,7 @@ test_iter_group(FileAccPropList &fapl)
     info.command = RET_TWO;
     i = 0;
     idx = 0;
-    while((ret = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) > 0) {
+    while((ret = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) > 0) {
         /* Verify return value from iterator gets propagated correctly */
         verify_val(ret, 2, "H5Literate", __LINE__, __FILE__);
 
@@ -305,7 +301,7 @@ test_iter_group(FileAccPropList &fapl)
             TestErrPrintf("Group iteration function walked too far!\n");
 
         /* Verify that the correct name is retrieved */
-        if(HDstrcmp(info.name, lnames[(size_t)(idx - 1)]) != 0)
+        if(strcmp(info.name, lnames[(size_t)(idx - 1)]) != 0)
             TestErrPrintf("Group iteration function didn't return name correctly for link - lnames[%u] = '%s'!\n", (unsigned)(idx - 1), lnames[(size_t)(idx - 1)]);
     } /* end while */
     verify_val(ret, -1, "H5Literate", __LINE__, __FILE__);
@@ -318,7 +314,7 @@ test_iter_group(FileAccPropList &fapl)
     info.command = new_format ? RET_CHANGE2 : RET_CHANGE;
     i = 0;
     idx = 0;
-    while((ret = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) >= 0) {
+    while((ret = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) >= 0) {
         /* Verify return value from iterator gets propagated correctly */
         verify_val(ret, 1, "H5Literate", __LINE__, __FILE__);
 
@@ -331,7 +327,7 @@ test_iter_group(FileAccPropList &fapl)
             TestErrPrintf("Group iteration function walked too far!\n");
 
         /* Verify that the correct name is retrieved */
-        if(HDstrcmp(info.name, lnames[(size_t)(idx - 1)]) != 0)
+        if(strcmp(info.name, lnames[(size_t)(idx - 1)]) != 0)
             TestErrPrintf("Group iteration function didn't return name correctly for link - lnames[%u] = '%s'!\n", (unsigned)(idx - 1), lnames[(size_t)(idx - 1)]);
     } /* end while */
     verify_val(ret, -1, "H5Literate", __LINE__, __FILE__);
@@ -385,9 +381,6 @@ printelems(const Group &group, const H5std_string &dsname, const H5std_string &a
  * Function:    test_HDFFV_9920
  *
  * Purpose      Tests the fix for HDFFV-9920
- *
- * Programmer   Binh-Minh Ribler
- *              Friday, September 9, 2016
  *-------------------------------------------------------------------------
  */
 static void
@@ -444,9 +437,6 @@ test_HDFFV_9920()
  *
  * Return       Success: 0
  *              Failure: -1
- *
- * Programmer   Binh-Minh Ribler
- *              Tuesday, September 6, 2016
  *-------------------------------------------------------------------------
  */
 extern "C" void
