@@ -65,7 +65,7 @@ static void *test_vlstr_alloc_custom(size_t size, void *info)
 
     extra=MAX(sizeof(void *),sizeof(size_t));
 
-    if((ret_value=HDmalloc(extra+size))!=NULL) {
+    if((ret_value=malloc(extra+size))!=NULL) {
         *(size_t *)ret_value=size;
         *mem_used+=size;
     } // end if
@@ -108,7 +108,7 @@ static void test_vlstr_free_custom(void *_mem, void *info)
     if(_mem!=NULL) {
         mem=((unsigned char *)_mem)-extra;
         *mem_used-=*(size_t *)mem;
-        HDfree(mem);
+        free(mem);
     } // end if
 }
 #endif
@@ -119,10 +119,6 @@ static void test_vlstr_free_custom(void *_mem, void *info)
  * Purpose      Test writing/reading VL strings on datasets.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
- *
  *-------------------------------------------------------------------------
  */
 // String for testing datasets
@@ -162,11 +158,11 @@ test_vlstring_dataset()
 
         // Read and verify the dataset string as a string of chars.
         dset1.read(&string_ds_check, vlst);
-        if (HDstrcmp(string_ds_check, DSET1_DATA.c_str()) != 0)
+        if (strcmp(string_ds_check, DSET1_DATA.c_str()) != 0)
             TestErrPrintf("Line %d: Attribute data different: DSET1_DATA=%s,string_ds_check=%s\n", __LINE__,
                           DSET1_DATA.c_str(), string_ds_check);
 
-        HDfree(string_ds_check); // note: no need for std::string test
+        free(string_ds_check); // note: no need for std::string test
         string_ds_check = NULL;
 
         // Read and verify the dataset string as an std::string.
@@ -182,18 +178,18 @@ test_vlstring_dataset()
         // Test scalar type dataset with 1 value.
         dset1 = root.createDataSet("test_scalar_small", vlst, ds_space);
 
-        dynstring_ds_write = (char *)HDcalloc(2, sizeof(char));
-        HDmemset(dynstring_ds_write, 'A', 1);
+        dynstring_ds_write = static_cast<char *>(calloc(2, sizeof(char)));
+        memset(dynstring_ds_write, 'A', 1);
 
         // Write data to the dataset, then read it back.
         dset1.write(&dynstring_ds_write, vlst);
         dset1.read(&string_ds_check, vlst);
 
         // Verify data read.
-        if (HDstrcmp(string_ds_check, dynstring_ds_write) != 0)
+        if (strcmp(string_ds_check, dynstring_ds_write) != 0)
             TestErrPrintf("VL string datasets don't match!, dynstring_ds_write=%s, string_ds_check=%s\n",
                           dynstring_ds_write, string_ds_check);
-        HDfree(string_ds_check);
+        free(string_ds_check);
         string_ds_check = NULL;
         dset1.close();
 
@@ -213,9 +209,9 @@ test_vlstring_dataset()
     }
 
     if (dynstring_ds_write)
-        HDfree(dynstring_ds_write);
+        free(dynstring_ds_write);
     if (string_ds_check)
-        HDfree(string_ds_check);
+        free(string_ds_check);
 } // test_vlstring_dataset()
 
 /*-------------------------------------------------------------------------
@@ -224,10 +220,6 @@ test_vlstring_dataset()
  * Purpose      Test writing/reading VL string array to/from datasets.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler
- *              July, 2009
- *
  *-------------------------------------------------------------------------
  */
 const H5std_string DSSTRARR_NAME("StringArray_dset");
@@ -264,11 +256,11 @@ test_vlstring_array_dataset()
 
         hsize_t ii;
         for (ii = 0; ii < SPACE1_DIM1; ii++) {
-            if (HDstrcmp(string_ds_check[ii], string_ds_array[ii]) != 0)
+            if (strcmp(string_ds_check[ii], string_ds_array[ii]) != 0)
                 TestErrPrintf("Line %d: Dataset data different: written=%s,read=%s\n", __LINE__,
                               string_ds_array[ii], string_ds_check[ii]);
 
-            HDfree(string_ds_check[ii]);
+            free(string_ds_check[ii]);
         }
 
         // Close objects that are no longer needed.
@@ -284,20 +276,20 @@ test_vlstring_array_dataset()
 
         // Create and write another dataset.
         DataSet dataset2(file1->createDataSet("Dataset2", vlst, scalar_space));
-        char   *wdata2 = (char *)HDcalloc(65534, sizeof(char));
-        HDmemset(wdata2, 'A', 65533);
+        char   *wdata2 = static_cast<char *>(calloc(65534, sizeof(char)));
+        memset(wdata2, 'A', 65533);
         dataset2.write(&wdata2, vlst);
 
         char *rdata2;
         dataset2.read(&rdata2, vlst);
-        if (HDstrcmp(wdata2, rdata2) != 0)
+        if (strcmp(wdata2, rdata2) != 0)
             TestErrPrintf("Line %d: Dataset data different: written=%s,read=%s\n", __LINE__, wdata2, rdata2);
 
         // Release resources from second dataset operation.
         scalar_space.close();
         dataset2.close();
-        HDfree(wdata2);
-        HDfree(rdata2);
+        free(wdata2);
+        free(rdata2);
 
         // Close objects and file.
         dataset2.close();
@@ -312,8 +304,7 @@ test_vlstring_array_dataset()
         issue_fail_msg("test_vlstring_array_dataset()", __LINE__, __FILE__, E.getCDetailMsg());
     }
 
-    if (file1)
-        delete file1;
+    delete file1;
 } // end test_vlstring_array_dataset()
 
 /*-------------------------------------------------------------------------
@@ -323,10 +314,6 @@ test_vlstring_array_dataset()
  *              zero-sized.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -360,7 +347,7 @@ test_vlstrings_special()
         hsize_t ii; // counting variable
         for (ii = 0; ii < SPACE1_DIM1; ii++)
             if (rdata[ii] != NULL)
-                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n", (int)ii, rdata[ii]);
+                TestErrPrintf("VL doesn't match!, rdata[%d]=%s\n", static_cast<int>(ii), rdata[ii]);
 
         // Write dataset to disk, then read it back.
         dataset.write(wdata, vlst);
@@ -368,22 +355,23 @@ test_vlstrings_special()
 
         // Compare data read in.
         for (ii = 0; ii < SPACE1_DIM1; ii++) {
-            size_t wlen = HDstrlen(wdata[ii]);
-            size_t rlen = HDstrlen(rdata[ii]);
+            size_t wlen = strlen(wdata[ii]);
+            size_t rlen = strlen(rdata[ii]);
             if (wlen != rlen) {
                 TestErrPrintf("VL data lengths don't match!, strlen(wdata[%d])=%u, strlen(rdata[%d])=%u\n",
-                              (int)ii, (unsigned)wlen, (int)ii, (unsigned)rlen);
+                              static_cast<int>(ii), static_cast<unsigned>(wlen), static_cast<int>(ii),
+                              static_cast<unsigned>(rlen));
                 continue;
-            } // end if
-            if (HDstrcmp(wdata[ii], rdata[ii]) != 0) {
-                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n", (int)ii, wdata[ii],
-                              (int)ii, rdata[ii]);
+            }
+            if (strcmp(wdata[ii], rdata[ii]) != 0) {
+                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n",
+                              static_cast<int>(ii), wdata[ii], static_cast<int>(ii), rdata[ii]);
                 continue;
-            } // end if
-        }     // end for
+            }
+        }
 
         // Reclaim the read VL data.
-        DataSet::vlenReclaim((void *)rdata, vlst, sid1);
+        DataSet::vlenReclaim(static_cast<void *>(rdata), vlst, sid1);
 
         // Close Dataset.
         dataset.close();
@@ -408,7 +396,7 @@ test_vlstrings_special()
         // Check data read in.
         for (ii = 0; ii < SPACE1_DIM1; ii++)
             if (rdata[ii] != NULL)
-                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n", (int)ii, rdata[ii]);
+                TestErrPrintf("VL doesn't match!, rdata[%d]=%s\n", static_cast<int>(ii), rdata[ii]);
 
         // Try to write nil strings to disk.
         dataset.write(wdata2, vlst);
@@ -419,7 +407,7 @@ test_vlstrings_special()
         // Check data read in.
         for (ii = 0; ii < SPACE1_DIM1; ii++)
             if (rdata[ii] != NULL)
-                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n", (int)ii, rdata[ii]);
+                TestErrPrintf("VL doesn't match!, rdata[%d]=%s\n", static_cast<int>(ii), rdata[ii]);
 
         // Close objects and file.
         dataset.close();
@@ -442,10 +430,6 @@ test_vlstrings_special()
  * Purpose      Test if VL string is treated as string.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
- *
  *-------------------------------------------------------------------------
  */
 const H5std_string VLSTR_TYPE("vl_string_type");
@@ -467,22 +451,26 @@ test_vlstring_type()
         // Change padding and verify it.
         vlst.setStrpad(H5T_STR_NULLPAD);
         H5T_str_t pad = vlst.getStrpad();
-        verify_val(pad, H5T_STR_NULLPAD, "StrType::getStrpad", __LINE__, __FILE__);
+        verify_val(static_cast<long>(pad), static_cast<long>(H5T_STR_NULLPAD), "StrType::getStrpad", __LINE__,
+                   __FILE__);
 
         // Convert to variable-length string.
         vlst.setSize(H5T_VARIABLE);
 
         // Check if datatype is VL string.
         H5T_class_t type_class = vlst.getClass();
-        verify_val(type_class, H5T_STRING, "DataType::getClass", __LINE__, __FILE__);
+        verify_val(static_cast<long>(type_class), static_cast<long>(H5T_STRING), "DataType::getClass",
+                   __LINE__, __FILE__);
         bool is_variable_str = vlst.isVariableStr();
         verify_val(is_variable_str, true, "DataType::isVariableStr", __LINE__, __FILE__);
 
         // Check default character set and padding.
         H5T_cset_t cset = vlst.getCset();
-        verify_val(cset, H5T_CSET_ASCII, "StrType::getCset", __LINE__, __FILE__);
+        verify_val(static_cast<long>(cset), static_cast<long>(H5T_CSET_ASCII), "StrType::getCset", __LINE__,
+                   __FILE__);
         pad = vlst.getStrpad();
-        verify_val(pad, H5T_STR_NULLPAD, "StrType::getStrpad", __LINE__, __FILE__);
+        verify_val(static_cast<long>(pad), static_cast<long>(H5T_STR_NULLPAD), "StrType::getStrpad", __LINE__,
+                   __FILE__);
 
         // Commit variable-length string datatype to storage.
         vlst.commit(*file1, VLSTR_TYPE);
@@ -510,9 +498,11 @@ test_vlstring_type()
 
         // Verify character set and padding
         cset = vlst2.getCset();
-        verify_val(cset, H5T_CSET_ASCII, "StrType::getCset", __LINE__, __FILE__);
+        verify_val(static_cast<long>(cset), static_cast<long>(H5T_CSET_ASCII), "StrType::getCset", __LINE__,
+                   __FILE__);
         pad = vlst2.getStrpad();
-        verify_val(pad, H5T_STR_NULLPAD, "StrType::getStrpad", __LINE__, __FILE__);
+        verify_val(static_cast<long>(pad), static_cast<long>(H5T_STR_NULLPAD), "StrType::getStrpad", __LINE__,
+                   __FILE__);
 
         // Close datatype and file
         vlst2.close();
@@ -526,8 +516,7 @@ test_vlstring_type()
         issue_fail_msg("test_vlstring_type()", __LINE__, __FILE__, E.getCDetailMsg());
     }
 
-    if (file1)
-        delete file1;
+    delete file1;
 } // end test_vlstring_type()
 
 /*-------------------------------------------------------------------------
@@ -536,10 +525,6 @@ test_vlstring_type()
  * Purpose      Test storing VL strings in compact datasets.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -577,20 +562,21 @@ test_compact_vlstring()
         // Compare data read in
         hsize_t i;
         for (i = 0; i < SPACE1_DIM1; i++) {
-            if (HDstrlen(wdata[i]) != strlen(rdata[i])) {
+            if (strlen(wdata[i]) != strlen(rdata[i])) {
                 TestErrPrintf("VL data length don't match!, strlen(wdata[%d])=%d, strlen(rdata[%d])=%d\n",
-                              (int)i, (int)strlen(wdata[i]), (int)i, (int)strlen(rdata[i]));
+                              static_cast<int>(i), static_cast<int>(strlen(wdata[i])), static_cast<int>(i),
+                              static_cast<int>(strlen(rdata[i])));
                 continue;
             } // end if
-            if (HDstrcmp(wdata[i], rdata[i]) != 0) {
-                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n", (int)i, wdata[i],
-                              (int)i, rdata[i]);
+            if (strcmp(wdata[i], rdata[i]) != 0) {
+                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n",
+                              static_cast<int>(i), wdata[i], static_cast<int>(i), rdata[i]);
                 continue;
             } // end if
         }     // end for
 
         // Reclaim the read VL data
-        DataSet::vlenReclaim((void *)rdata, vlst, sid1);
+        DataSet::vlenReclaim(static_cast<void *>(rdata), vlst, sid1);
 
         // Close objects and file
         dataset.close();
@@ -614,10 +600,6 @@ test_compact_vlstring()
  * Purpose      Test writing/reading VL strings on attributes.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
- *
  *-------------------------------------------------------------------------
  */
 static char       *string_att_write = NULL;
@@ -652,11 +634,11 @@ test_vlstring_attribute()
         // Read and verify the attribute string as a string of chars.
         char *string_att_check;
         gr_attr.read(vlst, &string_att_check);
-        if (HDstrcmp(string_att_check, ATTRSTR_DATA.c_str()) != 0)
+        if (strcmp(string_att_check, ATTRSTR_DATA.c_str()) != 0)
             TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,string_att_check=%s\n",
                           __LINE__, ATTRSTR_DATA.c_str(), string_att_check);
 
-        HDfree(string_att_check); // note: no need for std::string test
+        free(string_att_check); // note: no need for std::string test
 
         // Read and verify the attribute string as an std::string.
         H5std_string read_str;
@@ -671,21 +653,21 @@ test_vlstring_attribute()
         // Test creating a "large" sized string attribute
         gr_attr = root.createAttribute("test_scalar_large", vlst, att_space);
 
-        string_att_write = (char *)HDcalloc(8192, sizeof(char));
-        HDmemset(string_att_write, 'A', 8191);
+        string_att_write = static_cast<char *>(calloc(8192, sizeof(char)));
+        memset(string_att_write, 'A', 8191);
 
         // Write data to the attribute, then read it back.
         gr_attr.write(vlst, &string_att_write);
         gr_attr.read(vlst, &string_att_check);
 
         // Verify data read.
-        if (HDstrcmp(string_att_check, string_att_write) != 0)
+        if (strcmp(string_att_check, string_att_write) != 0)
             TestErrPrintf("VL string attributes don't match!, string_att_write=%s, string_att_check=%s\n",
                           string_att_write, string_att_check);
 
         // Release resources.
-        HDfree(string_att_check);
-        HDfree(string_att_write);
+        free(string_att_check);
+        free(string_att_write);
         gr_attr.close();
         file1.close();
 
@@ -705,10 +687,6 @@ test_vlstring_attribute()
  * Purpose      Test reading VL strings from attributes.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
- *
  *-------------------------------------------------------------------------
  */
 static void test_read_vl_string_attribute()
@@ -731,18 +709,18 @@ static void test_read_vl_string_attribute()
         // Test reading "normal" sized string attribute
         char *string_att_check;
         att.read(vlst, &string_att_check);
-        if(HDstrcmp(string_att_check,ATTRSTR_DATA.c_str())!=0)
+        if(strcmp(string_att_check,ATTRSTR_DATA.c_str())!=0)
             TestErrPrintf("VL string attributes don't match!, string_att=%s, string_att_check=%s\n",ATTRSTR_DATA.c_str(),string_att_check);
-        HDfree(string_att_check);
+        free(string_att_check);
         att.close();
 
         // Test reading "large" sized string attribute
         att = root.openAttribute("test_scalar_large");
         att.read(vlst, &string_att_check);
-        if(HDstrcmp(string_att_check,string_att_write)!=0)
+        if(strcmp(string_att_check,string_att_write)!=0)
             TestErrPrintf("VL string attributes don't match!, string_att_write=%s, string_att_check=%s\n",string_att_write,string_att_check);
-        HDfree(string_att_check);
-        HDfree(string_att_write);   // Free string allocated in test_write_vl_string_attribute
+        free(string_att_check);
+        free(string_att_write);   // Free string allocated in test_write_vl_string_attribute
 
         // Close objects and file.
         att.close();
@@ -767,10 +745,6 @@ static void test_read_vl_string_attribute()
  * Purpose      Test writing/reading VL string array to/from attributes.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler
- *              July, 2009
- *
  *-------------------------------------------------------------------------
  */
 const H5std_string ATTRSTRARR_NAME("StringArray_attr");
@@ -811,11 +785,11 @@ test_vlstring_array_attribute()
 
         hsize_t ii;
         for (ii = 0; ii < SPACE1_DIM1; ii++) {
-            if (HDstrcmp(string_att_check[ii], string_att_array[ii]) != 0)
+            if (strcmp(string_att_check[ii], string_att_array[ii]) != 0)
                 TestErrPrintf("Line %d: Attribute data different: written=%s,read=%s\n", __LINE__,
                               string_att_check[ii], string_att_check[ii]);
 
-            HDfree(string_att_check[ii]); // note: no need for std::string test
+            free(string_att_check[ii]); // note: no need for std::string test
         }
 
         // Close group's attribute.
@@ -860,10 +834,10 @@ read_scalar_dset(H5File &file, DataType &type, DataSpace &space, char *name, cha
         dset.read(&data_read, type, space, space);
         dset.close();
 
-        if (HDstrcmp(data, data_read) != 0)
+        if (strcmp(data, data_read) != 0)
             TestErrPrintf("Expected %s for dataset %s but read %s\n", data, name, data_read);
 
-        HDfree(data_read);
+        free(data_read);
     } // end try
     catch (FileIException &ferr) {
         throw;
@@ -880,10 +854,6 @@ read_scalar_dset(H5File &file, DataType &type, DataSpace &space, char *name, cha
  *              have been linked/unlinked.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
- *
  *-------------------------------------------------------------------------
  */
 const H5std_string FILENAME2("tvlstr2.h5");
@@ -910,32 +880,32 @@ test_vl_rewrite()
         int  i;
         char name[256]; // Buffer for names & data
         for (i = 0; i < REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+            snprintf(name, sizeof(name), "/set_%d", i);
             write_scalar_dset(file1, type, space, name, name);
         }
 
         // Effectively copy data from file 1 to 2.
         for (i = 0; i < REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+            snprintf(name, sizeof(name), "/set_%d", i);
             read_scalar_dset(file1, type, space, name, name);
             write_scalar_dset(file2, type, space, name, name);
         }
 
         // Read back from file 2.
         for (i = 0; i < REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+            snprintf(name, sizeof(name), "/set_%d", i);
             read_scalar_dset(file2, type, space, name, name);
         }
 
         // Remove from file 2.
         for (i = 0; i < REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+            snprintf(name, sizeof(name), "/set_%d", i);
             file2.unlink(name);
         }
 
         // Effectively copy from file 1 to file 2.
         for (i = 0; i < REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+            snprintf(name, sizeof(name), "/set_%d", i);
             read_scalar_dset(file1, type, space, name, name);
             write_scalar_dset(file2, type, space, name, name);
         }
@@ -961,10 +931,6 @@ test_vl_rewrite()
  * Purpose      VL string testing main routine.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler
- *              January, 2007
- *
  *-------------------------------------------------------------------------
  */
 extern "C" void
