@@ -34,11 +34,6 @@
  *  type_id - dataset identifier
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Saturday, August 14, 1999
- * HISTORY
- *
  * SOURCE
  */
 int_f
@@ -66,7 +61,7 @@ h5topen_c(hid_t_f *loc_id, _fcd name, int_f *namelen, hid_t_f *type_id, hid_t_f
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
 
     return ret_value;
 }
@@ -86,13 +81,6 @@ done:
  *  tapl_id - Datatype access property list
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Saturday, August 14, 1999
- * HISTORY
- *
- *              - Added passing optional parameters for version 1.8
- *                M. Scot Breitenfeld
  * SOURCE
  */
 int_f
@@ -116,7 +104,7 @@ h5tcommit_c(hid_t_f *loc_id, _fcd name, int_f *namelen, hid_t_f *type_id, hid_t_
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
     return ret_value;
 }
 
@@ -129,11 +117,6 @@ done:
  *  type_id - identifier of the datatype to be closed
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Saturday, August 14, 1999
- * HISTORY
- *
  * SOURCE
  */
 
@@ -161,11 +144,6 @@ h5tclose_c(hid_t_f *type_id)
  *  new_type_id - identifier of the new datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Saturday, August 14, 1999
- * HISTORY
- *
  * SOURCE
  */
 
@@ -197,11 +175,6 @@ h5tcopy_c(hid_t_f *type_id, hid_t_f *new_type_id)
  *  c_flag - flag; indicates if two datatypes are equal or not.
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Tuesday, February 22, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -246,11 +219,6 @@ h5tequal_c(hid_t_f *type1_id, hid_t_f *type2_id, int_f *c_flag)
  *               H5T_ARRAY_F (10)
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Saturday, August 14, 1999
- * HISTORY
- *
  * SOURCE
  */
 
@@ -299,11 +267,6 @@ h5tget_class_c(hid_t_f *type_id, int_f *classtype)
  *              H5T_ORDER_VAX_F (2)
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Saturday, August 14, 1999
- * HISTORY
- *
  * SOURCE
  */
 
@@ -342,11 +305,6 @@ h5tget_order_c(hid_t_f *type_id, int_f *order)
  *              H5T_ORDER_VAX_F (2)
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Saturday, August 14, 1999
- * HISTORY
- *
  * SOURCE
  */
 
@@ -382,11 +340,6 @@ h5tset_order_c(hid_t_f *type_id, int_f *order)
  *  size (in bytes)
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Saturday, August 14, 1999
- * HISTORY
- *
  * SOURCE
  */
 
@@ -418,11 +371,6 @@ h5tget_size_c(hid_t_f *type_id, size_t_f *size)
  *  size (in bytes)
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Saturday, August 14, 1999
- * HISTORY
- *
  * SOURCE
  */
 
@@ -455,11 +403,6 @@ h5tset_size_c(hid_t_f *type_id, size_t_f *size)
  *  precision -  number of significant bits
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Tuesday, January 25, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -490,11 +433,6 @@ h5tget_precision_c(hid_t_f *type_id, size_t_f *precision)
  *  precision -  number of significant bits
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Tuesday, January 25, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -528,11 +466,6 @@ h5tset_precision_c(hid_t_f *type_id, size_t_f *precision)
  *  offset - bit offset of the first significant bit
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Tuesday, January 25, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -565,11 +498,6 @@ h5tget_offset_c(hid_t_f *type_id, size_t_f *offset)
  *  offset - bit offset of the first significant bit
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Tuesday, January 25, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -605,11 +533,6 @@ h5tset_offset_c(hid_t_f *type_id, size_t_f *offset)
  *  msbpad - padding type of the least significant bit
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -648,11 +571,6 @@ h5tget_pad_c(hid_t_f *type_id, int_f *lsbpad, int_f *msbpad)
  *  msbpad - padding type of the least significant bit
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -686,11 +604,6 @@ h5tset_pad_c(hid_t_f *type_id, int_f *lsbpad, int_f *msbpad)
  *  sign - sign type for an integer type
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -721,11 +634,6 @@ h5tget_sign_c(hid_t_f *type_id, int_f *sign)
  *  sign - sign type for an integer typ
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -763,11 +671,6 @@ h5tset_sign_c(hid_t_f *type_id, int_f *sign)
  *  msize -  size of mantissa in bits
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Thursday, January 27, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -808,11 +711,6 @@ h5tget_fields_c(hid_t_f *type_id, size_t_f *spos, size_t_f *epos, size_t_f *esiz
  *  msize -  size of mantissa in bits
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -852,11 +750,6 @@ h5tset_fields_c(hid_t_f *type_id, size_t_f *spos, size_t_f *epos, size_t_f *esiz
  *  ebias - exponent bias of a floating-point type of the datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Xiangyang Su
- *  Friday, January 27, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -889,11 +782,6 @@ h5tget_ebias_c(hid_t_f *type_id, size_t_f *ebias)
  *  ebias - exponent bias of a floating-point type of the datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Xiangyang Su
- *  Friday, January 27, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -928,11 +816,6 @@ h5tset_ebias_c(hid_t_f *type_id, size_t_f *ebias)
  *  norm - mantissa normalization of a floating-point type
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Xiangyang Su
- *  Friday, January 27, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -965,11 +848,6 @@ h5tget_norm_c(hid_t_f *type_id, int_f *norm)
  *  norm -  mantissa normalization of a floating-point type
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Xiangyang Su
- *  Friday, January 27, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1006,11 +884,6 @@ h5tset_norm_c(hid_t_f *type_id, int_f *norm)
  *  unused bits in floating-point datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1047,11 +920,6 @@ h5tget_inpad_c(hid_t_f *type_id, int_f *padtype)
  *  in floating-point datatypes
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1087,11 +955,6 @@ h5tset_inpad_c(hid_t_f *type_id, int_f *padtype)
  *  cset - character set type of a string datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1127,11 +990,6 @@ h5tget_cset_c(hid_t_f *type_id, int_f *cset)
  *  cset -  character set type of a string datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1166,11 +1024,6 @@ h5tset_cset_c(hid_t_f *type_id, int_f *cset)
  *  strpad - string padding method for a string datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 int_f
@@ -1205,11 +1058,6 @@ h5tget_strpad_c(hid_t_f *type_id, int_f *strpad)
  *  strpad - string padding method for a string datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1244,11 +1092,6 @@ h5tset_strpad_c(hid_t_f *type_id, int_f *strpad)
  *  num_members - number of fields in a compound datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Thursday, February 3, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1280,12 +1123,6 @@ h5tget_nmembers_c(hid_t_f *type_id, int_f *num_members)
  *  member_name - name of a field of a compound datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Thursday, February 3, 2000
- * HISTORY
- *  Elena Pourmal
- *  Added namelen parameter to return length of the name to Fortran user
  * SOURCE
  */
 
@@ -1324,11 +1161,6 @@ h5tget_member_name_c(hid_t_f *type_id, int_f *idx, _fcd member_name, int_f *name
  *  index - 0-based index
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Thursday, September 26, 2002
- * HISTORY
- *
  * SOURCE
  */
 int_f
@@ -1357,7 +1189,7 @@ h5tget_member_index_c(hid_t_f *type_id, _fcd name, int_f *namelen, int_f *idx)
         goto DONE;
     *idx = (int_f)c_index;
 DONE:
-    HDfree(c_name);
+    free(c_name);
     ret_value = 0;
     return ret_value;
 }
@@ -1373,15 +1205,10 @@ DONE:
  *  type_id - identifier of the dataspace
  *  member_no - Number of the field whose offset is requested
  * OUTPUTS
- *  offset - byte offset of the the beginning of the field of
+ *  offset - byte offset of the beginning of the field of
  *  a compound datatype
  * RETURNS
  *  always 0
- * AUTHOR
- *  XIANGYANG SU
- *  Thursday, February 3, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1410,11 +1237,6 @@ h5tget_member_offset_c(hid_t_f *type_id, int_f *member_no, size_t_f *offset)
  *  dims -  dimensions(sizes of dimensions) of the array
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Thursday, November 16, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1453,11 +1275,6 @@ DONE:
  *  ndims -  number of dimensions of the array
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Thursday, November 16, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1491,11 +1308,6 @@ h5tget_array_ndims_c(hid_t_f *type_id, int_f *ndims)
  *  base_type_id - base datatype identifier
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Thursday, November 16, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1530,11 +1342,6 @@ h5tget_super_c(hid_t_f *type_id, hid_t_f *base_type_id)
  *  datatype - identifier of a copy of the datatype of the field
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Thursday, February 3, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1562,11 +1369,6 @@ h5tget_member_type_c(hid_t_f *type_id, int_f *field_idx, hid_t_f *datatype)
  *  size - size of the class member
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Thursday, February 17, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1602,11 +1404,6 @@ h5tcreate_c(int_f *cls, size_t_f *size, hid_t_f *type_id)
  *  field_id - datatype identifier of the new member
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Thursday, February 3, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1624,7 +1421,7 @@ h5tinsert_c(hid_t_f *type_id, _fcd name, int_f *namelen, size_t_f *offset, hid_t
 
     error = H5Tinsert((hid_t)*type_id, c_name, (size_t)*offset, (hid_t)*field_id);
 
-    HDfree(c_name);
+    free(c_name);
     if (error < 0)
         return ret_value;
     ret_value = 0;
@@ -1642,11 +1439,6 @@ h5tinsert_c(hid_t_f *type_id, _fcd name, int_f *namelen, size_t_f *offset, hid_t
  *  type_id - identifier of the datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Thursday, February 3, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1679,11 +1471,6 @@ h5tpack_c(hid_t_f *type_id)
  *  type_id - identifier of the array datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Thursday, November 16, 2000
- * HISTORY
- *
  * SOURCE
  */
 int_f
@@ -1723,11 +1510,6 @@ DONE:
  *  enumeration datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Xiangyang Su
- *  Tuesday, February 15, 1999
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1758,10 +1540,7 @@ h5tenum_create_c(hid_t_f *parent_id, hid_t_f *new_type_id)
  *  value   - value of the new member
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Thursday, February 3, 2000
- * HISTORY
+ *
  *  'value' is no longer cast into an int. If the user passes in an 8 byte integer then
  *  it should not be cast to an int (which might be 4 bytes). Instead the value
  *  is written as the size of an int_f.
@@ -1784,7 +1563,7 @@ h5tenum_insert_c(hid_t_f *type_id, _fcd name, int_f *namelen, int_f *value)
     c_value = *value;
     error   = H5Tenum_insert((hid_t)*type_id, c_name, &c_value);
 
-    HDfree(c_name);
+    free(c_name);
     if (error < 0)
         return ret_value;
 
@@ -1805,11 +1584,6 @@ h5tenum_insert_c(hid_t_f *type_id, _fcd name, int_f *namelen, int_f *value)
  *  Output:      name  - Name of  the enumeration datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Thursday, February 3, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1825,11 +1599,11 @@ h5tenum_nameof_c(hid_t_f *type_id, int_f *value, _fcd name, size_t_f *namelen)
     int_f  c_value;
     c_value   = *value;
     c_namelen = ((size_t)*namelen) + 1;
-    c_name    = (char *)HDmalloc(sizeof(char) * c_namelen);
+    c_name    = (char *)malloc(sizeof(char) * c_namelen);
     c_type_id = (hid_t)*type_id;
     error     = H5Tenum_nameof(c_type_id, &c_value, c_name, c_namelen);
     HD5packFstring(c_name, _fcdtocp(name), strlen(c_name));
-    HDfree(c_name);
+    free(c_name);
 
     if (error < 0)
         return ret_value;
@@ -1850,11 +1624,6 @@ h5tenum_nameof_c(hid_t_f *type_id, int_f *value, _fcd name, size_t_f *namelen)
  *  Output:      value  - value of the enumeration datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Thursday, February 3, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1870,7 +1639,7 @@ h5tenum_valueof_c(hid_t_f *type_id, _fcd name, int_f *namelen, int_f *value)
         return ret_value;
 
     error = H5Tenum_valueof((hid_t)*type_id, c_name, value);
-    HDfree(c_name);
+    free(c_name);
 
     if (error < 0)
         return ret_value;
@@ -1890,11 +1659,6 @@ h5tenum_valueof_c(hid_t_f *type_id, _fcd name, int_f *namelen, int_f *value)
  *  Output:      value  - value of the enumeration datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Thursday, February 3, 2000
- * HISTORY
- *
  * SOURCE
  */
 
@@ -1929,11 +1693,6 @@ h5tget_member_value_c(hid_t_f *type_id, int_f *member_no, int_f *value)
  *  namelen - length of tag
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 int_f
@@ -1947,7 +1706,7 @@ h5tset_tag_c(hid_t_f *type_id, _fcd tag, int_f *namelen)
     c_tag = (char *)HD5f2cstring(tag, (size_t)*namelen);
 
     status = H5Tset_tag((hid_t)*type_id, c_tag);
-    HDfree(c_tag);
+    free(c_tag);
     if (status < 0)
         return ret_value;
 
@@ -1968,11 +1727,6 @@ h5tset_tag_c(hid_t_f *type_id, _fcd tag, int_f *namelen)
  *  taglen - length of tag
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  XIANGYANG SU
- *  Wednesday, January 26, 2000
- * HISTORY
- *
  * SOURCE
  */
 int_f
@@ -1989,7 +1743,7 @@ h5tget_tag_c(hid_t_f *type_id, _fcd tag, size_t_f *tag_size, int_f *taglen)
         return ret_value;
 
     HD5packFstring(c_tag, _fcdtocp(tag), (size_t)*tag_size);
-    *taglen = (int_f)HDstrlen(c_tag);
+    *taglen = (int_f)strlen(c_tag);
     H5free_memory(c_tag);
     ret_value = 0;
     return ret_value;
@@ -2005,11 +1759,6 @@ h5tget_tag_c(hid_t_f *type_id, _fcd tag, size_t_f *tag_size, int_f *taglen)
  *  vltype_id - identifier of the VL datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Wednesday, October 23, 2002
- * HISTORY
- *
  * SOURCE
  */
 int_f
@@ -2041,11 +1790,6 @@ h5tvlen_create_c(hid_t_f *type_id, hid_t_f *vltype_id)
  *  and negative on failure.
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Wednesday, March 12 , 2003
- * HISTORY
- *
  * SOURCE
  */
 
@@ -2078,11 +1822,6 @@ h5tis_variable_str_c(hid_t_f *type_id, int_f *flag)
  *  and negative on failure.
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Wednesday, April 6, 2005
- * HISTORY
- *
  * SOURCE
  */
 
@@ -2117,11 +1856,6 @@ h5tget_member_class_c(hid_t_f *type_id, int_f *member_no, int_f *cls)
  *  tapl_id - Datatype access property list
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  February 25, 2008
- * HISTORY
- *
  * SOURCE
  */
 int_f
@@ -2150,11 +1884,6 @@ done:
  *  a positive value, for TRUE, if the datatype has been committed,
  *  or 0 (zero), for FALSE, if the datatype has not been committed.
  *		Otherwise returns a negative value.
- * AUTHOR
- *  M. Scot Breitenfeld
- *  February 25, 2008
- * HISTORY
- *
  * SOURCE
  */
 int_f
@@ -2184,11 +1913,6 @@ h5tcommitted_c(hid_t_f *dtype_id)
  *
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  April 9, 2008
- * HISTORY
- *
  * SOURCE
  */
 
@@ -2228,11 +1952,6 @@ h5tdecode_c(_fcd buf, hid_t_f *obj_id)
  *  nalloc - The size of the allocated buffer.
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  April 9, 2008
- * HISTORY
- *
  * SOURCE
  */
 
@@ -2263,7 +1982,7 @@ h5tencode_c(_fcd buf, hid_t_f *obj_id, size_t_f *nalloc)
      * Allocate buffer
      */
     c_size = (size_t)*nalloc;
-    if (NULL == (c_buf = (unsigned char *)HDmalloc(c_size)))
+    if (NULL == (c_buf = (unsigned char *)malloc(c_size)))
         return ret_value;
 
     /*
@@ -2278,11 +1997,11 @@ h5tencode_c(_fcd buf, hid_t_f *obj_id, size_t_f *nalloc)
      * with blanks.
      */
 
-    HDmemcpy(_fcdtocp(buf), (char *)c_buf, c_size);
+    memcpy(_fcdtocp(buf), (char *)c_buf, c_size);
 
     ret_value = 0;
     if (c_buf)
-        HDfree(c_buf);
+        free(c_buf);
     return ret_value;
 }
 
@@ -2297,11 +2016,6 @@ h5tencode_c(_fcd buf, hid_t_f *obj_id, size_t_f *nalloc)
  *  dtpl_id           - Datatype property list identifier
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  April 9, 2008
- * HISTORY
- * N/A
  * SOURCE
  */
 
@@ -2331,11 +2045,6 @@ h5tget_create_plist_c(hid_t_f *dtype_id, hid_t_f *dtpl_id)
  *  c_flag - flag; TRUE for compiler conversion, FALSE for library conversion
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  M.Scot Breitenfeld
- *  April 9, 2008
- * HISTORY
- *
  * SOURCE
  */
 
@@ -2366,11 +2075,6 @@ h5tcompiler_conv_c(hid_t_f *src_id, hid_t_f *dst_id, int_f *c_flag)
  *  native_dtype_id  - The native datatype identifier for the specified dataset datatype
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  June 18, 2008
- * HISTORY
- *
  * SOURCE
  */
 
@@ -2408,10 +2112,6 @@ h5tget_native_type_c(hid_t_f *dtype_id, int_f *direction, hid_t_f *native_dtype_
  *
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  December 8, 2008
- *
  * SOURCE
  */
 int_f
@@ -2443,10 +2143,6 @@ h5tconvert_c(hid_t_f *src_id, hid_t_f *dst_id, size_t_f *nelmts, void *buf, void
  *
  * RETURNS
  *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  February 6, 2015
- *
  * SOURCE
  */
 int_f
@@ -2466,7 +2162,7 @@ h5tenum_insert_ptr_c(hid_t_f *type_id, _fcd name, int_f *namelen, void *value)
 
     status = H5Tenum_insert((hid_t)*type_id, c_name, value);
 
-    HDfree(c_name);
+    free(c_name);
     if (status < 0)
         return ret_value;
 
