@@ -439,6 +439,12 @@ main(void)
     fprintf(fort_header, "        INTEGER, PARAMETER :: H5R_DSET_REG_REF_BUF_SIZE_F = %u\n",
             H5_SIZEOF_HADDR_T + 4);
 
+    /* Need the buffer size for the fortran derived type 'h5o_token_t'
+     * in order to be interoperable with C's structure.
+     */
+
+    fprintf(fort_header, "        INTEGER, PARAMETER :: H5O_MAX_TOKEN_SIZE_F = %u\n", H5O_MAX_TOKEN_SIZE);
+
     /* Close files */
     endCfile();
     endFfile();
