@@ -29,6 +29,9 @@
 #define DSET6_NAME "dataset double"
 #define DSET7_NAME "dataset string"
 
+/* Name of a non-existing dataset, do not create a dataset with this name */
+#define NODS_NAME "dataset"
+
 #define DIM 6
 
 #define ATTR_NAME_SUB "att"
@@ -42,8 +45,9 @@
 #define ATTR7_NAME    "attr ushort"
 #define ATTR8_NAME    "attr uint"
 #define ATTR9_NAME    "attr ulong"
-#define ATTR10_NAME   "attr float"
-#define ATTR11_NAME   "attr double"
+#define ATTR10_NAME   "attr ullong"
+#define ATTR11_NAME   "attr float"
+#define ATTR12_NAME   "attr double"
 
 static herr_t make_attributes(hid_t loc_id, const char *obj_name);
 
@@ -59,6 +63,7 @@ test_dsets(void)
     hsize_t     dims[2] = {2, 3};
     hid_t       file_id;
     hid_t       dataset_id;
+    herr_t      ds_existed        = 0; /* whether searched ds exists */
     char        data_char_in[DIM] = {1, 2, 3, 4, 5, 6};
     char        data_char_out[DIM];
     short       data_short_in[DIM] = {1, 2, 3, 4, 5, 6};
@@ -344,9 +349,26 @@ test_dsets(void)
     if (H5LTread_dataset_string(file_id, DSET7_NAME, data_string_out) < 0)
         goto out;
 
-    if (HDstrcmp(data_string_in, data_string_out) != 0)
+    if (strcmp(data_string_in, data_string_out) != 0)
         goto out;
 
+    PASSED();
+
+    /*-------------------------------------------------------------------------
+     * H5LTfind_dataset test
+     *-------------------------------------------------------------------------
+     */
+
+    HL_TESTING2("H5LTfind_dataset");
+
+    /* Try to find a non-existing ds whose name matches existing datasets partially */
+    if ((ds_existed = H5LTfind_dataset(file_id, NODS_NAME)) < 0)
+        goto out;
+    if (ds_existed > 0) {
+        printf("Dataset \"%s\" does not exist.\n", NODS_NAME);
+        goto out;
+    }
+
     /*-------------------------------------------------------------------------
      * end tests
      *-------------------------------------------------------------------------
@@ -471,28 +493,30 @@ make_attributes(hid_t loc_id, const char *obj_name)
     size_t      type_size;
     int         i;
 
-    char           attr_str_in[] = {"My attribute"};
-    char           attr_str_out[20];
-    char           attr_char_in[5] = {1, 2, 3, 4, 5};
-    char           attr_char_out[5];
-    short          attr_short_in[5] = {1, 2, 3, 4, 5};
-    short          attr_short_out[5];
-    int            attr_int_in[5] = {1, 2, 3, 4, 5};
-    int            attr_int_out[5];
-    long           attr_long_in[5] = {1, 2, 3, 4, 5};
-    long           attr_long_out[5];
-    float          attr_float_in[5] = {1, 2, 3, 4, 5};
-    float          attr_float_out[5];
-    double         attr_double_in[5] = {1, 2, 3, 4, 5};
-    double         attr_double_out[5];
-    unsigned char  attr_uchar_in[5] = {1, 2, 3, 4, 5};
-    unsigned char  attr_uchar_out[5];
-    unsigned short attr_ushort_in[5] = {1, 2, 3, 4, 5};
-    unsigned short attr_ushort_out[5];
-    unsigned int   attr_uint_in[5] = {1, 2, 3, 4, 5};
-    unsigned int   attr_uint_out[5];
-    unsigned long  attr_ulong_in[5] = {1, 2, 3, 4, 5};
-    unsigned long  attr_ulong_out[5];
+    char               attr_str_in[] = {"My attribute"};
+    char               attr_str_out[20];
+    char               attr_char_in[5] = {1, 2, 3, 4, 5};
+    char               attr_char_out[5];
+    short              attr_short_in[5] = {1, 2, 3, 4, 5};
+    short              attr_short_out[5];
+    int                attr_int_in[5] = {1, 2, 3, 4, 5};
+    int                attr_int_out[5];
+    long               attr_long_in[5] = {1, 2, 3, 4, 5};
+    long               attr_long_out[5];
+    float              attr_float_in[5] = {1, 2, 3, 4, 5};
+    float              attr_float_out[5];
+    double             attr_double_in[5] = {1, 2, 3, 4, 5};
+    double             attr_double_out[5];
+    unsigned char      attr_uchar_in[5] = {1, 2, 3, 4, 5};
+    unsigned char      attr_uchar_out[5];
+    unsigned short     attr_ushort_in[5] = {1, 2, 3, 4, 5};
+    unsigned short     attr_ushort_out[5];
+    unsigned int       attr_uint_in[5] = {1, 2, 3, 4, 5};
+    unsigned int       attr_uint_out[5];
+    unsigned long      attr_ulong_in[5] = {1, 2, 3, 4, 5};
+    unsigned long      attr_ulong_out[5];
+    unsigned long long attr_ullong_in[5] = {1, 2, 3, 4, 5};
+    unsigned long long attr_ullong_out[5];
 
     /*-------------------------------------------------------------------------
      * H5LTset_attribute_string test
@@ -508,7 +532,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     PASSED();
 
     /*-------------------------------------------------------------------------
-     * H5LTset_attribute_string test
+     * H5LTget_attribute_string test
      *-------------------------------------------------------------------------
      */
 
@@ -518,7 +542,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     if (H5LTget_attribute_string(loc_id, obj_name, ATTR1_NAME, attr_str_out) < 0)
         return -1;
 
-    if (HDstrcmp(attr_str_in, attr_str_out) != 0) {
+    if (strcmp(attr_str_in, attr_str_out) != 0) {
         return -1;
     }
 
@@ -858,7 +882,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     PASSED();
 
     /*-------------------------------------------------------------------------
-     * H5LTget_attribute_long test
+     * H5LTget_attribute_ulong test
      *-------------------------------------------------------------------------
      */
 
@@ -886,6 +910,48 @@ make_attributes(hid_t loc_id, const char *obj_name)
 
     PASSED();
 
+    /*-------------------------------------------------------------------------
+     * H5LTset_attribute_ullong test
+     *-------------------------------------------------------------------------
+     */
+
+    HL_TESTING2("H5LTset_attribute_ullong");
+
+    /* Set the attribute */
+    if (H5LTset_attribute_ullong(loc_id, obj_name, ATTR10_NAME, attr_ullong_in, (size_t)5) < 0)
+        return -1;
+
+    PASSED();
+
+    /*-------------------------------------------------------------------------
+     * H5LTget_attribute_ullong test
+     *-------------------------------------------------------------------------
+     */
+
+    HL_TESTING2("H5LTget_attribute_ullong");
+
+    /* Get the attribute */
+    if (H5LTget_attribute_ullong(loc_id, obj_name, ATTR10_NAME, attr_ullong_out) < 0)
+        return -1;
+
+    for (i = 0; i < 5; i++) {
+        if (attr_ullong_in[i] != attr_ullong_out[i]) {
+            return -1;
+        }
+    }
+
+    /* Get the attribute */
+    if (H5LTget_attribute(loc_id, obj_name, ATTR10_NAME, H5T_NATIVE_ULLONG, attr_ullong_out) < 0)
+        return -1;
+
+    for (i = 0; i < 5; i++) {
+        if (attr_ullong_in[i] != attr_ullong_out[i]) {
+            return -1;
+        }
+    }
+
+    PASSED();
+
     /*-------------------------------------------------------------------------
      * H5LTset_attribute_float test
      *-------------------------------------------------------------------------
@@ -894,7 +960,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     HL_TESTING2("H5LTset_attribute_float");
 
     /* Set the attribute */
-    if (H5LTset_attribute_float(loc_id, obj_name, ATTR10_NAME, attr_float_in, (size_t)5) < 0)
+    if (H5LTset_attribute_float(loc_id, obj_name, ATTR11_NAME, attr_float_in, (size_t)5) < 0)
         return -1;
 
     PASSED();
@@ -907,7 +973,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     HL_TESTING2("H5LTget_attribute_float");
 
     /* Get the attribute */
-    if (H5LTget_attribute_float(loc_id, obj_name, ATTR10_NAME, attr_float_out) < 0)
+    if (H5LTget_attribute_float(loc_id, obj_name, ATTR11_NAME, attr_float_out) < 0)
         return -1;
 
     for (i = 0; i < 5; i++) {
@@ -917,7 +983,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     }
 
     /* Get the attribute */
-    if (H5LTget_attribute(loc_id, obj_name, ATTR10_NAME, H5T_NATIVE_FLOAT, attr_float_out) < 0)
+    if (H5LTget_attribute(loc_id, obj_name, ATTR11_NAME, H5T_NATIVE_FLOAT, attr_float_out) < 0)
         return -1;
 
     for (i = 0; i < 5; i++) {
@@ -936,7 +1002,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     HL_TESTING2("H5LTset_attribute_double");
 
     /* Set the attribute */
-    if (H5LTset_attribute_double(loc_id, obj_name, ATTR11_NAME, attr_double_in, (size_t)5) < 0)
+    if (H5LTset_attribute_double(loc_id, obj_name, ATTR12_NAME, attr_double_in, (size_t)5) < 0)
         return -1;
 
     PASSED();
@@ -949,7 +1015,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     HL_TESTING2("H5LTget_attribute_double");
 
     /* Get the attribute */
-    if (H5LTget_attribute_double(loc_id, obj_name, ATTR11_NAME, attr_double_out) < 0)
+    if (H5LTget_attribute_double(loc_id, obj_name, ATTR12_NAME, attr_double_out) < 0)
         return -1;
 
     for (i = 0; i < 5; i++) {
@@ -959,7 +1025,7 @@ make_attributes(hid_t loc_id, const char *obj_name)
     }
 
     /* Get the attribute */
-    if (H5LTget_attribute(loc_id, obj_name, ATTR11_NAME, H5T_NATIVE_DOUBLE, attr_double_out) < 0)
+    if (H5LTget_attribute(loc_id, obj_name, ATTR12_NAME, H5T_NATIVE_DOUBLE, attr_double_out) < 0)
         return -1;
 
     for (i = 0; i < 5; i++) {
@@ -993,26 +1059,26 @@ make_attributes(hid_t loc_id, const char *obj_name)
 
     HL_TESTING2("H5LTget_attribute_info");
 
-    if (NULL == (dims_out = (hsize_t *)HDmalloc(sizeof(hsize_t) * (size_t)rank_out)))
+    if (NULL == (dims_out = (hsize_t *)malloc(sizeof(hsize_t) * (size_t)rank_out)))
         return -1;
 
     if (H5LTget_attribute_info(loc_id, obj_name, ATTR2_NAME, dims_out, &type_class, &type_size) < 0) {
-        HDfree(dims_out);
+        free(dims_out);
         return -1;
     }
 
     for (i = 0; i < rank_out; i++) {
         if (dims_out[i] != 5) {
-            HDfree(dims_out);
+            free(dims_out);
             return -1;
         }
     }
 
     if (type_class != H5T_INTEGER) {
-        HDfree(dims_out);
+        free(dims_out);
         return -1;
     }
-    HDfree(dims_out);
+    free(dims_out);
 
     PASSED();
 
@@ -1030,7 +1096,7 @@ test_integers(void)
     char  *dt_str;
     size_t str_len;
 
-    HL_TESTING3("\n        text for integer types");
+    HL_TESTING3("        text for integer types");
 
     if ((dtype = H5LTtext_to_dtype("H5T_NATIVE_INT\n", H5LT_DDL)) < 0)
         goto out;
@@ -1047,17 +1113,17 @@ test_integers(void)
     if (H5LTdtype_to_text(dtype, NULL, H5LT_DDL, &str_len) < 0)
         goto out;
 
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
-    if (HDstrcmp(dt_str, "H5T_STD_I8BE") != 0) {
-        HDfree(dt_str);
+    if (strcmp(dt_str, "H5T_STD_I8BE") != 0) {
+        free(dt_str);
         goto out;
     }
-    HDfree(dt_str);
+    free(dt_str);
 
     if (H5Tclose(dtype) < 0)
         goto out;
@@ -1105,17 +1171,17 @@ test_fps(void)
     if (H5LTdtype_to_text(dtype, NULL, H5LT_DDL, &str_len) < 0)
         goto out;
 
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
-    if (HDstrcmp(dt_str, "H5T_IEEE_F32BE") != 0) {
-        HDfree(dt_str);
+    if (strcmp(dt_str, "H5T_IEEE_F32BE") != 0) {
+        free(dt_str);
         goto out;
     }
-    HDfree(dt_str);
+    free(dt_str);
 
     if (H5Tclose(dtype) < 0)
         goto out;
@@ -1176,19 +1242,19 @@ test_strings(void)
 
     if (H5LTdtype_to_text(dtype, NULL, H5LT_DDL, &str_len) < 0)
         goto out;
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
-    if (HDstrcmp(dt_str, "H5T_STRING {\n      STRSIZE 13;\n      STRPAD H5T_STR_NULLTERM;\n      CSET "
-                         "H5T_CSET_ASCII;\n      CTYPE H5T_C_S1;\n   }") != 0) {
-        HDprintf("dt=\n%s\n", dt_str);
-        HDfree(dt_str);
+    if (strcmp(dt_str, "H5T_STRING {\n      STRSIZE 13;\n      STRPAD H5T_STR_NULLTERM;\n      CSET "
+                       "H5T_CSET_ASCII;\n      CTYPE H5T_C_S1;\n   }") != 0) {
+        printf("dt=\n%s\n", dt_str);
+        free(dt_str);
         goto out;
     }
-    HDfree(dt_str);
+    free(dt_str);
 
     if (H5Tclose(dtype) < 0)
         goto out;
@@ -1211,62 +1277,62 @@ test_strings(void)
 
     if (H5LTdtype_to_text(dtype, NULL, H5LT_DDL, &str_len) < 0)
         goto out;
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
-    if (HDstrcmp(dt_str, "H5T_STRING {\n      STRSIZE H5T_VARIABLE;\n      STRPAD H5T_STR_NULLPAD;\n      "
-                         "CSET H5T_CSET_ASCII;\n      CTYPE H5T_C_S1;\n   }") != 0) {
-        HDprintf("dt=\n%s\n", dt_str);
-        HDfree(dt_str);
+    if (strcmp(dt_str, "H5T_STRING {\n      STRSIZE H5T_VARIABLE;\n      STRPAD H5T_STR_NULLPAD;\n      "
+                       "CSET H5T_CSET_ASCII;\n      CTYPE H5T_C_S1;\n   }") != 0) {
+        printf("dt=\n%s\n", dt_str);
+        free(dt_str);
         goto out;
     }
-    HDfree(dt_str);
+    free(dt_str);
 
     /* Length of the character buffer is larger then needed */
     str_len = str_len + 10;
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
 
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
-    if (HDstrncmp(dt_str,
-                  "H5T_STRING {\n      STRSIZE H5T_VARIABLE;\n      STRPAD H5T_STR_NULLPAD;\n      CSET "
-                  "H5T_CSET_ASCII;\n      CTYPE H5T_C_S1;\n   }",
-                  str_len - 1) != 0) {
-        HDprintf("dt=\n%s\n", dt_str);
-        HDfree(dt_str);
+    if (strncmp(dt_str,
+                "H5T_STRING {\n      STRSIZE H5T_VARIABLE;\n      STRPAD H5T_STR_NULLPAD;\n      CSET "
+                "H5T_CSET_ASCII;\n      CTYPE H5T_C_S1;\n   }",
+                str_len - 1) != 0) {
+        printf("dt=\n%s\n", dt_str);
+        free(dt_str);
         goto out;
     }
-    HDfree(dt_str);
+    free(dt_str);
 
     /* Length of the character buffer is smaller then needed */
     str_len = 21;
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
 
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
     /* check the truncated string */
-    if (HDstrlen(dt_str) != str_len - 1)
+    if (strlen(dt_str) != str_len - 1)
         goto out;
-    str_len = HDstrlen(dt_str);
-    if (HDstrncmp(dt_str,
-                  "H5T_STRING {\n      STRSIZE H5T_VARIABLE;\n      STRPAD H5T_STR_NULLPAD;\n      CSET "
-                  "H5T_CSET_ASCII;\n      CTYPE H5T_C_S1;\n   }",
-                  str_len) != 0) {
-        HDprintf("dt=\n%s\n", dt_str);
-        HDfree(dt_str);
+    str_len = strlen(dt_str);
+    if (strncmp(dt_str,
+                "H5T_STRING {\n      STRSIZE H5T_VARIABLE;\n      STRPAD H5T_STR_NULLPAD;\n      CSET "
+                "H5T_CSET_ASCII;\n      CTYPE H5T_C_S1;\n   }",
+                str_len) != 0) {
+        printf("dt=\n%s\n", dt_str);
+        free(dt_str);
         goto out;
     }
 
-    HDfree(dt_str);
+    free(dt_str);
 
     if (H5Tclose(dtype) < 0)
         goto out;
@@ -1276,7 +1342,7 @@ test_strings(void)
 
 out:
     if (dt_str)
-        HDfree(dt_str);
+        free(dt_str);
 
     H5_FAILED();
     return -1;
@@ -1313,21 +1379,20 @@ test_opaques(void)
 
     if (H5LTdtype_to_text(dtype, NULL, H5LT_DDL, &str_len) < 0)
         goto out;
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
-    if (HDstrcmp(
-            dt_str,
-            "H5T_OPAQUE {\n      OPQ_SIZE 19;\n      OPQ_TAG \"This is a tag for opaque type\";\n   }") !=
+    if (strcmp(dt_str,
+               "H5T_OPAQUE {\n      OPQ_SIZE 19;\n      OPQ_TAG \"This is a tag for opaque type\";\n   }") !=
         0) {
-        HDprintf("dt=\n%s\n", dt_str);
-        HDfree(dt_str);
+        printf("dt=\n%s\n", dt_str);
+        free(dt_str);
         goto out;
     }
-    HDfree(dt_str);
+    free(dt_str);
 
     if (H5Tclose(dtype) < 0)
         goto out;
@@ -1376,7 +1441,7 @@ test_enums(void)
 
     if (H5Tenum_nameof(dtype, &value1, name1, size) < 0)
         goto out;
-    if (HDstrcmp(name1, "BLUE") != 0)
+    if (strcmp(name1, "BLUE") != 0)
         goto out;
 
     if (H5Tenum_valueof(dtype, name2, &value2) < 0)
@@ -1393,22 +1458,22 @@ test_enums(void)
 
     if (H5LTdtype_to_text(dtype, NULL, H5LT_DDL, &str_len) < 0)
         goto out;
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
-    if (HDstrcmp(dt_str,
-                 "H5T_ENUM {\n      H5T_STD_I32LE;\n      \"RED\"              5;\n      \"GREEN\"   "
-                 "         6;\n      \"BLUE\"             7;\n      \"WHITE\"            8;\n   }") != 0) {
+    if (strcmp(dt_str,
+               "H5T_ENUM {\n      H5T_STD_I32LE;\n      \"RED\"              5;\n      \"GREEN\"   "
+               "         6;\n      \"BLUE\"             7;\n      \"WHITE\"            8;\n   }") != 0) {
 
-        HDprintf("dt=\n%s\n", dt_str);
-        HDfree(dt_str);
+        printf("dt=\n%s\n", dt_str);
+        free(dt_str);
         goto out;
     }
 
-    HDfree(dt_str);
+    free(dt_str);
 
     if (H5Tclose(dtype) < 0)
         goto out;
@@ -1457,18 +1522,18 @@ test_variables(void)
 
     if (H5LTdtype_to_text(dtype, NULL, H5LT_DDL, &str_len) < 0)
         goto out;
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
-    if (HDstrcmp(dt_str, "H5T_VLEN {\n      H5T_VLEN {\n         H5T_STD_I32BE\n      }\n   }") != 0) {
-        HDprintf("dt=\n%s\n", dt_str);
-        HDfree(dt_str);
+    if (strcmp(dt_str, "H5T_VLEN {\n      H5T_VLEN {\n         H5T_STD_I32BE\n      }\n   }") != 0) {
+        printf("dt=\n%s\n", dt_str);
+        free(dt_str);
         goto out;
     }
-    HDfree(dt_str);
+    free(dt_str);
 
     if (H5Tclose(dtype) < 0)
         goto out;
@@ -1519,21 +1584,21 @@ test_arrays(void)
 
     if (H5LTdtype_to_text(dtype, NULL, H5LT_DDL, &str_len) < 0)
         goto out;
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
-    if (HDstrcmp(dt_str, "H5T_ARRAY {\n      [5][7][13] H5T_ARRAY {\n         [17][19] H5T_COMPOUND {\n      "
-                         "      H5T_STD_I8BE \"arr_compound_1\" : 0;\n            H5T_STD_I32BE "
-                         "\"arr_compound_2\" : 1;\n         }\n      }\n   }") != 0) {
-        HDprintf("dt=\n%s\n", dt_str);
-        HDfree(dt_str);
+    if (strcmp(dt_str, "H5T_ARRAY {\n      [5][7][13] H5T_ARRAY {\n         [17][19] H5T_COMPOUND {\n      "
+                       "      H5T_STD_I8BE \"arr_compound_1\" : 0;\n            H5T_STD_I32BE "
+                       "\"arr_compound_2\" : 1;\n         }\n      }\n   }") != 0) {
+        printf("dt=\n%s\n", dt_str);
+        free(dt_str);
         goto out;
     }
 
-    HDfree(dt_str);
+    free(dt_str);
 
     if (H5Tclose(dtype) < 0)
         goto out;
@@ -1580,19 +1645,19 @@ test_compounds(void)
 
     if (H5LTdtype_to_text(dtype, NULL, H5LT_DDL, &str_len) < 0)
         goto out;
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
-    if (HDstrcmp(dt_str, "H5T_COMPOUND {\n      H5T_STD_I16BE \"one_field\" : 2;\n      H5T_STD_U8LE "
-                         "\"two_field\" : 6;\n   }") != 0) {
-        HDprintf("dt=\n%s\n", dt_str);
-        HDfree(dt_str);
+    if (strcmp(dt_str, "H5T_COMPOUND {\n      H5T_STD_I16BE \"one_field\" : 2;\n      H5T_STD_U8LE "
+                       "\"two_field\" : 6;\n   }") != 0) {
+        printf("dt=\n%s\n", dt_str);
+        free(dt_str);
         goto out;
     }
-    HDfree(dt_str);
+    free(dt_str);
 
     if (H5Tclose(dtype) < 0)
         goto out;
@@ -1606,7 +1671,7 @@ test_compounds(void)
 
     if ((memb_name = H5Tget_member_name(dtype, 1)) == NULL)
         goto out;
-    if (HDstrcmp(memb_name, "i16_field") != 0) {
+    if (strcmp(memb_name, "i16_field") != 0) {
         H5free_memory(memb_name);
         goto out;
     }
@@ -1684,7 +1749,7 @@ test_compound_bug(void)
 
     if ((memb_name = H5Tget_member_name(dtype, 2)) == NULL)
         goto out;
-    if (HDstrcmp(memb_name, "sub") != 0) {
+    if (strcmp(memb_name, "sub") != 0) {
         H5free_memory(memb_name);
         goto out;
     }
@@ -1693,13 +1758,13 @@ test_compound_bug(void)
     if (H5LTdtype_to_text(dtype, NULL, H5LT_DDL, &str_len) < 0)
         goto out;
 
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
-    HDfree(dt_str);
+    free(dt_str);
 
     if (H5Tclose(dtype) < 0)
         goto out;
@@ -1720,8 +1785,8 @@ test_compound_bug(void)
 
     if ((memb_name = H5Tget_member_name(dtype, 1)) == NULL)
         goto out;
-    if (HDstrcmp(memb_name, "desc____________________________________________________________________________"
-                            "_____________") != 0) {
+    if (strcmp(memb_name, "desc____________________________________________________________________________"
+                          "_____________") != 0) {
         H5free_memory(memb_name);
         goto out;
     }
@@ -1730,14 +1795,14 @@ test_compound_bug(void)
     if (H5LTdtype_to_text(dtype, NULL, H5LT_DDL, &str_len) < 0)
         goto out;
 
-    if (NULL == (dt_str = (char *)HDcalloc(str_len, sizeof(char))))
+    if (NULL == (dt_str = (char *)calloc(str_len, sizeof(char))))
         goto out;
     if (H5LTdtype_to_text(dtype, dt_str, H5LT_DDL, &str_len) < 0) {
-        HDfree(dt_str);
+        free(dt_str);
         goto out;
     }
 
-    HDfree(dt_str);
+    free(dt_str);
 
     if (H5Tclose(dtype) < 0)
         goto out;
@@ -1768,9 +1833,9 @@ test_complicated_compound(void)
     HL_TESTING3("        text for complicated compound types");
 
     /* Open input file */
-    fp = HDfopen(filename, "r");
+    fp = fopen(filename, "r");
     if (fp == NULL) {
-        HDprintf("Could not find file %s. Try set $srcdir \n", filename);
+        printf("Could not find file %s. Try set $srcdir \n", filename);
         goto out;
     }
 
@@ -1778,23 +1843,23 @@ test_complicated_compound(void)
      * Library has convenient function getline() but isn't available on
      * all machines.
      */
-    if ((line = (char *)HDcalloc(size, sizeof(char))) == NULL)
+    if ((line = (char *)calloc(size, sizeof(char))) == NULL)
         goto out;
-    if (HDfgets(line, (int)size, fp) == NULL)
+    if (fgets(line, (int)size, fp) == NULL)
         goto out;
-    while (HDstrlen(line) == size - 1) {
+    while (strlen(line) == size - 1) {
         size *= 2;
         if (line)
-            HDfree(line);
-        if ((line = (char *)HDcalloc(size, sizeof(char))) == NULL)
+            free(line);
+        if ((line = (char *)calloc(size, sizeof(char))) == NULL)
             goto out;
         if (HDfseek(fp, 0L, SEEK_SET) != 0)
             goto out;
-        if (HDfgets(line, (int)size, fp) == NULL)
+        if (fgets(line, (int)size, fp) == NULL)
             goto out;
     }
 
-    HDfclose(fp);
+    fclose(fp);
     fp = NULL;
 
     if ((dtype = H5LTtext_to_dtype(line, H5LT_DDL)) < 0)
@@ -1812,7 +1877,7 @@ test_complicated_compound(void)
         goto out;
 
     if (line)
-        HDfree(line);
+        free(line);
 
     PASSED();
     return 0;
@@ -1820,9 +1885,9 @@ test_complicated_compound(void)
 out:
 
     if (line)
-        HDfree(line);
+        free(line);
     if (fp)
-        HDfclose(fp);
+        fclose(fp);
 
     H5_FAILED();
     return -1;
@@ -1837,6 +1902,7 @@ test_text_dtype(void)
 {
     HL_TESTING2("H5LTtext_to_dtype");
 
+    printf("\n");
     if (test_integers() < 0)
         goto out;
 
