@@ -20,13 +20,11 @@
 **  Title:       GIFHEAD.C                                                  **
 **  Purpose:     Display the data in a GIF image file.                      **
 **  Version:     1.0                                                        **
-**  Date:        March 1992                                                 **
-**  Author:      James D. Murray, Anaheim, CA, USA                          **
 **  C Compilers: Borland C++ v2.0, Microsoft C v6.00a                       **
 **                                                                          **
 **  GIFHEAD displays all real information contained within a GIF image      **
 **  file, including all color tables and extension block information.       **
-**  GIFHEAD reads both GIF 87a abd 89a-format files.                        **
+**  GIFHEAD reads both GIF 87a and 89a-format files.                        **
 **                                                                          **
 **  Copyright (C) 1991-92 by Graphics Software Labs.  All rights reserved.  **
 \****************************************************************************/
@@ -48,22 +46,22 @@ Gif2Mem(GIFBYTE *MemGif, GIFTOMEM *GifMemoryStruct)
     GIFCOMMENT        **gifComment;        /* Comment Extension structure     */
     GIFGRAPHICCONTROL **gifGraphicControl; /* Graphic Control Extension strct */
 
-    register GIFWORD i;          /* Loop counter                                 */
-    GIFBYTE          Identifier; /* Extension block identifier holder            */
-    GIFBYTE          Label;      /* Extension block label holder                 */
-    GIFBYTE          ImageCount; /* Count of the number of images in the file    */
-    GIFBYTE          ImageArray; /* Keep the size of the array to store Images   */
-    GIFBYTE          CommentCount;
-    GIFBYTE          CommentArray;
-    GIFBYTE          ApplicationCount;
-    GIFBYTE          ApplicationArray;
-    GIFBYTE          PlainTextCount;
-    GIFBYTE          PlainTextArray;
-    GIFBYTE          GCEflag;
-    GIFBYTE          aTemp;
-    GIFBYTE          j;
-    GIFBYTE          w; /* Two more variables needed only while testing */
-    GIFBYTE         *b; /* Endian Ordering                              */
+    GIFWORD  i;          /* Loop counter                                 */
+    GIFBYTE  Identifier; /* Extension block identifier holder            */
+    GIFBYTE  Label;      /* Extension block label holder                 */
+    GIFBYTE  ImageCount; /* Count of the number of images in the file    */
+    GIFBYTE  ImageArray; /* Keep the size of the array to store Images   */
+    GIFBYTE  CommentCount;
+    GIFBYTE  CommentArray;
+    GIFBYTE  ApplicationCount;
+    GIFBYTE  ApplicationArray;
+    GIFBYTE  PlainTextCount;
+    GIFBYTE  PlainTextArray;
+    GIFBYTE  GCEflag;
+    GIFBYTE  aTemp;
+    GIFBYTE  j;
+    GIFBYTE  w; /* Two more variables needed only while testing */
+    GIFBYTE *b; /* Endian Ordering                              */
 
     /* Allocate memory for the GIF structures           */
     /* Plug the structs into GifMemoryStruct at the end */
