@@ -10,12 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/*
- *  For details of the HDF libraries, see the HDF Documentation at:
- *    http://hdfgroup.org/HDF5/doc/
- *
- */
-
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -126,7 +120,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1name(JNIEnv *env, jclass clss, jlong file_id)
     if ((buf_size = H5Fget_name((hid_t)file_id, NULL, 0)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
-    if (NULL == (namePtr = (char *)HDmalloc(sizeof(char) * (size_t)buf_size + 1)))
+    if (NULL == (namePtr = (char *)malloc(sizeof(char) * (size_t)buf_size + 1)))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Fget_name: malloc failed");
 
     if ((H5Fget_name((hid_t)file_id, namePtr, (size_t)buf_size + 1)) < 0)
@@ -138,7 +132,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1name(JNIEnv *env, jclass clss, jlong file_id)
 
 done:
     if (namePtr)
-        HDfree(namePtr);
+        free(namePtr);
 
     return str;
 } /* end Java_hdf_hdf5lib_H5_H5Fget_1name */
@@ -151,11 +145,17 @@ done:
 JNIEXPORT jboolean JNICALL
 Java_hdf_hdf5lib_H5_H5Fis_1hdf5(JNIEnv *env, jclass clss, jstring name)
 {
+#ifndef H5_NO_DEPRECATED_SYMBOLS
     const char *fileName = NULL;
-    htri_t      bval     = JNI_FALSE;
+#endif
+    htri_t bval = JNI_FALSE;
 
     UNUSED(clss);
 
+#ifdef H5_NO_DEPRECATED_SYMBOLS
+    UNUSED(name);
+    H5_UNIMPLEMENTED(ENVONLY, "H5Fis_hdf5: not implemented");
+#else
     if (NULL == name)
         H5_NULL_ARGUMENT_ERROR(ENVONLY, "H5Fis_hdf5: file name is NULL");
 
@@ -165,13 +165,46 @@ Java_hdf_hdf5lib_H5_H5Fis_1hdf5(JNIEnv *env, jclass clss, jstring name)
         H5_LIBRARY_ERROR(ENVONLY);
 
     bval = (bval > 0) ? JNI_TRUE : JNI_FALSE;
+#endif
+
+done:
+#ifndef H5_NO_DEPRECATED_SYMBOLS
+    if (fileName)
+        UNPIN_JAVA_STRING(ENVONLY, name, fileName);
+#endif
+
+    return (jboolean)bval;
+} /* end Java_hdf_hdf5lib_H5_H5Fis_1hdf5 */
+
+/*
+ * Class:     hdf_hdf5lib_H5
+ * Method:    H5Fis_accessible
+ * Signature: (Ljava/lang/String;J)Z
+ */
+JNIEXPORT jboolean JNICALL
+Java_hdf_hdf5lib_H5_H5Fis_1accessible(JNIEnv *env, jclass clss, jstring name, jlong fapl_id)
+{
+    const char *fileName = NULL;
+    htri_t      bval     = JNI_FALSE;
+
+    UNUSED(clss);
+
+    if (NULL == name)
+        H5_NULL_ARGUMENT_ERROR(ENVONLY, "H5Fis_accessible: file name is NULL");
+
+    PIN_JAVA_STRING(ENVONLY, name, fileName, NULL, "H5Fis_accessible: file name not pinned");
+
+    if ((bval = H5Fis_accessible(fileName, (hid_t)fapl_id)) < 0)
+        H5_LIBRARY_ERROR(ENVONLY);
+
+    bval = (bval > 0) ? JNI_TRUE : JNI_FALSE;
 
 done:
     if (fileName)
         UNPIN_JAVA_STRING(ENVONLY, name, fileName);
 
     return (jboolean)bval;
-} /* end Java_hdf_hdf5lib_H5_H5Fis_1hdf5 */
+} /* end Java_hdf_hdf5lib_H5_H5Fis_1accessible */
 
 /*
  * Class:     hdf_hdf5lib_H5
@@ -230,6 +263,25 @@ done:
     return (jint)intent;
 } /* end Java_hdf_hdf5lib_H5_H5Fget_1intent */
 
+/*
+ * Class:     hdf_hdf5lib_H5
+ * Method:    H5Fget_fileno
+ * Signature: (J)J
+ */
+JNIEXPORT jlong JNICALL
+Java_hdf_hdf5lib_H5_H5Fget_1fileno(JNIEnv *env, jclass clss, jlong file_id)
+{
+    unsigned long fileno = 0;
+
+    UNUSED(clss);
+
+    if (H5Fget_fileno((hid_t)file_id, &fileno) < 0)
+        H5_LIBRARY_ERROR(ENVONLY);
+
+done:
+    return (jlong)fileno;
+} /* end Java_hdf_hdf5lib_H5_H5Fget_1fileno */
+
 /*
  * Class:     hdf_hdf5lib_H5
  * Method:    H5Fclose
@@ -372,7 +424,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1obj_1ids(JNIEnv *env, jclass clss, jlong file_id, ji
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Fget_obj_ids: obj_id_list length < 0");
     }
 
-    if (NULL == (id_list = (hid_t *)HDmalloc((size_t)rank * sizeof(hid_t))))
+    if (NULL == (id_list = (hid_t *)malloc((size_t)rank * sizeof(hid_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Fget_obj_ids: malloc failed");
 
     if ((ret_val = H5Fget_obj_ids((hid_t)file_id, (unsigned int)types, (size_t)maxObjs, id_list)) < 0)
@@ -384,7 +436,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1obj_1ids(JNIEnv *env, jclass clss, jlong file_id, ji
 
 done:
     if (id_list)
-        HDfree(id_list);
+        free(id_list);
     if (obj_id_listP)
         UNPIN_LONG_ARRAY(ENVONLY, obj_id_list, obj_id_listP, (ret_val < 0) ? JNI_ABORT : 0);
 
@@ -630,8 +682,8 @@ Java_hdf_hdf5lib_H5_H5Fget_1mdc_1logging_1status(JNIEnv *env, jclass clss, jlong
 {
     jboolean *mdc_logging_status_ptr = NULL;
     jboolean  isCopy;
-    hbool_t   is_enabled;
-    hbool_t   is_currently_logging;
+    bool      is_enabled;
+    bool      is_currently_logging;
     jsize     size;
 
     UNUSED(clss);
@@ -671,19 +723,19 @@ done:
 JNIEXPORT void JNICALL
 Java_hdf_hdf5lib_H5_H5Fset_1dset_1no_1attrs_1hint(JNIEnv *env, jclass clss, jlong file_id, jboolean minimize)
 {
-    hbool_t minimize_val;
-    herr_t  retVal = FAIL;
+    bool   minimize_val;
+    herr_t retVal = FAIL;
 
     UNUSED(clss);
 
-    minimize_val = (minimize == JNI_TRUE) ? TRUE : FALSE;
+    minimize_val = (minimize == JNI_TRUE) ? true : false;
 
-    if ((retVal = H5Fset_dset_no_attrs_hint((hid_t)file_id, (hbool_t)minimize_val)) < 0)
+    if ((retVal = H5Fset_dset_no_attrs_hint((hid_t)file_id, (bool)minimize_val)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
     return;
-}
+} /* end Java_hdf_hdf5lib_H5_H5Fset_1dset_1no_1attrs_1hint */
 
 /*
  * Class:     hdf_hdf5lib_H5
@@ -694,19 +746,19 @@ JNIEXPORT jboolean JNICALL
 Java_hdf_hdf5lib_H5_H5Fget_1dset_1no_1attrs_1hint(JNIEnv *env, jclass clss, jlong file_id)
 {
     jboolean bval     = JNI_FALSE;
-    hbool_t  minimize = FALSE;
+    bool     minimize = false;
 
     UNUSED(clss);
 
-    if (H5Fget_dset_no_attrs_hint((hid_t)file_id, (hbool_t *)&minimize) < 0)
+    if (H5Fget_dset_no_attrs_hint((hid_t)file_id, (bool *)&minimize) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
-    if (minimize == TRUE)
+    if (minimize == true)
         bval = JNI_TRUE;
 
 done:
     return bval;
-}
+} /* end Java_hdf_hdf5lib_H5_H5Fget_1dset_1no_1attrs_1hint */
 
 /*
  * Class:     hdf_hdf5lib_H5
