@@ -10,12 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/*
- *  For details of the HDF libraries, see the HDF Documentation at:
- *    http://hdfgroup.org/HDF5/doc/
- *
- */
-
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -30,54 +24,6 @@ extern "C" {
  */
 /* extern JavaVM *jvm; */
 
-/*
- * Class:     hdf_hdf5lib_H5
- * Method:    H5Pget_version
- * Signature: (J[I)I
- */
-JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Pget_1version(JNIEnv *env, jclass clss, jlong plist, jintArray version_info)
-{
-#ifndef H5_NO_DEPRECATED_SYMBOLS
-    jboolean isCopy;
-    jsize    arrLen;
-    jint    *theArray = NULL;
-#endif
-    herr_t status = FAIL;
-
-    UNUSED(clss);
-
-#ifdef H5_NO_DEPRECATED_SYMBOLS
-    UNUSED(plist);
-    UNUSED(version_info);
-    H5_UNIMPLEMENTED(ENVONLY, "H5Pget_version: not implemented");
-#else
-    if (NULL == version_info)
-        H5_NULL_ARGUMENT_ERROR(ENVONLY, "H5Pget_version: version_info input array is NULL");
-
-    if ((arrLen = ENVPTR->GetArrayLength(ENVONLY, version_info)) < 0) {
-        CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-        H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Pget_version: version_info array length < 0");
-    }
-    if (arrLen < 4)
-        H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Pget_version: version_info input array length < 4");
-
-    PIN_INT_ARRAY(ENVONLY, version_info, theArray, &isCopy, "H5Pget_version: version_info not pinned");
-
-    if ((status = H5Pget_version((hid_t)plist, (unsigned *)&(theArray[0]), (unsigned *)&(theArray[1]),
-                                 (unsigned *)&(theArray[2]), (unsigned *)&(theArray[3]))) < 0)
-        H5_LIBRARY_ERROR(ENVONLY);
-#endif
-
-done:
-#ifndef H5_NO_DEPRECATED_SYMBOLS
-    if (theArray)
-        UNPIN_INT_ARRAY(ENVONLY, version_info, theArray, (status < 0) ? JNI_ABORT : 0);
-#endif
-
-    return (jint)status;
-} /* end Java_hdf_hdf5lib_H5_H5Pget_1version */
-
 /*
  * Class:     hdf_hdf5lib_H5
  * Method:    H5Pset_userblock
@@ -342,7 +288,7 @@ Java_hdf_hdf5lib_H5_H5Pset_1file_1space_1strategy(JNIEnv *env, jclass clss, jlon
 {
     UNUSED(clss);
 
-    if (H5Pset_file_space_strategy((hid_t)fcpl_id, (H5F_fspace_strategy_t)strategy, (hbool_t)persist,
+    if (H5Pset_file_space_strategy((hid_t)fcpl_id, (H5F_fspace_strategy_t)strategy, (bool)persist,
                                    (hsize_t)threshold) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
@@ -373,7 +319,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1file_1space_1strategy(JNIEnv *env, jclass clss, jlon
         PIN_LONG_ARRAY(ENVONLY, threshold, thresholdArray, &isCopy,
                        "H5Pget_file_space: threshold not pinned");
 
-    if ((status = H5Pget_file_space_strategy((hid_t)fcpl_id, &thestrategy, (hbool_t *)persistArray,
+    if ((status = H5Pget_file_space_strategy((hid_t)fcpl_id, &thestrategy, (bool *)persistArray,
                                              (hsize_t *)thresholdArray)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
@@ -394,8 +340,8 @@ done:
 JNIEXPORT jboolean JNICALL
 Java_hdf_hdf5lib_H5_H5Pget_1file_1space_1strategy_1persist(JNIEnv *env, jclass clss, jlong fcpl_id)
 {
-    hbool_t persist = FALSE;
-    herr_t  status  = FAIL;
+    bool   persist = false;
+    herr_t status  = FAIL;
 
     UNUSED(clss);
 
