@@ -10,12 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/*
- *  For details of the HDF libraries, see the HDF Documentation at:
- *    http://hdfgroup.org/HDF5/doc/
- *
- */
-
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -95,7 +89,7 @@ Java_hdf_hdf5lib_H5__1H5Screate_1simple(JNIEnv *env, jclass clss, jint rank, jlo
 
     PIN_LONG_ARRAY(ENVONLY, dims, dimsP, &isCopy, "H5Screate_simple: dims not pinned");
 
-    if (NULL == (sa = lp = (hsize_t *)HDmalloc((size_t)rank * sizeof(hsize_t))))
+    if (NULL == (sa = lp = (hsize_t *)malloc((size_t)rank * sizeof(hsize_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Screate_simple: failed to allocate dims buffer");
 
     jlp = (jlong *)dimsP;
@@ -112,7 +106,7 @@ Java_hdf_hdf5lib_H5__1H5Screate_1simple(JNIEnv *env, jclass clss, jint rank, jlo
     else {
         PIN_LONG_ARRAY(ENVONLY, maxdims, maxdimsP, &isCopy, "H5Screate_simple: maxdims not pinned");
 
-        if (NULL == (msa = lp = (hsize_t *)HDmalloc((size_t)rank * sizeof(hsize_t))))
+        if (NULL == (msa = lp = (hsize_t *)malloc((size_t)rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Screate_simple: failed to allocate maxdims buffer");
 
         jlp = (jlong *)maxdimsP;
@@ -128,11 +122,11 @@ Java_hdf_hdf5lib_H5__1H5Screate_1simple(JNIEnv *env, jclass clss, jint rank, jlo
 
 done:
     if (msa)
-        HDfree(msa);
+        free(msa);
     if (maxdimsP)
         UNPIN_LONG_ARRAY(ENVONLY, maxdims, maxdimsP, JNI_ABORT);
     if (sa)
-        HDfree(sa);
+        free(sa);
     if (dimsP)
         UNPIN_LONG_ARRAY(ENVONLY, dims, dimsP, JNI_ABORT);
 
@@ -191,7 +185,7 @@ Java_hdf_hdf5lib_H5_H5Sselect_1elements(JNIEnv *env, jclass clss, jlong space_id
 
     PIN_LONG_ARRAY(ENVONLY, coords, P, &isCopy, "H5Sselect_elements: coords not pinned");
 
-    if (NULL == (sa = (hssize_t *)HDmalloc((size_t)num_elemn * 2 * sizeof(hssize_t))))
+    if (NULL == (sa = (hssize_t *)malloc((size_t)num_elemn * 2 * sizeof(hssize_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sselect_elements: failed to allocate coordinate buffer");
 
     for (i = 0; i < (num_elemn * 2); i++) {
@@ -203,7 +197,7 @@ Java_hdf_hdf5lib_H5_H5Sselect_1elements(JNIEnv *env, jclass clss, jlong space_id
 
 done:
     if (sa)
-        HDfree(sa);
+        free(sa);
     if (P)
         UNPIN_LONG_ARRAY(ENVONLY, coords, P, JNI_ABORT);
 
@@ -221,13 +215,11 @@ Java_hdf_hdf5lib_H5_H5Sselect_1elements(JNIEnv *env, jclass clss, jlong space_id
                                         jbyteArray coords)
 {
     jboolean isCopy;
-    hsize_t *lp  = NULL;
-    hsize_t *llp = NULL;
-    jlong   *jlp = NULL;
-    jbyte   *P   = NULL;
+    hsize_t *coords_p     = NULL;
+    uint8_t *pinned_arr_p = NULL;
+    jbyte   *pinned_arr   = NULL;
     jsize    size;
-    int      ii;
-    int      nlongs;
+    size_t   nlongs;
     herr_t   status = FAIL;
 
     UNUSED(clss);
@@ -235,35 +227,40 @@ Java_hdf_hdf5lib_H5_H5Sselect_1elements(JNIEnv *env, jclass clss, jlong space_id
     if (NULL == coords)
         H5_NULL_ARGUMENT_ERROR(ENVONLY, "H5Sselect_elements: coords is NULL");
 
-    PIN_BYTE_ARRAY(ENVONLY, coords, P, &isCopy, "H5Sselect_elements: coords not pinned");
+    PIN_BYTE_ARRAY(ENVONLY, coords, pinned_arr, &isCopy, "H5Sselect_elements: coords not pinned");
 
     if ((size = ENVPTR->GetArrayLength(ENVONLY, coords)) < 0) {
         CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Sselect_elements: coords array length < 0");
     }
 
-    nlongs = (int)((size_t)size / sizeof(jlong));
+    nlongs = (size_t)size / sizeof(jlong);
 
-    if (NULL == (lp = (hsize_t *)HDmalloc((size_t)nlongs * sizeof(hsize_t))))
+    if (NULL == (coords_p = malloc(nlongs * sizeof(hsize_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sselect_elements: failed to allocate coordinate buffer");
 
-    jlp = (jlong *)P;
-    llp = lp;
-    for (ii = 0; ii < nlongs; ii++) {
-        *lp = (hsize_t)*jlp;
-        lp++;
-        jlp++;
-    } /* end for */
+    pinned_arr_p = (uint8_t *)pinned_arr;
+    for (size_t i = 0; i < nlongs; i++) {
+        jlong coord_elem;
 
-    if ((status = H5Sselect_elements(space_id, (H5S_seloper_t)op, (size_t)num_elemn, (const hsize_t *)llp)) <
-        0)
+        memcpy(&coord_elem, pinned_arr_p, sizeof(jlong));
+
+        if (coord_elem < 0)
+            H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Sselect_elements: coordinate element can't be negative");
+
+        coords_p[i] = (hsize_t)coord_elem;
+
+        pinned_arr_p += sizeof(jlong);
+    }
+
+    if ((status = H5Sselect_elements(space_id, (H5S_seloper_t)op, (size_t)num_elemn, coords_p)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
-    if (llp)
-        HDfree(llp);
-    if (P)
-        UNPIN_BYTE_ARRAY(ENVONLY, coords, P, JNI_ABORT);
+    free(coords_p);
+
+    if (pinned_arr)
+        UNPIN_BYTE_ARRAY(ENVONLY, coords, pinned_arr, JNI_ABORT);
 
     return (jint)status;
 } /* end Java_hdf_hdf5lib_H5_H5Sselect_1elements */
@@ -435,7 +432,7 @@ Java_hdf_hdf5lib_H5_H5Sget_1simple_1extent_1dims(JNIEnv *env, jclass clss, jlong
             H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Sget_simple_extent_dims: dims array length < 0");
         }
 
-        if (NULL == (sa = (hsize_t *)HDmalloc((size_t)rank * sizeof(hsize_t))))
+        if (NULL == (sa = (hsize_t *)malloc((size_t)rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sget_simple_extent_dims: failed to allocate dimension buffer");
     }
 
@@ -456,7 +453,7 @@ Java_hdf_hdf5lib_H5_H5Sget_1simple_1extent_1dims(JNIEnv *env, jclass clss, jlong
         else if (mrank != rank)
             H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Sget_simple_extent_dims: maxdims rank not same as dims");
 
-        if (NULL == (msa = (hsize_t *)HDmalloc((size_t)rank * sizeof(hsize_t))))
+        if (NULL == (msa = (hsize_t *)malloc((size_t)rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY,
                                    "H5Sget_simple_extent_dims: failed to allocate maximum dimension buffer");
     }
@@ -478,11 +475,11 @@ Java_hdf_hdf5lib_H5_H5Sget_1simple_1extent_1dims(JNIEnv *env, jclass clss, jlong
 
 done:
     if (msa)
-        HDfree(msa);
+        free(msa);
     if (maxdimsP)
         UNPIN_LONG_ARRAY(ENVONLY, maxdims, maxdimsP, (status < 0) ? JNI_ABORT : 0);
     if (sa)
-        HDfree(sa);
+        free(sa);
     if (dimsP)
         UNPIN_LONG_ARRAY(ENVONLY, dims, dimsP, (status < 0) ? JNI_ABORT : 0);
 
@@ -555,7 +552,7 @@ Java_hdf_hdf5lib_H5_H5Sset_1extent_1simple(JNIEnv *env, jclass clss, jlong space
 
     PIN_LONG_ARRAY(ENVONLY, dims, dimsP, &isCopy, "H5Sset_extent_simple: dims not pinned");
 
-    if (NULL == (sa = lp = (hsize_t *)HDmalloc((size_t)rank * sizeof(hsize_t))))
+    if (NULL == (sa = lp = (hsize_t *)malloc((size_t)rank * sizeof(hsize_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sset_extent_simple: failed to allocate dimension buffer");
 
     jlp = (jlong *)dimsP;
@@ -572,7 +569,7 @@ Java_hdf_hdf5lib_H5_H5Sset_1extent_1simple(JNIEnv *env, jclass clss, jlong space
     else {
         PIN_LONG_ARRAY(ENVONLY, maxdims, maxdimsP, &isCopy, "H5Sset_extent_simple: maxdims not pinned");
 
-        if (NULL == (msa = lp = (hsize_t *)HDmalloc((size_t)rank * sizeof(hsize_t))))
+        if (NULL == (msa = lp = (hsize_t *)malloc((size_t)rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY,
                                    "H5Sset_extent_simple: failed to allocate maximum dimension buffer");
 
@@ -589,11 +586,11 @@ Java_hdf_hdf5lib_H5_H5Sset_1extent_1simple(JNIEnv *env, jclass clss, jlong space
 
 done:
     if (msa)
-        HDfree(msa);
+        free(msa);
     if (maxdimsP)
         UNPIN_LONG_ARRAY(ENVONLY, maxdims, maxdimsP, JNI_ABORT);
     if (sa)
-        HDfree(sa);
+        free(sa);
     if (dimsP)
         UNPIN_LONG_ARRAY(ENVONLY, dims, dimsP, JNI_ABORT);
 
@@ -630,49 +627,49 @@ JNIEXPORT jint JNICALL
 Java_hdf_hdf5lib_H5_H5Soffset_1simple(JNIEnv *env, jclass clss, jlong space_id, jbyteArray offset)
 {
     jboolean  isCopy;
-    hssize_t *sa = NULL;
-    hssize_t *lp = NULL;
+    hssize_t *offset_dims  = NULL;
+    uint8_t  *pinned_arr_p = NULL;
+    jbyte    *pinned_arr   = NULL;
     size_t    rank;
-    jsize     i;
-    jbyte    *P      = NULL;
-    jlong    *jlp    = NULL;
     herr_t    status = FAIL;
 
     UNUSED(clss);
 
     if (NULL != offset) {
-        PIN_BYTE_ARRAY(ENVONLY, offset, P, &isCopy, "H5Soffset_simple: offset not pinned");
+        jsize size;
 
-        if ((i = ENVPTR->GetArrayLength(ENVONLY, offset)) < 0) {
+        PIN_BYTE_ARRAY(ENVONLY, offset, pinned_arr, &isCopy, "H5Soffset_simple: offset not pinned");
+
+        if ((size = ENVPTR->GetArrayLength(ENVONLY, offset)) < 0) {
             CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
             H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Soffset_simple: offset array length < 0");
         }
 
-        rank = (size_t)i / sizeof(jlong);
+        rank = (size_t)size / sizeof(jlong);
 
-        if (NULL == (sa = lp = (hssize_t *)HDmalloc((size_t)rank * sizeof(hssize_t))))
+        if (NULL == (offset_dims = malloc((size_t)rank * sizeof(hssize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Soffset_simple: failed to allocate offset buffer");
 
-        jlp = (jlong *)P;
-        for (i = 0; (size_t)i < rank; i++) {
-            *lp = (hssize_t)*jlp;
-            lp++;
-            jlp++;
-        } /* end for */
-    }
-    else {
-        P  = NULL;
-        sa = (hssize_t *)P;
+        pinned_arr_p = (uint8_t *)pinned_arr;
+        for (size_t i = 0; i < rank; i++) {
+            jlong offset_elem;
+
+            memcpy(&offset_elem, pinned_arr_p, sizeof(jlong));
+
+            offset_dims[i] = (hssize_t)offset_elem;
+
+            pinned_arr_p += sizeof(jlong);
+        }
     }
 
-    if ((status = H5Soffset_simple(space_id, sa)) < 0)
+    if ((status = H5Soffset_simple(space_id, offset_dims)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
-    if (sa)
-        HDfree(sa);
-    if (P)
-        UNPIN_BYTE_ARRAY(ENVONLY, offset, P, JNI_ABORT);
+    free(offset_dims);
+
+    if (pinned_arr)
+        UNPIN_BYTE_ARRAY(ENVONLY, offset, pinned_arr, JNI_ABORT);
 
     return (jint)status;
 } /* end Java_hdf_hdf5lib_H5_H5Soffset_1simple */
@@ -775,7 +772,7 @@ Java_hdf_hdf5lib_H5_H5Sselect_1hyperslab(JNIEnv *env, jclass clss, jlong space_i
 
     PIN_LONG_ARRAY(ENVONLY, start, startP, &isCopy, "H5Sselect_hyperslab: start not pinned");
 
-    if (NULL == (strt = lp = (hsize_t *)HDmalloc((size_t)start_rank * sizeof(hsize_t))))
+    if (NULL == (strt = lp = (hsize_t *)malloc((size_t)start_rank * sizeof(hsize_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sselect_hyperslab: failed to allocate start buffer");
 
     jlp = (jlong *)startP;
@@ -787,7 +784,7 @@ Java_hdf_hdf5lib_H5_H5Sselect_1hyperslab(JNIEnv *env, jclass clss, jlong space_i
 
     PIN_LONG_ARRAY(ENVONLY, count, countP, &isCopy, "H5Sselect_hyperslab: count not pinned");
 
-    if (NULL == (cnt = lp = (hsize_t *)HDmalloc((size_t)count_rank * sizeof(hsize_t))))
+    if (NULL == (cnt = lp = (hsize_t *)malloc((size_t)count_rank * sizeof(hsize_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sselect_hyperslab: failed to allocate count buffer");
 
     jlp = (jlong *)countP;
@@ -812,7 +809,7 @@ Java_hdf_hdf5lib_H5_H5Sselect_1hyperslab(JNIEnv *env, jclass clss, jlong space_i
 
         PIN_LONG_ARRAY(ENVONLY, stride, strideP, &isCopy, "H5Sselect_hyperslab: stride not pinned");
 
-        if (NULL == (strd = lp = (hsize_t *)HDmalloc((size_t)stride_rank * sizeof(hsize_t))))
+        if (NULL == (strd = lp = (hsize_t *)malloc((size_t)stride_rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sselect_hyperslab: failed to allocate stride buffer");
 
         jlp = (jlong *)strideP;
@@ -838,7 +835,7 @@ Java_hdf_hdf5lib_H5_H5Sselect_1hyperslab(JNIEnv *env, jclass clss, jlong space_i
 
         PIN_LONG_ARRAY(ENVONLY, block, blockP, &isCopy, "H5Sselect_hyperslab: block not pinned");
 
-        if (NULL == (blk = lp = (hsize_t *)HDmalloc((size_t)block_rank * sizeof(hsize_t))))
+        if (NULL == (blk = lp = (hsize_t *)malloc((size_t)block_rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sselect_hyperslab: failed to allocate block buffer");
 
         jlp = (jlong *)blockP;
@@ -855,19 +852,19 @@ Java_hdf_hdf5lib_H5_H5Sselect_1hyperslab(JNIEnv *env, jclass clss, jlong space_i
 
 done:
     if (blk)
-        HDfree(blk);
+        free(blk);
     if (blockP)
         UNPIN_LONG_ARRAY(ENVONLY, block, blockP, JNI_ABORT);
     if (strd)
-        HDfree(strd);
+        free(strd);
     if (strideP)
         UNPIN_LONG_ARRAY(ENVONLY, stride, strideP, JNI_ABORT);
     if (cnt)
-        HDfree(cnt);
+        free(cnt);
     if (countP)
         UNPIN_LONG_ARRAY(ENVONLY, count, countP, JNI_ABORT);
     if (strt)
-        HDfree(strt);
+        free(strt);
     if (startP)
         UNPIN_LONG_ARRAY(ENVONLY, start, startP, JNI_ABORT);
 
@@ -972,7 +969,7 @@ Java_hdf_hdf5lib_H5_H5Sget_1select_1hyper_1blocklist(JNIEnv *env, jclass clss, j
     PIN_LONG_ARRAY(ENVONLY, buf, bufP, &isCopy, "H5Sget_select_hyper_blocklist: buffer not pinned");
 
     buf_size = (size_t)numblocks * (size_t)2 * (size_t)rank * sizeof(hsize_t);
-    if (NULL == (ba = (hsize_t *)HDmalloc(buf_size)))
+    if (NULL == (ba = (hsize_t *)malloc(buf_size)))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY,
                                "H5Sget_select_hyper_blocklist: failed to allocate block list buffer");
 
@@ -986,7 +983,7 @@ Java_hdf_hdf5lib_H5_H5Sget_1select_1hyper_1blocklist(JNIEnv *env, jclass clss, j
 
 done:
     if (ba)
-        HDfree(ba);
+        free(ba);
     if (bufP)
         UNPIN_LONG_ARRAY(ENVONLY, buf, bufP, (status < 0) ? JNI_ABORT : 0);
 
@@ -1030,7 +1027,7 @@ Java_hdf_hdf5lib_H5_H5Sget_1select_1elem_1pointlist(JNIEnv *env, jclass clss, jl
 
     PIN_LONG_ARRAY(ENVONLY, buf, bufP, &isCopy, "H5Sget_select_elem_pointlist: buffer not pinned");
 
-    if (NULL == (ba = (hsize_t *)HDmalloc(((size_t)numpoints * (size_t)rank) * sizeof(hsize_t))))
+    if (NULL == (ba = (hsize_t *)malloc(((size_t)numpoints * (size_t)rank) * sizeof(hsize_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sget_select_elem_pointlist: failed to allocate point list buffer");
 
     if ((status = H5Sget_select_elem_pointlist((hid_t)spaceid, (hsize_t)startpoint, (hsize_t)numpoints,
@@ -1043,7 +1040,7 @@ Java_hdf_hdf5lib_H5_H5Sget_1select_1elem_1pointlist(JNIEnv *env, jclass clss, jl
 
 done:
     if (ba)
-        HDfree(ba);
+        free(ba);
     if (bufP)
         UNPIN_LONG_ARRAY(ENVONLY, buf, bufP, (status < 0) ? JNI_ABORT : 0);
 
@@ -1081,12 +1078,12 @@ Java_hdf_hdf5lib_H5_H5Sget_1select_1bounds(JNIEnv *env, jclass clss, jlong space
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Sget_select_bounds: start array length < 0");
     }
 
-    if (NULL == (strt = (hsize_t *)HDmalloc((size_t)rank * sizeof(hsize_t))))
+    if (NULL == (strt = (hsize_t *)malloc((size_t)rank * sizeof(hsize_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sget_select_bounds: failed to allocate start buffer");
 
     PIN_LONG_ARRAY(ENVONLY, end, endP, &isCopy, "H5Sget_select_bounds: end not pinned");
 
-    if (NULL == (en = (hsize_t *)HDmalloc((size_t)rank * sizeof(hsize_t))))
+    if (NULL == (en = (hsize_t *)malloc((size_t)rank * sizeof(hsize_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sget_select_bounds: failed to allocate end buffer");
 
     if ((status = H5Sget_select_bounds((hid_t)spaceid, (hsize_t *)strt, (hsize_t *)en)) < 0)
@@ -1099,11 +1096,11 @@ Java_hdf_hdf5lib_H5_H5Sget_1select_1bounds(JNIEnv *env, jclass clss, jlong space
 
 done:
     if (en)
-        HDfree(en);
+        free(en);
     if (endP)
         UNPIN_LONG_ARRAY(ENVONLY, end, endP, (status < 0) ? JNI_ABORT : 0);
     if (strt)
-        HDfree(strt);
+        free(strt);
     if (startP)
         UNPIN_LONG_ARRAY(ENVONLY, start, startP, (status < 0) ? JNI_ABORT : 0);
 
@@ -1128,16 +1125,16 @@ Java_hdf_hdf5lib_H5_H5Sencode(JNIEnv *env, jclass clss, jlong obj_id)
     if (obj_id < 0)
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Sencode: invalid object ID");
 
-    if ((status = H5Sencode(obj_id, NULL, &buf_size)) < 0)
+    if ((status = H5Sencode2(obj_id, NULL, &buf_size, H5P_DEFAULT)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
     if (buf_size == 0)
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Sencode: buf_size = 0");
 
-    if (NULL == (bufPtr = (unsigned char *)HDcalloc((size_t)1, buf_size)))
+    if (NULL == (bufPtr = (unsigned char *)calloc((size_t)1, buf_size)))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sencode: failed to allocate encoding buffer");
 
-    if ((status = H5Sencode((hid_t)obj_id, bufPtr, &buf_size)) < 0)
+    if ((status = H5Sencode2((hid_t)obj_id, bufPtr, &buf_size, H5P_DEFAULT)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
     if (NULL == (returnedArray = ENVPTR->NewByteArray(ENVONLY, (jsize)buf_size)))
@@ -1148,7 +1145,7 @@ Java_hdf_hdf5lib_H5_H5Sencode(JNIEnv *env, jclass clss, jlong obj_id)
 
 done:
     if (bufPtr)
-        HDfree(bufPtr);
+        free(bufPtr);
 
     return returnedArray;
 } /* end Java_hdf_hdf5lib_H5_H5Sencode */
@@ -1243,7 +1240,7 @@ Java_hdf_hdf5lib_H5_H5Sget_1regular_1hyperslab(JNIEnv *env, jclass clss, jlong s
 
         PIN_LONG_ARRAY(ENVONLY, start, startP, &isCopy, "H5Sget_regular_hyperslab: start not pinned");
 
-        if (NULL == (strt = (hsize_t *)HDmalloc((size_t)start_rank * sizeof(hsize_t))))
+        if (NULL == (strt = (hsize_t *)malloc((size_t)start_rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sget_regular_hyperslab: failed to allocate start buffer");
     }
 
@@ -1263,7 +1260,7 @@ Java_hdf_hdf5lib_H5_H5Sget_1regular_1hyperslab(JNIEnv *env, jclass clss, jlong s
 
         PIN_LONG_ARRAY(ENVONLY, stride, strideP, &isCopy, "H5Sget_regular_hyperslab: stride not pinned");
 
-        if (NULL == (strd = (hsize_t *)HDmalloc((size_t)stride_rank * sizeof(hsize_t))))
+        if (NULL == (strd = (hsize_t *)malloc((size_t)stride_rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sget_regular_hyperslab: failed to allocate stride buffer");
     }
 
@@ -1283,7 +1280,7 @@ Java_hdf_hdf5lib_H5_H5Sget_1regular_1hyperslab(JNIEnv *env, jclass clss, jlong s
 
         PIN_LONG_ARRAY(ENVONLY, count, countP, &isCopy, "H5Sget_regular_hyperslab: count not pinned");
 
-        if (NULL == (cnt = (hsize_t *)HDmalloc((size_t)count_rank * sizeof(hsize_t))))
+        if (NULL == (cnt = (hsize_t *)malloc((size_t)count_rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sget_regular_hyperslab: failed to allocate count buffer");
     }
 
@@ -1303,7 +1300,7 @@ Java_hdf_hdf5lib_H5_H5Sget_1regular_1hyperslab(JNIEnv *env, jclass clss, jlong s
 
         PIN_LONG_ARRAY(ENVONLY, block, blockP, &isCopy, "H5Sget_regular_hyperslab: block not pinned");
 
-        if (NULL == (blk = (hsize_t *)HDmalloc((size_t)block_rank * sizeof(hsize_t))))
+        if (NULL == (blk = (hsize_t *)malloc((size_t)block_rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sget_regular_hyperslab: failed to allocate block buffer");
     }
 
@@ -1320,19 +1317,19 @@ Java_hdf_hdf5lib_H5_H5Sget_1regular_1hyperslab(JNIEnv *env, jclass clss, jlong s
 
 done:
     if (blk)
-        HDfree(blk);
+        free(blk);
     if (blockP)
         UNPIN_LONG_ARRAY(ENVONLY, block, blockP, (status < 0) ? JNI_ABORT : 0);
     if (cnt)
-        HDfree(cnt);
+        free(cnt);
     if (countP)
         UNPIN_LONG_ARRAY(ENVONLY, count, countP, (status < 0) ? JNI_ABORT : 0);
     if (strd)
-        HDfree(strd);
+        free(strd);
     if (strideP)
         UNPIN_LONG_ARRAY(ENVONLY, stride, strideP, (status < 0) ? JNI_ABORT : 0);
     if (strt)
-        HDfree(strt);
+        free(strt);
     if (startP)
         UNPIN_LONG_ARRAY(ENVONLY, start, startP, (status < 0) ? JNI_ABORT : 0);
 
@@ -1417,7 +1414,7 @@ Java_hdf_hdf5lib_H5_H5Sselect_1adjust(JNIEnv *env, jclass clss, jlong space_id,
 
         PIN_LONG_ARRAY(ENVONLY, offset, offsetP, &isCopy, "H5Sselect_adjust: offset not pinned");
 
-        if (NULL == (offst = (hssize_t *)HDmalloc((size_t)offset_rank * sizeof(hsize_t))))
+        if (NULL == (offst = (hssize_t *)malloc((size_t)offset_rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sselect_adjust: failed to allocate offset buffer");
     }
 
@@ -1430,7 +1427,7 @@ Java_hdf_hdf5lib_H5_H5Sselect_1adjust(JNIEnv *env, jclass clss, jlong space_id,
 
 done:
     if (offst)
-        HDfree(offst);
+        free(offst);
     if (offsetP)
         UNPIN_LONG_ARRAY(ENVONLY, offset, offsetP, (status < 0) ? JNI_ABORT : 0);
 
@@ -1477,7 +1474,7 @@ Java_hdf_hdf5lib_H5_H5Sselect_1intersect_1block(JNIEnv *env, jclass clss, jlong
 
         PIN_LONG_ARRAY(ENVONLY, start, startP, &isCopy, "H5Sselect_intersect_block: start not pinned");
 
-        if (NULL == (strt = (hsize_t *)HDmalloc((size_t)start_rank * sizeof(hsize_t))))
+        if (NULL == (strt = (hsize_t *)malloc((size_t)start_rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sselect_intersect_block: failed to allocate start buffer");
     }
 
@@ -1497,7 +1494,7 @@ Java_hdf_hdf5lib_H5_H5Sselect_1intersect_1block(JNIEnv *env, jclass clss, jlong
 
         PIN_LONG_ARRAY(ENVONLY, end, endP, &isCopy, "H5Sselect_intersect_block: end not pinned");
 
-        if (NULL == (nd = (hsize_t *)HDmalloc((size_t)end_rank * sizeof(hsize_t))))
+        if (NULL == (nd = (hsize_t *)malloc((size_t)end_rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Sselect_intersect_block: failed to allocate end buffer");
     }
 
@@ -1513,11 +1510,11 @@ Java_hdf_hdf5lib_H5_H5Sselect_1intersect_1block(JNIEnv *env, jclass clss, jlong
 
 done:
     if (strt)
-        HDfree(strt);
+        free(strt);
     if (startP)
         UNPIN_LONG_ARRAY(ENVONLY, start, startP, (bval < 0) ? JNI_ABORT : 0);
     if (nd)
-        HDfree(nd);
+        free(nd);
     if (endP)
         UNPIN_LONG_ARRAY(ENVONLY, end, endP, (bval < 0) ? JNI_ABORT : 0);
 
@@ -1584,7 +1581,7 @@ Java_hdf_hdf5lib_H5_H5Scombine_1hyperslab(JNIEnv *env, jclass clss, jlong space_
 
     PIN_LONG_ARRAY(ENVONLY, start, startP, &isCopy, "H5Scombine_hyperslab: start not pinned");
 
-    if (NULL == (strt = lp = (hsize_t *)HDmalloc((size_t)start_rank * sizeof(hsize_t))))
+    if (NULL == (strt = lp = (hsize_t *)malloc((size_t)start_rank * sizeof(hsize_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Scombine_hyperslab: failed to allocate start buffer");
 
     jlp = (jlong *)startP;
@@ -1596,7 +1593,7 @@ Java_hdf_hdf5lib_H5_H5Scombine_1hyperslab(JNIEnv *env, jclass clss, jlong space_
 
     PIN_LONG_ARRAY(ENVONLY, count, countP, &isCopy, "H5Scombine_hyperslab: count not pinned");
 
-    if (NULL == (cnt = lp = (hsize_t *)HDmalloc((size_t)count_rank * sizeof(hsize_t))))
+    if (NULL == (cnt = lp = (hsize_t *)malloc((size_t)count_rank * sizeof(hsize_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Scombine_hyperslab: failed to allocate count buffer");
 
     jlp = (jlong *)countP;
@@ -1621,7 +1618,7 @@ Java_hdf_hdf5lib_H5_H5Scombine_1hyperslab(JNIEnv *env, jclass clss, jlong space_
 
         PIN_LONG_ARRAY(ENVONLY, stride, strideP, &isCopy, "H5Scombine_hyperslab: stride not pinned");
 
-        if (NULL == (strd = lp = (hsize_t *)HDmalloc((size_t)stride_rank * sizeof(hsize_t))))
+        if (NULL == (strd = lp = (hsize_t *)malloc((size_t)stride_rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Scombine_hyperslab: failed to allocate stride buffer");
 
         jlp = (jlong *)strideP;
@@ -1647,7 +1644,7 @@ Java_hdf_hdf5lib_H5_H5Scombine_1hyperslab(JNIEnv *env, jclass clss, jlong space_
 
         PIN_LONG_ARRAY(ENVONLY, block, blockP, &isCopy, "H5Scombine_hyperslab: block not pinned");
 
-        if (NULL == (blk = lp = (hsize_t *)HDmalloc((size_t)block_rank * sizeof(hsize_t))))
+        if (NULL == (blk = lp = (hsize_t *)malloc((size_t)block_rank * sizeof(hsize_t))))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Scombine_hyperslab: failed to allocate block buffer");
 
         jlp = (jlong *)blockP;
@@ -1664,19 +1661,19 @@ Java_hdf_hdf5lib_H5_H5Scombine_1hyperslab(JNIEnv *env, jclass clss, jlong space_
 
 done:
     if (blk)
-        HDfree(blk);
+        free(blk);
     if (blockP)
         UNPIN_LONG_ARRAY(ENVONLY, block, blockP, JNI_ABORT);
     if (strd)
-        HDfree(strd);
+        free(strd);
     if (strideP)
         UNPIN_LONG_ARRAY(ENVONLY, stride, strideP, JNI_ABORT);
     if (cnt)
-        HDfree(cnt);
+        free(cnt);
     if (countP)
         UNPIN_LONG_ARRAY(ENVONLY, count, countP, JNI_ABORT);
     if (strt)
-        HDfree(strt);
+        free(strt);
     if (startP)
         UNPIN_LONG_ARRAY(ENVONLY, start, startP, JNI_ABORT);
 
