@@ -13,6 +13,7 @@
 package test;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
@@ -30,8 +31,9 @@ import org.junit.rules.TestName;
 
 public class TestH5F {
     @Rule
-    public TestName testname            = new TestName();
-    private static final String H5_FILE = "testF.h5";
+    public TestName testname             = new TestName();
+    private static final String H5_FILE  = "testF.h5";
+    private static final String H5_FILE2 = "testF2.h5";
 
     private static final int COUNT_OBJ_FILE     = 1;
     private static final int COUNT_OBJ_DATASET  = 0;
@@ -43,8 +45,8 @@ public class TestH5F {
     private static final int[] OBJ_COUNTS = {COUNT_OBJ_FILE,     COUNT_OBJ_DATASET, COUNT_OBJ_GROUP,
                                              COUNT_OBJ_DATATYPE, COUNT_OBJ_ATTR,    COUNT_OBJ_ALL};
     private static final int[] OBJ_TYPES  = {HDF5Constants.H5F_OBJ_FILE,  HDF5Constants.H5F_OBJ_DATASET,
-                                            HDF5Constants.H5F_OBJ_GROUP, HDF5Constants.H5F_OBJ_DATATYPE,
-                                            HDF5Constants.H5F_OBJ_ATTR,  HDF5Constants.H5F_OBJ_ALL};
+                                             HDF5Constants.H5F_OBJ_GROUP, HDF5Constants.H5F_OBJ_DATATYPE,
+                                             HDF5Constants.H5F_OBJ_ATTR,  HDF5Constants.H5F_OBJ_ALL};
     long H5fid                            = HDF5Constants.H5I_INVALID_HID;
 
     private final void _deleteFile(String filename)
@@ -214,6 +216,65 @@ public class TestH5F {
         assertEquals(HDF5Constants.H5F_ACC_RDONLY, intent);
     }
 
+    @Test
+    public void testH5Fget_fileno_same()
+    {
+        long fileno1 = 0;
+        long fileno2 = 0;
+        long fid1    = HDF5Constants.H5I_INVALID_HID;
+        long fid2    = HDF5Constants.H5I_INVALID_HID;
+
+        try {
+            fid1 = H5.H5Fcreate(H5_FILE2, HDF5Constants.H5F_ACC_TRUNC, HDF5Constants.H5P_DEFAULT,
+                                HDF5Constants.H5P_DEFAULT);
+            H5.H5Fflush(fid1, HDF5Constants.H5F_SCOPE_LOCAL);
+            assertTrue("H5Fcreate failed", fid1 > 0);
+            fid2 = H5.H5Fopen(H5_FILE2, HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
+            assertTrue("H5Fopen failed", fid2 > 0);
+            fileno1 = H5.H5Fget_fileno(fid1);
+            assertTrue("H5Fget_fileno1=" + fileno1, fileno1 > 0);
+            fileno2 = H5.H5Fget_fileno(fid2);
+            assertTrue("H5Fget_fileno2=" + fileno2, fileno2 > 0);
+
+            assertEquals("fileno1[" + fileno1 + "]!=fileno2[" + fileno2 + "]", fileno1, fileno2);
+        }
+        catch (Throwable err) {
+            fail("testH5Fget_fileno_same: " + err);
+        }
+        finally {
+            H5.H5Fclose(fid1);
+            H5.H5Fclose(fid2);
+        }
+    }
+
+    @Test
+    public void testH5Fget_fileno_diff()
+    {
+        long fileno1 = 0;
+        long fileno2 = 0;
+        long fid2    = HDF5Constants.H5I_INVALID_HID;
+
+        try {
+            fid2 = H5.H5Fcreate(H5_FILE2, HDF5Constants.H5F_ACC_TRUNC, HDF5Constants.H5P_DEFAULT,
+                                HDF5Constants.H5P_DEFAULT);
+            H5.H5Fflush(fid2, HDF5Constants.H5F_SCOPE_LOCAL);
+            assertTrue("H5Fcreate failed", fid2 > 0);
+
+            fileno1 = H5.H5Fget_fileno(H5fid);
+            assertTrue("H5Fget_fileno1=" + fileno1, fileno1 > 0);
+            fileno2 = H5.H5Fget_fileno(fid2);
+            assertTrue("H5Fget_fileno2=" + fileno2, fileno2 > 0);
+
+            assertNotEquals("fileno1[" + fileno1 + "]==fileno2[" + fileno2 + "]", fileno1, fileno2);
+        }
+        catch (Throwable err) {
+            fail("testH5Fget_fileno_diff: " + err);
+        }
+        finally {
+            H5.H5Fclose(fid2);
+        }
+    }
+
     @Test
     public void testH5Fget_obj_count()
     {
