@@ -21,7 +21,7 @@ import java.util.ArrayList;
 
 import hdf.hdf5lib.H5;
 import hdf.hdf5lib.HDF5Constants;
-import hdf.hdf5lib.callbacks.H5O_iterate_cb;
+import hdf.hdf5lib.callbacks.H5O_iterate_opdata_t;
 import hdf.hdf5lib.callbacks.H5O_iterate_t;
 import hdf.hdf5lib.exceptions.HDF5Exception;
 import hdf.hdf5lib.exceptions.HDF5LibraryException;
@@ -313,7 +313,7 @@ public class TestH5Ocreate {
         }
         assertFalse("H5Oget_info", obj_info == null);
         assertTrue("H5Oget_info link type", obj_info.type == HDF5Constants.H5O_TYPE_DATASET);
-        assertTrue("Link Address ", obj_info.addr > 0);
+        assertTrue("Link Object Token", obj_info.token != null);
     }
 
     @Test(expected = HDF5LibraryException.class)
@@ -338,7 +338,7 @@ public class TestH5Ocreate {
         }
         assertFalse("H5Oget_info", obj_info == null);
         assertTrue("H5Oget_info link type", obj_info.type == HDF5Constants.H5O_TYPE_NAMED_DATATYPE);
-        assertTrue("Link Address ", obj_info.addr > 0);
+        assertTrue("Link Object Token", obj_info.token != null);
     }
 
     @Test
@@ -411,19 +411,19 @@ public class TestH5Ocreate {
                 this.link_type = type;
             }
         }
-        class H5O_iter_data implements H5O_iterate_t {
+        class H5O_iter_data implements H5O_iterate_opdata_t {
             public ArrayList<idata> iterdata = new ArrayList<idata>();
         }
-        H5O_iterate_t iter_data = new H5O_iter_data();
-        class H5O_iter_callback implements H5O_iterate_cb {
-            public int callback(long group, String name, H5O_info_t info, H5O_iterate_t op_data)
+        H5O_iterate_opdata_t iter_data = new H5O_iter_data();
+        class H5O_iter_callback implements H5O_iterate_t {
+            public int callback(long group, String name, H5O_info_t info, H5O_iterate_opdata_t op_data)
             {
                 idata id = new idata(name, info.type);
                 ((H5O_iter_data)op_data).iterdata.add(id);
                 return 0;
             }
         }
-        H5O_iterate_cb iter_cb = new H5O_iter_callback();
+        H5O_iterate_t iter_cb = new H5O_iter_callback();
         try {
             H5.H5Ovisit(H5fid, HDF5Constants.H5_INDEX_CRT_ORDER, HDF5Constants.H5_ITER_INC, iter_cb,
                         iter_data);
