@@ -180,235 +180,356 @@ public class TestH5R {
         System.out.println();
     }
 
+    // Test v1.12 APIs params
+
     @Test
-    public void testH5Rget_name()
+    public void testH5Rget_object()
     {
-        long loc_id    = H5fid;
-        int ref_type   = HDF5Constants.H5R_OBJECT;
+        int ref_type   = HDF5Constants.H5R_OBJECT2;
         long ret_val   = -1;
         byte[] ref     = null;
-        String[] name  = {""};
+        String name    = "";
         String objName = "/dset";
 
         try {
-            ref = H5.H5Rcreate(H5fid, objName, ref_type, -1);
+            ref = H5.H5Rcreate_object(H5fid, objName, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
             err.printStackTrace();
-            fail("H5.H5Rget_name:H5Rcreate " + err);
+            fail("testH5Rget_object: H5Rcreate_object " + err);
         }
 
         try {
-            ret_val = H5.H5Rget_name(loc_id, ref_type, ref, name, 16);
+            ret_val = H5.H5Rget_type(ref);
         }
         catch (Throwable err) {
             err.printStackTrace();
-            fail("H5.H5Rget_name: " + err);
+            fail("testH5Rget_object: H5Rget_type: " + err);
         }
+        assertTrue("testH5Rget_object: H5Rget_type", ret_val == ref_type);
 
-        assertTrue("testH5Rget_name: H5Rget_name", ret_val > 0);
-        assertTrue("The name of the object: ", objName.equals(name[0]));
+        try {
+            name = H5.H5Rget_file_name(ref);
+        }
+        catch (Throwable err) {
+            err.printStackTrace();
+            fail("testH5Rget_object: H5Rget_file_name: " + err);
+        }
+        assertTrue("testH5Rget_object: H5Rget_file_name", H5_FILE.equals(name));
+
+        try {
+            name = H5.H5Rget_obj_name(ref, HDF5Constants.H5P_DEFAULT);
+        }
+        catch (Throwable err) {
+            err.printStackTrace();
+            fail("testH5Rget_object: H5Rget_obj_name: " + err);
+        }
+        assertTrue("The name of the object: ", objName.equals(name));
+        H5.H5Rdestroy(ref);
     }
 
     @Test
-    public void testH5Rget_obj_type2()
+    public void testH5Rget_obj_type3()
     {
-        int ref_type   = HDF5Constants.H5R_OBJECT;
+        int obj_type   = -1;
         byte[] ref     = null;
         String objName = "/dset";
-        int obj_type   = -1;
-        ;
 
         try {
-            ref = H5.H5Rcreate(H5fid, objName, ref_type, -1);
+            ref = H5.H5Rcreate_object(H5fid, objName, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
             err.printStackTrace();
+            fail("testH5Rget_obj_type3: H5Rcreate_object " + err);
         }
 
         try {
-            obj_type = H5.H5Rget_obj_type(H5fid, HDF5Constants.H5R_OBJECT, ref);
+            obj_type = H5.H5Rget_obj_type3(ref, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
             err.printStackTrace();
-            fail("H5.H5Rget_obj_type2: " + err);
+            fail("testH5Rget_obj_type3: H5.H5Rget_obj_type3: " + err);
         }
         assertEquals(obj_type, HDF5Constants.H5O_TYPE_DATASET);
+        H5.H5Rdestroy(ref);
     }
 
     @Test
-    public void testH5Rcreate_refobj()
+    public void testH5Rcreate_regionref_object()
     {
-        byte[] ref = null;
+        byte[] ref     = null;
+        String objName = "/dset";
+        long start[]   = {2, 2}; // Starting location of hyperslab
+        long stride[]  = {1, 1}; // Stride of hyperslab
+        long count[]   = {1, 1}; // Element count of hyperslab
+        long block[]   = {3, 3}; // Block size of hyperslab
 
+        // Select 3x3 hyperslab for reference
         try {
-            ref = H5.H5Rcreate(H5fid, "/dset", HDF5Constants.H5R_OBJECT, -1);
+            H5.H5Sselect_hyperslab(H5dsid, HDF5Constants.H5S_SELECT_SET, start, stride, count, block);
         }
         catch (Throwable err) {
             err.printStackTrace();
-            fail("H5.H5Rcreate: " + err);
+            fail("testH5Rget_object: H5Sselect_hyperslab " + err);
+        }
+        try {
+            ref = H5.H5Rcreate_region(H5fid, objName, H5dsid, HDF5Constants.H5P_DEFAULT);
+        }
+        catch (Throwable err) {
+            err.printStackTrace();
+            fail("testH5Rget_object: H5Rcreate_region " + err);
         }
         assertNotNull(ref);
+        H5.H5Rdestroy(ref);
     }
 
-    @Test
-    public void testH5Rcreate_regionrefobj()
+    // These tests need to be updated with new APIs
+    //    @Test//
+    //    public void testH5Rget_group() {
+    //        long loc_id = H5fid;
+    //        int ref_type = HDF5Constants.H5R_OBJECT2;
+    //        long ret_val = -1;
+    //        byte[] ref = null;
+    //        String name = "";
+    //        String objName = "/dset";
+    //
+    //        try {
+    //            ref = H5.H5Rcreate_object(H5fid, objName, HDF5Constants.H5P_DEFAULT);
+    //        }
+    //        catch (Throwable err) {
+    //            err.printStackTrace();
+    //            fail("testH5Rget_object: H5Rcreate_object " + err);
+    //        }
+    //        try {
+    //            dataset_id= H5.H5Rdereference(H5fid, HDF5Constants.H5P_DEFAULT,
+    //            HDF5Constants.H5R_DATASET_REGION, ref1);
+    //
+    //            //Create reference on group
+    //            ref2 = H5.H5Rcreate(H5gid, "/Group1", HDF5Constants.H5R_OBJECT, -1);
+    //            group_id= H5.H5Rdereference(H5gid, HDF5Constants.H5P_DEFAULT, HDF5Constants.H5R_OBJECT,
+    //            ref2); assertNotNull(ref1); assertNotNull(ref2); assertTrue(dataset_id >= 0);
+    //            assertTrue(group_id >= 0);
+    //        }
+    //        catch (Throwable err) {
+    //            err.printStackTrace();
+    //            fail("TestH5Rdereference " + err);
+    //        }
+    //        finally {
+    //            try {H5.H5Dclose(dataset_id);} catch (Exception ex) {}
+    //            try {H5.H5Gclose(group_id);} catch (Exception ex) {}
+    //        }
+    //    }
+
+    //    @Test//
+    //    public void testH5Rget_region_dataset() {
+    //        long loc_id = H5fid;
+    //        int ref_type = HDF5Constants.H5R_OBJECT2;
+    //        long ret_val = -1;
+    //        byte[] ref = null;
+    //        String name = "";
+    //        String objName = "/dset";
+    //
+    //        try {
+    //            ref = H5.H5Rcreate_object(H5fid, objName, HDF5Constants.H5P_DEFAULT);
+    //        }
+    //        catch (Throwable err) {
+    //            err.printStackTrace();
+    //            fail("testH5Rget_object: H5Rcreate_object " + err);
+    //        }
+    //        try {
+    //            dsid = H5.H5Rget_region(H5fid, HDF5Constants.H5R_DATASET_REGION, ref);
+    //            assertNotNull(ref);
+    //            assertTrue(dsid >= 0);
+    //        }
+    //        catch (Throwable err) {
+    //            err.printStackTrace();
+    //            fail("TestH5Rget_region: " + err);
+    //        }
+    //        finally {
+    //            try {H5.H5Sclose(dsid);} catch (Exception ex) {}
+    //        }
+    //    }
+
+    //    @Test//
+    //    public void testH5Rget_attr() {
+    //        long loc_id = H5fid;
+    //        int ref_type = HDF5Constants.H5R_OBJECT2;
+    //        long ret_val = -1;
+    //        byte[] ref = null;
+    //        String name = "";
+    //        String objName = "/dset";
+    //
+    //        try {
+    //            ref = H5.H5Rcreate_object(H5fid, objName, HDF5Constants.H5P_DEFAULT);
+    //        }
+    //        catch (Throwable err) {
+    //            err.printStackTrace();
+    //            fail("testH5Rget_object: H5Rcreate_object " + err);
+    //        }
+    //        try {
+    //            dsid = H5.H5Rget_region(H5fid, HDF5Constants.H5R_DATASET_REGION, ref);
+    //            assertNotNull(ref);
+    //            assertTrue(dsid >= 0);
+    //        }
+    //        catch (Throwable err) {
+    //            err.printStackTrace();
+    //            fail("TestH5Rget_region: " + err);
+    //        }
+    //        finally {
+    //            try {H5.H5Sclose(dsid);} catch (Exception ex) {}
+    //        }
+    //    }
+
+    // Test parameters to H5Rcreate_object
+    @Test(expected = NullPointerException.class)
+    public void testH5Rcreate_object_Nullname() throws Throwable
     {
-        byte[] ref = null;
-        try {
-            ref = H5.H5Rcreate(H5fid, "/dset", HDF5Constants.H5R_DATASET_REGION, H5dsid);
-        }
-        catch (Throwable err) {
-            err.printStackTrace();
-            fail("H5.H5Rcreate: " + err);
-        }
-        assertNotNull(ref);
+        String name = null;
+        H5.H5Rcreate_object(H5fid, name, HDF5Constants.H5P_DEFAULT);
     }
 
-    @Test
-    public void testH5Rdereference()
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Rget_name_Invalidloc() throws Throwable
     {
-        byte[] ref1     = null;
-        byte[] ref2     = null;
-        long dataset_id = HDF5Constants.H5I_INVALID_HID;
-        long group_id   = HDF5Constants.H5I_INVALID_HID;
-        try {
-            // Create reference on dataset
-            ref1 = H5.H5Rcreate(H5fid, "/dset", HDF5Constants.H5R_DATASET_REGION, H5dsid);
-            dataset_id =
-                H5.H5Rdereference(H5fid, HDF5Constants.H5P_DEFAULT, HDF5Constants.H5R_DATASET_REGION, ref1);
-
-            // Create reference on group
-            ref2     = H5.H5Rcreate(H5gid, "/Group1", HDF5Constants.H5R_OBJECT, -1);
-            group_id = H5.H5Rdereference(H5gid, HDF5Constants.H5P_DEFAULT, HDF5Constants.H5R_OBJECT, ref2);
-            assertNotNull(ref1);
-            assertNotNull(ref2);
-            assertTrue(dataset_id >= 0);
-            assertTrue(group_id >= 0);
-        }
-        catch (Throwable err) {
-            err.printStackTrace();
-            fail("TestH5Rdereference " + err);
-        }
-        finally {
-            try {
-                H5.H5Dclose(dataset_id);
-            }
-            catch (Exception ex) {
-            }
-            try {
-                H5.H5Gclose(group_id);
-            }
-            catch (Exception ex) {
-            }
-        }
+        String name = "";
+        H5.H5Rcreate_object(-1, name, HDF5Constants.H5P_DEFAULT);
     }
 
-    @Test
-    public void testH5Rget_region()
+    // Test parameters to H5Rcreate_region
+    @Test(expected = NullPointerException.class)
+    public void testH5Rcreate_region_Nullname() throws Throwable
     {
-        byte[] ref = null;
-        long dsid  = HDF5Constants.H5I_INVALID_HID;
-        try {
-            ref  = H5.H5Rcreate(H5fid, "/dset", HDF5Constants.H5R_DATASET_REGION, H5dsid);
-            dsid = H5.H5Rget_region(H5fid, HDF5Constants.H5R_DATASET_REGION, ref);
-            assertNotNull(ref);
-            assertTrue(dsid >= 0);
-        }
-        catch (Throwable err) {
-            err.printStackTrace();
-            fail("TestH5Rget_region: " + err);
-        }
-        finally {
-            try {
-                H5.H5Sclose(dsid);
-            }
-            catch (Exception ex) {
-            }
-        }
+        String name = null;
+        H5.H5Rcreate_region(H5fid, name, -1, HDF5Constants.H5P_DEFAULT);
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Rget_name_Invalidreftype() throws Throwable
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Rcreate_region_Invalidloc() throws Throwable
     {
-        byte[] ref    = null;
-        String[] name = {""};
-        ref           = H5.H5Rcreate(H5fid, "/dset", HDF5Constants.H5R_OBJECT, -1);
-        H5.H5Rget_name(H5fid, HDF5Constants.H5R_DATASET_REGION, ref, name, 16);
+        String name = "";
+        H5.H5Rcreate_region(-1, name, -1, HDF5Constants.H5P_DEFAULT);
+    }
+
+    // Test parameters to H5Rcreate_attr
+    @Test(expected = NullPointerException.class)
+    public void testH5Rcreate_attr_Nullname() throws Throwable
+    {
+        String name     = null;
+        String attrname = "";
+        H5.H5Rcreate_attr(H5fid, name, attrname, HDF5Constants.H5P_DEFAULT);
     }
 
     @Test(expected = NullPointerException.class)
-    public void testH5Rget_name_NULLreference() throws Throwable
+    public void testH5Rcreate_attr_Nullattrname() throws Throwable
     {
-        byte[] ref    = null;
-        String[] name = {""};
-        H5.H5Rget_name(H5fid, HDF5Constants.H5R_OBJECT, ref, name, 16);
+        String name     = "";
+        String attrname = null;
+        H5.H5Rcreate_attr(H5fid, name, attrname, HDF5Constants.H5P_DEFAULT);
     }
 
-    @Test(expected = HDF5LibraryException.class)
-    public void testH5Rget_obj_type2_Invalidreftype() throws Throwable
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Rcreate_attr_Invalidloc() throws Throwable
     {
-        byte[] ref = null;
-        ref        = H5.H5Rcreate(H5fid, "/dset", HDF5Constants.H5R_OBJECT, -1);
-        H5.H5Rget_obj_type(H5fid, HDF5Constants.H5R_DATASET_REGION, ref);
-    }
-
-    @Test(expected = HDF5LibraryException.class)
-    public void testH5Rcreate_InvalidObjectName() throws Throwable
-    {
-        H5.H5Rcreate(H5fid, "/GROUPS", HDF5Constants.H5R_OBJECT, -1);
-    }
-
-    @Test(expected = HDF5LibraryException.class)
-    public void testH5Rcreate_Invalidspace_id() throws Throwable
-    {
-        H5.H5Rcreate(H5fid, "/dset", HDF5Constants.H5R_DATASET_REGION, -1);
-    }
-
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Rcreate_Invalidreftype() throws Throwable
-    {
-        H5.H5Rcreate(H5fid, "/dset", HDF5Constants.H5R_BADTYPE, -1);
-    }
-
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Rgetregion_Invalidreftype() throws Throwable
-    {
-        byte[] ref = null;
-        ref        = H5.H5Rcreate(H5fid, "/dset", HDF5Constants.H5R_OBJECT, H5dsid);
-        H5.H5Rget_region(H5fid, HDF5Constants.H5R_DATASET_REGION, ref);
-    }
-
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Rgetregion_Badreferencetype() throws Throwable
-    {
-        byte[] ref = null;
-        ref        = H5.H5Rcreate(H5fid, "/dset", HDF5Constants.H5R_OBJECT, H5dsid);
-        H5.H5Rget_region(H5fid, HDF5Constants.H5R_OBJECT, ref);
+        String name     = "";
+        String attrname = "";
+        H5.H5Rcreate_attr(-1, name, attrname, HDF5Constants.H5P_DEFAULT);
     }
 
+    // Test parameters to H5Rdestroy
     @Test(expected = NullPointerException.class)
-    public void testH5Rgetregion_Nullreference() throws Throwable
+    public void testH5Rdestroy_Nullref() throws Throwable
     {
         byte[] ref = null;
-        H5.H5Rget_region(H5fid, HDF5Constants.H5R_DATASET_REGION, ref);
+        H5.H5Rdestroy(ref);
     }
 
+    // Test parameters to H5Rget_type
     @Test(expected = NullPointerException.class)
-    public void testH5Rdereference_Nullreference() throws Throwable
+    public void testH5Rget_type_Nullref() throws Throwable
     {
         byte[] ref = null;
-        H5.H5Rdereference(H5did2, HDF5Constants.H5P_DEFAULT, HDF5Constants.H5R_OBJECT, ref);
+        H5.H5Rget_type(ref);
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Rdereference_Invalidreference() throws Throwable
+    // Test parameters to H5Requal
+    @Test(expected = NullPointerException.class)
+    public void testH5Requal_Nullref1() throws Throwable
     {
         byte[] ref1 = null;
+        byte[] ref2 = {0, 0, 0, 0};
+        H5.H5Requal(ref1, ref2);
+    }
+
+    @Test(expected = NullPointerException.class)
+    public void testH5Requal_Nullref2() throws Throwable
+    {
+        byte[] ref1 = {0, 0, 0, 0};
         byte[] ref2 = null;
-        ref1        = H5.H5Rcreate(H5fid, "/dset", HDF5Constants.H5R_DATASET_REGION, H5dsid);
-        ref2        = H5.H5Rcreate(H5gid, "/Group1", HDF5Constants.H5R_OBJECT, -1);
-        H5.H5Rdereference(H5gid, HDF5Constants.H5P_DEFAULT, HDF5Constants.H5R_OBJECT, ref1);
+        H5.H5Requal(ref1, ref2);
+    }
+
+    // Test parameters to H5Rcopy
+    @Test(expected = NullPointerException.class)
+    public void testH5Rcopy_Nullref1() throws Throwable
+    {
+        byte[] ref1 = null;
+        byte[] ref2 = H5.H5Rcopy(ref1);
+    }
+
+    // Test parameters to H5Ropen_object
+    @Test(expected = NullPointerException.class)
+    public void testH5Ropen_object_Nullref() throws Throwable
+    {
+        byte[] ref = null;
+        H5.H5Ropen_object(ref, -1, -1);
+    }
+
+    // Test parameters to H5Ropen_region
+    @Test(expected = NullPointerException.class)
+    public void testH5Ropen_region_Nullref() throws Throwable
+    {
+        byte[] ref = null;
+        H5.H5Ropen_region(ref, -1, -1);
+    }
+
+    // Test parameters to H5Ropen_attr
+    @Test(expected = NullPointerException.class)
+    public void testH5Ropen_attr_Nullref() throws Throwable
+    {
+        byte[] ref = null;
+        H5.H5Ropen_attr(ref, -1, -1);
+    }
+
+    // Test parameters to H5Rget_obj_type3
+    @Test(expected = NullPointerException.class)
+    public void testH5Rget_obj_type3_Nullref() throws Throwable
+    {
+        byte[] ref = null;
+        H5.H5Rget_obj_type3(ref, -1);
+    }
+
+    // Test parameters to H5Rget_file_name
+    @Test(expected = NullPointerException.class)
+    public void testH5Rget_file_name_Nullref() throws Throwable
+    {
+        byte[] ref = null;
+        H5.H5Rget_file_name(ref);
+    }
+
+    // Test parameters to H5Rget_obj_name
+    @Test(expected = NullPointerException.class)
+    public void testH5Rget_obj_name_Nullref() throws Throwable
+    {
+        byte[] ref = null;
+        H5.H5Rget_obj_name(ref, -1);
+    }
+
+    // Test parameters to H5Rget_attr_name
+    @Test(expected = NullPointerException.class)
+    public void testH5Rget_attr_name_Nullref() throws Throwable
+    {
+        byte[] ref = null;
+        H5.H5Rget_attr_name(ref);
     }
 
     @Test
@@ -479,7 +600,7 @@ public class TestH5R {
                                            HDF5Constants.H5P_DEFAULT, HDF5Constants.H5P_DEFAULT);
                 assertTrue("testH5RVLattr_ref: ", attr_obj_id >= 0);
 
-                H5.H5AwriteVL(attr_obj_id, atype_obj_id, vl_obj_data);
+                H5.H5Awrite(attr_obj_id, atype_obj_id, vl_obj_data);
             }
             catch (Exception err) {
                 if (attr_obj_id > 0)
@@ -536,7 +657,7 @@ public class TestH5R {
                                            HDF5Constants.H5P_DEFAULT, HDF5Constants.H5P_DEFAULT);
                 assertTrue("testH5RVLattr_ref: ", attr_reg_id >= 0);
 
-                H5.H5AwriteVL(attr_reg_id, atype_reg_id, vl_reg_data);
+                H5.H5Awrite(attr_reg_id, atype_reg_id, vl_reg_data);
             }
             catch (Exception err) {
                 if (attr_reg_id > 0)
@@ -575,7 +696,7 @@ public class TestH5R {
                 vl_readbuf[j] = new ArrayList<byte[]>();
 
             try {
-                H5.H5AreadVL(attr_obj_id, atype_obj_id, vl_readbuf);
+                H5.H5Aread(attr_obj_id, atype_obj_id, vl_readbuf);
             }
             catch (Exception ex) {
                 ex.printStackTrace();
@@ -595,7 +716,7 @@ public class TestH5R {
                 vl_readbuf[j] = new ArrayList<byte[]>();
 
             try {
-                H5.H5AreadVL(attr_reg_id, atype_reg_id, vl_readbuf);
+                H5.H5Aread(attr_reg_id, atype_reg_id, vl_readbuf);
             }
             catch (Exception ex) {
                 ex.printStackTrace();
@@ -710,8 +831,8 @@ public class TestH5R {
                                  HDF5Constants.H5P_DEFAULT, HDF5Constants.H5P_DEFAULT);
                 assertTrue("testH5RVLdset_ref: ", dset_obj_id >= 0);
 
-                H5.H5DwriteVL(dset_obj_id, dtype_obj_id, HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
-                              HDF5Constants.H5P_DEFAULT, vl_obj_data);
+                H5.H5Dwrite(dset_obj_id, dtype_obj_id, HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
+                            HDF5Constants.H5P_DEFAULT, vl_obj_data);
             }
             catch (Exception err) {
                 if (dset_obj_id > 0)
@@ -769,8 +890,8 @@ public class TestH5R {
                                  HDF5Constants.H5P_DEFAULT, HDF5Constants.H5P_DEFAULT);
                 assertTrue("testH5RVLdset_ref: ", dset_reg_id >= 0);
 
-                H5.H5DwriteVL(dset_reg_id, dtype_reg_id, HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
-                              HDF5Constants.H5P_DEFAULT, vl_reg_data);
+                H5.H5Dwrite(dset_reg_id, dtype_reg_id, HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
+                            HDF5Constants.H5P_DEFAULT, vl_reg_data);
             }
             catch (Exception err) {
                 if (dset_reg_id > 0)
@@ -809,8 +930,8 @@ public class TestH5R {
                 vl_readbuf[j] = new ArrayList<byte[]>();
 
             try {
-                H5.H5DreadVL(dset_obj_id, dtype_obj_id, HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
-                             HDF5Constants.H5P_DEFAULT, vl_readbuf);
+                H5.H5Dread(dset_obj_id, dtype_obj_id, HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
+                           HDF5Constants.H5P_DEFAULT, vl_readbuf);
             }
             catch (Exception ex) {
                 ex.printStackTrace();
@@ -830,8 +951,8 @@ public class TestH5R {
                 vl_readbuf[j] = new ArrayList<byte[]>();
 
             try {
-                H5.H5DreadVL(dset_reg_id, dtype_reg_id, HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
-                             HDF5Constants.H5P_DEFAULT, vl_readbuf);
+                H5.H5Dread(dset_reg_id, dtype_reg_id, HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
+                           HDF5Constants.H5P_DEFAULT, vl_readbuf);
             }
             catch (Exception ex) {
                 ex.printStackTrace();
