@@ -32,7 +32,9 @@
 #include "H5private.h"   /* Generic Functions                    */
 #include "H5ACpkg.h"     /* Metadata cache                       */
 #include "H5Eprivate.h"  /* Error handling                       */
+#include "H5FLprivate.h" /* Free Lists                               */
 #include "H5MFprivate.h" /* File memory management		*/
+#include "H5SLprivate.h" /* Skip Lists                               */
 
 /****************/
 /* Local Macros */
@@ -97,9 +99,6 @@ H5FL_DEFINE_STATIC(H5AC_proxy_entry_t);
  * Return:	Success:	Pointer to the new proxy entry object.
  *		Failure:	NULL
  *
- * Programmer:  Quincey Koziol
- *              September 17, 2016
- *
  *-------------------------------------------------------------------------
  */
 H5AC_proxy_entry_t *
@@ -112,7 +111,7 @@ H5AC_proxy_entry_create(void)
 
     /* Allocate new proxy entry */
     if (NULL == (pentry = H5FL_CALLOC(H5AC_proxy_entry_t)))
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, NULL, "can't allocate proxy entry")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, NULL, "can't allocate proxy entry");
 
     /* Set non-zero fields */
     pentry->addr = HADDR_UNDEF;
@@ -136,9 +135,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              September 17, 2016
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -150,26 +146,26 @@ H5AC_proxy_entry_add_parent(H5AC_proxy_entry_t *pentry, void *_parent)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(parent);
-    HDassert(pentry);
+    assert(parent);
+    assert(pentry);
 
     /* Add parent to the list of parents */
     if (NULL == pentry->parents)
         if (NULL == (pentry->parents = H5SL_create(H5SL_TYPE_HADDR, NULL)))
             HGOTO_ERROR(H5E_CACHE, H5E_CANTCREATE, FAIL,
-                        "unable to create skip list for parents of proxy entry")
+                        "unable to create skip list for parents of proxy entry");
 
     /* Insert parent address into skip list */
     if (H5SL_insert(pentry->parents, parent, &parent->addr) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTINSERT, FAIL, "unable to insert parent into proxy's skip list")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTINSERT, FAIL, "unable to insert parent into proxy's skip list");
 
     /* Add flush dependency on parent */
     if (pentry->nchildren > 0) {
         /* Sanity check */
-        HDassert(H5F_addr_defined(pentry->addr));
+        assert(H5_addr_defined(pentry->addr));
 
         if (H5AC_create_flush_dependency(parent, pentry) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTDEPEND, FAIL, "unable to set flush dependency on proxy entry")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTDEPEND, FAIL, "unable to set flush dependency on proxy entry");
     } /* end if */
 
 done:
@@ -183,9 +179,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              September 17, 2016
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -198,30 +191,31 @@ H5AC_proxy_entry_remove_parent(H5AC_proxy_entry_t *pentry, void *_parent)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(pentry);
-    HDassert(pentry->parents);
-    HDassert(parent);
+    assert(pentry);
+    assert(pentry->parents);
+    assert(parent);
 
     /* Remove parent from skip list */
     if (NULL == (rem_parent = (H5AC_info_t *)H5SL_remove(pentry->parents, &parent->addr)))
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTREMOVE, FAIL, "unable to remove proxy entry parent from skip list")
-    if (!H5F_addr_eq(rem_parent->addr, parent->addr))
-        HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "removed proxy entry parent not the same as real parent")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTREMOVE, FAIL, "unable to remove proxy entry parent from skip list");
+    if (!H5_addr_eq(rem_parent->addr, parent->addr))
+        HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "removed proxy entry parent not the same as real parent");
 
     /* Shut down the skip list, if this is the last parent */
     if (0 == H5SL_count(pentry->parents)) {
         /* Sanity check */
-        HDassert(0 == pentry->nchildren);
+        assert(0 == pentry->nchildren);
 
         if (H5SL_close(pentry->parents) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CLOSEERROR, FAIL, "can't close proxy parent skip list")
+            HGOTO_ERROR(H5E_CACHE, H5E_CLOSEERROR, FAIL, "can't close proxy parent skip list");
         pentry->parents = NULL;
     } /* end if */
 
     /* Remove flush dependency between the proxy entry and a parent */
     if (pentry->nchildren > 0)
         if (H5AC_destroy_flush_dependency(parent, pentry) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTUNDEPEND, FAIL, "unable to remove flush dependency on proxy entry")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTUNDEPEND, FAIL,
+                        "unable to remove flush dependency on proxy entry");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -236,9 +230,6 @@ done:
  * Return:	Success:	Non-negative on success
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *		Thursday, September 22, 2016
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -248,12 +239,12 @@ H5AC__proxy_entry_add_child_cb(void *_item, void H5_ATTR_UNUSED *_key, void *_ud
     H5AC_proxy_entry_t *pentry    = (H5AC_proxy_entry_t *)_udata; /* Pointer to the proxy entry */
     int                 ret_value = H5_ITER_CONT;                 /* Callback return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Add flush dependency on parent for proxy entry */
     if (H5AC_create_flush_dependency(parent, pentry) < 0)
         HGOTO_ERROR(H5E_CACHE, H5E_CANTDEPEND, H5_ITER_ERROR,
-                    "unable to set flush dependency for virtual entry")
+                    "unable to set flush dependency for virtual entry");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -266,9 +257,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              September 17, 2016
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -279,39 +267,39 @@ H5AC_proxy_entry_add_child(H5AC_proxy_entry_t *pentry, H5F_t *f, void *child)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(pentry);
-    HDassert(child);
+    assert(pentry);
+    assert(child);
 
     /* Check for first child */
     if (0 == pentry->nchildren) {
         /* Get an address, if the proxy doesn't already have one */
-        if (!H5F_addr_defined(pentry->addr))
+        if (!H5_addr_defined(pentry->addr))
             if (HADDR_UNDEF == (pentry->addr = H5MF_alloc_tmp(f, 1)))
                 HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL,
-                            "temporary file space allocation failed for proxy entry")
+                            "temporary file space allocation failed for proxy entry");
 
         /* Insert the proxy entry into the cache */
         if (H5AC_insert_entry(f, H5AC_PROXY_ENTRY, pentry->addr, pentry, H5AC__PIN_ENTRY_FLAG) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTINSERT, FAIL, "unable to cache proxy entry")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTINSERT, FAIL, "unable to cache proxy entry");
 
         /* Proxies start out clean (insertions are automatically marked dirty) */
         if (H5AC_mark_entry_clean(pentry) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTCLEAN, FAIL, "can't mark proxy entry clean")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTCLEAN, FAIL, "can't mark proxy entry clean");
 
         /* Proxies start out serialized (insertions are automatically marked unserialized) */
         if (H5AC_mark_entry_serialized(pentry) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTSERIALIZE, FAIL, "can't mark proxy entry clean")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTSERIALIZE, FAIL, "can't mark proxy entry clean");
 
         /* If there are currently parents, iterate over the list of parents, creating flush dependency on them
          */
         if (pentry->parents)
             if (H5SL_iterate(pentry->parents, H5AC__proxy_entry_add_child_cb, pentry) < 0)
-                HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "can't visit parents")
+                HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "can't visit parents");
     } /* end if */
 
     /* Add flush dependency on proxy entry */
     if (H5AC_create_flush_dependency(pentry, child) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTDEPEND, FAIL, "unable to set flush dependency on proxy entry")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTDEPEND, FAIL, "unable to set flush dependency on proxy entry");
 
     /* Increment count of children */
     pentry->nchildren++;
@@ -329,9 +317,6 @@ done:
  * Return:	Success:	Non-negative on success
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *		Thursday, September 22, 2016
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -341,12 +326,12 @@ H5AC__proxy_entry_remove_child_cb(void *_item, void H5_ATTR_UNUSED *_key, void *
     H5AC_proxy_entry_t *pentry    = (H5AC_proxy_entry_t *)_udata; /* Pointer to the proxy entry */
     int                 ret_value = H5_ITER_CONT;                 /* Callback return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Remove flush dependency on parent for proxy entry */
     if (H5AC_destroy_flush_dependency(parent, pentry) < 0)
         HGOTO_ERROR(H5E_CACHE, H5E_CANTUNDEPEND, H5_ITER_ERROR,
-                    "unable to remove flush dependency for proxy entry")
+                    "unable to remove flush dependency for proxy entry");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -359,9 +344,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              September 17, 2016
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -372,12 +354,12 @@ H5AC_proxy_entry_remove_child(H5AC_proxy_entry_t *pentry, void *child)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(pentry);
-    HDassert(child);
+    assert(pentry);
+    assert(child);
 
     /* Remove flush dependency on proxy entry */
     if (H5AC_destroy_flush_dependency(pentry, child) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTUNDEPEND, FAIL, "unable to remove flush dependency on proxy entry")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTUNDEPEND, FAIL, "unable to remove flush dependency on proxy entry");
 
     /* Decrement count of children */
     pentry->nchildren--;
@@ -388,15 +370,15 @@ H5AC_proxy_entry_remove_child(H5AC_proxy_entry_t *pentry, void *child)
         if (pentry->parents)
             /* Iterate over the list of parents, removing flush dependency on them */
             if (H5SL_iterate(pentry->parents, H5AC__proxy_entry_remove_child_cb, pentry) < 0)
-                HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "can't visit parents")
+                HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "can't visit parents");
 
         /* Unpin proxy */
         if (H5AC_unpin_entry(pentry) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTUNPIN, FAIL, "can't unpin proxy entry")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTUNPIN, FAIL, "can't unpin proxy entry");
 
         /* Remove proxy entry from cache */
         if (H5AC_remove_entry(pentry) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTREMOVE, FAIL, "unable to remove proxy entry")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTREMOVE, FAIL, "unable to remove proxy entry");
     } /* end if */
 
 done:
@@ -410,9 +392,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              September 17, 2016
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -420,19 +399,18 @@ H5AC_proxy_entry_dest(H5AC_proxy_entry_t *pentry)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI(FAIL)
+    FUNC_ENTER_NOAPI_NOERR
 
     /* Sanity checks */
-    HDassert(pentry);
-    HDassert(NULL == pentry->parents);
-    HDassert(0 == pentry->nchildren);
-    HDassert(0 == pentry->ndirty_children);
-    HDassert(0 == pentry->nunser_children);
+    assert(pentry);
+    assert(NULL == pentry->parents);
+    assert(0 == pentry->nchildren);
+    assert(0 == pentry->ndirty_children);
+    assert(0 == pentry->nunser_children);
 
     /* Free the proxy entry object */
     pentry = H5FL_FREE(H5AC_proxy_entry_t, pentry);
 
-done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5AC_proxy_entry_dest() */
 
@@ -443,18 +421,15 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              September 17, 2016
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
 H5AC__proxy_entry_image_len(const void H5_ATTR_UNUSED *thing, size_t *image_len)
 {
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(image_len);
+    assert(image_len);
 
     /* Set the image length size to 1 byte */
     *image_len = 1;
@@ -471,19 +446,16 @@ H5AC__proxy_entry_image_len(const void H5_ATTR_UNUSED *thing, size_t *image_len)
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              September 17, 2016
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
 H5AC__proxy_entry_serialize(const H5F_t H5_ATTR_UNUSED *f, void H5_ATTR_UNUSED *image,
                             size_t H5_ATTR_UNUSED len, void H5_ATTR_UNUSED *thing)
 {
-    FUNC_ENTER_STATIC_NOERR /* Yes, even though this pushes an error on the stack */
+    FUNC_ENTER_PACKAGE_NOERR /* Yes, even though this pushes an error on the stack */
 
         /* Should never be invoked */
-        HDassert(0 && "Invalid callback?!?");
+        assert(0 && "Invalid callback?!?");
 
     HERROR(H5E_CACHE, H5E_CANTSERIALIZE, "called unreachable fcn.");
 
@@ -497,9 +469,6 @@ H5AC__proxy_entry_serialize(const H5F_t H5_ATTR_UNUSED *f, void H5_ATTR_UNUSED *
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              September 17, 2016
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -508,10 +477,10 @@ H5AC__proxy_entry_notify(H5AC_notify_action_t action, void *_thing)
     H5AC_proxy_entry_t *pentry    = (H5AC_proxy_entry_t *)_thing;
     herr_t              ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(pentry);
+    assert(pentry);
 
     switch (action) {
         case H5AC_NOTIFY_ACTION_AFTER_INSERT:
@@ -519,38 +488,38 @@ H5AC__proxy_entry_notify(H5AC_notify_action_t action, void *_thing)
 
         case H5AC_NOTIFY_ACTION_AFTER_LOAD:
 #ifdef NDEBUG
-            HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "invalid notify action from metadata cache")
+            HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "invalid notify action from metadata cache");
 #else  /* NDEBUG */
-            HDassert(0 && "Invalid action?!?");
+            assert(0 && "Invalid action?!?");
 #endif /* NDEBUG */
             break;
 
         case H5AC_NOTIFY_ACTION_AFTER_FLUSH:
 #ifdef NDEBUG
-            HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "invalid notify action from metadata cache")
+            HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "invalid notify action from metadata cache");
 #else  /* NDEBUG */
-            HDassert(0 && "Invalid action?!?");
+            assert(0 && "Invalid action?!?");
 #endif /* NDEBUG */
             break;
 
         case H5AC_NOTIFY_ACTION_BEFORE_EVICT:
             /* Sanity checks */
-            HDassert(0 == pentry->ndirty_children);
-            HDassert(0 == pentry->nunser_children);
+            assert(0 == pentry->ndirty_children);
+            assert(0 == pentry->nunser_children);
 
             /* No action */
             break;
 
         case H5AC_NOTIFY_ACTION_ENTRY_DIRTIED:
             /* Sanity checks */
-            HDassert(pentry->ndirty_children > 0);
+            assert(pentry->ndirty_children > 0);
 
             /* No action */
             break;
 
         case H5AC_NOTIFY_ACTION_ENTRY_CLEANED:
             /* Sanity checks */
-            HDassert(0 == pentry->ndirty_children);
+            assert(0 == pentry->ndirty_children);
 
             /* No action */
             break;
@@ -562,12 +531,12 @@ H5AC__proxy_entry_notify(H5AC_notify_action_t action, void *_thing)
             /* Check for first dirty child */
             if (1 == pentry->ndirty_children)
                 if (H5AC_mark_entry_dirty(pentry) < 0)
-                    HGOTO_ERROR(H5E_CACHE, H5E_CANTDIRTY, FAIL, "can't mark proxy entry dirty")
+                    HGOTO_ERROR(H5E_CACHE, H5E_CANTDIRTY, FAIL, "can't mark proxy entry dirty");
             break;
 
         case H5AC_NOTIFY_ACTION_CHILD_CLEANED:
             /* Sanity check */
-            HDassert(pentry->ndirty_children > 0);
+            assert(pentry->ndirty_children > 0);
 
             /* Decrement # of dirty children */
             pentry->ndirty_children--;
@@ -575,7 +544,7 @@ H5AC__proxy_entry_notify(H5AC_notify_action_t action, void *_thing)
             /* Check for last dirty child */
             if (0 == pentry->ndirty_children)
                 if (H5AC_mark_entry_clean(pentry) < 0)
-                    HGOTO_ERROR(H5E_CACHE, H5E_CANTCLEAN, FAIL, "can't mark proxy entry clean")
+                    HGOTO_ERROR(H5E_CACHE, H5E_CANTCLEAN, FAIL, "can't mark proxy entry clean");
             break;
 
         case H5AC_NOTIFY_ACTION_CHILD_UNSERIALIZED:
@@ -585,12 +554,12 @@ H5AC__proxy_entry_notify(H5AC_notify_action_t action, void *_thing)
             /* Check for first unserialized child */
             if (1 == pentry->nunser_children)
                 if (H5AC_mark_entry_unserialized(pentry) < 0)
-                    HGOTO_ERROR(H5E_CACHE, H5E_CANTUNSERIALIZE, FAIL, "can't mark proxy entry unserialized")
+                    HGOTO_ERROR(H5E_CACHE, H5E_CANTUNSERIALIZE, FAIL, "can't mark proxy entry unserialized");
             break;
 
         case H5AC_NOTIFY_ACTION_CHILD_SERIALIZED:
             /* Sanity check */
-            HDassert(pentry->nunser_children > 0);
+            assert(pentry->nunser_children > 0);
 
             /* Decrement # of unserialized children */
             pentry->nunser_children--;
@@ -598,14 +567,14 @@ H5AC__proxy_entry_notify(H5AC_notify_action_t action, void *_thing)
             /* Check for last unserialized child */
             if (0 == pentry->nunser_children)
                 if (H5AC_mark_entry_serialized(pentry) < 0)
-                    HGOTO_ERROR(H5E_CACHE, H5E_CANTSERIALIZE, FAIL, "can't mark proxy entry serialized")
+                    HGOTO_ERROR(H5E_CACHE, H5E_CANTSERIALIZE, FAIL, "can't mark proxy entry serialized");
             break;
 
         default:
 #ifdef NDEBUG
-            HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "unknown notify action from metadata cache")
+            HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "unknown notify action from metadata cache");
 #else  /* NDEBUG */
-            HDassert(0 && "Unknown action?!?");
+            assert(0 && "Unknown action?!?");
 #endif /* NDEBUG */
     }  /* end switch */
 
@@ -621,9 +590,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              September 17, 2016
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -632,11 +598,11 @@ H5AC__proxy_entry_free_icr(void *_thing)
     H5AC_proxy_entry_t *pentry    = (H5AC_proxy_entry_t *)_thing;
     herr_t              ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Destroy the proxy entry */
     if (H5AC_proxy_entry_dest(pentry) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTFREE, FAIL, "unable to destroy proxy entry")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTFREE, FAIL, "unable to destroy proxy entry");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
