@@ -31,11 +31,11 @@
 /***********/
 #include "H5private.h"   /* Generic Functions                        */
 #include "H5Apkg.h"      /* Attributes                               */
-#include "H5ACprivate.h" /* Metadata cache                           */
 #include "H5CXprivate.h" /* API Contexts                             */
 #include "H5Eprivate.h"  /* Error handling                           */
 #include "H5Iprivate.h"  /* IDs                                      */
 #include "H5SMprivate.h" /* Shared object header messages            */
+#include "H5VLprivate.h" /* Virtual Object Layer                     */
 
 /****************/
 /* Local Macros */
@@ -70,10 +70,7 @@
  *
  * Purpose:     Check if an attribute is shared
  *
- * Return:      TRUE/FALSE/FAIL
- *
- * Programmer:	Quincey Koziol
- *	        Dec 19, 2006
+ * Return:      true/false/FAIL
  *
  *-------------------------------------------------------------------------
  */
@@ -86,8 +83,8 @@ H5A__is_shared_test(hid_t attr_id)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    if (NULL == (attr = (H5A_t *)H5I_object_verify(attr_id, H5I_ATTR)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an attribute")
+    if (NULL == (attr = (H5A_t *)H5VL_object_verify(attr_id, H5I_ATTR)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an attribute");
 
     /* Check if attribute is shared */
     ret_value = H5O_msg_is_shared(H5O_ATTR_ID, attr);
@@ -103,39 +100,36 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *	        Dec 19, 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
 H5A__get_shared_rc_test(hid_t attr_id, hsize_t *ref_count)
 {
-    H5A_t  *attr;                     /* Attribute object for ID */
-    hbool_t api_ctx_pushed = FALSE;   /* Whether API context pushed */
-    herr_t  ret_value      = SUCCEED; /* Return value */
+    H5A_t *attr;                     /* Attribute object for ID */
+    bool   api_ctx_pushed = false;   /* Whether API context pushed */
+    herr_t ret_value      = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    if (NULL == (attr = (H5A_t *)H5I_object_verify(attr_id, H5I_ATTR)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an attribute")
+    if (NULL == (attr = (H5A_t *)H5VL_object_verify(attr_id, H5I_ATTR)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an attribute");
 
     /* Push API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_ATTR, H5E_CANTSET, FAIL, "can't set API context")
-    api_ctx_pushed = TRUE;
+        HGOTO_ERROR(H5E_ATTR, H5E_CANTSET, FAIL, "can't set API context");
+    api_ctx_pushed = true;
 
     /* Sanity check */
-    HDassert(H5O_msg_is_shared(H5O_ATTR_ID, attr));
+    assert(H5O_msg_is_shared(H5O_ATTR_ID, attr));
 
     /* Retrieve ref count for shared or shareable attribute */
     if (H5SM_get_refcount(attr->oloc.file, H5O_ATTR_ID, &attr->sh_loc, ref_count) < 0)
-        HGOTO_ERROR(H5E_ATTR, H5E_CANTGET, FAIL, "can't retrieve shared message ref count")
+        HGOTO_ERROR(H5E_ATTR, H5E_CANTGET, FAIL, "can't retrieve shared message ref count");
 
 done:
-    if (api_ctx_pushed && H5CX_pop() < 0)
-        HDONE_ERROR(H5E_ATTR, H5E_CANTRESET, FAIL, "can't reset API context")
+    if (api_ctx_pushed && H5CX_pop(false) < 0)
+        HDONE_ERROR(H5E_ATTR, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5A__get_shared_rc_test() */
