@@ -5,29 +5,24 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:	Quincey Koziol
- *		Saturday, September 12, 2015
- *
- * Purpose:	This file contains declarations which define macros for the
- *		H5C package.  Including this header means that the source file
- *		is part of the H5C package.
+ * Purpose: This file contains declarations which define macros for the
+ *          H5C package.  Including this header means that the source file
+ *          is part of the H5C package.
  */
-#ifndef _H5Cmodule_H
-#define _H5Cmodule_H
+#ifndef H5Cmodule_H
+#define H5Cmodule_H
 
 /* Define the proper control macros for the generic FUNC_ENTER/LEAVE and error
  *      reporting macros.
  */
 #define H5C_MODULE
-#define H5_MY_PKG       H5C
-#define H5_MY_PKG_ERR   H5E_CACHE
-#define H5_MY_PKG_INIT  NO
-
-#endif /* _H5Cmodule_H */
+#define H5_MY_PKG     H5C
+#define H5_MY_PKG_ERR H5E_CACHE
 
+#endif /* H5Cmodule_H */
