@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:     H5Cquery.c
- *              May 30 2016
- *              Quincey Koziol
  *
  * Purpose:     Routines which query different components of the generic
  *              cache structure or entries.
@@ -70,9 +68,6 @@
  *
  * Return:      SUCCEED on success, and FAIL on failure.
  *
- * Programmer:  John Mainzer
- *		10/8/04
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -82,14 +77,14 @@ H5C_get_cache_auto_resize_config(const H5C_t *cache_ptr, H5C_auto_size_ctl_t *co
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.")
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
     if (config_ptr == NULL)
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad config_ptr on entry.")
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad config_ptr on entry.");
 
     *config_ptr = cache_ptr->resize_ctl;
 
-    config_ptr->set_initial_size = FALSE;
+    config_ptr->set_initial_size = false;
     config_ptr->initial_size     = cache_ptr->max_cache_size;
 
 done:
@@ -107,21 +102,18 @@ done:
  *
  * Return:      SUCCEED on success, and FAIL on failure.
  *
- * Programmer:  John Mainzer
- *		10/8/04
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_get_cache_size(H5C_t *cache_ptr, size_t *max_size_ptr, size_t *min_clean_size_ptr, size_t *cur_size_ptr,
-                   uint32_t *cur_num_entries_ptr)
+H5C_get_cache_size(const H5C_t *cache_ptr, size_t *max_size_ptr, size_t *min_clean_size_ptr,
+                   size_t *cur_size_ptr, uint32_t *cur_num_entries_ptr)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.")
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
 
     if (max_size_ptr != NULL)
         *max_size_ptr = cache_ptr->max_cache_size;
@@ -139,6 +131,33 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_get_cache_size() */
 
+/*-------------------------------------------------------------------------
+ * Function:    H5C_get_cache_flush_in_progress
+ *
+ * Purpose:	Return flush_in_progress in *flush_in_progress_ptr
+ *		    If the parameter is NULL, skip that value.
+ *
+ * Return:  SUCCEED on success, and FAIL on failure.
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5C_get_cache_flush_in_progress(const H5C_t *cache_ptr, bool *flush_in_progress_ptr)
+{
+    herr_t ret_value = SUCCEED; /* Return value */
+
+    FUNC_ENTER_NOAPI(FAIL)
+
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
+
+    if (flush_in_progress_ptr != NULL)
+        *flush_in_progress_ptr = cache_ptr->flush_in_progress;
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* H5C_get_cache_flush_in_progress() */
+
 /*-------------------------------------------------------------------------
  * Function:    H5C_get_cache_hit_rate
  *
@@ -150,37 +169,33 @@ done:
  *
  * Return:      SUCCEED on success, and FAIL on failure.
  *
- * Programmer:  John Mainzer
- *		10/7/04
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_get_cache_hit_rate(H5C_t *cache_ptr, double *hit_rate_ptr)
+H5C_get_cache_hit_rate(const H5C_t *cache_ptr, double *hit_rate_ptr)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.")
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
     if (hit_rate_ptr == NULL)
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad hit_rate_ptr on entry.")
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad hit_rate_ptr on entry.");
 
-    HDassert(cache_ptr->cache_hits >= 0);
-    HDassert(cache_ptr->cache_accesses >= cache_ptr->cache_hits);
+    assert(cache_ptr->cache_hits >= 0);
+    assert(cache_ptr->cache_accesses >= cache_ptr->cache_hits);
 
     if (cache_ptr->cache_accesses > 0)
         *hit_rate_ptr = ((double)(cache_ptr->cache_hits)) / ((double)(cache_ptr->cache_accesses));
     else
-        *hit_rate_ptr = 0.0f;
+        *hit_rate_ptr = 0.0;
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_get_cache_hit_rate() */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C_get_entry_status
  *
  * Purpose:     This function is used to determine whether the cache
@@ -196,16 +211,12 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  John Mainzer
- *              7/1/05
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_get_entry_status(const H5F_t *f, haddr_t addr, size_t *size_ptr, hbool_t *in_cache_ptr,
-                     hbool_t *is_dirty_ptr, hbool_t *is_protected_ptr, hbool_t *is_pinned_ptr,
-                     hbool_t *is_corked_ptr, hbool_t *is_flush_dep_parent_ptr,
-                     hbool_t *is_flush_dep_child_ptr, hbool_t *image_up_to_date_ptr)
+H5C_get_entry_status(const H5F_t *f, haddr_t addr, size_t *size_ptr, bool *in_cache_ptr, bool *is_dirty_ptr,
+                     bool *is_protected_ptr, bool *is_pinned_ptr, bool *is_corked_ptr,
+                     bool *is_flush_dep_parent_ptr, bool *is_flush_dep_child_ptr, bool *image_up_to_date_ptr)
 {
     H5C_t             *cache_ptr;
     H5C_cache_entry_t *entry_ptr = NULL;
@@ -214,32 +225,26 @@ H5C_get_entry_status(const H5F_t *f, haddr_t addr, size_t *size_ptr, hbool_t *in
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f);
-    HDassert(f->shared);
-
+    assert(f);
+    assert(f->shared);
     cache_ptr = f->shared->cache;
+    assert(cache_ptr != NULL);
+    assert(H5_addr_defined(addr));
+    assert(in_cache_ptr != NULL);
 
-    HDassert(cache_ptr != NULL);
-    HDassert(cache_ptr->magic == H5C__H5C_T_MAGIC);
-    HDassert(H5F_addr_defined(addr));
-    HDassert(in_cache_ptr != NULL);
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
 
-    /* this test duplicates two of the above asserts, but we need an
-     * invocation of HGOTO_ERROR to keep the compiler happy.
-     */
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.")
-
-    H5C__SEARCH_INDEX(cache_ptr, addr, entry_ptr, FAIL)
+    H5C__SEARCH_INDEX(cache_ptr, addr, entry_ptr, FAIL);
 
     if (entry_ptr == NULL) {
         /* the entry doesn't exist in the cache -- report this
          * and quit.
          */
-        *in_cache_ptr = FALSE;
+        *in_cache_ptr = false;
     } /* end if */
     else {
-        *in_cache_ptr = TRUE;
+        *in_cache_ptr = true;
         if (size_ptr != NULL)
             *size_ptr = entry_ptr->size;
         if (is_dirty_ptr != NULL)
@@ -249,7 +254,7 @@ H5C_get_entry_status(const H5F_t *f, haddr_t addr, size_t *size_ptr, hbool_t *in
         if (is_pinned_ptr != NULL)
             *is_pinned_ptr = entry_ptr->is_pinned;
         if (is_corked_ptr != NULL)
-            *is_corked_ptr = entry_ptr->tag_info ? entry_ptr->tag_info->corked : FALSE;
+            *is_corked_ptr = entry_ptr->tag_info ? entry_ptr->tag_info->corked : false;
         if (is_flush_dep_parent_ptr != NULL)
             *is_flush_dep_parent_ptr = (entry_ptr->flush_dep_nchildren > 0);
         if (is_flush_dep_child_ptr != NULL)
@@ -270,23 +275,20 @@ done:
  *
  * Return:      SUCCEED on success, and FAIL on failure.
  *
- * Programmer:  John Mainzer
- *              7/27/07
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_get_evictions_enabled(const H5C_t *cache_ptr, hbool_t *evictions_enabled_ptr)
+H5C_get_evictions_enabled(const H5C_t *cache_ptr, bool *evictions_enabled_ptr)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.")
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
 
     if (evictions_enabled_ptr == NULL)
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad evictions_enabled_ptr on entry.")
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad evictions_enabled_ptr on entry.");
 
     *evictions_enabled_ptr = cache_ptr->evictions_enabled;
 
@@ -304,9 +306,6 @@ done:
  *
  * Return:      NULL/non-NULL (can't fail)
  *
- * Programmer:  Quincey Koziol
- *              6/29/15
- *
  *-------------------------------------------------------------------------
  */
 void *
@@ -315,8 +314,7 @@ H5C_get_aux_ptr(const H5C_t *cache_ptr)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check arguments */
-    HDassert(cache_ptr);
-    HDassert(cache_ptr->magic == H5C__H5C_T_MAGIC);
+    assert(cache_ptr);
 
     FUNC_LEAVE_NOAPI(cache_ptr->aux_ptr)
 } /* H5C_get_aux_ptr() */
@@ -331,9 +329,6 @@ H5C_get_aux_ptr(const H5C_t *cache_ptr)
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              9/8/15
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -346,17 +341,16 @@ H5C_get_entry_ring(const H5F_t *f, haddr_t addr, H5C_ring_t *ring)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
     cache_ptr = f->shared->cache;
-    HDassert(cache_ptr);
-    HDassert(cache_ptr->magic == H5C__H5C_T_MAGIC);
-    HDassert(H5F_addr_defined(addr));
+    assert(cache_ptr);
+    assert(H5_addr_defined(addr));
 
     /* Locate the entry at the address */
-    H5C__SEARCH_INDEX(cache_ptr, addr, entry_ptr, FAIL)
+    H5C__SEARCH_INDEX(cache_ptr, addr, entry_ptr, FAIL);
     if (entry_ptr == NULL)
-        HGOTO_ERROR(H5E_CACHE, H5E_NOTFOUND, FAIL, "can't find entry in index")
+        HGOTO_ERROR(H5E_CACHE, H5E_NOTFOUND, FAIL, "can't find entry in index");
 
     /* Return the ring value */
     *ring = entry_ptr->ring;
@@ -372,24 +366,22 @@ done:
  *
  * Return:      SUCCEED on success, and FAIL on failure.
  *
- * Programmer:  Vailin Choi; March 2017
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_get_mdc_image_info(H5C_t *cache_ptr, haddr_t *image_addr, hsize_t *image_len)
+H5C_get_mdc_image_info(const H5C_t *cache_ptr, haddr_t *image_addr, hsize_t *image_len)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "bad cache_ptr on entry")
-    if (image_addr == NULL || image_len == NULL)
-        HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "bad image_addr or image_len on entry")
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "bad cache_ptr on entry");
 
-    *image_addr = cache_ptr->image_addr;
-    *image_len  = cache_ptr->image_len;
+    if (image_addr)
+        *image_addr = cache_ptr->image_addr;
+    if (image_len)
+        *image_len = cache_ptr->image_len;
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
