@@ -78,11 +78,16 @@
 #define H5D_MPIO_LOCAL_NO_COLLECTIVE_CAUSE_NAME                                                              \
     "local_no_collective_cause" /* cause of broken collective I/O in each process */
 #define H5D_MPIO_GLOBAL_NO_COLLECTIVE_CAUSE_NAME                                                             \
-    "global_no_collective_cause"                 /* cause of broken collective I/O in all processes */
-#define H5D_XFER_EDC_NAME       "err_detect"     /* EDC */
-#define H5D_XFER_FILTER_CB_NAME "filter_cb"      /* Filter callback function */
-#define H5D_XFER_CONV_CB_NAME   "type_conv_cb"   /* Type conversion callback function */
-#define H5D_XFER_XFORM_NAME     "data_transform" /* Data transform */
+    "global_no_collective_cause" /* cause of broken collective I/O in all processes */
+#define H5D_XFER_EDC_NAME                      "err_detect"            /* EDC */
+#define H5D_XFER_FILTER_CB_NAME                "filter_cb"             /* Filter callback function */
+#define H5D_XFER_CONV_CB_NAME                  "type_conv_cb"          /* Type conversion callback function */
+#define H5D_XFER_XFORM_NAME                    "data_transform"        /* Data transform */
+#define H5D_XFER_DSET_IO_SEL_NAME              "dset_io_selection"     /* Dataset I/O selection */
+#define H5D_XFER_SELECTION_IO_MODE_NAME        "selection_io_mode"     /* Selection I/O mode */
+#define H5D_XFER_NO_SELECTION_IO_CAUSE_NAME    "no_selection_io_cause" /* Cause for no selection I/O */
+#define H5D_XFER_ACTUAL_SELECTION_IO_MODE_NAME "actual_selection_io_mode" /* Actual selection I/O mode */
+#define H5D_XFER_MODIFY_WRITE_BUF_NAME         "modify_write_buf"         /* Modify write buffers */
 #ifdef H5_HAVE_INSTRUMENTED_LIBRARY
 /* Collective chunk instrumentation properties */
 #define H5D_XFER_COLL_CHUNK_LINK_HARD_NAME        "coll_chunk_link_hard"
@@ -100,8 +105,8 @@
 #define H5D_XFER_COLL_RANK0_BCAST_NAME "coll_rank0_bcast"
 
 /* Definitions for general collective I/O instrumentation properties */
-#define H5D_XFER_COLL_RANK0_BCAST_SIZE sizeof(hbool_t)
-#define H5D_XFER_COLL_RANK0_BCAST_DEF  FALSE
+#define H5D_XFER_COLL_RANK0_BCAST_SIZE sizeof(bool)
+#define H5D_XFER_COLL_RANK0_BCAST_DEF  false
 #endif /* H5_HAVE_INSTRUMENTED_LIBRARY */
 
 /* Default temporary buffer size */
@@ -119,12 +124,19 @@
 /* Default virtual dataset list size */
 #define H5D_VIRTUAL_DEF_LIST_SIZE 8
 
+#ifdef H5D_MODULE
+#define H5D_OBJ_ID(D) (((H5D_obj_create_t *)(D))->dcpl_id)
+#else /* H5D_MODULE */
+#define H5D_OBJ_ID(D) (H5D_get_dcpl_id(D))
+#endif
+
 /****************************/
 /* Library Private Typedefs */
 /****************************/
 
 /* Typedef for dataset in memory (defined in H5Dpkg.h) */
-typedef struct H5D_t H5D_t;
+typedef struct H5D_t            H5D_t;
+typedef struct H5D_obj_create_t H5D_obj_create_t;
 
 /* Typedef for cached dataset creation property list information */
 typedef struct H5D_dcpl_cache_t {
@@ -163,16 +175,13 @@ H5_DLL herr_t      H5D_mult_refresh_close(hid_t dset_id);
 H5_DLL herr_t      H5D_mult_refresh_reopen(H5D_t *dataset);
 H5_DLL H5O_loc_t  *H5D_oloc(H5D_t *dataset);
 H5_DLL H5G_name_t *H5D_nameof(H5D_t *dataset);
-H5_DLL H5T_t      *H5D_typeof(const H5D_t *dset);
 H5_DLL herr_t      H5D_flush_all(H5F_t *f);
 H5_DLL hid_t       H5D_get_create_plist(const H5D_t *dset);
 H5_DLL hid_t       H5D_get_access_plist(const H5D_t *dset);
-
-/* Functions that operate on vlen data */
-H5_DLL herr_t H5D_vlen_reclaim(hid_t type_id, H5S_t *space, void *buf);
+H5_DLL hid_t       H5D_get_dcpl_id(const H5D_obj_create_t *d);
 
 /* Functions that operate on chunked storage */
-H5_DLL herr_t H5D_chunk_idx_reset(H5O_storage_chunk_t *storage, hbool_t reset_addr);
+H5_DLL herr_t H5D_chunk_idx_reset(H5O_storage_chunk_t *storage, bool reset_addr);
 
 /* Functions that operate on virtual storage */
 H5_DLL herr_t H5D_virtual_check_mapping_pre(const H5S_t *vspace, const H5S_t *src_space,
