@@ -16,10 +16,6 @@
 #ifndef H5FOprivate_H
 #define H5FOprivate_H
 
-#ifdef LATER
-#include "H5FOpublic.h"
-#endif /* LATER */
-
 /* Private headers needed by this file */
 #include "H5private.h"   /* Generic Functions			*/
 #include "H5Fprivate.h"  /* File access				*/
@@ -35,10 +31,10 @@ typedef H5SL_t H5FO_t; /* Currently, all open objects are stored in skip list */
 /* Private routines */
 H5_DLL herr_t  H5FO_create(const H5F_t *f);
 H5_DLL void   *H5FO_opened(const H5F_t *f, haddr_t addr);
-H5_DLL herr_t  H5FO_insert(const H5F_t *f, haddr_t addr, void *obj, hbool_t delete_flag);
+H5_DLL herr_t  H5FO_insert(const H5F_t *f, haddr_t addr, void *obj, bool delete_flag);
 H5_DLL herr_t  H5FO_delete(H5F_t *f, haddr_t addr);
-H5_DLL herr_t  H5FO_mark(const H5F_t *f, haddr_t addr, hbool_t deleted);
-H5_DLL hbool_t H5FO_marked(const H5F_t *f, haddr_t addr);
+H5_DLL herr_t  H5FO_mark(const H5F_t *f, haddr_t addr, bool deleted);
+H5_DLL bool    H5FO_marked(const H5F_t *f, haddr_t addr);
 H5_DLL herr_t  H5FO_dest(const H5F_t *f);
 H5_DLL herr_t  H5FO_top_create(H5F_t *f);
 H5_DLL herr_t  H5FO_top_incr(const H5F_t *f, haddr_t addr);
