@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke
- *              Friday, March 27, 1998
- *
  * Purpose:	Operations on the global heap.  The global heap is the set of
  *		all collections and each collection contains one or more
  *		global heap objects.  An object belongs to exactly one
@@ -46,6 +43,7 @@
 #include "H5private.h"   /* Generic Functions			*/
 #include "H5Eprivate.h"  /* Error handling		  	*/
 #include "H5Fprivate.h"  /* File access				*/
+#include "H5FLprivate.h" /* Free Lists                               */
 #include "H5HGpkg.h"     /* Global heaps				*/
 #include "H5MFprivate.h" /* File memory management		*/
 #include "H5MMprivate.h" /* Memory management			*/
@@ -83,9 +81,6 @@ static size_t  H5HG__alloc(H5F_t *f, H5HG_heap_t *heap, size_t size, unsigned *h
 /* Package Variables */
 /*********************/
 
-/* Package initialization variable */
-hbool_t H5_PKG_INIT_VAR = FALSE;
-
 /* Declare a free list to manage the H5HG_heap_t struct */
 H5FL_DEFINE(H5HG_heap_t);
 
@@ -117,9 +112,6 @@ H5FL_BLK_DEFINE(gheap_chunk);
  *
  *		Failure:	NULL
  *
- * Programmer:	Robb Matzke
- *              Friday, March 27, 1998
- *
  *-------------------------------------------------------------------------
  */
 static haddr_t
@@ -131,10 +123,10 @@ H5HG__create(H5F_t *f, size_t size)
     size_t       n;
     haddr_t      ret_value = HADDR_UNDEF; /* Return value */
 
-    FUNC_ENTER_STATIC_TAG(H5AC__GLOBALHEAP_TAG)
+    FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(f);
+    assert(f);
     if (size < H5HG_MINSIZE)
         size = H5HG_MINSIZE;
     size = H5HG_ALIGN(size);
@@ -142,20 +134,20 @@ H5HG__create(H5F_t *f, size_t size)
     /* Create it */
     H5_CHECK_OVERFLOW(size, size_t, hsize_t);
     if (HADDR_UNDEF == (addr = H5MF_alloc(f, H5FD_MEM_GHEAP, (hsize_t)size)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, HADDR_UNDEF, "unable to allocate file space for global heap")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, HADDR_UNDEF, "unable to allocate file space for global heap");
     if (NULL == (heap = H5FL_CALLOC(H5HG_heap_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, HADDR_UNDEF, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, HADDR_UNDEF, "memory allocation failed");
     heap->addr   = addr;
     heap->size   = size;
     heap->shared = H5F_SHARED(f);
 
     if (NULL == (heap->chunk = H5FL_BLK_MALLOC(gheap_chunk, size)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, HADDR_UNDEF, "memory allocation failed")
-    HDmemset(heap->chunk, 0, size);
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, HADDR_UNDEF, "memory allocation failed");
+    memset(heap->chunk, 0, size);
     heap->nalloc = H5HG_NOBJS(f, size);
     heap->nused  = 1; /* account for index 0, which is used for the free object */
     if (NULL == (heap->obj = H5FL_SEQ_MALLOC(H5HG_obj_t, heap->nalloc)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, HADDR_UNDEF, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, HADDR_UNDEF, "memory allocation failed");
 
     /* Initialize the header */
     H5MM_memcpy(heap->chunk, H5HG_MAGIC, (size_t)H5_SIZEOF_MAGIC);
@@ -172,55 +164,47 @@ H5HG__create(H5F_t *f, size_t size)
      * align the pointer, but this might not be the case.
      */
     n = (size_t)H5HG_ALIGN(p - heap->chunk) - (size_t)(p - heap->chunk);
-#ifdef OLD_WAY
-    /* Don't bother zeroing out the rest of the info in the heap -QAK */
-    HDmemset(p, 0, n);
-#endif /* OLD_WAY */
     p += n;
 
     /* The freespace object */
     heap->obj[0].size = size - H5HG_SIZEOF_HDR(f);
-    HDassert(H5HG_ISALIGNED(heap->obj[0].size));
+    assert(H5HG_ISALIGNED(heap->obj[0].size));
     heap->obj[0].nrefs = 0;
     heap->obj[0].begin = p;
     UINT16ENCODE(p, 0); /*object ID*/
     UINT16ENCODE(p, 0); /*reference count*/
     UINT32ENCODE(p, 0); /*reserved*/
     H5F_ENCODE_LENGTH(f, p, heap->obj[0].size);
-#ifdef OLD_WAY
-    /* Don't bother zeroing out the rest of the info in the heap -QAK */
-    HDmemset(p, 0, (size_t)((heap->chunk + heap->size) - p));
-#endif /* OLD_WAY */
 
     /* Add this heap to the beginning of the CWFS list */
     if (H5F_cwfs_add(f, heap) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, HADDR_UNDEF,
-                    "unable to add global heap collection to file's CWFS")
+                    "unable to add global heap collection to file's CWFS");
 
     /* Add the heap to the cache */
     if (H5AC_insert_entry(f, H5AC_GHEAP, addr, heap, H5AC__NO_FLAGS_SET) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, HADDR_UNDEF, "unable to cache global heap collection")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, HADDR_UNDEF, "unable to cache global heap collection");
 
     ret_value = addr;
 
 done:
     /* Cleanup on error */
-    if (!H5F_addr_defined(ret_value)) {
-        if (H5F_addr_defined(addr)) {
+    if (!H5_addr_defined(ret_value)) {
+        if (H5_addr_defined(addr)) {
             /* Release the space on disk */
             if (H5MF_xfree(f, H5FD_MEM_GHEAP, addr, (hsize_t)size) < 0)
-                HDONE_ERROR(H5E_BTREE, H5E_CANTFREE, HADDR_UNDEF, "unable to free global heap")
+                HDONE_ERROR(H5E_BTREE, H5E_CANTFREE, HADDR_UNDEF, "unable to free global heap");
 
             /* Check if the heap object was allocated */
             if (heap)
                 /* Destroy the heap object */
                 if (H5HG__free(heap) < 0)
                     HDONE_ERROR(H5E_HEAP, H5E_CANTFREE, HADDR_UNDEF,
-                                "unable to destroy global heap collection")
+                                "unable to destroy global heap collection");
         } /* end if */
     }     /* end if */
 
-    FUNC_LEAVE_NOAPI_TAG(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* H5HG__create() */
 
 /*-------------------------------------------------------------------------
@@ -230,9 +214,6 @@ done:
  *
  * Return:	Pointer to indirect block on success, NULL on failure
  *
- * Programmer:	Quincey Koziol
- *              Wednesday, May  5, 2010
- *
  *-------------------------------------------------------------------------
  */
 H5HG_heap_t *
@@ -244,15 +225,15 @@ H5HG__protect(H5F_t *f, haddr_t addr, unsigned flags)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(H5_addr_defined(addr));
 
     /* only H5AC__READ_ONLY_FLAG may appear in flags */
-    HDassert((flags & (unsigned)(~H5AC__READ_ONLY_FLAG)) == 0);
+    assert((flags & (unsigned)(~H5AC__READ_ONLY_FLAG)) == 0);
 
     /* Lock the heap into memory */
     if (NULL == (heap = (H5HG_heap_t *)H5AC_protect(f, H5AC_GHEAP, addr, f, flags)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, NULL, "unable to protect global heap")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, NULL, "unable to protect global heap");
 
     /* Set the heap's address */
     heap->addr = addr;
@@ -277,9 +258,6 @@ done:
  *
  *		Failure:	0
  *
- * Programmer:	Robb Matzke
- *              Friday, March 27, 1998
- *
  *-------------------------------------------------------------------------
  */
 static size_t
@@ -290,12 +268,12 @@ H5HG__alloc(H5F_t *f, H5HG_heap_t *heap, size_t size, unsigned *heap_flags_ptr)
     size_t   need      = H5HG_SIZEOF_OBJHDR(f) + H5HG_ALIGN(size);
     size_t   ret_value = 0; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(heap);
-    HDassert(heap->obj[0].size >= need);
-    HDassert(heap_flags_ptr);
+    assert(heap);
+    assert(heap->obj[0].size >= need);
+    assert(heap_flags_ptr);
 
     /*
      * Find an ID for the new object. ID zero is reserved for the free space
@@ -309,7 +287,7 @@ H5HG__alloc(H5F_t *f, H5HG_heap_t *heap, size_t size, unsigned *heap_flags_ptr)
                 break;
     } /* end else */
 
-    HDassert(idx < heap->nused);
+    assert(idx < heap->nused);
 
     /* Check if we need more room to store heap objects */
     if (idx >= heap->nalloc) {
@@ -319,19 +297,19 @@ H5HG__alloc(H5F_t *f, H5HG_heap_t *heap, size_t size, unsigned *heap_flags_ptr)
         /* Determine the new number of objects to index */
         /* nalloc is *not* guaranteed to be a power of 2! - NAF 10/26/09 */
         new_alloc = MIN(MAX(heap->nalloc * 2, (idx + 1)), (H5HG_MAXIDX + 1));
-        HDassert(idx < new_alloc);
+        assert(idx < new_alloc);
 
         /* Reallocate array of objects */
         if (NULL == (new_obj = H5FL_SEQ_REALLOC(H5HG_obj_t, heap->obj, new_alloc)))
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, 0, "memory allocation failed")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, 0, "memory allocation failed");
 
         /* Clear newly allocated space */
-        HDmemset(&new_obj[heap->nalloc], 0, (new_alloc - heap->nalloc) * sizeof(heap->obj[0]));
+        memset(&new_obj[heap->nalloc], 0, (new_alloc - heap->nalloc) * sizeof(heap->obj[0]));
 
         /* Update heap information */
         heap->nalloc = new_alloc;
         heap->obj    = new_obj;
-        HDassert(heap->nalloc > heap->nused);
+        assert(heap->nalloc > heap->nused);
     } /* end if */
 
     /* Initialize the new object */
@@ -364,7 +342,7 @@ H5HG__alloc(H5F_t *f, H5HG_heap_t *heap, size_t size, unsigned *heap_flags_ptr)
         UINT16ENCODE(p, 0); /*nrefs*/
         UINT32ENCODE(p, 0); /*reserved*/
         H5F_ENCODE_LENGTH(f, p, heap->obj[0].size);
-        HDassert(H5HG_ISALIGNED(heap->obj[0].size));
+        assert(H5HG_ISALIGNED(heap->obj[0].size));
     } /* end else-if */
     else {
         /*
@@ -373,7 +351,7 @@ H5HG__alloc(H5F_t *f, H5HG_heap_t *heap, size_t size, unsigned *heap_flags_ptr)
          */
         heap->obj[0].size -= need;
         heap->obj[0].begin += need;
-        HDassert(H5HG_ISALIGNED(heap->obj[0].size));
+        assert(H5HG_ISALIGNED(heap->obj[0].size));
     }
 
     /* Mark the heap as dirty */
@@ -383,7 +361,7 @@ H5HG__alloc(H5F_t *f, H5HG_heap_t *heap, size_t size, unsigned *heap_flags_ptr)
     ret_value = idx;
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HG__alloc() */
 
 /*-------------------------------------------------------------------------
@@ -398,9 +376,6 @@ done:
  *
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Saturday, June 12, 2004
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -417,17 +392,17 @@ H5HG_extend(H5F_t *f, haddr_t addr, size_t need)
     FUNC_ENTER_NOAPI_NOINIT
 
     /* Check args */
-    HDassert(f);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(H5_addr_defined(addr));
 
     /* Protect the heap */
     if (NULL == (heap = H5HG__protect(f, addr, H5AC__NO_FLAGS_SET)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect global heap")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect global heap");
 
     /* Re-allocate the heap information in memory */
     if (NULL == (new_chunk = H5FL_BLK_REALLOC(gheap_chunk, heap->chunk, (heap->size + need))))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "new heap allocation failed")
-    HDmemset(new_chunk + heap->size, 0, need);
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "new heap allocation failed");
+    memset(new_chunk + heap->size, 0, need);
 
     /* Adjust the size of the heap */
     old_size = heap->size;
@@ -454,18 +429,18 @@ H5HG_extend(H5F_t *f, haddr_t addr, size_t need)
     UINT16ENCODE(p, 0); /*nrefs*/
     UINT32ENCODE(p, 0); /*reserved*/
     H5F_ENCODE_LENGTH(f, p, heap->obj[0].size);
-    HDassert(H5HG_ISALIGNED(heap->obj[0].size));
+    assert(H5HG_ISALIGNED(heap->obj[0].size));
 
     /* Resize the heap in the cache */
     if (H5AC_resize_entry(heap, heap->size) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTRESIZE, FAIL, "unable to resize global heap in cache")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTRESIZE, FAIL, "unable to resize global heap in cache");
 
     /* Mark the heap as dirty */
     heap_flags |= H5AC__DIRTIED_FLAG;
 
 done:
     if (heap && H5AC_unprotect(f, H5AC_GHEAP, heap->addr, heap, heap_flags) < 0)
-        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to unprotect heap")
+        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to unprotect heap");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HG_extend() */
@@ -487,9 +462,6 @@ done:
  *
  *		Failure:	Negative
  *
- * Programmer:	Robb Matzke
- *              Friday, March 27, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -505,12 +477,12 @@ H5HG_insert(H5F_t *f, size_t size, const void *obj, H5HG_t *hobj /*out*/)
     FUNC_ENTER_NOAPI_TAG(H5AC__GLOBALHEAP_TAG, FAIL)
 
     /* Check args */
-    HDassert(f);
-    HDassert(0 == size || obj);
-    HDassert(hobj);
+    assert(f);
+    assert(0 == size || obj);
+    assert(hobj);
 
     if (0 == (H5F_INTENT(f) & H5F_ACC_RDWR))
-        HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "no write intent on file")
+        HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "no write intent on file");
 
     /* Find a large enough collection on the CWFS list */
     need = H5HG_SIZEOF_OBJHDR(f) + H5HG_ALIGN(size);
@@ -518,36 +490,30 @@ H5HG_insert(H5F_t *f, size_t size, const void *obj, H5HG_t *hobj /*out*/)
     /* Look for a heap in the file's CWFS that has enough space for the object */
     addr = HADDR_UNDEF;
     if (H5F_cwfs_find_free_heap(f, need, &addr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "error trying to locate heap")
+        HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "error trying to locate heap");
 
     /*
      * If we didn't find any collection with enough free space then allocate a
      * new collection large enough for the message plus the collection header.
      */
-    if (!H5F_addr_defined(addr)) {
+    if (!H5_addr_defined(addr)) {
         addr = H5HG__create(f, need + H5HG_SIZEOF_HDR(f));
 
-        if (!H5F_addr_defined(addr))
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "unable to allocate a global heap collection")
+        if (!H5_addr_defined(addr))
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "unable to allocate a global heap collection");
     } /* end if */
-    HDassert(H5F_addr_defined(addr));
+    assert(H5_addr_defined(addr));
 
     if (NULL == (heap = H5HG__protect(f, addr, H5AC__NO_FLAGS_SET)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect global heap")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect global heap");
 
     /* Split the free space to make room for the new object */
     if (0 == (idx = H5HG__alloc(f, heap, size, &heap_flags)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "unable to allocate global heap object")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "unable to allocate global heap object");
 
     /* Copy data into the heap */
-    if (size > 0) {
+    if (size > 0)
         H5MM_memcpy(heap->obj[idx].begin + H5HG_SIZEOF_OBJHDR(f), obj, size);
-#ifdef OLD_WAY
-        /* Don't bother zeroing out the rest of the info in the heap -QAK */
-        HDmemset(heap->obj[idx].begin + H5HG_SIZEOF_OBJHDR(f) + size, 0,
-                 need - (H5HG_SIZEOF_OBJHDR(f) + size));
-#endif /* OLD_WAY */
-    }  /* end if */
     heap_flags |= H5AC__DIRTIED_FLAG;
 
     /* Return value */
@@ -556,7 +522,7 @@ H5HG_insert(H5F_t *f, size_t size, const void *obj, H5HG_t *hobj /*out*/)
 
 done:
     if (heap && H5AC_unprotect(f, H5AC_GHEAP, heap->addr, heap, heap_flags) < 0)
-        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to unprotect heap.")
+        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to unprotect heap.");
 
     FUNC_LEAVE_NOAPI_TAG(ret_value)
 } /* H5HG_insert() */
@@ -573,9 +539,6 @@ done:
  *
  *		Failure:	NULL
  *
- * Programmer:	Robb Matzke
- *              Monday, March 30, 1998
- *
  *-------------------------------------------------------------------------
  */
 void *
@@ -590,21 +553,30 @@ H5HG_read(H5F_t *f, H5HG_t *hobj, void *object /*out*/, size_t *buf_size)
     FUNC_ENTER_NOAPI_TAG(H5AC__GLOBALHEAP_TAG, NULL)
 
     /* Check args */
-    HDassert(f);
-    HDassert(hobj);
+    assert(f);
+    assert(hobj);
+
+    /* Heap object idx 0 is the free space in the heap and should never be given out */
+    if (0 == hobj->idx)
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, NULL, "bad heap index, heap object = {%" PRIxHADDR ", %zu}",
+                    hobj->addr, hobj->idx);
 
     /* Load the heap */
     if (NULL == (heap = H5HG__protect(f, hobj->addr, H5AC__READ_ONLY_FLAG)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, NULL, "unable to protect global heap")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, NULL, "unable to protect global heap");
+    if (hobj->idx >= heap->nused)
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, NULL, "bad heap index, heap object = {%" PRIxHADDR ", %zu}",
+                    hobj->addr, hobj->idx);
+    if (NULL == heap->obj[hobj->idx].begin)
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, NULL, "bad heap pointer, heap object = {%" PRIxHADDR ", %zu}",
+                    hobj->addr, hobj->idx);
 
-    HDassert(hobj->idx < heap->nused);
-    HDassert(heap->obj[hobj->idx].begin);
     size = heap->obj[hobj->idx].size;
     p    = heap->obj[hobj->idx].begin + H5HG_SIZEOF_OBJHDR(f);
 
     /* Allocate a buffer for the object read in, if the user didn't give one */
     if (!object && NULL == (object = H5MM_malloc(size)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
     H5MM_memcpy(object, p, size);
 
     /*
@@ -612,8 +584,8 @@ H5HG_read(H5F_t *f, H5HG_t *hobj, void *object /*out*/, size_t *buf_size)
      * with the H5AC_protect(), but it won't hurt to do it twice.
      */
     if (heap->obj[0].begin) {
-        if (H5F_cwfs_advance_heap(f, heap, FALSE) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTMODIFY, NULL, "can't adjust file's CWFS")
+        if (H5F_cwfs_advance_heap(f, heap, false) < 0)
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTMODIFY, NULL, "can't adjust file's CWFS");
     } /* end if */
 
     /* If the caller would like to know the heap object's size, set that */
@@ -625,7 +597,7 @@ H5HG_read(H5F_t *f, H5HG_t *hobj, void *object /*out*/, size_t *buf_size)
 
 done:
     if (heap && H5AC_unprotect(f, H5AC_GHEAP, hobj->addr, heap, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, NULL, "unable to release object header")
+        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, NULL, "unable to release object header");
 
     if (NULL == ret_value && NULL == orig_object && object)
         H5MM_free(object);
@@ -646,9 +618,6 @@ done:
  *
  *		Failure:	Negative
  *
- * Programmer:	Robb Matzke
- *              Monday, March 30, 1998
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -661,22 +630,31 @@ H5HG_link(H5F_t *f, const H5HG_t *hobj, int adjust)
     FUNC_ENTER_NOAPI_TAG(H5AC__GLOBALHEAP_TAG, FAIL)
 
     /* Check args */
-    HDassert(f);
-    HDassert(hobj);
+    assert(f);
+    assert(hobj);
     if (0 == (H5F_INTENT(f) & H5F_ACC_RDWR))
-        HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "no write intent on file")
+        HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "no write intent on file");
+
+    /* Heap object idx 0 is the free space in the heap and should never be given out */
+    if (0 == hobj->idx)
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad heap index, heap object = {%" PRIxHADDR ", %zu}",
+                    hobj->addr, hobj->idx);
 
     /* Load the heap */
     if (NULL == (heap = H5HG__protect(f, hobj->addr, H5AC__NO_FLAGS_SET)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect global heap")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect global heap");
 
     if (adjust != 0) {
-        HDassert(hobj->idx < heap->nused);
-        HDassert(heap->obj[hobj->idx].begin);
+        if (hobj->idx >= heap->nused)
+            HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad heap index, heap object = {%" PRIxHADDR ", %zu}",
+                        hobj->addr, hobj->idx);
+        if (NULL == heap->obj[hobj->idx].begin)
+            HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad heap pointer, heap object = {%" PRIxHADDR ", %zu}",
+                        hobj->addr, hobj->idx);
         if ((heap->obj[hobj->idx].nrefs + adjust) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_BADRANGE, FAIL, "new link count would be out of range")
+            HGOTO_ERROR(H5E_HEAP, H5E_BADRANGE, FAIL, "new link count would be out of range");
         if ((heap->obj[hobj->idx].nrefs + adjust) > H5HG_MAXLINK)
-            HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "new link count would be out of range")
+            HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "new link count would be out of range");
         heap->obj[hobj->idx].nrefs += adjust;
         heap_flags |= H5AC__DIRTIED_FLAG;
     } /* end if */
@@ -686,7 +664,7 @@ H5HG_link(H5F_t *f, const H5HG_t *hobj, int adjust)
 
 done:
     if (heap && H5AC_unprotect(f, H5AC_GHEAP, hobj->addr, heap, heap_flags) < 0)
-        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
+        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release object header");
 
     FUNC_LEAVE_NOAPI_TAG(ret_value)
 } /* end H5HG_link() */
@@ -699,9 +677,6 @@ done:
  *
  *              Failure:        Negative
  *
- * Programmer:  Neil Fortner
- *              Thursday, February 12, 2015
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -713,23 +688,33 @@ H5HG_get_obj_size(H5F_t *f, H5HG_t *hobj, size_t *obj_size)
     FUNC_ENTER_NOAPI_TAG(H5AC__GLOBALHEAP_TAG, FAIL)
 
     /* Check args */
-    HDassert(f);
-    HDassert(hobj);
-    HDassert(obj_size);
+    assert(f);
+    assert(hobj);
+    assert(obj_size);
+
+    /* Heap object idx 0 is the free space in the heap and should never be given out */
+    if (0 == hobj->idx)
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad heap index, heap object = {%" PRIxHADDR ", %zu}",
+                    hobj->addr, hobj->idx);
 
     /* Load the heap */
     if (NULL == (heap = H5HG__protect(f, hobj->addr, H5AC__READ_ONLY_FLAG)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect global heap")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect global heap");
 
-    HDassert(hobj->idx < heap->nused);
-    HDassert(heap->obj[hobj->idx].begin);
+    /* Sanity check the heap object */
+    if (hobj->idx >= heap->nused)
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad heap index, heap object = {%" PRIxHADDR ", %zu}",
+                    hobj->addr, hobj->idx);
+    if (NULL == heap->obj[hobj->idx].begin)
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad heap pointer, heap object = {%" PRIxHADDR ", %zu}",
+                    hobj->addr, hobj->idx);
 
     /* Set object size */
     *obj_size = heap->obj[hobj->idx].size;
 
 done:
     if (heap && H5AC_unprotect(f, H5AC_GHEAP, hobj->addr, heap, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
+        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release object header");
 
     FUNC_LEAVE_NOAPI_TAG(ret_value)
 } /* end H5HG_get_obj_size() */
@@ -741,9 +726,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *              Monday, March 30, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -759,23 +741,36 @@ H5HG_remove(H5F_t *f, H5HG_t *hobj)
     FUNC_ENTER_NOAPI_TAG(H5AC__GLOBALHEAP_TAG, FAIL)
 
     /* Check args */
-    HDassert(f);
-    HDassert(hobj);
+    assert(f);
+    assert(hobj);
     if (0 == (H5F_INTENT(f) & H5F_ACC_RDWR))
-        HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "no write intent on file")
+        HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "no write intent on file");
+
+    /* Heap object idx 0 is the free space in the heap and should never be given out */
+    if (0 == hobj->idx)
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad heap index, heap object = {%" PRIxHADDR ", %zu}",
+                    hobj->addr, hobj->idx);
 
     /* Load the heap */
     if (NULL == (heap = H5HG__protect(f, hobj->addr, H5AC__NO_FLAGS_SET)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect global heap")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect global heap");
 
-    HDassert(hobj->idx < heap->nused);
+    /* Sanity check the heap object (split around bugfix below) */
+    if (hobj->idx >= heap->nused)
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad heap index, heap object = {%" PRIxHADDR ", %zu}",
+                    hobj->addr, hobj->idx);
 
     /* When the application selects the same location to rewrite the VL element by using H5Sselect_elements,
      * it can happen that the entry has been removed by first rewrite.  Here we simply skip the removal of
      * the entry and let the second rewrite happen (see HDFFV-10635).  In the future, it'd be nice to handle
      * this situation in H5T_conv_vlen in H5Tconv.c instead of this level (HDFFV-10648). */
     if (heap->obj[hobj->idx].nrefs == 0 && heap->obj[hobj->idx].size == 0 && !heap->obj[hobj->idx].begin)
-        HGOTO_DONE(ret_value)
+        HGOTO_DONE(SUCCEED);
+
+    /* Finish sanity checking the heap object */
+    if (NULL == heap->obj[hobj->idx].begin)
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad heap pointer, heap object = {%" PRIxHADDR ", %zu}",
+                    hobj->addr, hobj->idx);
 
     obj_start = heap->obj[hobj->idx].begin;
     /* Include object header size */
@@ -792,7 +787,7 @@ H5HG_remove(H5F_t *f, H5HG_t *hobj)
     } /* end if */
     else
         heap->obj[0].size += need;
-    HDmemmove(obj_start, obj_start + need, heap->size - (size_t)((obj_start + need) - heap->chunk));
+    memmove(obj_start, obj_start + need, heap->size - (size_t)((obj_start + need) - heap->chunk));
     if (heap->obj[0].size >= H5HG_SIZEOF_OBJHDR(f)) {
         p = heap->obj[0].begin;
         UINT16ENCODE(p, 0); /*id*/
@@ -800,7 +795,7 @@ H5HG_remove(H5F_t *f, H5HG_t *hobj)
         UINT32ENCODE(p, 0); /*reserved*/
         H5F_ENCODE_LENGTH(f, p, heap->obj[0].size);
     } /* end if */
-    HDmemset(heap->obj + hobj->idx, 0, sizeof(H5HG_obj_t));
+    memset(heap->obj + hobj->idx, 0, sizeof(H5HG_obj_t));
     flags |= H5AC__DIRTIED_FLAG;
 
     if ((heap->obj[0].size + H5HG_SIZEOF_HDR(f)) == heap->size) {
@@ -818,15 +813,15 @@ H5HG_remove(H5F_t *f, H5HG_t *hobj)
          * H5AC_protect() might have done that too, but that's okay.  If the
          * heap isn't on the CWFS list then add it to the end.
          */
-        if (H5F_cwfs_advance_heap(f, heap, TRUE) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTMODIFY, FAIL, "can't adjust file's CWFS")
+        if (H5F_cwfs_advance_heap(f, heap, true) < 0)
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTMODIFY, FAIL, "can't adjust file's CWFS");
     } /* end else */
 
 done:
     if (heap && H5AC_unprotect(f, H5AC_GHEAP, hobj->addr, heap, flags) < 0)
-        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
+        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release object header");
 
-    FUNC_LEAVE_NOAPI_TAG(ret_value);
+    FUNC_LEAVE_NOAPI_TAG(ret_value)
 } /* end H5HG_remove() */
 
 /*-------------------------------------------------------------------------
@@ -836,9 +831,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *              Wednesday, January 15, 2003
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -849,11 +841,11 @@ H5HG__free(H5HG_heap_t *heap)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(heap);
+    assert(heap);
 
     /* Remove the heap from the CWFS list */
     if (H5F_cwfs_remove_heap(heap->shared, heap) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove heap from file's CWFS")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove heap from file's CWFS");
 
     if (heap->chunk)
         heap->chunk = H5FL_BLK_FREE(gheap_chunk, heap->chunk);
