@@ -10,9 +10,7 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer:  Quincey Koziol
- *              Wednesday, July 9, 2003
- *
+/*
  * Purpose:     Local Heap object debugging functions.
  */
 
@@ -38,9 +36,6 @@
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Robb Matzke
- *              Aug  1 1997
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -56,36 +51,36 @@ H5HL_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(addr));
-    HDassert(stream);
-    HDassert(indent >= 0);
-    HDassert(fwidth >= 0);
+    assert(f);
+    assert(H5_addr_defined(addr));
+    assert(stream);
+    assert(indent >= 0);
+    assert(fwidth >= 0);
 
     if (NULL == (h = (H5HL_t *)H5HL_protect(f, addr, H5AC__READ_ONLY_FLAG)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to load/protect local heap")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to load/protect local heap");
 
-    HDfprintf(stream, "%*sLocal Heap...\n", indent, "");
-    HDfprintf(stream, "%*s%-*s %zu\n", indent, "", fwidth, "Header size (in bytes):", h->prfx_size);
-    HDfprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth, "Address of heap data:", h->dblk_addr);
-    HDfprintf(stream, "%*s%-*s %zu\n", indent, "", fwidth, "Data bytes allocated for heap:", h->dblk_size);
+    fprintf(stream, "%*sLocal Heap...\n", indent, "");
+    fprintf(stream, "%*s%-*s %zu\n", indent, "", fwidth, "Header size (in bytes):", h->prfx_size);
+    fprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth, "Address of heap data:", h->dblk_addr);
+    fprintf(stream, "%*s%-*s %zu\n", indent, "", fwidth, "Data bytes allocated for heap:", h->dblk_size);
 
     /* Traverse the free list and check that all free blocks fall within
      * the heap and that no two free blocks point to the same region of
      * the heap.
      */
     if (NULL == (marker = (uint8_t *)H5MM_calloc(h->dblk_size)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "memory allocation failed")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "memory allocation failed");
 
-    HDfprintf(stream, "%*sFree Blocks (offset, size):\n", indent, "");
+    fprintf(stream, "%*sFree Blocks (offset, size):\n", indent, "");
     for (free_block = 0, freelist = h->freelist; freelist; freelist = freelist->next, free_block++) {
         char temp_str[32];
 
-        HDsnprintf(temp_str, sizeof(temp_str), "Block #%d:", free_block);
-        HDfprintf(stream, "%*s%-*s %8zu, %8zu\n", indent + 3, "", MAX(0, fwidth - 9), temp_str,
-                  freelist->offset, freelist->size);
+        snprintf(temp_str, sizeof(temp_str), "Block #%d:", free_block);
+        fprintf(stream, "%*s%-*s %8zu, %8zu\n", indent + 3, "", MAX(0, fwidth - 9), temp_str,
+                freelist->offset, freelist->size);
         if ((freelist->offset + freelist->size) > h->dblk_size)
-            HDfprintf(stream, "***THAT FREE BLOCK IS OUT OF BOUNDS!\n");
+            fprintf(stream, "***THAT FREE BLOCK IS OUT OF BOUNDS!\n");
         else {
             int    overlap = 0;
             size_t i;
@@ -96,25 +91,25 @@ H5HL_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth)
                 marker[freelist->offset + i] = 1;
             }
             if (overlap)
-                HDfprintf(stream, "***THAT FREE BLOCK OVERLAPPED A PREVIOUS ONE!\n");
+                fprintf(stream, "***THAT FREE BLOCK OVERLAPPED A PREVIOUS ONE!\n");
             else
                 amount_free += freelist->size;
         }
     }
 
     if (h->dblk_size)
-        HDfprintf(stream, "%*s%-*s %.2f%%\n", indent, "", fwidth, "Percent of heap used:",
-                  (100.0 * (double)(h->dblk_size - amount_free) / (double)h->dblk_size));
+        fprintf(stream, "%*s%-*s %.2f%%\n", indent, "", fwidth, "Percent of heap used:",
+                (100.0 * (double)(h->dblk_size - amount_free) / (double)h->dblk_size));
 
     /* Print the data in a VMS-style octal dump */
     H5_buffer_dump(stream, indent, h->dblk_image, marker, (size_t)0, h->dblk_size);
 
 done:
     if (h && FAIL == H5HL_unprotect(h))
-        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release/unprotect local heap")
+        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release/unprotect local heap");
 
     if (marker && NULL != (marker = (uint8_t *)H5MM_xfree(marker)))
-        HDONE_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "can't free marker buffer")
+        HDONE_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "can't free marker buffer");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HL_debug() */
