@@ -150,6 +150,8 @@
 /* Input/output flags for decode functions */
 #define H5O_DECODEIO_NOCHANGE 0x01u /* IN: do not modify values */
 #define H5O_DECODEIO_DIRTY    0x02u /* OUT: message has been changed */
+#define H5O_DECODEIO_RFIC_UNUBNT                                                                             \
+    0x04u /* IN: Relax file integrity checks for unusual numbers of unused bits in numeric datatypes */
 
 /* Macro to incremend ndecode_dirtied (only if we are debugging) */
 #ifndef NDEBUG
@@ -166,14 +168,14 @@
         unsigned               ioflags  = (IOF);                                                             \
                                                                                                              \
         /* Decode the message */                                                                             \
-        HDassert(msg_type->decode);                                                                          \
+        assert(msg_type->decode);                                                                            \
         if (NULL == ((MSG)->native = (msg_type->decode)((F), (OH), (MSG)->flags, &ioflags, (MSG)->raw_size,  \
                                                         (MSG)->raw)))                                        \
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTDECODE, ERR, "unable to decode message")                           \
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTDECODE, ERR, "unable to decode message");                          \
                                                                                                              \
         /* Mark the message dirty if it was changed by decoding */                                           \
         if ((ioflags & H5O_DECODEIO_DIRTY) && (H5F_get_intent((F)) & H5F_ACC_RDWR)) {                        \
-            (MSG)->dirty = TRUE;                                                                             \
+            (MSG)->dirty = true;                                                                             \
             /* Increment the count of messages dirtied by decoding, but */                                   \
             /* only ifndef NDEBUG */                                                                         \
             INCR_NDECODE_DIRTIED(OH)                                                                         \
@@ -181,7 +183,7 @@
                                                                                                              \
         /* Set the message's "shared info", if it's shareable */                                             \
         if ((MSG)->flags & H5O_MSG_FLAG_SHAREABLE) {                                                         \
-            HDassert(msg_type->share_flags &H5O_SHARE_IS_SHARABLE);                                          \
+            assert(msg_type->share_flags &H5O_SHARE_IS_SHARABLE);                                            \
             H5O_UPDATE_SHARED((H5O_shared_t *)(MSG)->native, H5O_SHARE_TYPE_HERE, (F), msg_type->id,         \
                               (MSG)->crt_idx, (OH)->chunk[0].addr)                                           \
         } /* end if */                                                                                       \
@@ -190,7 +192,7 @@
         if (msg_type->set_crt_index) {                                                                       \
             /* Set the creation index for the message */                                                     \
             if ((msg_type->set_crt_index)((MSG)->native, (MSG)->crt_idx) < 0)                                \
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, ERR, "unable to set creation index")                      \
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, ERR, "unable to set creation index");                     \
         } /* end if */                                                                                       \
     }     /* end if */
 
@@ -211,18 +213,18 @@ struct H5O_msg_class_t {
     size_t      native_size; /*size of native message    */
     unsigned    share_flags; /* Message sharing settings */
     void *(*decode)(H5F_t *, H5O_t *, unsigned, unsigned *, size_t, const uint8_t *);
-    herr_t (*encode)(H5F_t *, hbool_t, uint8_t *, const void *);
-    void *(*copy)(const void *, void *);                      /*copy native value         */
-    size_t (*raw_size)(const H5F_t *, hbool_t, const void *); /*sizeof encoded message	*/
-    herr_t (*reset)(void *);                                  /*free nested data structs  */
-    herr_t (*free)(void *);                                   /*free main data struct  */
+    herr_t (*encode)(H5F_t *, bool, size_t, uint8_t *, const void *);
+    void *(*copy)(const void *, void *);                   /*copy native value         */
+    size_t (*raw_size)(const H5F_t *, bool, const void *); /*sizeof encoded message	*/
+    herr_t (*reset)(void *);                               /*free nested data structs  */
+    herr_t (*free)(void *);                                /*free main data struct  */
     herr_t (*del)(H5F_t *, H5O_t *, void *);  /* Delete space in file referenced by this message */
     herr_t (*link)(H5F_t *, H5O_t *, void *); /* Increment any links in file reference by this message */
     herr_t (*set_share)(void *, const H5O_shared_t *); /* Set shared information */
     htri_t (*can_share)(const void *);                 /* Is message allowed to be shared? */
-    herr_t (*pre_copy_file)(H5F_t *, const void *, hbool_t *, const H5O_copy_t *,
+    herr_t (*pre_copy_file)(H5F_t *, const void *, bool *, const H5O_copy_t *,
                             void *); /*"pre copy" action when copying native value to file */
-    void *(*copy_file)(H5F_t *, void *, H5F_t *, hbool_t *, unsigned *, H5O_copy_t *,
+    void *(*copy_file)(H5F_t *, void *, H5F_t *, bool *, unsigned *, H5O_copy_t *,
                        void *); /*copy native value to file */
     herr_t (*post_copy_file)(const H5O_loc_t *, const void *, H5O_loc_t *, void *, unsigned *,
                              H5O_copy_t *); /*"post copy" action when copying native value to file */
@@ -233,7 +235,7 @@ struct H5O_msg_class_t {
 
 struct H5O_mesg_t {
     const H5O_msg_class_t *type;     /* type of message                  */
-    hbool_t                dirty;    /* raw out of date wrt native       */
+    bool                   dirty;    /* raw out of date wrt native       */
     uint8_t                flags;    /* message flags                    */
     H5O_msg_crt_idx_t      crt_idx;  /* message creation index           */
     unsigned               chunkno;  /* chunk number for this mesg       */
@@ -266,17 +268,17 @@ struct H5O_t {
                             /* first field in structure */
 
     /* File-specific information (not stored) */
-    size_t  sizeof_size; /* Size of file sizes 		     */
-    size_t  sizeof_addr; /* Size of file addresses	     */
-    hbool_t swmr_write;  /* Whether we are doing SWMR writes  */
+    size_t sizeof_size; /* Size of file sizes 		     */
+    size_t sizeof_addr; /* Size of file addresses	     */
+    bool   swmr_write;  /* Whether we are doing SWMR writes  */
 
     /* Debugging information (not stored) */
 #ifdef H5O_ENABLE_BAD_MESG_COUNT
-    hbool_t store_bad_mesg_count; /* Flag to indicate that a bad message count should be stored */
-                                  /* (This is to simulate a bug in earlier
-                                   *      versions of the library)
-                                   */
-#endif                            /* H5O_ENABLE_BAD_MESG_COUNT */
+    bool store_bad_mesg_count; /* Flag to indicate that a bad message count should be stored */
+                               /* (This is to simulate a bug in earlier
+                                *      versions of the library)
+                                */
+#endif                         /* H5O_ENABLE_BAD_MESG_COUNT */
 #ifndef NDEBUG
     size_t ndecode_dirtied; /* Number of messages dirtied by decoding */
 #endif                      /* NDEBUG */
@@ -285,7 +287,7 @@ struct H5O_t {
     size_t rc; /* Reference count of [continuation] chunks using this structure */
 
     /* Object information (stored) */
-    hbool_t  has_refcount_msg; /* Whether the object has a ref. count message */
+    bool     has_refcount_msg; /* Whether the object has a ref. count message */
     unsigned nlink;            /*link count			     */
     uint8_t  version;          /*version number		     */
     uint8_t  flags;            /*flags				     */
@@ -311,7 +313,7 @@ struct H5O_t {
     size_t       nchunks;       /*number of chunks		     */
     size_t       alloc_nchunks; /*chunks allocated		     */
     H5O_chunk_t *chunk;         /*array of chunks		     */
-    hbool_t      chunks_pinned; /* Whether chunks are pinned from ohdr protect */
+    bool         chunks_pinned; /* Whether chunks are pinned from ohdr protect */
 
     /* Object header proxy information (not stored) */
     H5AC_proxy_entry_t *proxy; /* Proxy cache entry for all ohdr entries */
@@ -319,14 +321,14 @@ struct H5O_t {
 
 /* Class for types of objects in file */
 typedef struct H5O_obj_class_t {
-    H5O_type_t  type;                              /*object type on disk	     */
-    const char *name;                              /*for debugging		     */
-    void *(*get_copy_file_udata)(void);            /*retrieve user data for 'copy file' operation */
-    void (*free_copy_file_udata)(void *);          /*free user data for 'copy file' operation */
-    htri_t (*isa)(const H5O_t *);                  /*if a header matches an object class */
-    hid_t (*open)(const H5G_loc_t *, hbool_t);     /*open an object of this class */
-    void *(*create)(H5F_t *, void *, H5G_loc_t *); /*create an object of this class */
-    H5O_loc_t *(*get_oloc)(hid_t);                 /*get the object header location for an object */
+    H5O_type_t  type;                               /*object type on disk	     */
+    const char *name;                               /*for debugging		     */
+    void *(*get_copy_file_udata)(void);             /*retrieve user data for 'copy file' operation */
+    void (*free_copy_file_udata)(void *);           /*free user data for 'copy file' operation */
+    htri_t (*isa)(const H5O_t *);                   /*if a header matches an object class */
+    void *(*open)(const H5G_loc_t *, H5I_type_t *); /*open an object of this class */
+    void *(*create)(H5F_t *, void *, H5G_loc_t *);  /*create an object of this class */
+    H5O_loc_t *(*get_oloc)(hid_t);                  /*get the object header location for an object */
     herr_t (*bh_info)(const H5O_loc_t *loc, H5O_t *oh,
                       H5_ih_info_t *bh_info); /*get the index & heap info for an object */
     herr_t (*flush)(void *obj_ptr);           /*flush an opened object of this class */
@@ -336,7 +338,7 @@ typedef struct H5O_obj_class_t {
 typedef struct H5O_addr_map_t {
     H5_obj_t               src_obj_pos;   /* Location of source object */
     haddr_t                dst_addr;      /* Address of object in destination file */
-    hbool_t                is_locked;     /* Indicate that the destination object is locked currently */
+    bool                   is_locked;     /* Indicate that the destination object is locked currently */
     hsize_t                inc_ref_count; /* Number of deferred increments to reference count */
     const H5O_obj_class_t *obj_class;     /* Object class */
     void                  *udata;         /* Object class copy file udata */
@@ -360,11 +362,11 @@ typedef struct H5O_common_cache_ud_t {
 
 /* Callback information for loading object header prefix from disk */
 typedef struct H5O_cache_ud_t {
-    hbool_t               made_attempt;  /* Whether the deserialize routine was already attempted */
+    bool                  made_attempt;  /* Whether the deserialize routine was already attempted */
     unsigned              v1_pfx_nmesgs; /* Number of messages from v1 prefix header */
     size_t                chunk0_size;   /* Size of serialized first chunk    */
     H5O_t                *oh;            /* Partially deserialized object header, for later use */
-    hbool_t               free_oh;       /* Whether to free the object header or not */
+    uint8_t               oh_version;    /* Oh version number          */
     H5O_common_cache_ud_t common;        /* Common object header cache callback info */
 } H5O_cache_ud_t;
 
@@ -393,7 +395,7 @@ typedef struct H5O_chunk_proxy_t {
 
 /* Callback information for loading object header chunk from disk */
 typedef struct H5O_chk_cache_ud_t {
-    hbool_t               decoding; /* Whether the object header is being decoded */
+    bool                  decoding; /* Whether the object header is being decoded */
     H5O_t                *oh;       /* Object header for this chunk */
     unsigned              chunkno;  /* Index of chunk being brought in (for re-loads) */
     size_t                size;     /* Size of chunk in the file */
@@ -539,19 +541,18 @@ H5_DLLVAR const H5O_obj_class_t H5O_OBJ_DATASET[1];
 H5_DLLVAR const H5O_obj_class_t H5O_OBJ_DATATYPE[1];
 
 /* Package-local function prototypes */
-H5_DLL hid_t                  H5O__open_by_idx(const H5G_loc_t *loc, const char *name, H5_index_t idx_type,
-                                               H5_iter_order_t order, hsize_t n);
-H5_DLL hid_t                  H5O__open_by_addr(const H5G_loc_t *loc, haddr_t addr);
-H5_DLL hid_t                  H5O__open_by_loc(const H5G_loc_t *obj_loc, hbool_t app_ref);
+H5_DLL void *H5O__open_by_addr(const H5G_loc_t *loc, haddr_t addr, H5I_type_t *opened_type /*out*/);
+H5_DLL void *H5O__open_by_idx(const H5G_loc_t *loc, const char *name, H5_index_t idx_type,
+                              H5_iter_order_t order, hsize_t n, H5I_type_t *opened_type /*out*/);
 H5_DLL const H5O_obj_class_t *H5O__obj_class(const H5O_loc_t *loc);
-H5_DLL int                    H5O__link_oh(H5F_t *f, int adjust, H5O_t *oh, hbool_t *deleted);
-H5_DLL herr_t H5O__get_info_by_idx(const H5G_loc_t *loc, const char *group_name, H5_index_t idx_type,
-                                   H5_iter_order_t order, hsize_t n, H5O_info_t *oinfo, unsigned fields);
-H5_DLL herr_t H5O__visit(hid_t loc_id, const char *obj_name, H5_index_t idx_type, H5_iter_order_t order,
-                         H5O_iterate_t op, void *op_data, unsigned fields);
+H5_DLL herr_t                 H5O__copy(const H5G_loc_t *src_loc, const char *src_name, H5G_loc_t *dst_loc,
+                                        const char *dst_name, hid_t ocpypl_id, hid_t lcpl_id);
+H5_DLL int                    H5O__link_oh(H5F_t *f, int adjust, H5O_t *oh, bool *deleted);
+H5_DLL herr_t H5O__visit(H5G_loc_t *loc, const char *obj_name, H5_index_t idx_type, H5_iter_order_t order,
+                         H5O_iterate2_t op, void *op_data, unsigned fields);
 H5_DLL herr_t H5O__inc_rc(H5O_t *oh);
 H5_DLL herr_t H5O__dec_rc(H5O_t *oh);
-H5_DLL herr_t H5O__free(H5O_t *oh);
+H5_DLL herr_t H5O__free(H5O_t *oh, bool force);
 
 /* Object header message routines */
 H5_DLL herr_t   H5O__msg_alloc(H5F_t *f, H5O_t *oh, const H5O_msg_class_t *type, unsigned *mesg_flags,
@@ -560,63 +561,66 @@ H5_DLL herr_t   H5O__msg_append_real(H5F_t *f, H5O_t *oh, const H5O_msg_class_t
                                      unsigned update_flags, void *mesg);
 H5_DLL herr_t   H5O__msg_write_real(H5F_t *f, H5O_t *oh, const H5O_msg_class_t *type, unsigned mesg_flags,
                                     unsigned update_flags, void *mesg);
-H5_DLL void    *H5O__msg_free_real(const H5O_msg_class_t *type, void *mesg);
 H5_DLL herr_t   H5O__msg_free_mesg(H5O_mesg_t *mesg);
-H5_DLL unsigned H5O_msg_count_real(const H5O_t *oh, const H5O_msg_class_t *type);
+H5_DLL unsigned H5O__msg_count_real(const H5O_t *oh, const H5O_msg_class_t *type);
 H5_DLL herr_t   H5O__msg_remove_real(H5F_t *f, H5O_t *oh, const H5O_msg_class_t *type, int sequence,
-                                     H5O_operator_t op, void *op_data, hbool_t adj_link);
+                                     H5O_operator_t op, void *op_data, bool adj_link);
 H5_DLL void *H5O__msg_copy_file(const H5O_msg_class_t *type, H5F_t *file_src, void *mesg_src, H5F_t *file_dst,
-                                hbool_t *recompute_size, unsigned *mesg_flags, H5O_copy_t *cpy_info,
+                                bool *recompute_size, unsigned *mesg_flags, H5O_copy_t *cpy_info,
                                 void *udata);
 H5_DLL herr_t H5O__msg_iterate_real(H5F_t *f, H5O_t *oh, const H5O_msg_class_t *type,
                                     const H5O_mesg_operator_t *op, void *op_data);
-H5_DLL herr_t H5O_msg_flush(H5F_t *f, H5O_t *oh, H5O_mesg_t *mesg);
-H5_DLL herr_t H5O_flush_msgs(H5F_t *f, H5O_t *oh);
+H5_DLL herr_t H5O__flush_msgs(H5F_t *f, H5O_t *oh);
 H5_DLL herr_t H5O__delete_mesg(H5F_t *f, H5O_t *open_oh, H5O_mesg_t *mesg);
 
 /* Object header chunk routines */
 H5_DLL herr_t             H5O__chunk_add(H5F_t *f, H5O_t *oh, unsigned idx, unsigned cont_chunkno);
 H5_DLL H5O_chunk_proxy_t *H5O__chunk_protect(H5F_t *f, H5O_t *oh, unsigned idx);
-H5_DLL herr_t             H5O__chunk_unprotect(H5F_t *f, H5O_chunk_proxy_t *chk_proxy, hbool_t chk_dirtied);
+H5_DLL herr_t             H5O__chunk_unprotect(H5F_t *f, H5O_chunk_proxy_t *chk_proxy, bool chk_dirtied);
 H5_DLL herr_t             H5O__chunk_update_idx(H5F_t *f, H5O_t *oh, unsigned idx);
 H5_DLL herr_t             H5O__chunk_resize(H5O_t *oh, H5O_chunk_proxy_t *chk_proxy);
 H5_DLL herr_t             H5O__chunk_delete(H5F_t *f, H5O_t *oh, unsigned idx);
 H5_DLL herr_t             H5O__chunk_dest(H5O_chunk_proxy_t *chunk_proxy);
 
+/* Cache corking functions */
+H5_DLL herr_t H5O__disable_mdc_flushes(H5O_loc_t *oloc);
+H5_DLL herr_t H5O__enable_mdc_flushes(H5O_loc_t *oloc);
+H5_DLL herr_t H5O__are_mdc_flushes_disabled(const H5O_loc_t *oloc, bool *are_disabled);
+
 /* Collect storage info for btree and heap */
 H5_DLL herr_t H5O__attr_bh_info(H5F_t *f, H5O_t *oh, H5_ih_info_t *bh_info);
 
 /* Object header allocation routines */
-H5_DLL herr_t H5O_alloc_msgs(H5O_t *oh, size_t min_alloc);
+H5_DLL herr_t H5O__alloc_msgs(H5O_t *oh, size_t min_alloc);
 H5_DLL herr_t H5O__alloc_chunk(H5F_t *f, H5O_t *oh, size_t size, size_t found_null,
                                const H5O_msg_alloc_info_t *found_msg, size_t *new_idx);
 H5_DLL herr_t H5O__alloc(H5F_t *f, H5O_t *oh, const H5O_msg_class_t *type, const void *mesg,
                          size_t *mesg_idx);
-H5_DLL herr_t H5O_condense_header(H5F_t *f, H5O_t *oh);
-H5_DLL herr_t H5O_release_mesg(H5F_t *f, H5O_t *oh, H5O_mesg_t *mesg, hbool_t adj_link);
+H5_DLL herr_t H5O__condense_header(H5F_t *f, H5O_t *oh);
+H5_DLL herr_t H5O__release_mesg(H5F_t *f, H5O_t *oh, H5O_mesg_t *mesg, bool adj_link);
 
 /* Shared object operators */
-H5_DLL void  *H5O_shared_decode(H5F_t *f, H5O_t *open_oh, unsigned *ioflags, const uint8_t *buf,
-                                const H5O_msg_class_t *type);
-H5_DLL herr_t H5O_shared_encode(const H5F_t *f, uint8_t *buf /*out*/, const H5O_shared_t *sh_mesg);
-H5_DLL size_t H5O_shared_size(const H5F_t *f, const H5O_shared_t *sh_mesg);
+H5_DLL void  *H5O__shared_decode(H5F_t *f, H5O_t *open_oh, unsigned *ioflags, size_t buf_size,
+                                 const uint8_t *buf, const H5O_msg_class_t *type);
+H5_DLL herr_t H5O__shared_encode(const H5F_t *f, uint8_t *buf /*out*/, const H5O_shared_t *sh_mesg);
+H5_DLL size_t H5O__shared_size(const H5F_t *f, const H5O_shared_t *sh_mesg);
 H5_DLL herr_t H5O__shared_delete(H5F_t *f, H5O_t *open_oh, const H5O_msg_class_t *mesg_type,
                                  H5O_shared_t *sh_mesg);
 H5_DLL herr_t H5O__shared_link(H5F_t *f, H5O_t *open_oh, const H5O_msg_class_t *mesg_type,
                                H5O_shared_t *sh_mesg);
 H5_DLL herr_t H5O__shared_copy_file(H5F_t *file_src, H5F_t *file_dst, const H5O_msg_class_t *mesg_type,
-                                    const void *_native_src, void *_native_dst, hbool_t *recompute_size,
+                                    const void *_native_src, void *_native_dst, bool *recompute_size,
                                     unsigned *mesg_flags, H5O_copy_t *cpy_info, void *udata);
 H5_DLL herr_t H5O__shared_post_copy_file(H5F_t *f, const H5O_msg_class_t *mesg_type,
                                          const H5O_shared_t *shared_src, H5O_shared_t *shared_dst,
                                          unsigned *mesg_flags, H5O_copy_t *cpy_info);
-H5_DLL herr_t H5O_shared_debug(const H5O_shared_t *mesg, FILE *stream, int indent, int fwidth);
+H5_DLL herr_t H5O__shared_debug(const H5O_shared_t *mesg, FILE *stream, int indent, int fwidth);
 
 /* Attribute message operators */
 H5_DLL herr_t H5O__attr_reset(void *_mesg);
 H5_DLL herr_t H5O__attr_delete(H5F_t *f, H5O_t *open_oh, void *_mesg);
 H5_DLL herr_t H5O__attr_link(H5F_t *f, H5O_t *open_oh, void *_mesg);
-H5_DLL herr_t H5O_attr_count_real(H5F_t *f, H5O_t *oh, hsize_t *nattrs);
+H5_DLL herr_t H5O__attr_count_real(H5F_t *f, H5O_t *oh, hsize_t *nattrs);
 
 /* Arrays of versions for:
  * Object header, Attribute/Fill value/Filter pipeline messages
@@ -633,7 +637,7 @@ H5_DLL htri_t H5O__is_attr_empty_test(hid_t oid);
 H5_DLL htri_t H5O__is_attr_dense_test(hid_t oid);
 H5_DLL herr_t H5O__num_attrs_test(hid_t oid, hsize_t *nattrs);
 H5_DLL herr_t H5O__attr_dense_info_test(hid_t oid, hsize_t *name_count, hsize_t *corder_count);
-H5_DLL herr_t H5O__check_msg_marked_test(hid_t oid, hbool_t flag_val);
+H5_DLL herr_t H5O__check_msg_marked_test(hid_t oid, bool flag_val);
 H5_DLL herr_t H5O__expunge_chunks_test(const H5O_loc_t *oloc);
 H5_DLL herr_t H5O__get_rc_test(const H5O_loc_t *oloc, unsigned *rc);
 H5_DLL herr_t H5O__msg_get_chunkno_test(hid_t oid, unsigned msg_type, unsigned *chunk_num);
@@ -642,8 +646,8 @@ H5_DLL herr_t H5O__msg_move_to_new_chunk_test(hid_t oid, unsigned msg_type);
 
 /* Object header debugging routines */
 #ifdef H5O_DEBUG
-H5_DLL herr_t H5O_assert(const H5O_t *oh);
+H5_DLL herr_t H5O__assert(const H5O_t *oh);
 #endif /* H5O_DEBUG */
-H5_DLL herr_t H5O_debug_real(H5F_t *f, H5O_t *oh, haddr_t addr, FILE *stream, int indent, int fwidth);
+H5_DLL herr_t H5O__debug_real(H5F_t *f, H5O_t *oh, haddr_t addr, FILE *stream, int indent, int fwidth);
 
 #endif /* H5Opkg_H */
