@@ -76,17 +76,16 @@ typedef enum H5P_plist_type_t {
     H5P_TYPE_LINK_CREATE      = 16,
     H5P_TYPE_LINK_ACCESS      = 17,
     H5P_TYPE_ATTRIBUTE_ACCESS = 18,
+    H5P_TYPE_VOL_INITIALIZE   = 19,
+    H5P_TYPE_MAP_CREATE       = 20,
+    H5P_TYPE_MAP_ACCESS       = 21,
+    H5P_TYPE_REFERENCE_ACCESS = 22,
     H5P_TYPE_MAX_TYPE
 } H5P_plist_type_t;
 
 /* Function pointer for library classes with properties to register */
 typedef herr_t (*H5P_reg_prop_func_t)(H5P_genclass_t *pclass);
 
-/* Move encode/decode callback typedefs from H5Ppublic.h: not exposed to user */
-/* Add a parameter to encode callback */
-typedef herr_t (*H5P_prp_encode_func_t)(const void *value, void **buf, size_t *size);
-typedef herr_t (*H5P_prp_decode_func_t)(const void **buf, void *value);
-
 /*
  * Each library property list class has a variable of this type that contains
  * class variables and methods used to initialize the class.
@@ -127,6 +126,8 @@ H5_DLLVAR H5P_genclass_t *H5P_CLS_GROUP_CREATE_g;
 H5_DLLVAR H5P_genclass_t *H5P_CLS_GROUP_ACCESS_g;
 H5_DLLVAR H5P_genclass_t *H5P_CLS_DATATYPE_CREATE_g;
 H5_DLLVAR H5P_genclass_t *H5P_CLS_DATATYPE_ACCESS_g;
+H5_DLLVAR H5P_genclass_t *H5P_CLS_MAP_CREATE_g;
+H5_DLLVAR H5P_genclass_t *H5P_CLS_MAP_ACCESS_g;
 H5_DLLVAR H5P_genclass_t *H5P_CLS_ATTRIBUTE_CREATE_g;
 H5_DLLVAR H5P_genclass_t *H5P_CLS_ATTRIBUTE_ACCESS_g;
 H5_DLLVAR H5P_genclass_t *H5P_CLS_OBJECT_COPY_g;
@@ -141,6 +142,7 @@ H5_DLLVAR const struct H5P_libclass_t H5P_CLS_AACC[1]; /* Attribute access */
 H5_DLLVAR const struct H5P_libclass_t H5P_CLS_DACC[1]; /* Dataset access */
 H5_DLLVAR const struct H5P_libclass_t H5P_CLS_GACC[1]; /* Group access */
 H5_DLLVAR const struct H5P_libclass_t H5P_CLS_TACC[1]; /* Named datatype access */
+H5_DLLVAR const struct H5P_libclass_t H5P_CLS_MACC[1]; /* Map access */
 H5_DLLVAR const struct H5P_libclass_t H5P_CLS_FACC[1]; /* File access */
 H5_DLLVAR const struct H5P_libclass_t H5P_CLS_OCPY[1]; /* Object copy */
 
@@ -151,14 +153,16 @@ H5_DLLVAR const struct H5P_libclass_t H5P_CLS_OCPY[1]; /* Object copy */
 /* Forward declaration of structs used below */
 struct H5O_fill_t;
 struct H5T_t;
+struct H5VL_connector_prop_t;
 
-/* Package initialization routine */
-H5_DLL herr_t H5P_init(void);
+/* Package initialization routines */
+H5_DLL herr_t H5P_init_phase1(void);
+H5_DLL herr_t H5P_init_phase2(void);
 
 /* Internal versions of API routines */
-H5_DLL herr_t H5P_close(void *_plist);
-H5_DLL hid_t  H5P_create_id(H5P_genclass_t *pclass, hbool_t app_ref);
-H5_DLL hid_t  H5P_copy_plist(const H5P_genplist_t *old_plist, hbool_t app_ref);
+H5_DLL herr_t H5P_close(H5P_genplist_t *plist);
+H5_DLL hid_t  H5P_create_id(H5P_genclass_t *pclass, bool app_ref);
+H5_DLL hid_t  H5P_copy_plist(const H5P_genplist_t *old_plist, bool app_ref);
 H5_DLL herr_t H5P_get(H5P_genplist_t *plist, const char *name, void *value);
 H5_DLL herr_t H5P_set(H5P_genplist_t *plist, const char *name, const void *value);
 H5_DLL herr_t H5P_peek(H5P_genplist_t *plist, const char *name, void *value);
@@ -171,13 +175,21 @@ H5_DLL herr_t H5P_insert(H5P_genplist_t *plist, const char *name, size_t size, v
 H5_DLL herr_t H5P_remove(H5P_genplist_t *plist, const char *name);
 H5_DLL htri_t H5P_exist_plist(const H5P_genplist_t *plist, const char *name);
 H5_DLL htri_t H5P_class_isa(const H5P_genclass_t *pclass1, const H5P_genclass_t *pclass2);
-H5_DLL char  *H5P_get_class_name(H5P_genclass_t *pclass);
+H5_DLL char  *H5P_get_class_name(H5P_genclass_t *pclass) H5_ATTR_MALLOC;
 
 /* Internal helper routines */
-H5_DLL herr_t      H5P_get_nprops_pclass(const H5P_genclass_t *pclass, size_t *nprops, hbool_t recurse);
+H5_DLL herr_t      H5P_get_nprops_pclass(const H5P_genclass_t *pclass, size_t *nprops, bool recurse);
 H5_DLL hid_t       H5P_peek_driver(H5P_genplist_t *plist);
 H5_DLL const void *H5P_peek_driver_info(H5P_genplist_t *plist);
-H5_DLL herr_t      H5P_set_driver(H5P_genplist_t *plist, hid_t new_driver_id, const void *new_driver_info);
+H5_DLL const char *H5P_peek_driver_config_str(H5P_genplist_t *plist);
+H5_DLL herr_t      H5P_set_driver(H5P_genplist_t *plist, hid_t new_driver_id, const void *new_driver_info,
+                                  const char *new_driver_config_str);
+H5_DLL herr_t      H5P_set_driver_by_name(H5P_genplist_t *plist, const char *driver_name,
+                                          const char *driver_config, bool app_ref);
+H5_DLL herr_t      H5P_set_driver_by_value(H5P_genplist_t *plist, H5FD_class_value_t driver_value,
+                                           const char *driver_config, bool app_ref);
+H5_DLL herr_t      H5P_set_vol(H5P_genplist_t *plist, hid_t vol_id, const void *vol_info);
+H5_DLL herr_t H5P_reset_vol_class(const H5P_genclass_t *pclass, const struct H5VL_connector_prop_t *vol_prop);
 H5_DLL herr_t H5P_set_vlen_mem_manager(H5P_genplist_t *plist, H5MM_allocate_t alloc_func, void *alloc_info,
                                        H5MM_free_t free_func, void *free_info);
 H5_DLL herr_t H5P_is_fill_value_defined(const struct H5O_fill_t *fill, H5D_fill_value_t *status);
@@ -188,7 +200,6 @@ H5_DLL herr_t H5P_get_filter_by_id(H5P_genplist_t *plist, H5Z_filter_t id, unsig
                                    size_t *cd_nelmts, unsigned cd_values[], size_t namelen, char name[],
                                    unsigned *filter_config);
 H5_DLL htri_t H5P_filter_in_pline(H5P_genplist_t *plist, H5Z_filter_t id);
-H5_DLL hid_t  H5P_get_default(const H5P_libclass_t *pclass);
 
 /* Query internal fields of the property list struct */
 H5_DLL hid_t           H5P_get_plist_id(const H5P_genplist_t *plist);
@@ -201,5 +212,7 @@ H5_DLL H5P_genplist_t *H5P_object_verify(hid_t plist_id, hid_t pclass_id);
 /* Private DCPL routines */
 H5_DLL herr_t H5P_fill_value_defined(H5P_genplist_t *plist, H5D_fill_value_t *status);
 H5_DLL herr_t H5P_get_fill_value(H5P_genplist_t *plist, const struct H5T_t *type, void *value);
+H5_DLL int    H5P_ignore_cmp(const void H5_ATTR_UNUSED *val1, const void H5_ATTR_UNUSED *val2,
+                             size_t H5_ATTR_UNUSED size);
 
 #endif /* H5Pprivate_H */
