@@ -19,15 +19,13 @@
 #include "H5Rpublic.h"
 
 /* Private headers needed by this file */
-#include "H5Fprivate.h" /* Files                                    */
-#include "H5Gprivate.h" /* Groups                                   */
-#include "H5Oprivate.h" /* Object headers                           */
-#include "H5Sprivate.h" /* Dataspaces                               */
 
 /**************************/
 /* Library Private Macros */
 /**************************/
 
+#define H5R_ENCODE_VERSION 0x1 /* Version for encoding references */
+
 /****************************/
 /* Library Private Typedefs */
 /****************************/
@@ -40,4 +38,6 @@
 /* Library Private Prototypes */
 /******************************/
 
+H5_DLL herr_t H5R_init(void);
+
 #endif /* H5Rprivate_H */
