@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  James Laird
- *              Thursday, March 30, 2006
- *
  * Purpose:     This file contains declarations which are visible only within
  *              the H5SM shared object header messages package.  Source files
  *              outside the H5SM package should	include H5SMprivate.h instead.
@@ -32,6 +29,7 @@
 #include "H5ACprivate.h" /* Metadata Cache		  	*/
 #include "H5B2private.h" /* B-trees                              */
 #include "H5HFprivate.h" /* Fractal heaps		  	*/
+#include "H5FLprivate.h" /* Free Lists                           */
 
 /****************************/
 /* Package Macros           */
@@ -254,22 +252,16 @@ H5_DLLVAR const H5B2_class_t H5SM_INDEX[1];
 /****************************/
 
 /* General routines */
-H5_DLL ssize_t H5SM_get_index(const H5SM_master_table_t *table, unsigned type_id);
+H5_DLL herr_t H5SM__get_index(const H5SM_master_table_t *table, unsigned type_id, ssize_t *idx);
 
 /* Encode and decode routines, used for B-tree and cache encoding/decoding */
 H5_DLL herr_t H5SM__message_compare(const void *rec1, const void *rec2, int *result);
 H5_DLL herr_t H5SM__message_encode(uint8_t *raw, const void *native, void *ctx);
 H5_DLL herr_t H5SM__message_decode(const uint8_t *raw, void *native, void *ctx);
 
-/* H5B2_remove_t callback to add messages to a list index */
-H5_DLL herr_t H5SM_bt2_convert_to_list_op(const void *record, void *op_data);
-
-/* Fractal heap 'op' callback to compute hash value for message "in place" */
-H5_DLL herr_t H5SM_get_hash_fh_cb(const void *obj, size_t obj_len, void *_udata);
-
 /* Routines to release data structures */
-herr_t H5SM_table_free(H5SM_master_table_t *table);
-herr_t H5SM_list_free(H5SM_list_t *list);
+H5_DLL herr_t H5SM__table_free(H5SM_master_table_t *table);
+H5_DLL herr_t H5SM__list_free(H5SM_list_t *list);
 
 /* Testing functions */
 #ifdef H5SM_TESTING
