@@ -35,9 +35,6 @@
  *
  * Errors:
  *
- * Programmer:	Robb Matzke
- *		Monday, December  8, 1997
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -47,14 +44,13 @@ H5Tget_nmembers(hid_t type_id)
     int    ret_value; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE1("Is", "i", type_id);
 
     /* Check args */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype");
 
     if ((ret_value = H5T_get_nmembers(dt)) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "cannot return member number")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "cannot return member number");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -73,9 +69,6 @@ done:
  *
  * Errors:
  *
- * Programmer:  Raymond Lu
- *	        October 8, 2002
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -85,14 +78,14 @@ H5T_get_nmembers(const H5T_t *dt)
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(dt);
+    assert(dt);
 
     if (H5T_COMPOUND == dt->shared->type)
         ret_value = (int)dt->shared->u.compnd.nmembs;
     else if (H5T_ENUM == dt->shared->type)
         ret_value = (int)dt->shared->u.enumer.nmembs;
     else
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "operation not supported for type class")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "operation not supported for type class");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -111,9 +104,6 @@ done:
  *
  *		Failure:	NULL
  *
- * Programmer:	Robb Matzke
- *		Wednesday, January  7, 1998
- *
  *-------------------------------------------------------------------------
  */
 char *
@@ -123,14 +113,13 @@ H5Tget_member_name(hid_t type_id, unsigned membno)
     char  *ret_value;
 
     FUNC_ENTER_API(NULL)
-    H5TRACE2("*s", "iIu", type_id, membno);
 
     /* Check args */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, NULL, "not a datatype")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, NULL, "not a datatype");
 
     if (NULL == (ret_value = H5T__get_member_name(dt, membno)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, NULL, "unable to get member name")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, NULL, "unable to get member name");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -149,9 +138,6 @@ done:
  *
  *		Failure:	NULL
  *
- * Programmer:	Raymond Lu
- *              October 9, 2002
- *
  *-------------------------------------------------------------------------
  */
 char *
@@ -161,18 +147,18 @@ H5T__get_member_name(H5T_t const *dt, unsigned membno)
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(dt);
+    assert(dt);
 
     switch (dt->shared->type) {
         case H5T_COMPOUND:
             if (membno >= dt->shared->u.compnd.nmembs)
-                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, NULL, "invalid member number")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, NULL, "invalid member number");
             ret_value = H5MM_xstrdup(dt->shared->u.compnd.memb[membno].name);
             break;
 
         case H5T_ENUM:
             if (membno >= dt->shared->u.enumer.nmembs)
-                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, NULL, "invalid member number")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, NULL, "invalid member number");
             ret_value = H5MM_xstrdup(dt->shared->u.enumer.name[membno]);
             break;
 
@@ -188,8 +174,8 @@ H5T__get_member_name(H5T_t const *dt, unsigned membno)
         case H5T_ARRAY:
         case H5T_NCLASSES:
         default:
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, NULL, "operation not supported for type class")
-    } /*lint !e788 All appropriate cases are covered */
+            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, NULL, "operation not supported for type class");
+    }
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -206,9 +192,6 @@ done:
  * Return:      Success:        index of the member if exists.
  *              Failure:        -1.
  *
- * Programmer:  Raymond Lu
- *              Thursday, April 4, 2002
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -219,24 +202,23 @@ H5Tget_member_index(hid_t type_id, const char *name)
     unsigned i;
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE2("Is", "i*s", type_id, name);
 
     /* Check arguments */
-    HDassert(name);
+    assert(name);
     if (NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype");
 
     /* Locate member by name */
     switch (dt->shared->type) {
         case H5T_COMPOUND:
             for (i = 0; i < dt->shared->u.compnd.nmembs; i++)
-                if (!HDstrcmp(dt->shared->u.compnd.memb[i].name, name))
-                    HGOTO_DONE((int)i)
+                if (!strcmp(dt->shared->u.compnd.memb[i].name, name))
+                    HGOTO_DONE((int)i);
             break;
         case H5T_ENUM:
             for (i = 0; i < dt->shared->u.enumer.nmembs; i++)
-                if (!HDstrcmp(dt->shared->u.enumer.name[i], name))
-                    HGOTO_DONE((int)i)
+                if (!strcmp(dt->shared->u.enumer.name[i], name))
+                    HGOTO_DONE((int)i);
             break;
 
         case H5T_NO_CLASS:
@@ -251,8 +233,8 @@ H5Tget_member_index(hid_t type_id, const char *name)
         case H5T_ARRAY:
         case H5T_NCLASSES:
         default:
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "operation not supported for this type")
-    } /*lint !e788 All appropriate cases are covered */
+            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "operation not supported for this type");
+    }
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -269,9 +251,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *		Wednesday, January  7, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -279,7 +258,7 @@ H5T__sort_value(const H5T_t *dt, int *map)
 {
     unsigned nmembs; /* Number of members for datatype */
     size_t   size;
-    hbool_t  swapped; /* Whether we've swapped fields */
+    bool     swapped; /* Whether we've swapped fields */
     uint8_t  tbuf[32];
     unsigned i, j;                /* Local index variables */
     herr_t   ret_value = SUCCEED; /* Return value */
@@ -287,16 +266,16 @@ H5T__sort_value(const H5T_t *dt, int *map)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(dt);
-    HDassert(H5T_COMPOUND == dt->shared->type || H5T_ENUM == dt->shared->type);
+    assert(dt);
+    assert(H5T_COMPOUND == dt->shared->type || H5T_ENUM == dt->shared->type);
 
     /* Use a bubble sort because we can short circuit */
     if (H5T_COMPOUND == dt->shared->type) {
         if (H5T_SORT_VALUE != dt->shared->u.compnd.sorted) {
             dt->shared->u.compnd.sorted = H5T_SORT_VALUE;
             nmembs                      = dt->shared->u.compnd.nmembs;
-            for (i = nmembs - 1, swapped = TRUE; i > 0 && swapped; --i) {
-                for (j = 0, swapped = FALSE; j < i; j++) {
+            for (i = nmembs - 1, swapped = true; i > 0 && swapped; --i) {
+                for (j = 0, swapped = false; j < i; j++) {
                     if (dt->shared->u.compnd.memb[j].offset > dt->shared->u.compnd.memb[j + 1].offset) {
                         H5T_cmemb_t tmp                  = dt->shared->u.compnd.memb[j];
                         dt->shared->u.compnd.memb[j]     = dt->shared->u.compnd.memb[j + 1];
@@ -307,14 +286,14 @@ H5T__sort_value(const H5T_t *dt, int *map)
                             map[j]     = map[j + 1];
                             map[j + 1] = x;
                         } /* end if */
-                        swapped = TRUE;
+                        swapped = true;
                     } /* end if */
                 }     /* end for */
             }         /* end for */
 #ifndef NDEBUG
             /* I never trust a sort :-) -RPM */
             for (i = 0; i < (nmembs - 1); i++)
-                HDassert(dt->shared->u.compnd.memb[i].offset < dt->shared->u.compnd.memb[i + 1].offset);
+                assert(dt->shared->u.compnd.memb[i].offset < dt->shared->u.compnd.memb[i + 1].offset);
 #endif
         } /* end if */
     }
@@ -323,11 +302,11 @@ H5T__sort_value(const H5T_t *dt, int *map)
             dt->shared->u.enumer.sorted = H5T_SORT_VALUE;
             nmembs                      = dt->shared->u.enumer.nmembs;
             size                        = dt->shared->size;
-            HDassert(size <= sizeof(tbuf));
-            for (i = (nmembs - 1), swapped = TRUE; i > 0 && swapped; --i) {
-                for (j = 0, swapped = FALSE; j < i; j++) {
-                    if (HDmemcmp((uint8_t *)dt->shared->u.enumer.value + (j * size),
-                                 (uint8_t *)dt->shared->u.enumer.value + ((j + 1) * size), size) > 0) {
+            assert(size <= sizeof(tbuf));
+            for (i = (nmembs - 1), swapped = true; i > 0 && swapped; --i) {
+                for (j = 0, swapped = false; j < i; j++) {
+                    if (memcmp((uint8_t *)dt->shared->u.enumer.value + (j * size),
+                               (uint8_t *)dt->shared->u.enumer.value + ((j + 1) * size), size) > 0) {
                         /* Swap names */
                         char *tmp                        = dt->shared->u.enumer.name[j];
                         dt->shared->u.enumer.name[j]     = dt->shared->u.enumer.name[j + 1];
@@ -347,15 +326,15 @@ H5T__sort_value(const H5T_t *dt, int *map)
                             map[j + 1] = x;
                         } /* end if */
 
-                        swapped = TRUE;
+                        swapped = true;
                     } /* end if */
                 }     /* end for */
             }         /* end for */
 #ifndef NDEBUG
             /* I never trust a sort :-) -RPM */
             for (i = 0; i < (nmembs - 1); i++)
-                HDassert(HDmemcmp((uint8_t *)dt->shared->u.enumer.value + (i * size),
-                                  (uint8_t *)dt->shared->u.enumer.value + ((i + 1) * size), size) < 0);
+                assert(memcmp((uint8_t *)dt->shared->u.enumer.value + (i * size),
+                              (uint8_t *)dt->shared->u.enumer.value + ((i + 1) * size), size) < 0);
 #endif
         } /* end if */
     }     /* end else */
@@ -374,9 +353,6 @@ H5T__sort_value(const H5T_t *dt, int *map)
  *
  *		Failure:	Negative
  *
- * Programmer:	Robb Matzke
- *              Monday, January  4, 1999
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -384,28 +360,28 @@ H5T__sort_name(const H5T_t *dt, int *map)
 {
     unsigned i, j, nmembs;
     size_t   size;
-    hbool_t  swapped;
+    bool     swapped;
     uint8_t  tbuf[32];
 
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(dt);
-    HDassert(H5T_COMPOUND == dt->shared->type || H5T_ENUM == dt->shared->type);
+    assert(dt);
+    assert(H5T_COMPOUND == dt->shared->type || H5T_ENUM == dt->shared->type);
 
     /* Use a bubble sort because we can short circuit */
     if (H5T_COMPOUND == dt->shared->type) {
         if (H5T_SORT_NAME != dt->shared->u.compnd.sorted) {
             dt->shared->u.compnd.sorted = H5T_SORT_NAME;
             nmembs                      = dt->shared->u.compnd.nmembs;
-            for (i = nmembs - 1, swapped = TRUE; i > 0 && swapped; --i) {
-                for (j = 0, swapped = FALSE; j < i; j++) {
-                    if (HDstrcmp(dt->shared->u.compnd.memb[j].name, dt->shared->u.compnd.memb[j + 1].name) >
+            for (i = nmembs - 1, swapped = true; i > 0 && swapped; --i) {
+                for (j = 0, swapped = false; j < i; j++) {
+                    if (strcmp(dt->shared->u.compnd.memb[j].name, dt->shared->u.compnd.memb[j + 1].name) >
                         0) {
                         H5T_cmemb_t tmp                  = dt->shared->u.compnd.memb[j];
                         dt->shared->u.compnd.memb[j]     = dt->shared->u.compnd.memb[j + 1];
                         dt->shared->u.compnd.memb[j + 1] = tmp;
-                        swapped                          = TRUE;
+                        swapped                          = true;
                         if (map) {
                             int x      = map[j];
                             map[j]     = map[j + 1];
@@ -417,8 +393,7 @@ H5T__sort_name(const H5T_t *dt, int *map)
 #ifndef NDEBUG
             /* I never trust a sort :-) -RPM */
             for (i = 0; i < nmembs - 1; i++) {
-                HDassert(HDstrcmp(dt->shared->u.compnd.memb[i].name, dt->shared->u.compnd.memb[i + 1].name) <
-                         0);
+                assert(strcmp(dt->shared->u.compnd.memb[i].name, dt->shared->u.compnd.memb[i + 1].name) < 0);
             }
 #endif
         }
@@ -428,10 +403,10 @@ H5T__sort_name(const H5T_t *dt, int *map)
             dt->shared->u.enumer.sorted = H5T_SORT_NAME;
             nmembs                      = dt->shared->u.enumer.nmembs;
             size                        = dt->shared->size;
-            HDassert(size <= sizeof(tbuf));
-            for (i = nmembs - 1, swapped = TRUE; i > 0 && swapped; --i) {
-                for (j = 0, swapped = FALSE; j < i; j++) {
-                    if (HDstrcmp(dt->shared->u.enumer.name[j], dt->shared->u.enumer.name[j + 1]) > 0) {
+            assert(size <= sizeof(tbuf));
+            for (i = nmembs - 1, swapped = true; i > 0 && swapped; --i) {
+                for (j = 0, swapped = false; j < i; j++) {
+                    if (strcmp(dt->shared->u.enumer.name[j], dt->shared->u.enumer.name[j + 1]) > 0) {
                         /* Swap names */
                         char *tmp                        = dt->shared->u.enumer.name[j];
                         dt->shared->u.enumer.name[j]     = dt->shared->u.enumer.name[j + 1];
@@ -450,14 +425,14 @@ H5T__sort_name(const H5T_t *dt, int *map)
                             map[j + 1] = x;
                         }
 
-                        swapped = TRUE;
+                        swapped = true;
                     }
                 }
             }
 #ifndef NDEBUG
             /* I never trust a sort :-) -RPM */
             for (i = 0; i < nmembs - 1; i++)
-                HDassert(HDstrcmp(dt->shared->u.enumer.name[i], dt->shared->u.enumer.name[i + 1]) < 0);
+                assert(strcmp(dt->shared->u.enumer.name[i], dt->shared->u.enumer.name[i + 1]) < 0);
 #endif
         }
     }
