@@ -10,10 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/*
- * Programmer: Robb Matzke
- *             Friday, October 10, 1997
- */
 #ifndef H5VMprivate_H
 #define H5VMprivate_H
 
@@ -39,50 +35,50 @@ typedef herr_t (*H5VM_opvv_func_t)(hsize_t dst_off, hsize_t src_off, size_t len,
 
 /* Other functions */
 #define H5VM_vector_cpy(N, DST, SRC)                                                                         \
-    {                                                                                                        \
-        HDassert(sizeof(*(DST)) == sizeof(*(SRC)));                                                          \
+    do {                                                                                                     \
+        assert(sizeof(*(DST)) == sizeof(*(SRC)));                                                            \
         if (SRC)                                                                                             \
             H5MM_memcpy(DST, SRC, (N) * sizeof(*(DST)));                                                     \
         else                                                                                                 \
-            HDmemset(DST, 0, (N) * sizeof(*(DST)));                                                          \
-    }
+            memset(DST, 0, (N) * sizeof(*(DST)));                                                            \
+    } while (0)
 
-#define H5VM_vector_zero(N, DST) HDmemset(DST, 0, (N) * sizeof(*(DST)))
+#define H5VM_vector_zero(N, DST) memset(DST, 0, (N) * sizeof(*(DST)))
 
 /* Given a coordinate offset array (COORDS) of type TYPE, move the unlimited
  * dimension (UNLIM_DIM) value to offset 0, sliding any intermediate values down
  * one position. */
 #define H5VM_swizzle_coords(TYPE, COORDS, UNLIM_DIM)                                                         \
-    {                                                                                                        \
+    do {                                                                                                     \
         /* COORDS must be an array of type TYPE */                                                           \
-        HDassert(sizeof(COORDS[0]) == sizeof(TYPE));                                                         \
+        assert(sizeof(COORDS[0]) == sizeof(TYPE));                                                           \
                                                                                                              \
         /* Nothing to do when unlimited dimension is at position 0 */                                        \
         if (0 != (UNLIM_DIM)) {                                                                              \
             TYPE _tmp = (COORDS)[UNLIM_DIM];                                                                 \
                                                                                                              \
-            HDmemmove(&(COORDS)[1], &(COORDS)[0], sizeof(TYPE) * (UNLIM_DIM));                               \
+            memmove(&(COORDS)[1], &(COORDS)[0], sizeof(TYPE) * (UNLIM_DIM));                                 \
             (COORDS)[0] = _tmp;                                                                              \
         } /* end if */                                                                                       \
-    }
+    } while (0)
 
 /* Given a coordinate offset array (COORDS) of type TYPE, move the value at
  * offset 0 to offset of the unlimied dimension (UNLIM_DIM), sliding any
  * intermediate values up one position.  Undoes the "swizzle_coords" operation.
  */
 #define H5VM_unswizzle_coords(TYPE, COORDS, UNLIM_DIM)                                                       \
-    {                                                                                                        \
+    do {                                                                                                     \
         /* COORDS must be an array of type TYPE */                                                           \
-        HDassert(sizeof(COORDS[0]) == sizeof(TYPE));                                                         \
+        assert(sizeof(COORDS[0]) == sizeof(TYPE));                                                           \
                                                                                                              \
         /* Nothing to do when unlimited dimension is at position 0 */                                        \
         if (0 != (UNLIM_DIM)) {                                                                              \
             TYPE _tmp = (COORDS)[0];                                                                         \
                                                                                                              \
-            HDmemmove(&(COORDS)[0], &(COORDS)[1], sizeof(TYPE) * (UNLIM_DIM));                               \
+            memmove(&(COORDS)[0], &(COORDS)[1], sizeof(TYPE) * (UNLIM_DIM));                                 \
             (COORDS)[UNLIM_DIM] = _tmp;                                                                      \
         } /* end if */                                                                                       \
-    }
+    } while (0)
 
 /* A null pointer is equivalent to a zero vector */
 #define H5VM_ZERO NULL
@@ -133,13 +129,8 @@ H5_DLL ssize_t H5VM_memcpyvv(void *_dst, size_t dst_max_nseq, size_t *dst_curr_s
  *              only as an optimization and the naming (with a single underscore)
  *              reflects its inclusion in a "private" header file.
  *
- * Return:      Success:        Product of elements
- *
- *              Failure:        1 if N is zero
- *
- * Programmer:  Robb Matzke
- *              Friday, October 10, 1997
- *
+ * Return:      Success:    Product of elements
+ *              Failure:    1 if N is zero
  *-------------------------------------------------------------------------
  */
 static inline hsize_t H5_ATTR_UNUSED
@@ -151,7 +142,7 @@ H5VM_vector_reduce_product(unsigned n, const hsize_t *v)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     if (n && !v)
-        HGOTO_DONE(0)
+        HGOTO_DONE(0);
     while (n--)
         ret_value *= *v++;
 
@@ -168,29 +159,23 @@ done:
  *              only as an optimization and the naming (with a single underscore)
  *              reflects its inclusion in a "private" header file.
  *
- * Return:      Success:        TRUE if all elements are zero,
- *                              FALSE otherwise
- *
- *              Failure:        TRUE if N is zero
- *
- * Programmer:  Robb Matzke
- *              Friday, October 10, 1997
- *
+ * Return:      Success:    true if all elements are zero,
+ *              Failure:    true if N is zero
  *-------------------------------------------------------------------------
  */
 static inline htri_t H5_ATTR_UNUSED
 H5VM_vector_zerop_u(int n, const hsize_t *v)
 {
-    htri_t ret_value = TRUE; /* Return value */
+    htri_t ret_value = true; /* Return value */
 
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     if (!v)
-        HGOTO_DONE(TRUE)
+        HGOTO_DONE(true);
     while (n--)
         if (*v++)
-            HGOTO_DONE(FALSE)
+            HGOTO_DONE(false);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -205,29 +190,24 @@ done:
  *              only as an optimization and the naming (with a single underscore)
  *              reflects its inclusion in a "private" header file.
  *
- * Return:      Success:        TRUE if all elements are zero,
- *                              FALSE otherwise
- *
- *              Failure:        TRUE if N is zero
- *
- * Programmer:  Robb Matzke
- *              Friday, October 10, 1997
- *
+ * Return:      Success:    true if all elements are zero,
+ *                          false otherwise
+ *              Failure:    true if N is zero
  *-------------------------------------------------------------------------
  */
 static inline htri_t H5_ATTR_UNUSED
 H5VM_vector_zerop_s(int n, const hssize_t *v)
 {
-    htri_t ret_value = TRUE; /* Return value */
+    htri_t ret_value = true; /* Return value */
 
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     if (!v)
-        HGOTO_DONE(TRUE)
+        HGOTO_DONE(true);
     while (n--)
         if (*v++)
-            HGOTO_DONE(FALSE)
+            HGOTO_DONE(false);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -243,15 +223,11 @@ done:
  *              only as an optimization and the naming (with a single underscore)
  *              reflects its inclusion in a "private" header file.
  *
- * Return:      Success:        -1 if V1 is less than V2
- *                              0 if they are equal
- *                              1 if V1 is greater than V2
- *
- *              Failure:        0 if N is zero
- *
- * Programmer:  Robb Matzke
- *              Friday, October 10, 1997
+ * Return:      Success:    -1 if V1 is less than V2
+ *                          0 if they are equal
+ *                          1 if V1 is greater than V2
  *
+ *              Failure:    0 if N is zero
  *-------------------------------------------------------------------------
  */
 static inline int H5_ATTR_UNUSED
@@ -263,16 +239,16 @@ H5VM_vector_cmp_u(unsigned n, const hsize_t *v1, const hsize_t *v2)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     if (v1 == v2)
-        HGOTO_DONE(0)
+        HGOTO_DONE(0);
     if (v1 == NULL)
-        HGOTO_DONE(-1)
+        HGOTO_DONE(-1);
     if (v2 == NULL)
-        HGOTO_DONE(1)
+        HGOTO_DONE(1);
     while (n--) {
         if (*v1 < *v2)
-            HGOTO_DONE(-1)
+            HGOTO_DONE(-1);
         if (*v1 > *v2)
-            HGOTO_DONE(1)
+            HGOTO_DONE(1);
         v1++;
         v2++;
     }
@@ -291,15 +267,11 @@ done:
  *              only as an optimization and the naming (with a single underscore)
  *              reflects its inclusion in a "private" header file.
  *
- * Return:      Success:        -1 if V1 is less than V2
- *                              0 if they are equal
- *                              1 if V1 is greater than V2
- *
- *              Failure:        0 if N is zero
- *
- * Programmer:  Robb Matzke
- *              Wednesday, April  8, 1998
+ * Return:      Success:    -1 if V1 is less than V2
+ *                          0 if they are equal
+ *                          1 if V1 is greater than V2
  *
+ *              Failure:    0 if N is zero
  *-------------------------------------------------------------------------
  */
 static inline int H5_ATTR_UNUSED
@@ -311,16 +283,16 @@ H5VM_vector_cmp_s(unsigned n, const hssize_t *v1, const hssize_t *v2)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     if (v1 == v2)
-        HGOTO_DONE(0)
+        HGOTO_DONE(0);
     if (v1 == NULL)
-        HGOTO_DONE(-1)
+        HGOTO_DONE(-1);
     if (v2 == NULL)
-        HGOTO_DONE(1)
+        HGOTO_DONE(1);
     while (n--) {
         if (*v1 < *v2)
-            HGOTO_DONE(-1)
+            HGOTO_DONE(-1);
         if (*v1 > *v2)
-            HGOTO_DONE(1)
+            HGOTO_DONE(1);
         v1++;
         v2++;
     }
@@ -339,10 +311,6 @@ done:
  *              reflects its inclusion in a "private" header file.
  *
  * Return:      void
- *
- * Programmer:  Robb Matzke
- *              Monday, October 13, 1997
- *
  *-------------------------------------------------------------------------
  */
 static inline void H5_ATTR_UNUSED
@@ -383,17 +351,13 @@ static const unsigned char LogTable256[] = {
  *              reflects its inclusion in a "private" header file.
  *
  * Return:      log2(n) (always - no failure condition)
- *
- * Programmer:  Quincey Koziol
- *              Monday, March  6, 2006
- *
  *-------------------------------------------------------------------------
  */
 static inline unsigned H5_ATTR_UNUSED
 H5VM_log2_gen(uint64_t n)
 {
-    unsigned              r;          /* r will be log2(n) */
-    register unsigned int t, tt, ttt; /* temporaries */
+    unsigned     r;          /* r will be log2(n) */
+    unsigned int t, tt, ttt; /* temporaries */
 
     if ((ttt = (unsigned)(n >> 32)))
         if ((tt = (unsigned)(n >> 48)))
@@ -432,17 +396,13 @@ static const unsigned MultiplyDeBruijnBitPosition[32] = {0,  1,  28, 2,  29, 14,
  *              reflects its inclusion in a "private" header file.
  *
  * Return:      log2(n) (always - no failure condition)
- *
- * Programmer:  Quincey Koziol
- *              Monday, February 27, 2006
- *
  *-------------------------------------------------------------------------
  */
 static inline H5_ATTR_PURE unsigned
 H5VM_log2_of2(uint32_t n)
 {
 #ifndef NDEBUG
-    HDassert(POWER_OF_TWO(n));
+    assert(POWER_OF_TWO(n));
 #endif /* NDEBUG */
     return (MultiplyDeBruijnBitPosition[(n * (uint32_t)0x077CB531UL) >> 27]);
 } /* H5VM_log2_of2() */
@@ -450,16 +410,13 @@ H5VM_log2_of2(uint32_t n)
 /*-------------------------------------------------------------------------
  * Function:    H5VM_power2up
  *
- * Purpose:    Round up a number to the next power of 2
+ * Purpose:     Round up a number to the next power of 2
  *
  * Note:        Although this routine is 'static' in this file, that's intended
  *              only as an optimization and the naming (with a single underscore)
  *              reflects its inclusion in a "private" header file.
  *
- * Return:    Return the number which is a power of 2
- *
- * Programmer:    Vailin Choi; Nov 2014
- *
+ * Return:      Return the number which is a power of 2
  *-------------------------------------------------------------------------
  */
 static inline H5_ATTR_CONST hsize_t
@@ -488,10 +445,6 @@ H5VM_power2up(hsize_t n)
  *              reflects its inclusion in a "private" header file.
  *
  * Return:      Number of bytes needed
- *
- * Programmer:  Quincey Koziol
- *              Thursday, March 13, 2008
- *
  *-------------------------------------------------------------------------
  */
 static inline unsigned H5_ATTR_UNUSED
@@ -519,18 +472,14 @@ static const unsigned char H5VM_bit_clear_g[8] = {0x7F, 0xBF, 0xDF, 0xEF, 0xF7,
  *              only as an optimization and the naming (with a single underscore)
  *              reflects its inclusion in a "private" header file.
  *
- * Return:      TRUE/FALSE
- *
- * Programmer:  Quincey Koziol
- *              Tuesday, November 25, 2008
- *
+ * Return:      true/false
  *-------------------------------------------------------------------------
  */
-static inline hbool_t H5_ATTR_UNUSED
+static inline bool H5_ATTR_UNUSED
 H5VM_bit_get(const unsigned char *buf, size_t offset)
 {
     /* Test the appropriate bit in the buffer */
-    return (hbool_t)((buf[offset / 8] & (H5VM_bit_set_g[offset % 8])) ? TRUE : FALSE);
+    return (bool)((buf[offset / 8] & (H5VM_bit_set_g[offset % 8])) ? true : false);
 } /* end H5VM_bit_get() */
 
 /*-------------------------------------------------------------------------
@@ -549,15 +498,11 @@ H5VM_bit_get(const unsigned char *buf, size_t offset)
  *              only as an optimization and the naming (with a single underscore)
  *              reflects its inclusion in a "private" header file.
  *
- * Return:      None
- *
- * Programmer:  Quincey Koziol
- *              Tuesday, November 25, 2008
- *
+ * Return:      void
  *-------------------------------------------------------------------------
  */
 static inline void H5_ATTR_UNUSED
-H5VM_bit_set(unsigned char *buf, size_t offset, hbool_t val)
+H5VM_bit_set(unsigned char *buf, size_t offset, bool val)
 {
     /* Set/reset the appropriate bit in the buffer */
     if (val)
