@@ -11,14 +11,11 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Quincey Koziol
- *              Tuesday, May 13, 2003
- *
  * Purpose:    Test dangling IDs
  */
 #include "h5test.h"
 
-const char *FILENAME[] = {"dangle", NULL};
+static const char *FILENAME[] = {"dangle", NULL};
 
 #define MAX_DANGLE 1000
 
@@ -36,11 +33,6 @@ const char *FILENAME[] = {"dangle", NULL};
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Tuesday, May 13, 2003
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -86,7 +78,7 @@ test_dangle_dataset(H5F_close_degree_t degree)
             0)
             TEST_ERROR;
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     if (H5Sclose(sid) < 0)
         TEST_ERROR;
@@ -102,7 +94,7 @@ test_dangle_dataset(H5F_close_degree_t degree)
             if (H5Fclose(fid) >= 0)
                 TEST_ERROR;
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     } /* end if */
     else if (H5Fclose(fid) < 0)
         TEST_ERROR;
@@ -135,11 +127,6 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Tuesday, May 13, 2003
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -169,7 +156,7 @@ test_dangle_group(H5F_close_degree_t degree)
         TEST_ERROR;
 
     if ((gid = H5Gcreate2(fid, GROUPNAME, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5Gclose(gid) < 0)
         TEST_ERROR;
@@ -179,17 +166,17 @@ test_dangle_group(H5F_close_degree_t degree)
     {
         gid = H5Gcreate2(fid, GROUPNAME, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (gid >= 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Leave open a _lot_ of objects */
     for (u = 0; u < MAX_DANGLE; u++)
         if ((gid = H5Gopen2(fid, GROUPNAME, H5P_DEFAULT)) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
 
     if ((gid = H5Gopen2(fid, GROUPNAME, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (degree == H5F_CLOSE_SEMI) {
         H5E_BEGIN_TRY
@@ -197,7 +184,7 @@ test_dangle_group(H5F_close_degree_t degree)
             if (H5Fclose(fid) >= 0)
                 TEST_ERROR;
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     } /* end if */
     else if (H5Fclose(fid) < 0)
         TEST_ERROR;
@@ -230,11 +217,6 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Tuesday, May 13, 2003
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -280,14 +262,14 @@ test_dangle_datatype1(H5F_close_degree_t degree)
         if (H5Tcommit2(fid, TYPENAME, tid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT) >= 0)
             TEST_ERROR;
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (H5Tclose(tid) < 0)
         TEST_ERROR;
 
     /* Leave open a _lot_ of objects */
     for (u = 0; u < MAX_DANGLE; u++)
         if ((tid = H5Topen2(fid, TYPENAME, H5P_DEFAULT)) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
 
     if (degree == H5F_CLOSE_SEMI) {
         H5E_BEGIN_TRY
@@ -295,7 +277,7 @@ test_dangle_datatype1(H5F_close_degree_t degree)
             if (H5Fclose(fid) >= 0)
                 TEST_ERROR;
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     } /* end if */
     else if (H5Fclose(fid) < 0)
         TEST_ERROR;
@@ -328,11 +310,6 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Thursday, August 25, 2005
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -382,7 +359,7 @@ test_dangle_datatype2(H5F_close_degree_t degree)
             if (H5Fclose(fid) >= 0)
                 TEST_ERROR;
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     } /* end if */
     else if (H5Fclose(fid) < 0)
         TEST_ERROR;
@@ -415,11 +392,6 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Wednesday, June 18, 2003
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -472,7 +444,7 @@ test_dangle_attribute(H5F_close_degree_t degree)
         if ((aid = H5Acreate2(dsid, ATTRNAME, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT)) >= 0)
             TEST_ERROR;
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     if (H5Sclose(sid) < 0)
         TEST_ERROR;
@@ -480,10 +452,10 @@ test_dangle_attribute(H5F_close_degree_t degree)
     /* Leave open a _lot_ of objects */
     for (u = 0; u < MAX_DANGLE; u++)
         if ((aid = H5Aopen(dsid, ATTRNAME, H5P_DEFAULT)) < 0)
-            TEST_ERROR
+            TEST_ERROR;
 
     if (H5Dclose(dsid) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     if (degree == H5F_CLOSE_SEMI) {
         H5E_BEGIN_TRY
@@ -491,7 +463,7 @@ test_dangle_attribute(H5F_close_degree_t degree)
             if (H5Fclose(fid) >= 0)
                 TEST_ERROR;
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     } /* end if */
     else if (H5Fclose(fid) < 0)
         TEST_ERROR;
@@ -524,9 +496,6 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Friday, October 29, 2010
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -547,73 +516,73 @@ test_dangle_force(void)
 
     h5_fixname(FILENAME[0], H5P_DEFAULT, filename, sizeof filename);
     if ((fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Create a dataspace for the dataset & attribute to use */
     if ((sid = H5Screate(H5S_SCALAR)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Create a dataset */
     if ((dsid = H5Dcreate2(fid, DSETNAME, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Re-open the dataset */
     if ((dsid2 = H5Dopen2(fid, DSETNAME, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Create an attribute on the dataset */
     if ((aid = H5Acreate2(dsid, ATTRNAME, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Re-open the attribute */
     if ((aid2 = H5Aopen(dsid, ATTRNAME, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Close the dataspace ID */
     if (H5Sclose(sid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Open a group ID */
     if ((gid = H5Gopen2(fid, "/", H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Open group again */
     if ((gid2 = H5Gopen2(fid, "/", H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Create a named datatype */
     if ((tid = H5Tcopy(H5T_NATIVE_INT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tcommit2(fid, TYPENAME, tid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Re-open the named datatype */
     if ((tid2 = H5Topen2(fid, TYPENAME, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Increment the ref count on all the "second" objects */
     if (H5Iinc_ref(dsid2) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Iinc_ref(aid2) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Iinc_ref(gid2) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Iinc_ref(aid2) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get the number of open objects */
     if ((count = H5Fget_obj_count((hid_t)H5F_OBJ_ALL, H5F_OBJ_ALL)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (0 == count)
         TEST_ERROR;
 
     /* Allocate the array of object IDs */
-    if (NULL == (objs = (hid_t *)HDcalloc((size_t)count, sizeof(hid_t))))
+    if (NULL == (objs = (hid_t *)calloc((size_t)count, sizeof(hid_t))))
         TEST_ERROR;
 
     /* Get the list of open IDs */
     if (H5Fget_obj_ids((hid_t)H5F_OBJ_ALL, H5F_OBJ_ALL, (size_t)count, objs) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Close all open IDs */
     for (u = 0; u < (size_t)count; u++)
@@ -622,7 +591,7 @@ test_dangle_force(void)
 
     /* Get the number of open objects */
     if ((count = H5Fget_obj_count((hid_t)H5F_OBJ_ALL, H5F_OBJ_ALL)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (0 != count)
         TEST_ERROR;
 
@@ -630,14 +599,14 @@ test_dangle_force(void)
     HDremove(filename);
 
     /* Release object ID array */
-    HDfree(objs);
+    free(objs);
 
     PASSED();
     return 0;
 
 error:
     if (objs)
-        HDfree(objs);
+        free(objs);
     return 1;
 }
 
@@ -649,20 +618,27 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Tuesday, May 13, 2003
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 int
 main(void)
 {
-    int nerrors = 0;
+    const char *driver_name; /* File Driver value from environment */
+    int         nerrors = 0;
+
+    /* Get the VFD to use */
+    driver_name = h5_get_test_driver_name();
+
+    /* Don't run this test with the multi/split VFD. A bug in library shutdown
+     * ordering causes problems with the multi VFD when IDs are left dangling.
+     */
+    if (!strcmp(driver_name, "multi") || !strcmp(driver_name, "split")) {
+        puts(" -- SKIPPED for incompatible VFD --");
+        return 0;
+    }
 
     /* Run tests w/weak file close */
-    HDputs("Testing dangling objects with weak file close:");
+    puts("Testing dangling objects with weak file close:");
     nerrors += test_dangle_dataset(H5F_CLOSE_WEAK);
     nerrors += test_dangle_group(H5F_CLOSE_WEAK);
     nerrors += test_dangle_datatype1(H5F_CLOSE_WEAK);
@@ -670,7 +646,7 @@ main(void)
     nerrors += test_dangle_attribute(H5F_CLOSE_WEAK);
 
     /* Run tests w/semi file close */
-    HDputs("Testing dangling objects with semi file close:");
+    puts("Testing dangling objects with semi file close:");
     nerrors += test_dangle_dataset(H5F_CLOSE_SEMI);
     nerrors += test_dangle_group(H5F_CLOSE_SEMI);
     nerrors += test_dangle_datatype1(H5F_CLOSE_SEMI);
@@ -678,7 +654,7 @@ main(void)
     nerrors += test_dangle_attribute(H5F_CLOSE_SEMI);
 
     /* Run tests w/strong file close */
-    HDputs("Testing dangling objects with strong file close:");
+    puts("Testing dangling objects with strong file close:");
     nerrors += test_dangle_dataset(H5F_CLOSE_STRONG);
     nerrors += test_dangle_group(H5F_CLOSE_STRONG);
     nerrors += test_dangle_datatype1(H5F_CLOSE_STRONG);
@@ -691,11 +667,11 @@ main(void)
     /* Check for errors */
     if (nerrors)
         goto error;
-    HDputs("All dangling ID tests passed.");
+    puts("All dangling ID tests passed.");
 
     return 0;
 
 error:
-    HDputs("***** DANGLING ID TESTS FAILED *****");
+    puts("***** DANGLING ID TESTS FAILED *****");
     return 1;
 }
