@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:    Raymond Lu
- *              October 14, 2001
- *
  * Purpose:    Tests the error API routines.
  */
 #include "h5test.h"
@@ -23,36 +20,36 @@
 int
 main(void)
 {
-    HDfprintf(stderr, "Test skipped because backward compatibility with v1.6 is configured in\n");
+    fprintf(stderr, "Test skipped because backward compatibility with v1.6 is configured in\n");
     return 0;
 }
 #else /* H5_USE_16_API */
 
-const char *FILENAME[] = {"errors", NULL};
+static const char *FILENAME[] = {"errors", NULL};
 
 #define DATAFILE "filter_error"
 
 #define DIM0 100
 #define DIM1 200
 
-int **ipoints2      = NULL;
-int **icheck2       = NULL;
-int  *ipoints2_data = NULL;
-int  *icheck2_data  = NULL;
+static int **ipoints2      = NULL;
+static int **icheck2       = NULL;
+static int  *ipoints2_data = NULL;
+static int  *icheck2_data  = NULL;
 
-hid_t ERR_CLS;
-hid_t ERR_CLS2;
-hid_t ERR_STACK;
+static hid_t ERR_CLS;
+static hid_t ERR_CLS2;
+static hid_t ERR_STACK;
 
-hid_t ERR_MAJ_TEST;
-hid_t ERR_MAJ_IO;
-hid_t ERR_MAJ_API;
+static hid_t ERR_MAJ_TEST;
+static hid_t ERR_MAJ_IO;
+static hid_t ERR_MAJ_API;
 
-hid_t ERR_MIN_SUBROUTINE;
-hid_t ERR_MIN_ERRSTACK;
-hid_t ERR_MIN_CREATE;
-hid_t ERR_MIN_WRITE;
-hid_t ERR_MIN_GETNUM;
+static hid_t ERR_MIN_SUBROUTINE;
+static hid_t ERR_MIN_ERRSTACK;
+static hid_t ERR_MIN_CREATE;
+static hid_t ERR_MIN_WRITE;
+static hid_t ERR_MIN_GETNUM;
 
 #define DSET_NAME "a_dataset"
 #define FAKE_ID   (hid_t)0
@@ -92,15 +89,15 @@ static herr_t custom_print_cb(unsigned n, const H5E_error2_t *err_desc, void *cl
 static herr_t
 test_error(hid_t file)
 {
-    hid_t       dataset   = -1;
-    hid_t       space     = -1;
-    hid_t       estack_id = -1;
+    hid_t       dataset   = H5I_INVALID_HID;
+    hid_t       space     = H5I_INVALID_HID;
+    hid_t       estack_id = H5I_INVALID_HID;
     hsize_t     dims[2];
     const char *FUNC_test_error = "test_error";
     H5E_auto2_t old_func;
     void       *old_data = NULL;
 
-    HDfprintf(stderr, "\nTesting error API based on data I/O\n");
+    fprintf(stderr, "\nTesting error API based on data I/O\n");
 
     /* Create the data space */
     dims[0] = DIM0;
@@ -113,7 +110,7 @@ test_error(hid_t file)
     {
         dataset = H5Dcreate2(FAKE_ID, DSET_NAME, H5T_STD_I32BE, space, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     /* Create the dataset */
     if ((dataset = H5Dcreate2(file, DSET_NAME, H5T_STD_I32BE, space, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) <
@@ -178,23 +175,25 @@ error:
 static herr_t
 init_error(void)
 {
-    ssize_t    cls_size = (ssize_t)HDstrlen(ERR_CLS_NAME) + 1;
-    ssize_t    msg_size = (ssize_t)HDstrlen(ERR_MIN_SUBROUTINE_MSG) + 1;
+    ssize_t    cls_size = (ssize_t)strlen(ERR_CLS_NAME);
+    ssize_t    msg_size = (ssize_t)strlen(ERR_MIN_SUBROUTINE_MSG) + 1;
     char      *cls_name = NULL;
     char      *msg      = NULL;
     H5E_type_t msg_type;
 
-    if (NULL == (cls_name = (char *)HDmalloc(HDstrlen(ERR_CLS_NAME) + 1)))
-        TEST_ERROR
-    if (NULL == (msg = (char *)HDmalloc(HDstrlen(ERR_MIN_SUBROUTINE_MSG) + 1)))
-        TEST_ERROR
+    /* Account for null terminator */
+    if (NULL == (cls_name = (char *)malloc(strlen(ERR_CLS_NAME) + 1)))
+        TEST_ERROR;
+    if (NULL == (msg = (char *)malloc(strlen(ERR_MIN_SUBROUTINE_MSG) + 1)))
+        TEST_ERROR;
 
     if ((ERR_CLS = H5Eregister_class(ERR_CLS_NAME, PROG_NAME, PROG_VERS)) < 0)
         TEST_ERROR;
 
-    if (cls_size != H5Eget_class_name(ERR_CLS, cls_name, (size_t)cls_size) + 1)
+    /* Account for null terminator */
+    if (cls_size != H5Eget_class_name(ERR_CLS, cls_name, (size_t)cls_size + 1))
         TEST_ERROR;
-    if (HDstrcmp(ERR_CLS_NAME, cls_name) != 0)
+    if (strcmp(ERR_CLS_NAME, cls_name) != 0)
         TEST_ERROR;
 
     if ((ERR_MAJ_TEST = H5Ecreate_msg(ERR_CLS, H5E_MAJOR, ERR_MAJ_TEST_MSG)) < 0)
@@ -219,23 +218,23 @@ init_error(void)
         TEST_ERROR;
     if (msg_type != H5E_MINOR)
         TEST_ERROR;
-    if (HDstrcmp(msg, ERR_MIN_SUBROUTINE_MSG) != 0)
+    if (strcmp(msg, ERR_MIN_SUBROUTINE_MSG) != 0)
         TEST_ERROR;
 
     /* Register another class for later testing. */
     if ((ERR_CLS2 = H5Eregister_class(ERR_CLS2_NAME, PROG2_NAME, PROG_VERS)) < 0)
         TEST_ERROR;
 
-    HDfree(cls_name);
-    HDfree(msg);
+    free(cls_name);
+    free(msg);
 
     return 0;
 
 error:
     if (cls_name)
-        HDfree(cls_name);
+        free(cls_name);
     if (msg)
-        HDfree(msg);
+        free(msg);
 
     return -1;
 } /* end init_error() */
@@ -296,7 +295,7 @@ long_desc_cb(unsigned H5_ATTR_UNUSED n, const H5E_error2_t *err_desc, void *clie
 {
     char *real_desc = (char *)client_data;
 
-    if (err_desc->desc != NULL && HDstrcmp(err_desc->desc, real_desc) == 0)
+    if (err_desc->desc != NULL && strcmp(err_desc->desc, real_desc) == 0)
         return 0;
     else
         return -1;
@@ -318,7 +317,7 @@ long_desc_cb(unsigned H5_ATTR_UNUSED n, const H5E_error2_t *err_desc, void *clie
  *      'full_desc' in the code below, but early (4.4.7, at least) gcc only
  *      allows diagnostic pragmas to be toggled outside of functions.
  */
-H5_GCC_DIAG_OFF("format-nonliteral")
+H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
 static herr_t
 test_long_desc(void)
 {
@@ -329,9 +328,9 @@ test_long_desc(void)
     const char *test_FUNC = "test_long_desc";
 
     /* Allocate space for the error description info */
-    if (NULL == (long_desc = (char *)HDmalloc(LONG_DESC_SIZE)))
+    if (NULL == (long_desc = (char *)malloc(LONG_DESC_SIZE)))
         TEST_ERROR;
-    if (NULL == (full_desc = (char *)HDmalloc(LONG_DESC_SIZE + 128)))
+    if (NULL == (full_desc = (char *)malloc(LONG_DESC_SIZE + 128)))
         TEST_ERROR;
 
     /* Create the long part of the error description */
@@ -348,10 +347,10 @@ test_long_desc(void)
                 long_desc) < 0)
         TEST_ERROR;
 
-    /* Create the string that should be in the description. Must use HDsnprintf here
+    /* Create the string that should be in the description. Must use snprintf here
      * because snprintf is _snprintf on Windows
      */
-    HDsnprintf(full_desc, (size_t)(LONG_DESC_SIZE + 128), format, long_desc);
+    snprintf(full_desc, (size_t)(LONG_DESC_SIZE + 128), format, long_desc);
 
     /* Make certain that the description is correct */
     if (H5Ewalk2(H5E_DEFAULT, H5E_WALK_UPWARD, long_desc_cb, full_desc) < 0)
@@ -361,20 +360,20 @@ test_long_desc(void)
     if (H5Eclear2(H5E_DEFAULT) < 0)
         TEST_ERROR;
 
-    HDfree(long_desc);
-    HDfree(full_desc);
+    free(long_desc);
+    free(full_desc);
 
     return 0;
 
 error:
     if (long_desc)
-        HDfree(long_desc);
+        free(long_desc);
     if (full_desc)
-        HDfree(full_desc);
+        free(full_desc);
 
     return -1;
 } /* end test_long_desc() */
-H5_GCC_DIAG_ON("format-nonliteral")
+H5_GCC_CLANG_DIAG_ON("format-nonliteral")
 
 /*-------------------------------------------------------------------------
  * Function:    dump_error
@@ -390,12 +389,12 @@ static herr_t
 dump_error(hid_t estack)
 {
     /* Print errors in library default way */
-    HDfprintf(stderr, "********* Print error stack in HDF5 default way *********\n");
+    fprintf(stderr, "********* Print error stack in HDF5 default way *********\n");
     if (H5Eprint2(estack, stderr) < 0)
         TEST_ERROR;
 
     /* Customized way to print errors */
-    HDfprintf(stderr, "\n********* Print error stack in customized way *********\n");
+    fprintf(stderr, "\n********* Print error stack in customized way *********\n");
     if (H5Ewalk2(estack, H5E_WALK_UPWARD, custom_print_cb, stderr) < 0)
         TEST_ERROR;
 
@@ -434,11 +433,11 @@ custom_print_cb(unsigned n, const H5E_error2_t *err_desc, void *client_data)
     if (H5Eget_msg(err_desc->min_num, NULL, min, MSG_SIZE) < 0)
         TEST_ERROR;
 
-    HDfprintf(stream, "%*serror #%03d: %s in %s(): line %u\n", indent, "", n, err_desc->file_name,
-              err_desc->func_name, err_desc->line);
-    HDfprintf(stream, "%*sclass: %s\n", indent * 2, "", cls);
-    HDfprintf(stream, "%*smajor: %s\n", indent * 2, "", maj);
-    HDfprintf(stream, "%*sminor: %s\n", indent * 2, "", min);
+    fprintf(stream, "%*serror #%03d: %s in %s(): line %u\n", indent, "", n, err_desc->file_name,
+            err_desc->func_name, err_desc->line);
+    fprintf(stream, "%*sclass: %s\n", indent * 2, "", cls);
+    fprintf(stream, "%*smajor: %s\n", indent * 2, "", maj);
+    fprintf(stream, "%*sminor: %s\n", indent * 2, "", min);
 
     return 0;
 
@@ -459,42 +458,41 @@ error:
 static herr_t
 test_create(void)
 {
-    const char *err_func = "test_create";   /* Function name for pushing error */
-    const char *err_msg  = "Error message"; /* Error message for pushing error */
-    ssize_t     err_num;                    /* Number of errors on stack */
-    hid_t       estack_id = -1;             /* Error stack ID */
+    const char *err_msg = "Error message";   /* Error message for pushing error */
+    ssize_t     err_num;                     /* Number of errors on stack */
+    hid_t       estack_id = H5I_INVALID_HID; /* Error stack ID */
 
     /* Create an empty error stack */
     if ((estack_id = H5Ecreate_stack()) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Check the number of errors on stack */
     err_num = H5Eget_num(estack_id);
     if (err_num != 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Push an error with a long description */
-    if (H5Epush(estack_id, __FILE__, err_func, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, "%s",
+    if (H5Epush(estack_id, __FILE__, __func__, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, "%s",
                 err_msg) < 0)
         TEST_ERROR;
 
     /* Check the number of errors on stack */
     err_num = H5Eget_num(estack_id);
     if (err_num != 1)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Clear the error stack */
     if (H5Eclear2(estack_id) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Check the number of errors on stack */
     err_num = H5Eget_num(estack_id);
     if (err_num != 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close error stack */
     if (H5Eclose_stack(estack_id) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -515,44 +513,43 @@ error:
 static herr_t
 test_copy(void)
 {
-    const char *err_func = "test_copy";     /* Function name for pushing error */
-    const char *err_msg  = "Error message"; /* Error message for pushing error */
-    ssize_t     err_num;                    /* Number of errors on stack */
-    hid_t       estack_id = -1;             /* Error stack ID */
-    herr_t      ret;                        /* Generic return value */
+    const char *err_msg = "Error message";   /* Error message for pushing error */
+    ssize_t     err_num;                     /* Number of errors on stack */
+    hid_t       estack_id = H5I_INVALID_HID; /* Error stack ID */
+    herr_t      ret;                         /* Generic return value */
 
     /* Push an error with a long description */
-    if (H5Epush(H5E_DEFAULT, __FILE__, err_func, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, "%s",
+    if (H5Epush(H5E_DEFAULT, __FILE__, __func__, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, "%s",
                 err_msg) < 0)
         TEST_ERROR;
 
     /* Check the number of errors on stack */
     err_num = H5Eget_num(H5E_DEFAULT);
     if (err_num != 1)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Copy error stack, which clears the original */
     if ((estack_id = H5Eget_current_stack()) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Check the number of errors on stack copy */
     err_num = H5Eget_num(estack_id);
     if (err_num != 1)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Check the number of errors on original stack */
     err_num = H5Eget_num(H5E_DEFAULT);
     if (err_num != 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Put the stack copy as the default.  It closes the stack copy, too. */
     if (H5Eset_current_stack(estack_id) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Check the number of errors on default stack */
     err_num = H5Eget_num(H5E_DEFAULT);
     if (err_num != 1)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Try to close error stack copy.  Should fail because
      * the current H5Eset_current_stack closes the stack to be set.
@@ -563,7 +560,7 @@ test_copy(void)
     }
     H5E_END_TRY
     if (ret >= 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -571,6 +568,282 @@ error:
     return -1;
 } /* end test_copy() */
 
+/*-------------------------------------------------------------------------
+ * Function:    test_append
+ *
+ * Purpose:     Test appending one error stack to another
+ *
+ * Return:      Success:    0
+ *              Failure:    -1
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+test_append(void)
+{
+    const char *err_msg1 = "Error message #1"; /* Error message #1 for pushing error */
+    const char *err_msg2 = "Error message #2"; /* Error message #2 for pushing error */
+    ssize_t     err_num;                       /* Number of errors on stack */
+    hid_t       estack_id1 = H5I_INVALID_HID;  /* Error stack ID */
+    hid_t       estack_id2 = H5I_INVALID_HID;  /* Error stack ID */
+    herr_t      ret;                           /* Generic return value */
+
+    /* Push an error */
+    if (H5Epush(H5E_DEFAULT, __FILE__, __func__, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, "%s",
+                err_msg1) < 0)
+        TEST_ERROR;
+
+    /* Copy error stack, which clears the original */
+    if ((estack_id1 = H5Eget_current_stack()) < 0)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #1 */
+    err_num = H5Eget_num(estack_id1);
+    if (err_num != 1)
+        TEST_ERROR;
+
+    /* Create another stack, from scratch */
+    if ((estack_id2 = H5Ecreate_stack()) < 0)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #2 */
+    err_num = H5Eget_num(estack_id2);
+    if (err_num != 0)
+        TEST_ERROR;
+
+    /* Push an error on stack #2 */
+    if (H5Epush(estack_id2, __FILE__, __func__, __LINE__, ERR_CLS, ERR_MAJ_IO, ERR_MIN_CREATE, "%s",
+                err_msg2) < 0)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #2 */
+    err_num = H5Eget_num(estack_id2);
+    if (err_num != 1)
+        TEST_ERROR;
+
+    /* Try to append bad error stack IDs */
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eappend_stack(H5E_DEFAULT, H5E_DEFAULT, false);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eappend_stack(estack_id1, H5E_DEFAULT, false);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eappend_stack(H5E_DEFAULT, estack_id2, false);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+
+    /* Append error stack #2 to error stack #1, without closing stack #2 */
+    if (H5Eappend_stack(estack_id1, estack_id2, false) < 0)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #1 */
+    err_num = H5Eget_num(estack_id1);
+    if (err_num != 2)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #2 */
+    err_num = H5Eget_num(estack_id2);
+    if (err_num != 1)
+        TEST_ERROR;
+
+    /* Append error stack #2 to error stack #1, and close stack #2 */
+    if (H5Eappend_stack(estack_id1, estack_id2, TRUE) < 0)
+        TEST_ERROR;
+
+    /* Try to close error stack #2.  Should fail because H5Eappend_stack
+     * should have already closed it.
+     */
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eclose_stack(estack_id2);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #1 */
+    err_num = H5Eget_num(estack_id1);
+    if (err_num != 3)
+        TEST_ERROR;
+
+    return 0;
+
+error:
+    return -1;
+} /* end test_append() */
+
+/*-------------------------------------------------------------------------
+ * Function:    test_pause
+ *
+ * Purpose:     Test pausing error stacks
+ *
+ * Return:      Success:    0
+ *              Failure:    -1
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+test_pause(void)
+{
+    const char *err_msg1 = "Error message #1"; /* Error message #1 for pushing error */
+    ssize_t     err_num;                       /* Number of errors on stack */
+    hid_t       estack_id1 = H5I_INVALID_HID;  /* Error stack ID */
+    hbool_t     is_paused;                     /* Whether error stack is paused */
+    herr_t      ret;                           /* Generic return value */
+
+    /* Push an error */
+    if (H5Epush(H5E_DEFAULT, __FILE__, __func__, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, "%s",
+                err_msg1) < 0)
+        TEST_ERROR;
+
+    /* Copy error stack, which clears the original */
+    if ((estack_id1 = H5Eget_current_stack()) < 0)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #1 */
+    err_num = H5Eget_num(estack_id1);
+    if (err_num != 1)
+        TEST_ERROR;
+
+    /* Check for bad arguments */
+    is_paused = TRUE;
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eis_paused(H5I_INVALID_HID, &is_paused);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+
+    /* Verify that default stack is not paused */
+    is_paused = TRUE;
+    if (H5Eis_paused(H5E_DEFAULT, &is_paused) < 0)
+        TEST_ERROR;
+    if (FALSE != is_paused)
+        TEST_ERROR;
+
+    /* Verify that application stack is not paused */
+    is_paused = TRUE;
+    if (H5Eis_paused(estack_id1, &is_paused) < 0)
+        TEST_ERROR;
+    if (FALSE != is_paused)
+        TEST_ERROR;
+
+    /* Check for bad arguments */
+    H5E_BEGIN_TRY
+    {
+        ret = H5Epause_stack(H5I_INVALID_HID);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+    /* Check for bad arguments */
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eresume_stack(H5I_INVALID_HID);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+
+    /* Pause error stack */
+    if (H5Epause_stack(estack_id1) < 0)
+        TEST_ERROR;
+
+    /* Check if stack is paused */
+    is_paused = FALSE;
+    if (H5Eis_paused(estack_id1, &is_paused) < 0)
+        TEST_ERROR;
+    if (TRUE != is_paused)
+        TEST_ERROR;
+
+    /* Resume error stack */
+    if (H5Eresume_stack(estack_id1) < 0)
+        TEST_ERROR;
+
+    /* Check if stack is paused */
+    is_paused = TRUE;
+    if (H5Eis_paused(estack_id1, &is_paused) < 0)
+        TEST_ERROR;
+    if (FALSE != is_paused)
+        TEST_ERROR;
+
+    /* Check for resuming too many times */
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eresume_stack(estack_id1);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+
+    /* Check if stack is paused, after trying to resume too many times */
+    is_paused = TRUE;
+    if (H5Eis_paused(estack_id1, &is_paused) < 0)
+        TEST_ERROR;
+    if (FALSE != is_paused)
+        TEST_ERROR;
+
+    /* Close error stack */
+    if (H5Eclose_stack(estack_id1) < 0)
+        TEST_ERROR;
+
+    /* Pause default error stack */
+    if (H5Epause_stack(H5E_DEFAULT) < 0)
+        TEST_ERROR;
+
+    /* Check if stack is paused */
+    is_paused = FALSE;
+    if (H5Eis_paused(H5E_DEFAULT, &is_paused) < 0)
+        TEST_ERROR;
+    if (TRUE != is_paused)
+        TEST_ERROR;
+
+    /* Resume error stack */
+    if (H5Eresume_stack(H5E_DEFAULT) < 0)
+        TEST_ERROR;
+
+    /* Check if stack is paused */
+    is_paused = TRUE;
+    if (H5Eis_paused(H5E_DEFAULT, &is_paused) < 0)
+        TEST_ERROR;
+    if (FALSE != is_paused)
+        TEST_ERROR;
+
+    /* Check for resuming too many times */
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eresume_stack(H5E_DEFAULT);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+
+    /* Check if stack is paused, after trying to resume too many times */
+    is_paused = TRUE;
+    if (H5Eis_paused(H5E_DEFAULT, &is_paused) < 0)
+        TEST_ERROR;
+    if (FALSE != is_paused)
+        TEST_ERROR;
+
+    return 0;
+
+error:
+    return -1;
+} /* end test_pause() */
+
 /*-------------------------------------------------------------------------
  * Function:    close_error
  *
@@ -620,17 +893,17 @@ error:
  *-------------------------------------------------------------------------
  */
 static herr_t
-test_filter_error(const char *fname)
+test_filter_error(const char *fname, hid_t fapl)
 {
     const char *pathname = H5_get_srcdir_filename(fname); /* Corrected test file name */
-    hid_t       file     = -1;
-    hid_t       dataset  = -1;
+    hid_t       file     = H5I_INVALID_HID;
+    hid_t       dataset  = H5I_INVALID_HID;
     int         buf[20];
 
-    HDfprintf(stderr, "\nTesting error message during data reading when filter isn't registered\n");
+    fprintf(stderr, "\nTesting error message during data reading when filter isn't registered\n");
 
     /* Open the file */
-    if ((file = H5Fopen(pathname, H5F_ACC_RDONLY, H5P_DEFAULT)) < 0)
+    if ((file = H5Fopen(pathname, H5F_ACC_RDONLY, fapl)) < 0)
         TEST_ERROR;
 
     /* Open the regular dataset */
@@ -642,10 +915,10 @@ test_filter_error(const char *fname)
 
     /* Close/release resources */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     if (H5Fclose(file) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -663,14 +936,18 @@ error:
 int
 main(void)
 {
-    hid_t       file      = -1;
-    hid_t       fapl      = -1;
-    hid_t       estack_id = -1;
+    hid_t       file      = H5I_INVALID_HID;
+    hid_t       fapl      = H5I_INVALID_HID;
+    hid_t       estack_id = H5I_INVALID_HID;
     char        filename[1024];
+    const char *driver_name; /* File driver value from environment */
     const char *FUNC_main = "main";
     int         i;
 
-    HDfprintf(stderr, "   This program tests the Error API.  There're supposed to be some error messages\n");
+    /* Get the VFD to use */
+    driver_name = h5_get_test_driver_name();
+
+    fprintf(stderr, "   This program tests the Error API.  There're supposed to be some error messages\n");
 
     /* Initialize errors */
     if (init_error() < 0)
@@ -680,16 +957,16 @@ main(void)
         TEST_ERROR;
 
     /* Set up data arrays */
-    if (NULL == (ipoints2_data = (int *)HDcalloc(DIM0 * DIM1, sizeof(int))))
+    if (NULL == (ipoints2_data = (int *)calloc(DIM0 * DIM1, sizeof(int))))
         TEST_ERROR;
-    if (NULL == (ipoints2 = (int **)HDcalloc(DIM0, sizeof(ipoints2_data))))
+    if (NULL == (ipoints2 = (int **)calloc(DIM0, sizeof(ipoints2_data))))
         TEST_ERROR;
     for (i = 0; i < DIM0; i++)
         ipoints2[i] = ipoints2_data + (i * DIM1);
 
-    if (NULL == (icheck2_data = (int *)HDcalloc(DIM0 * DIM1, sizeof(int))))
+    if (NULL == (icheck2_data = (int *)calloc(DIM0 * DIM1, sizeof(int))))
         TEST_ERROR;
-    if (NULL == (icheck2 = (int **)HDcalloc(DIM0, sizeof(icheck2_data))))
+    if (NULL == (icheck2 = (int **)calloc(DIM0, sizeof(icheck2_data))))
         TEST_ERROR;
     for (i = 0; i < DIM0; i++)
         icheck2[i] = icheck2_data + (i * DIM1);
@@ -746,6 +1023,14 @@ main(void)
     if (H5Fclose(file) < 0)
         TEST_ERROR;
 
+    /* Test appending error stacks */
+    if (test_append() < 0)
+        TEST_ERROR;
+
+    /* Test pausing error stacks */
+    if (test_pause() < 0)
+        TEST_ERROR;
+
     /* Close error information */
     if (close_error() < 0)
         TEST_ERROR;
@@ -755,26 +1040,35 @@ main(void)
      * the test file was pre-generated.
      */
     h5_fixname(DATAFILE, H5P_DEFAULT, filename, sizeof filename);
-    if (test_filter_error(filename) < 0)
+    if (!h5_using_default_driver(driver_name) && strcmp(driver_name, "stdio")) {
+        /* If not using the library's default VFD or the stdio VFD, force
+         * the library's default VFD here. The test file was pre-generated
+         * and can cause issues with many VFDs.
+         */
+        if (H5Pset_driver(fapl, H5_DEFAULT_VFD, NULL) < 0)
+            TEST_ERROR;
+    }
+    if (test_filter_error(filename, fapl) < 0)
         TEST_ERROR;
 
-    h5_clean_files(FILENAME, fapl);
+    h5_delete_all_test_files(FILENAME, fapl);
+    H5Pclose(fapl);
 
-    HDfree(ipoints2);
-    HDfree(ipoints2_data);
-    HDfree(icheck2);
-    HDfree(icheck2_data);
+    free(ipoints2);
+    free(ipoints2_data);
+    free(icheck2);
+    free(icheck2_data);
 
-    HDfprintf(stderr, "\nAll error API tests passed.\n");
+    fprintf(stderr, "\nAll error API tests passed.\n");
     return 0;
 
 error:
-    HDfree(ipoints2);
-    HDfree(ipoints2_data);
-    HDfree(icheck2);
-    HDfree(icheck2_data);
+    free(ipoints2);
+    free(ipoints2_data);
+    free(icheck2);
+    free(icheck2_data);
 
-    HDfprintf(stderr, "\n***** ERROR TEST FAILED (real problem)! *****\n");
+    fprintf(stderr, "\n***** ERROR TEST FAILED (real problem)! *****\n");
     return 1;
 }
 #endif /* H5_USE_16_API */
