@@ -23,7 +23,7 @@
 #define VERIFY(condition, string)                                                                            \
     do {                                                                                                     \
         if (!(condition))                                                                                    \
-            FAIL_PUTS_ERROR(string)                                                                          \
+            FAIL_PUTS_ERROR(string);                                                                         \
     } while (0)
 
 /* Values for callback bit field */
@@ -43,19 +43,19 @@
 
 #define USERBLOCK_SIZE 512
 
-const char *FILENAME[] = {"file_image_core_test", NULL};
+static const char *FILENAME[] = {"file_image_core_test", NULL};
 
 /* need a second file name array, as the first file name array contains
  * files we don't want to delete on cleanup.
  */
-const char *FILENAME2[] = {"sec2_get_file_image_test",
-                           "stdio_get_file_image_test",
-                           "core_get_file_image_test",
-                           "family_get_file_image_test",
-                           "multi_get_file_image_test",
-                           "split_get_file_image_test",
-                           "get_file_image_error_rejection_test",
-                           NULL};
+static const char *FILENAME2[] = {"sec2_get_file_image_test",
+                                  "stdio_get_file_image_test",
+                                  "core_get_file_image_test",
+                                  "family_get_file_image_test",
+                                  "multi_get_file_image_test",
+                                  "split_get_file_image_test",
+                                  "get_file_image_error_rejection_test",
+                                  NULL};
 
 typedef struct {
     unsigned char        used_callbacks; /* Bitfield for tracking callbacks */
@@ -74,16 +74,13 @@ typedef struct {
  * Returns:     Success: 0
  *              Failure: 1
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static int
 test_properties(void)
 {
-    hid_t  fapl_1 = -1;
-    hid_t  fapl_2 = -1;
+    hid_t  fapl_1 = H5I_INVALID_HID;
+    hid_t  fapl_2 = H5I_INVALID_HID;
     char  *buffer = 0;
     int    count  = 10;
     void  *temp   = 0;
@@ -102,19 +99,19 @@ test_properties(void)
      * not be the case.
      */
     size = (size_t)count * sizeof(char);
-    if (NULL == (buffer = (char *)HDmalloc(size)))
-        TEST_ERROR
+    if (NULL == (buffer = (char *)malloc(size)))
+        TEST_ERROR;
     for (i = 0; i < count - 1; i++)
         buffer[i] = (char)(65 + i);
     buffer[count - 1] = '\0';
 
     /* Create fapl */
     if ((fapl_1 = H5Pcreate(H5P_FILE_ACCESS)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get file image stuff */
     if (H5Pget_file_image(fapl_1, (void **)&temp, &temp_size) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Check default values */
     VERIFY(temp == NULL, "Default pointer is wrong");
@@ -122,32 +119,32 @@ test_properties(void)
 
     /* Set file image stuff */
     if (H5Pset_file_image(fapl_1, (void *)buffer, size) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get the same */
     if (H5Pget_file_image(fapl_1, (void **)&temp, &temp_size) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Check that sizes are the same, and that the buffers are identical but separate */
     VERIFY(temp != NULL, "temp is null!");
     VERIFY(temp_size == size, "Sizes of buffers don't match");
     VERIFY(temp != buffer, "Retrieved buffer is the same as original");
-    VERIFY(0 == HDmemcmp(temp, buffer, size), "Buffers contain different data");
+    VERIFY(0 == memcmp(temp, buffer, size), "Buffers contain different data");
 
     /* Copy the fapl */
     if ((fapl_2 = H5Pcopy(fapl_1)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get values from the new fapl */
     if (H5Pget_file_image(fapl_2, (void **)&temp2, &temp_size) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Check that sizes are the same, and that the buffers are identical but separate */
     VERIFY(temp_size == size, "Sizes of buffers don't match");
     VERIFY(temp2 != NULL, "Received buffer not set");
     VERIFY(temp2 != buffer, "Retrieved buffer is the same as original");
     VERIFY(temp2 != temp, "Retrieved buffer is the same as previously retrieved buffer");
-    VERIFY(0 == HDmemcmp(temp2, buffer, size), "Buffers contain different data");
+    VERIFY(0 == memcmp(temp2, buffer, size), "Buffers contain different data");
 
     retval = 0;
 
@@ -158,7 +155,7 @@ error:
         retval = 1;
     if (H5Pclose(fapl_2) < 0)
         retval = 1;
-    HDfree(buffer);
+    free(buffer);
     H5free_memory(temp);
     H5free_memory(temp2);
 
@@ -175,9 +172,6 @@ error:
  *
  * Returns:     The result of a standard malloc
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static void *
@@ -187,7 +181,7 @@ malloc_cb(size_t size, H5FD_file_image_op_t op, void *udata)
 
     u->used_callbacks |= MALLOC;
     u->malloc_src = op;
-    return HDmalloc(size);
+    return malloc(size);
 }
 
 /******************************************************************************
@@ -197,9 +191,6 @@ malloc_cb(size_t size, H5FD_file_image_op_t op, void *udata)
  *
  * Returns:     The result of a standard memcpy
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static void *
@@ -209,7 +200,7 @@ memcpy_cb(void *dest, const void *src, size_t size, H5FD_file_image_op_t op, voi
 
     u->used_callbacks |= MEMCPY;
     u->memcpy_src = op;
-    return HDmemcpy(dest, src, size);
+    return memcpy(dest, src, size);
 }
 
 /******************************************************************************
@@ -219,9 +210,6 @@ memcpy_cb(void *dest, const void *src, size_t size, H5FD_file_image_op_t op, voi
  *
  * Returns:     The result of a standard realloc
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static void *
@@ -231,7 +219,7 @@ realloc_cb(void *ptr, size_t size, H5FD_file_image_op_t op, void *udata)
 
     u->used_callbacks |= REALLOC;
     u->realloc_src = op;
-    return HDrealloc(ptr, size);
+    return realloc(ptr, size);
 }
 
 /******************************************************************************
@@ -239,9 +227,6 @@ realloc_cb(void *ptr, size_t size, H5FD_file_image_op_t op, void *udata)
  *
  * Purpose:     This function allows calls to the free callback to be tracked.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static herr_t
@@ -251,7 +236,7 @@ free_cb(void *ptr, H5FD_file_image_op_t op, void *udata)
 
     u->used_callbacks |= FREE;
     u->free_src = op;
-    HDfree(ptr);
+    free(ptr);
     return (SUCCEED);
 }
 
@@ -264,9 +249,6 @@ free_cb(void *ptr, H5FD_file_image_op_t op, void *udata)
  *
  * Returns:     A pointer to the same udata that was passed in.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static void *
@@ -287,9 +269,6 @@ udata_copy_cb(void *udata)
  *              udata_copy callback doesn't copy, only one instance of the udata
  *              is kept alive and such it must be freed explicitly at the end of the tests.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static herr_t
@@ -307,9 +286,6 @@ udata_free_cb(void *udata)
  * Purpose:     Resets the udata to default values. This facilitates storing only
  *              the results of a single operation in the udata.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static void
@@ -324,9 +300,6 @@ reset_udata(udata_t *u)
  *
  * Purpose:     Tests that callbacks are called properly in property list functions.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static int
@@ -349,7 +322,7 @@ test_callbacks(void)
     TESTING("Callback use in property list operations");
 
     /* Allocate and initialize udata */
-    udata = (udata_t *)HDmalloc(sizeof(udata_t));
+    udata = (udata_t *)malloc(sizeof(udata_t));
     VERIFY(udata != NULL, "udata malloc failed");
     reset_udata(udata);
 
@@ -358,7 +331,7 @@ test_callbacks(void)
 
     /* Allocate and initialize file image buffer */
     size       = (size_t)count * sizeof(char);
-    file_image = (char *)HDmalloc(size);
+    file_image = (char *)malloc(size);
     VERIFY(file_image != NULL, "file_image malloc failed");
     for (i = 0; i < count - 1; i++)
         file_image[i] = (char)(65 + i);
@@ -366,12 +339,12 @@ test_callbacks(void)
 
     /* Create fapl */
     if ((fapl_1 = H5Pcreate(H5P_FILE_ACCESS)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get file image stuff */
     callbacks = real_callbacks;
     if (H5Pget_file_image_callbacks(fapl_1, &callbacks) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Check default values */
     VERIFY(callbacks.image_malloc == NULL, "Default malloc callback is wrong");
@@ -385,12 +358,12 @@ test_callbacks(void)
     /* Set file image callbacks */
     callbacks = real_callbacks;
     if (H5Pset_file_image_callbacks(fapl_1, &callbacks) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get file image callbacks */
     callbacks = null_callbacks;
     if (H5Pget_file_image_callbacks(fapl_1, &callbacks) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify values */
     VERIFY(callbacks.image_malloc == &malloc_cb, "malloc callback was not set or retrieved properly");
@@ -408,7 +381,7 @@ test_callbacks(void)
     /* Copy fapl */
     reset_udata(udata);
     if ((fapl_2 = H5Pcopy(fapl_1)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify that the property's copy callback used the correct image callbacks */
     VERIFY(udata->used_callbacks == (UDATA_COPY), "Copying a fapl with no image used incorrect callbacks");
@@ -416,19 +389,19 @@ test_callbacks(void)
     /* Close fapl */
     reset_udata(udata);
     if (H5Pclose(fapl_2) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify that the udata free callback was used */
     VERIFY(udata->used_callbacks == (UDATA_FREE), "Closing a fapl with no image used incorrect callbacks");
 
     /* Copy again */
     if ((fapl_2 = H5Pcopy(fapl_1)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Remove property from fapl */
     reset_udata(udata);
     if (H5Premove(fapl_2, H5F_ACS_FILE_IMAGE_INFO_NAME) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify that the property's delete callback was called using the correct image callbacks */
     VERIFY(udata->used_callbacks == (UDATA_FREE),
@@ -436,12 +409,12 @@ test_callbacks(void)
 
     /* Close it again */
     if (H5Pclose(fapl_2) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get file image */
     reset_udata(udata);
     if (H5Pget_file_image(fapl_1, (void **)&temp_file_image, &temp_size) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify that the correct callbacks were used */
     VERIFY(udata->used_callbacks == 0,
@@ -450,7 +423,7 @@ test_callbacks(void)
     /* Set file image */
     reset_udata(udata);
     if (H5Pset_file_image(fapl_1, (void *)file_image, size) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     VERIFY(udata->used_callbacks == (MALLOC | MEMCPY),
            "Setting a file image (first time) used incorrect callbacks");
@@ -462,7 +435,7 @@ test_callbacks(void)
     /* Copy fapl */
     reset_udata(udata);
     if ((fapl_2 = H5Pcopy(fapl_1)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify that the property's copy callback used the correct image callbacks */
     VERIFY(udata->used_callbacks == (MALLOC | MEMCPY | UDATA_COPY),
@@ -473,7 +446,7 @@ test_callbacks(void)
     /* Close fapl */
     reset_udata(udata);
     if (H5Pclose(fapl_2) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify that the udata free callback was used */
     VERIFY(udata->used_callbacks == (FREE | UDATA_FREE),
@@ -482,12 +455,12 @@ test_callbacks(void)
 
     /* Copy again */
     if ((fapl_2 = H5Pcopy(fapl_1)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Remove property from fapl */
     reset_udata(udata);
     if (H5Premove(fapl_2, H5F_ACS_FILE_IMAGE_INFO_NAME) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify that the property's delete callback was called using the correct image callbacks */
     VERIFY(udata->used_callbacks == (FREE | UDATA_FREE),
@@ -496,12 +469,12 @@ test_callbacks(void)
 
     /* Close it again */
     if (H5Pclose(fapl_2) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get file image */
     reset_udata(udata);
     if (H5Pget_file_image(fapl_1, (void **)&temp_file_image, &temp_size) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify that the correct callbacks were used */
     VERIFY(udata->used_callbacks == (MALLOC | MEMCPY),
@@ -512,7 +485,7 @@ test_callbacks(void)
     /* Set file image */
     reset_udata(udata);
     if (H5Pset_file_image(fapl_1, (void *)file_image, size) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     VERIFY(udata->used_callbacks == (FREE | MALLOC | MEMCPY),
            "Setting a file image (second time) used incorrect callbacks");
@@ -522,17 +495,17 @@ test_callbacks(void)
 
     /* Close stuff */
     if (H5Pclose(fapl_1) < 0)
-        FAIL_STACK_ERROR
-    HDfree(file_image);
-    HDfree(temp_file_image);
-    HDfree(udata);
+        FAIL_STACK_ERROR;
+    free(file_image);
+    free(temp_file_image);
+    free(udata);
 
     PASSED();
     return 0;
 
 error:
-    HDfree(file_image);
-    HDfree(udata);
+    free(file_image);
+    free(udata);
 
     return 1;
 } /* test_callbacks() */
@@ -543,9 +516,6 @@ error:
  * Purpose:     Tests that callbacks are called properly in the core VFD and
  *              that the initial file image works properly.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static int
@@ -582,17 +552,17 @@ test_core(void)
     VERIFY(tmp != NULL, "h5_fixname failed");
 
     /* Append ".copy" to the filename from the source directory */
-    VERIFY(HDstrlen(filename) < (1023 - 5), "file name too long.");
-    HDstrncpy(copied_filename, filename, (size_t)1023);
+    VERIFY(strlen(filename) < (1023 - 5), "file name too long.");
+    strncpy(copied_filename, filename, (size_t)1023);
     copied_filename[1023] = '\0';
-    HDstrcat(copied_filename, ".copy");
+    strcat(copied_filename, ".copy");
 
     /* Make a copy of the data file from svn. */
     ret = h5_make_local_copy(filename, copied_filename);
     VERIFY(ret >= 0, "h5_make_local_copy");
 
     /* Allocate and initialize udata */
-    udata = (udata_t *)HDmalloc(sizeof(udata_t));
+    udata = (udata_t *)malloc(sizeof(udata_t));
     VERIFY(udata != NULL, "udata malloc failed");
 
     /* copy the address of the udata into the callbacks structure */
@@ -658,10 +628,11 @@ test_core(void)
     /* Create file image buffer */
     fd = HDopen(copied_filename, O_RDONLY);
     VERIFY(fd > 0, "open failed");
+    memset(&sb, 0, sizeof(h5_stat_t));
     ret = HDfstat(fd, &sb);
     VERIFY(ret == 0, "fstat failed");
     size       = (size_t)sb.st_size;
-    file_image = (unsigned char *)HDmalloc(size);
+    file_image = (unsigned char *)malloc(size);
     if (HDread(fd, file_image, size) < 0)
         FAIL_PUTS_ERROR("unable to read from file descriptor");
     ret = HDclose(fd);
@@ -669,18 +640,19 @@ test_core(void)
 
     /* Set file image in plist */
     if (H5Pset_file_image(fapl, file_image, size) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Test open with file image */
     if ((file = H5Fopen("dne.h5", H5F_ACC_RDONLY, fapl)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Fclose(file) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Release resources */
-    h5_clean_files(FILENAME, fapl);
-    HDfree(udata);
-    HDfree(file_image);
+    h5_delete_all_test_files(FILENAME, fapl);
+    H5Pclose(fapl);
+    free(udata);
+    free(file_image);
     HDremove(copied_filename);
 
     PASSED();
@@ -696,13 +668,6 @@ error:
  *
  * Purpose:     Test the H5Fget_file_image() call.
  *
- * Programmer:  John Mainzer
- *              Tuesday, November 15, 2011
- *
- * Modifications:
- *      Vailin Choi; July 2013
- *      Add the creation of user block to the file as indicated by the parameter "user".
- *
  ******************************************************************************
  */
 /* Disable warning for "format not a string literal" here -QAK */
@@ -711,47 +676,49 @@ error:
  *      'member_file_name' in the code below, but early (4.4.7, at least) gcc only
  *      allows diagnostic pragmas to be toggled outside of functions.
  */
-H5_GCC_DIAG_OFF("format-nonliteral")
+H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
 static int
-test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl, hbool_t user)
+test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl, bool user)
 {
     char      file_name[1024] = "\0";
     void     *insertion_ptr   = NULL;
     void     *image_ptr       = NULL;
     void     *file_image_ptr  = NULL;
-    hbool_t   is_family_file  = FALSE;
-    hbool_t   identical;
+    bool      is_family_file  = false;
+    bool      identical;
     int       data[100];
     int       i;
     int       fd = -1;
     int       result;
-    hid_t     driver       = -1;
-    hid_t     file_id      = -1;
-    hid_t     dset_id      = -1;
-    hid_t     space_id     = -1;
-    hid_t     core_fapl_id = -1;
-    hid_t     core_file_id = -1;
+    hid_t     driver       = H5I_INVALID_HID;
+    hid_t     file_id      = H5I_INVALID_HID;
+    hid_t     dset_id      = H5I_INVALID_HID;
+    hid_t     space_id     = H5I_INVALID_HID;
+    hid_t     core_fapl_id = H5I_INVALID_HID;
+    hid_t     core_file_id = H5I_INVALID_HID;
     herr_t    err;
     hsize_t   dims[2];
     ssize_t   bytes_read;
     ssize_t   image_size;
     ssize_t   file_size;
     h5_stat_t stat_buf;
-    hid_t     fcpl = -1;
+    hid_t     fcpl = H5I_INVALID_HID;
     herr_t    ret;
 
     TESTING(test_banner);
 
+    memset(&stat_buf, 0, sizeof(h5_stat_t));
+
     /* set flag if we are dealing with a family file */
     driver = H5Pget_driver(fapl);
     VERIFY(driver >= 0, "H5Pget_driver(fapl) failed");
 
     if (driver == H5FD_FAMILY)
-        is_family_file = TRUE;
+        is_family_file = true;
 
     /* setup the file name */
     h5_fixname(FILENAME2[file_name_num], fapl, file_name, sizeof(file_name));
-    VERIFY(HDstrlen(file_name) > 0, "h5_fixname failed");
+    VERIFY(strlen(file_name) > 0, "h5_fixname failed");
 
     fcpl = H5Pcreate(H5P_FILE_CREATE);
     VERIFY(fcpl >= 0, "H5Pcreate");
@@ -789,8 +756,8 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
     VERIFY(image_size > 0, "H5Fget_file_image(1) failed.");
 
     /* allocate a buffer of the appropriate size */
-    image_ptr = HDmalloc((size_t)image_size);
-    VERIFY(image_ptr != NULL, "HDmalloc(1) failed.");
+    image_ptr = malloc((size_t)image_size);
+    VERIFY(image_ptr != NULL, "malloc(1) failed.");
 
     /* load the image of the file into the buffer */
     bytes_read = H5Fget_file_image(file_id, image_ptr, (size_t)image_size);
@@ -820,7 +787,7 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
         file_size = 0;
 
         do {
-            HDsnprintf(member_file_name, (size_t)1024, file_name, i);
+            snprintf(member_file_name, (size_t)1024, file_name, i);
 
             /* get the size of the member file */
             result = HDstat(member_file_name, &stat_buf);
@@ -839,8 +806,8 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
         VERIFY(file_size >= image_size, "file size != image size.");
 
         /* allocate a buffer for the test file image */
-        file_image_ptr = HDmalloc((size_t)file_size);
-        VERIFY(file_image_ptr != NULL, "HDmalloc(2f) failed.");
+        file_image_ptr = malloc((size_t)file_size);
+        VERIFY(file_image_ptr != NULL, "malloc(2f) failed.");
 
         size_remaining = image_size;
         insertion_ptr  = file_image_ptr;
@@ -848,7 +815,7 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
 
         while (size_remaining > 0) {
             /* construct the member file name */
-            HDsnprintf(member_file_name, 1024, file_name, i);
+            snprintf(member_file_name, 1024, file_name, i);
 
             /* open the test file using standard I/O calls */
             fd = HDopen(member_file_name, O_RDONLY);
@@ -897,8 +864,8 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
         VERIFY(file_size == image_size, "file size != image size.");
 
         /* allocate a buffer for the test file image */
-        file_image_ptr = HDmalloc((size_t)file_size);
-        VERIFY(file_image_ptr != NULL, "HDmalloc(2) failed.");
+        file_image_ptr = malloc((size_t)file_size);
+        VERIFY(file_image_ptr != NULL, "malloc(2) failed.");
 
         /* open the test file using standard I/O calls */
         fd = HDopen(file_name, O_RDONLY);
@@ -908,7 +875,7 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
             HDoff_t off;
 
             /* Position at userblock */
-            off = HDlseek(fd, (off_t)USERBLOCK_SIZE, SEEK_SET);
+            off = HDlseek(fd, USERBLOCK_SIZE, SEEK_SET);
             VERIFY(off >= 0, "HDlseek() failed.");
         }
 
@@ -922,11 +889,11 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
     }
 
     /* verify that the file and the image contain the same data */
-    identical = TRUE;
+    identical = true;
     i         = 0;
     while ((i < (int)image_size) && identical) {
         if (((char *)image_ptr)[i] != ((char *)file_image_ptr)[i])
-            identical = FALSE;
+            identical = false;
         i++;
     }
     VERIFY(identical, "file and image differ.");
@@ -938,7 +905,7 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
     VERIFY(core_fapl_id >= 0, "H5Pcreate() failed");
 
     /* setup core_fapl_id to use the core file driver */
-    err = H5Pset_fapl_core(core_fapl_id, (size_t)(64 * 1024), FALSE);
+    err = H5Pset_fapl_core(core_fapl_id, (size_t)(64 * 1024), false);
     VERIFY(err == SUCCEED, "H5Pset_fapl_core() failed.");
 
     /* Set file image in core fapl */
@@ -958,15 +925,16 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
     VERIFY(err == SUCCEED, "H5Pclose(core_fapl_id) failed.");
 
     /* tidy up */
-    h5_clean_files(FILENAME2, fapl);
+    h5_delete_all_test_files(FILENAME2, fapl);
+    H5Pclose(fapl);
 
     /* discard the image buffer if it exists */
     if (image_ptr != NULL)
-        HDfree(image_ptr);
+        free(image_ptr);
 
     /* discard the image buffer if it exists */
     if (file_image_ptr != NULL)
-        HDfree(file_image_ptr);
+        free(file_image_ptr);
 
     PASSED();
 
@@ -975,16 +943,13 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
 error:
     return 1;
 } /* end test_get_file_image() */
-H5_GCC_DIAG_ON("format-nonliteral")
+H5_GCC_CLANG_DIAG_ON("format-nonliteral")
 
 /******************************************************************************
  * Function:    test_get_file_image_error_rejection
  *
  * Purpose:     Verify that H5Fget_file_image() rejects invalid input.
  *
- * Programmer:  John Mainzer
- *              Tuesday, November 22, 2011
- *
  ******************************************************************************
  */
 
@@ -998,10 +963,10 @@ test_get_file_image_error_rejection(void)
     void       *image_ptr       = NULL;
     int         data[100];
     int         i;
-    hid_t       fapl_id  = -1;
-    hid_t       file_id  = -1;
-    hid_t       dset_id  = -1;
-    hid_t       space_id = -1;
+    hid_t       fapl_id  = H5I_INVALID_HID;
+    hid_t       file_id  = H5I_INVALID_HID;
+    hid_t       dset_id  = H5I_INVALID_HID;
+    hid_t       space_id = H5I_INVALID_HID;
     herr_t      err;
     hsize_t     dims[2];
     ssize_t     bytes_read;
@@ -1034,7 +999,7 @@ test_get_file_image_error_rejection(void)
 
     /* setup the file name */
     h5_fixname(FILENAME2[6], fapl_id, file_name, sizeof(file_name));
-    VERIFY(HDstrlen(file_name) > 0, "h5_fixname failed");
+    VERIFY(strlen(file_name) > 0, "h5_fixname failed");
 
     /* create the file */
     file_id = H5Fcreate(file_name, 0, H5P_DEFAULT, fapl_id);
@@ -1065,15 +1030,15 @@ test_get_file_image_error_rejection(void)
     VERIFY(image_size > 0, "H5Fget_file_image(1 -- test 1) failed.");
 
     /* allocate a buffer of the appropriate size */
-    image_ptr = HDmalloc((size_t)image_size);
-    VERIFY(image_ptr != NULL, "HDmalloc(1) failed.");
+    image_ptr = malloc((size_t)image_size);
+    VERIFY(image_ptr != NULL, "malloc(1) failed.");
 
     /* load the image of the file into the buffer */
     H5E_BEGIN_TRY
     {
         bytes_read = H5Fget_file_image(file_id, image_ptr, (size_t)(image_size - 1));
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(bytes_read < 0, "H5Fget_file_image(2 -- test 1) succeeded.");
 
     /* Call H5Fget_file_image() with good buffer and buffer size,
@@ -1083,7 +1048,7 @@ test_get_file_image_error_rejection(void)
     {
         bytes_read = H5Fget_file_image((hid_t)0, image_ptr, (size_t)(image_size));
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(bytes_read < 0, "H5Fget_file_image(3 -- test 1) succeeded.");
 
     /* Call H5Fget_file_image() with good buffer and buffer size,
@@ -1093,7 +1058,7 @@ test_get_file_image_error_rejection(void)
     {
         bytes_read = H5Fget_file_image(dset_id, image_ptr, (size_t)(image_size));
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(bytes_read < 0, "H5Fget_file_image(4 -- test 1) succeeded.");
 
     /* Close dset and space */
@@ -1107,11 +1072,12 @@ test_get_file_image_error_rejection(void)
     VERIFY(err == SUCCEED, "H5Fclose(file_id) failed.");
 
     /* tidy up */
-    h5_clean_files(FILENAME2, fapl_id);
+    h5_delete_all_test_files(FILENAME2, fapl_id);
+    H5Pclose(fapl_id);
 
     /* discard the image buffer if it exists */
     if (image_ptr != NULL)
-        HDfree(image_ptr);
+        free(image_ptr);
 
     /************************** Test #2 **********************************/
     /* set up a multi file driver test file, and try to get its image
@@ -1161,12 +1127,12 @@ test_get_file_image_error_rejection(void)
     VERIFY(fapl_id >= 0, "H5Pcreate(2) failed");
 
     /* setup the fapl for the multi file driver */
-    err = H5Pset_fapl_multi(fapl_id, memb_map, memb_fapl, memb_name, memb_addr, FALSE);
+    err = H5Pset_fapl_multi(fapl_id, memb_map, memb_fapl, memb_name, memb_addr, false);
     VERIFY(err >= 0, "H5Pset_fapl_multi failed");
 
     /* setup the file name */
     h5_fixname(FILENAME2[4], fapl_id, file_name, sizeof(file_name));
-    VERIFY(HDstrlen(file_name) > 0, "h5_fixname failed");
+    VERIFY(strlen(file_name) > 0, "h5_fixname failed");
 
     /* create the file */
     file_id = H5Fcreate(file_name, 0, H5P_DEFAULT, fapl_id);
@@ -1197,7 +1163,7 @@ test_get_file_image_error_rejection(void)
     {
         image_size = H5Fget_file_image(file_id, NULL, (size_t)0);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(image_size == -1, "H5Fget_file_image(5) succeeded.");
 
     /* Close dset and space */
@@ -1211,7 +1177,8 @@ test_get_file_image_error_rejection(void)
     VERIFY(err == SUCCEED, "H5Fclose(2) failed.");
 
     /* tidy up */
-    h5_clean_files(FILENAME2, fapl_id);
+    h5_delete_all_test_files(FILENAME2, fapl_id);
+    H5Pclose(fapl_id);
 
     /************************** Test #3 **********************************/
     /* set up a split file driver test file, and try to get its image
@@ -1228,7 +1195,7 @@ test_get_file_image_error_rejection(void)
 
     /* setup the file name */
     h5_fixname(FILENAME2[5], fapl_id, file_name, sizeof(file_name));
-    VERIFY(HDstrlen(file_name) > 0, "h5_fixname failed");
+    VERIFY(strlen(file_name) > 0, "h5_fixname failed");
 
     /* create the file */
     file_id = H5Fcreate(file_name, 0, H5P_DEFAULT, fapl_id);
@@ -1259,7 +1226,7 @@ test_get_file_image_error_rejection(void)
     {
         image_size = H5Fget_file_image(file_id, NULL, (size_t)0);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(image_size == -1, "H5Fget_file_image(6) succeeded.");
 
     /* Close dset and space */
@@ -1273,7 +1240,8 @@ test_get_file_image_error_rejection(void)
     VERIFY(err == SUCCEED, "H5Fclose(2) failed.");
 
     /* tidy up */
-    h5_clean_files(FILENAME2, fapl_id);
+    h5_delete_all_test_files(FILENAME2, fapl_id);
+    H5Pclose(fapl_id);
 
     /************************** Test #4 **********************************/
     /* set up a family file driver test file, and try to get its image
@@ -1288,7 +1256,7 @@ test_get_file_image_error_rejection(void)
     VERIFY(err >= 0, "H5Pset_fapl_family failed");
 
     h5_fixname(FILENAME2[3], fapl_id, file_name, sizeof(file_name));
-    VERIFY(HDstrlen(file_name) > 0, "h5_fixname failed");
+    VERIFY(strlen(file_name) > 0, "h5_fixname failed");
 
     /* create the file */
     file_id = H5Fcreate(file_name, 0, H5P_DEFAULT, fapl_id);
@@ -1319,7 +1287,7 @@ test_get_file_image_error_rejection(void)
     {
         image_size = H5Fget_file_image(file_id, NULL, (size_t)0);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(image_size == -1, "H5Fget_file_image(7) succeeded.");
 
     /* Close dset and space */
@@ -1333,7 +1301,8 @@ test_get_file_image_error_rejection(void)
     VERIFY(err == SUCCEED, "H5Fclose(2) failed.");
 
     /* tidy up */
-    h5_clean_files(FILENAME2, fapl_id);
+    h5_delete_all_test_files(FILENAME2, fapl_id);
+    H5Pclose(fapl_id);
 
     PASSED();
 
@@ -1343,27 +1312,29 @@ error:
     return 1;
 } /* test_get_file_image_error_rejection() */
 
-/*
- * Modifications:
- *     Add testing for file image with or without user block in the file.
- */
 int
 main(void)
 {
     int      errors = 0;
     hid_t    fapl;
+    bool     driver_is_default_compatible;
     unsigned user;
 
-    h5_reset();
+    h5_test_init();
 
-    HDprintf("Testing File Image Functionality.\n");
+    printf("Testing File Image Functionality.\n");
 
     errors += test_properties();
     errors += test_callbacks();
-    errors += test_core();
+
+    if (h5_driver_is_default_vfd_compatible(H5P_DEFAULT, &driver_is_default_compatible) < 0)
+        errors++;
+    else if (driver_is_default_compatible) {
+        errors += test_core();
+    }
 
     /* Perform tests with/without user block */
-    for (user = FALSE; user <= TRUE; user++) {
+    for (user = false; user <= true; user++) {
 
         /* test H5Fget_file_image() with sec2 driver */
         fapl = H5Pcreate(H5P_FILE_ACCESS);
@@ -1381,7 +1352,7 @@ main(void)
 
         /* test H5Fget_file_image() with core driver */
         fapl = H5Pcreate(H5P_FILE_ACCESS);
-        if (H5Pset_fapl_core(fapl, (size_t)(64 * 1024), TRUE) < 0)
+        if (H5Pset_fapl_core(fapl, (size_t)(64 * 1024), true) < 0)
             errors++;
         else
             errors += test_get_file_image("H5Fget_file_image() with core driver", 2, fapl, user);
@@ -1410,14 +1381,14 @@ main(void)
 
     errors += test_get_file_image_error_rejection();
 
-    /* Restore the default error handler (set in h5_reset()) */
+    /* Restore the default error handler (set in h5_test_init()) */
     h5_restore_err();
 
     if (errors) {
-        HDprintf("***** %d File Image TEST%s FAILED! *****\n", errors, errors > 1 ? "S" : "");
+        printf("***** %d File Image TEST%s FAILED! *****\n", errors, errors > 1 ? "S" : "");
         return 1;
     }
 
-    HDprintf("All File Image tests passed.\n");
+    printf("All File Image tests passed.\n");
     return 0;
 }
