@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer: Mike McGreevy
- *             June 30, 2010
- *
  * Purpose: This test file contains routines used to test flushing and
  *          refreshing individual objects' metadata from the cache.
  *
@@ -66,26 +63,26 @@
    For errors occurring in the spawned process (from the test script), use
    the PROCESS_ERROR macro, which will send a signal to the main process so the
    main process can propagate errors correctly. */
-FILE *errorfile;
+static FILE *errorfile;
 #define ERRFILE "flushrefresh_ERROR"
 #define PROCESS_ERROR                                                                                        \
-    {                                                                                                        \
-        errorfile = HDfopen(ERRFILE, "w+");                                                                  \
-        HDfprintf(errorfile, "Error occurred in flushrefresh.\n");                                           \
-        HDfflush(errorfile);                                                                                 \
-        HDfclose(errorfile);                                                                                 \
+    do {                                                                                                     \
+        errorfile = fopen(ERRFILE, "w+");                                                                    \
+        fprintf(errorfile, "Error occurred in flushrefresh.\n");                                             \
+        fflush(errorfile);                                                                                   \
+        fclose(errorfile);                                                                                   \
         TEST_ERROR;                                                                                          \
-    }
+    } while (0)
 
 #define CLEANUP_FILES                                                                                        \
-    {                                                                                                        \
+    do {                                                                                                     \
         HDremove(ERRFILE);                                                                                   \
         HDremove(FILENAME);                                                                                  \
         HDremove(SIGNAL_TO_SCRIPT);                                                                          \
         HDremove(SIGNAL_BETWEEN_PROCESSES_1);                                                                \
         HDremove(SIGNAL_BETWEEN_PROCESSES_2);                                                                \
         HDremove(SIGNAL_FROM_SCRIPT);                                                                        \
-    }
+    } while (0)
 
 /* ===================== */
 /* Function Declarations */
@@ -130,16 +127,13 @@ herr_t end_verification(void);
  *
  * Return:      EXIT_SUCCESS/EXIT_FAILURE
  *
- * Programmer:  Mike McGreevy
- *              July 1, 2010
- *
  *-------------------------------------------------------------------------
  */
 int
 main(int argc, char *argv[])
 {
     /* Variables */
-    const char *envval = NULL;
+    const char *driver_name = NULL;
 
     /* Initialize library */
     if (H5open() < 0)
@@ -152,17 +146,16 @@ main(int argc, char *argv[])
          * anything. */
 
         /* Determine driver being used */
-        envval = HDgetenv("HDF5_DRIVER");
+        driver_name = h5_get_test_driver_name();
 
-        if (envval == NULL || H5FD__supports_swmr_test(envval)) {
+        if (driver_name == NULL || H5FD__supports_swmr_test(driver_name)) {
             if (test_flush() != SUCCEED)
                 TEST_ERROR;
             if (test_refresh() != SUCCEED)
                 TEST_ERROR;
         } /* end if */
         else {
-            HDfprintf(stdout,
-                      "Skipping all flush/refresh tests (only run with SWMR-enabled file drivers).\n");
+            fprintf(stdout, "Skipping all flush/refresh tests (only run with SWMR-enabled file drivers).\n");
 
             /* Test script is expecting some signals, so send them out to end it. */
             if (end_verification() < 0)
@@ -183,8 +176,8 @@ main(int argc, char *argv[])
     }
     else {
         /* Illegal number of arguments supplied. Error. */
-        HDfprintf(stderr, "Error. %d is an Invalid number of arguments to main().\n", argc);
-        PROCESS_ERROR
+        fprintf(stderr, "Error. %d is an Invalid number of arguments to main().\n", argc);
+        PROCESS_ERROR;
     } /* end if */
 
     return EXIT_SUCCESS;
@@ -202,9 +195,6 @@ error:
  *
  * Return:      0 on Success, 1 on Failure
  *
- * Programmer:  Mike McGreevy
- *              July 1, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -267,7 +257,7 @@ test_flush(void)
     hsize_t dims[2] = {3, 5};
 
     /* Testing Message */
-    HDfprintf(stdout, "Testing individual object flush behavior:\n");
+    fprintf(stdout, "Testing individual object flush behavior:\n");
 
     /* Cleanup any old error or signal files */
     CLEANUP_FILES;
@@ -670,9 +660,6 @@ error:
  *
  * Return:      0 on Success, 1 on Failure
  *
- * Programmer:  Mike McGreevy
- *              August 17, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -739,7 +726,7 @@ test_refresh(void)
     int     fillval  = 2;
 
     /* Testing Message */
-    HDfprintf(stdout, "Testing individual object refresh behavior:\n");
+    fprintf(stdout, "Testing individual object refresh behavior:\n");
 
     /* Cleanup any old error or signal files */
     CLEANUP_FILES;
@@ -1024,9 +1011,6 @@ error:
  *
  * Return:      0 on Success, 1 on Failure
  *
- * Programmer:  Mike McGreevy
- *              July 16, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1064,45 +1048,41 @@ error:
  *
  * Return:      0 on Success, 1 on Failure
  *
- * Programmer:  Mike McGreevy
- *              July 16, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
 flush_verification(const char *obj_pathname, const char *expected)
 {
     /* Variables */
-    hid_t      oid = -1, fid = -1;
-    herr_t     status = 0;
-    H5O_info_t oinfo;
+    hid_t       oid = H5I_INVALID_HID, fid = H5I_INVALID_HID;
+    herr_t      status = 0;
+    H5O_info2_t oinfo;
 
     /* Try to open the testfile and then obj_pathname within the file */
     H5E_BEGIN_TRY
     {
         fid    = H5Fopen(FILENAME, H5F_ACC_SWMR_READ, H5P_DEFAULT);
         oid    = H5Oopen(fid, obj_pathname, H5P_DEFAULT);
-        status = H5Oget_info2(oid, &oinfo, H5O_INFO_BASIC);
+        status = H5Oget_info3(oid, &oinfo, H5O_INFO_BASIC);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     /* Compare to expected result */
-    if (HDstrcmp(expected, FLUSHED) == 0) {
+    if (strcmp(expected, FLUSHED) == 0) {
         if ((oid < 0) || (status < 0)) {
-            HDfprintf(stderr, "Error! %s should be on disk, but was NOT!\n", obj_pathname);
+            fprintf(stderr, "Error! %s should be on disk, but was NOT!\n", obj_pathname);
             PROCESS_ERROR;
         } /* end if */
     }
-    else if (HDstrcmp(expected, NOT_FLUSHED) == 0) {
+    else if (strcmp(expected, NOT_FLUSHED) == 0) {
         if ((oid > 0) || (status > 0)) {
-            HDfprintf(stderr, "Error! %s not expected to be flushed, but it was found on disk!\n",
-                      obj_pathname);
+            fprintf(stderr, "Error! %s not expected to be flushed, but it was found on disk!\n",
+                    obj_pathname);
             PROCESS_ERROR;
         } /* end if */
     }
     else {
-        HDfprintf(stderr, "Error! Bad verification parameters. %s is an invalid expected outcome.\n",
-                  expected);
+        fprintf(stderr, "Error! Bad verification parameters. %s is an invalid expected outcome.\n", expected);
         PROCESS_ERROR;
     } /* end if */
 
@@ -1112,7 +1092,7 @@ flush_verification(const char *obj_pathname, const char *expected)
         H5Oclose(oid);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return SUCCEED;
 
@@ -1129,9 +1109,6 @@ error:
  *
  * Return:      0 on Success, 1 on Failure
  *
- * Programmer:  Mike McGreevy
- *              July 16, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1169,9 +1146,6 @@ error:
  *
  * Return:      0 on Success, 1 on Failure
  *
- * Programmer:  Mike McGreevy
- *              July 16, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1212,20 +1186,20 @@ error:
  *
  * Return:      0 on Success, 1 on Failure
  *
- * Programmer:  Mike McGreevy
- *              July 16, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
 refresh_verification(const char *obj_pathname)
 {
     /* Variables */
-    hid_t      oid, fid, status = 0;
-    H5O_info_t flushed_oinfo;
-    H5O_info_t refreshed_oinfo;
-    int        tries = 800, sleep_tries = 400;
-    hbool_t    ok = FALSE;
+    hid_t             oid, fid, status = 0;
+    H5O_info2_t       flushed_oinfo;
+    H5O_info2_t       refreshed_oinfo;
+    H5O_native_info_t flushed_ninfo;
+    H5O_native_info_t refreshed_ninfo;
+    int               tries = 800, sleep_tries = 400;
+    int               token_cmp;
+    bool              ok = false;
 
     HDremove(SIGNAL_BETWEEN_PROCESSES_2);
 
@@ -1236,7 +1210,9 @@ refresh_verification(const char *obj_pathname)
         PROCESS_ERROR;
 
     /* Get Object info */
-    if ((status = H5Oget_info2(oid, &flushed_oinfo, H5O_INFO_BASIC | H5O_INFO_NUM_ATTRS | H5O_INFO_HDR)) < 0)
+    if ((status = H5Oget_info3(oid, &flushed_oinfo, H5O_INFO_BASIC | H5O_INFO_NUM_ATTRS)) < 0)
+        PROCESS_ERROR;
+    if ((status = H5Oget_native_info(oid, &flushed_ninfo, H5O_NATIVE_INFO_HDR)) < 0)
         PROCESS_ERROR;
 
     /* Make sure there are no attributes on the object. This is just a sanity
@@ -1257,27 +1233,30 @@ refresh_verification(const char *obj_pathname)
     /* Get object info again. This will NOT reflect what's on disk, only what's
        in the cache. Thus, all values will be unchanged from above, despite
        newer information being on disk. */
-    if ((status = H5Oget_info2(oid, &refreshed_oinfo, H5O_INFO_BASIC | H5O_INFO_NUM_ATTRS | H5O_INFO_HDR)) <
-        0)
+    if ((status = H5Oget_info3(oid, &refreshed_oinfo, H5O_INFO_BASIC | H5O_INFO_NUM_ATTRS)) < 0)
+        PROCESS_ERROR;
+    if ((status = H5Oget_native_info(oid, &refreshed_ninfo, H5O_NATIVE_INFO_HDR)) < 0)
         PROCESS_ERROR;
 
     /* Verify that before doing a refresh, getting the object info returns stale
        information. (i.e., unchanged from above, despite new info on disk). */
-    if (flushed_oinfo.addr != refreshed_oinfo.addr)
+    if (H5Otoken_cmp(oid, &flushed_oinfo.token, &refreshed_oinfo.token, &token_cmp) < 0)
+        PROCESS_ERROR;
+    if (token_cmp)
         PROCESS_ERROR;
     if (flushed_oinfo.type != refreshed_oinfo.type)
         PROCESS_ERROR;
-    if (flushed_oinfo.hdr.version != refreshed_oinfo.hdr.version)
-        PROCESS_ERROR;
-    if (flushed_oinfo.hdr.flags != refreshed_oinfo.hdr.flags)
-        PROCESS_ERROR;
     if (flushed_oinfo.num_attrs != refreshed_oinfo.num_attrs)
         PROCESS_ERROR;
-    if (flushed_oinfo.hdr.nmesgs != refreshed_oinfo.hdr.nmesgs)
+    if (flushed_ninfo.hdr.version != refreshed_ninfo.hdr.version)
         PROCESS_ERROR;
-    if (flushed_oinfo.hdr.nchunks != refreshed_oinfo.hdr.nchunks)
+    if (flushed_ninfo.hdr.flags != refreshed_ninfo.hdr.flags)
         PROCESS_ERROR;
-    if (flushed_oinfo.hdr.space.total != refreshed_oinfo.hdr.space.total)
+    if (flushed_ninfo.hdr.nmesgs != refreshed_ninfo.hdr.nmesgs)
+        PROCESS_ERROR;
+    if (flushed_ninfo.hdr.nchunks != refreshed_ninfo.hdr.nchunks)
+        PROCESS_ERROR;
+    if (flushed_ninfo.hdr.space.total != refreshed_ninfo.hdr.space.total)
         PROCESS_ERROR;
 
     /* Refresh object */
@@ -1286,43 +1265,46 @@ refresh_verification(const char *obj_pathname)
      * test cases is easy). */
     do {
 
-        if ((HDstrcmp(obj_pathname, D1) == 0) || (HDstrcmp(obj_pathname, D2) == 0)) {
+        if ((strcmp(obj_pathname, D1) == 0) || (strcmp(obj_pathname, D2) == 0)) {
             if (H5Drefresh(oid) < 0)
                 PROCESS_ERROR;
         } /* end if */
-        else if ((HDstrcmp(obj_pathname, G1) == 0) || (HDstrcmp(obj_pathname, G2) == 0)) {
+        else if ((strcmp(obj_pathname, G1) == 0) || (strcmp(obj_pathname, G2) == 0)) {
             if (H5Grefresh(oid) < 0)
                 PROCESS_ERROR;
         } /* end if */
-        else if ((HDstrcmp(obj_pathname, T1) == 0) || (HDstrcmp(obj_pathname, T2) == 0)) {
+        else if ((strcmp(obj_pathname, T1) == 0) || (strcmp(obj_pathname, T2) == 0)) {
             if (H5Trefresh(oid) < 0)
                 PROCESS_ERROR;
         } /* end if */
-        else if ((HDstrcmp(obj_pathname, D3) == 0) || (HDstrcmp(obj_pathname, G3) == 0) ||
-                 (HDstrcmp(obj_pathname, T3) == 0)) {
+        else if ((strcmp(obj_pathname, D3) == 0) || (strcmp(obj_pathname, G3) == 0) ||
+                 (strcmp(obj_pathname, T3) == 0)) {
             if (H5Orefresh(oid) < 0)
                 PROCESS_ERROR;
         } /* end if */
         else {
-            HDfprintf(stdout, "Error. %s is an unrecognized object.\n", obj_pathname);
+            fprintf(stdout, "Error. %s is an unrecognized object.\n", obj_pathname);
             PROCESS_ERROR;
         } /* end else */
 
         /* Get object info. This should now accurately reflect the refreshed object on disk. */
-        if ((status =
-                 H5Oget_info2(oid, &refreshed_oinfo, H5O_INFO_BASIC | H5O_INFO_NUM_ATTRS | H5O_INFO_HDR)) < 0)
+        if ((status = H5Oget_info3(oid, &refreshed_oinfo, H5O_INFO_BASIC | H5O_INFO_NUM_ATTRS)) < 0)
+            PROCESS_ERROR;
+        if ((status = H5Oget_native_info(oid, &refreshed_ninfo, H5O_NATIVE_INFO_HDR)) < 0)
+            PROCESS_ERROR;
+        if (H5Otoken_cmp(oid, &flushed_oinfo.token, &refreshed_oinfo.token, &token_cmp) < 0)
             PROCESS_ERROR;
 
         /* Confirm following (first 4) attributes are the same: */
         /* Confirm following (last 4) attributes are different */
-        if ((flushed_oinfo.addr == refreshed_oinfo.addr) && (flushed_oinfo.type == refreshed_oinfo.type) &&
-            (flushed_oinfo.hdr.version == refreshed_oinfo.hdr.version) &&
-            (flushed_oinfo.hdr.flags == refreshed_oinfo.hdr.flags) &&
+        if ((!token_cmp) && (flushed_oinfo.type == refreshed_oinfo.type) &&
             (flushed_oinfo.num_attrs != refreshed_oinfo.num_attrs) &&
-            (flushed_oinfo.hdr.nmesgs != refreshed_oinfo.hdr.nmesgs) &&
-            (flushed_oinfo.hdr.nchunks != refreshed_oinfo.hdr.nchunks) &&
-            (flushed_oinfo.hdr.space.total != refreshed_oinfo.hdr.space.total)) {
-            ok = TRUE;
+            (flushed_ninfo.hdr.version == refreshed_ninfo.hdr.version) &&
+            (flushed_ninfo.hdr.flags == refreshed_ninfo.hdr.flags) &&
+            (flushed_ninfo.hdr.nmesgs != refreshed_ninfo.hdr.nmesgs) &&
+            (flushed_ninfo.hdr.nchunks != refreshed_ninfo.hdr.nchunks) &&
+            (flushed_ninfo.hdr.space.total != refreshed_ninfo.hdr.space.total)) {
+            ok = true;
             break;
         }
 
@@ -1332,12 +1314,12 @@ refresh_verification(const char *obj_pathname)
     } while (--tries);
 
     if (!ok) {
-        HDprintf("FLUSHED: num_attrs=%d, nmesgs=%d, nchunks=%d, total=%d\n", (int)flushed_oinfo.num_attrs,
-                 (int)flushed_oinfo.hdr.nmesgs, (int)flushed_oinfo.hdr.nchunks,
-                 (int)flushed_oinfo.hdr.space.total);
-        HDprintf("REFRESHED: num_attrs=%d, nmesgs=%d, nchunks=%d, total=%d\n", (int)refreshed_oinfo.num_attrs,
-                 (int)refreshed_oinfo.hdr.nmesgs, (int)refreshed_oinfo.hdr.nchunks,
-                 (int)refreshed_oinfo.hdr.space.total);
+        printf("FLUSHED: num_attrs=%d, nmesgs=%d, nchunks=%d, total=%d\n", (int)flushed_oinfo.num_attrs,
+               (int)flushed_ninfo.hdr.nmesgs, (int)flushed_ninfo.hdr.nchunks,
+               (int)flushed_ninfo.hdr.space.total);
+        printf("REFRESHED: num_attrs=%d, nmesgs=%d, nchunks=%d, total=%d\n", (int)refreshed_oinfo.num_attrs,
+               (int)refreshed_ninfo.hdr.nmesgs, (int)refreshed_ninfo.hdr.nchunks,
+               (int)refreshed_ninfo.hdr.space.total);
         PROCESS_ERROR;
     }
 
@@ -1366,9 +1348,6 @@ error:
  *
  * Return:      0 on Success, 1 on Failure
  *
- * Programmer:  Mike McGreevy
- *              July 1, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1376,8 +1355,8 @@ check_for_errors(void)
 {
     FILE *file;
 
-    if ((file = HDfopen(ERRFILE, "r"))) {
-        HDfclose(file);
+    if ((file = fopen(ERRFILE, "r"))) {
+        fclose(file);
         HDremove(ERRFILE);
         return FAIL;
     } /* end if */
@@ -1393,9 +1372,6 @@ check_for_errors(void)
  *
  * Return:      void
  *
- * Programmer:  Mike McGreevy
- *              July 16, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
