@@ -75,7 +75,7 @@ open_skeleton(const char *filename, unsigned verbose)
     hsize_t  dim[2]; /* Dataspace dimension */
     unsigned u, v;   /* Local index variable */
 
-    HDassert(filename);
+    assert(filename);
 
     /* Create file access property list */
     if ((fapl = h5_fileaccess()) < 0)
@@ -95,7 +95,7 @@ open_skeleton(const char *filename, unsigned verbose)
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Opening datasets\n");
+        fprintf(stderr, "Opening datasets\n");
 
     /* Open the datasets */
     for (u = 0; u < NLEVELS; u++)
@@ -148,10 +148,10 @@ addrem_records(hid_t fid, unsigned verbose, unsigned long nops, unsigned long fl
     unsigned long op_to_flush;                          /* # of operations before flush */
     unsigned long u, v;                                 /* Local index variables */
 
-    HDassert(fid > 0);
+    assert(fid > 0);
 
     /* Reset the buffer */
-    HDmemset(&buf, 0, sizeof(buf));
+    memset(&buf, 0, sizeof(buf));
 
     /* Create a dataspace for the record to add */
     if ((mem_sid = H5Screate_simple(2, count, NULL)) < 0)
@@ -250,7 +250,7 @@ addrem_records(hid_t fid, unsigned verbose, unsigned long nops, unsigned long fl
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Closing datasets\n");
+        fprintf(stderr, "Closing datasets\n");
 
     /* Close the datasets */
     for (u = 0; u < NLEVELS; u++)
@@ -264,21 +264,21 @@ addrem_records(hid_t fid, unsigned verbose, unsigned long nops, unsigned long fl
 static void
 usage(void)
 {
-    HDprintf("\n");
-    HDprintf("Usage error!\n");
-    HDprintf("\n");
-    HDprintf("Usage: swmr_addrem_writer [-q] [-f <# of operations between flushing\n");
-    HDprintf("    file contents>] [-r <random seed>] <# of operations>\n");
-    HDprintf("\n");
-    HDprintf("<# of operations between flushing file contents> should be 0 (for\n");
-    HDprintf("no flushing) or between 1 and (<# of operations> - 1).\n");
-    HDprintf("\n");
-    HDprintf("<# of operations> must be specified.\n");
-    HDprintf("\n");
-    HDprintf("Defaults to verbose (no '-q' given), flushing every 1000 operations\n");
-    HDprintf("('-f 1000'), and will generate a random seed (no -r given).\n");
-    HDprintf("\n");
-    HDexit(EXIT_FAILURE);
+    printf("\n");
+    printf("Usage error!\n");
+    printf("\n");
+    printf("Usage: swmr_addrem_writer [-q] [-f <# of operations between flushing\n");
+    printf("    file contents>] [-r <random seed>] <# of operations>\n");
+    printf("\n");
+    printf("<# of operations between flushing file contents> should be 0 (for\n");
+    printf("no flushing) or between 1 and (<# of operations> - 1).\n");
+    printf("\n");
+    printf("<# of operations> must be specified.\n");
+    printf("\n");
+    printf("Defaults to verbose (no '-q' given), flushing every 1000 operations\n");
+    printf("('-f 1000'), and will generate a random seed (no -r given).\n");
+    printf("\n");
+    exit(EXIT_FAILURE);
 }
 
 int
@@ -303,7 +303,7 @@ main(int argc, char *argv[])
                 switch (argv[u][1]) {
                     /* # of records to write between flushing file */
                     case 'f':
-                        flush_count = HDatol(argv[u + 1]);
+                        flush_count = atol(argv[u + 1]);
                         if (flush_count < 0)
                             usage();
                         u += 2;
@@ -318,7 +318,7 @@ main(int argc, char *argv[])
                     /* Random # seed */
                     case 'r':
                         use_seed = 1;
-                        temp     = HDatoi(argv[u + 1]);
+                        temp     = atoi(argv[u + 1]);
                         if (temp < 0)
                             usage();
                         else
@@ -333,7 +333,7 @@ main(int argc, char *argv[])
             }     /* end if */
             else {
                 /* Get the number of records to append */
-                nops = HDatol(argv[u]);
+                nops = atol(argv[u]);
                 if (nops <= 0)
                     usage();
 
@@ -348,9 +348,9 @@ main(int argc, char *argv[])
 
     /* Emit informational message */
     if (verbose) {
-        HDfprintf(stderr, "Parameters:\n");
-        HDfprintf(stderr, "\t# of operations between flushes = %ld\n", flush_count);
-        HDfprintf(stderr, "\t# of operations = %ld\n", nops);
+        fprintf(stderr, "Parameters:\n");
+        fprintf(stderr, "\t# of operations between flushes = %ld\n", flush_count);
+        fprintf(stderr, "\t# of operations = %ld\n", nops);
     } /* end if */
 
     /* Set the random seed */
@@ -361,11 +361,11 @@ main(int argc, char *argv[])
     } /* end if */
     HDsrandom(random_seed);
     /* ALWAYS emit the random seed for possible debugging */
-    HDfprintf(stderr, "Using writer random seed: %u\n", random_seed);
+    fprintf(stderr, "Using writer random seed: %u\n", random_seed);
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Generating symbol names\n");
+        fprintf(stderr, "Generating symbol names\n");
 
     /* Generate dataset names */
     if (generate_symbols() < 0)
@@ -373,12 +373,12 @@ main(int argc, char *argv[])
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Opening skeleton file: %s\n", FILENAME);
+        fprintf(stderr, "Opening skeleton file: %s\n", FILENAME);
 
     /* Open file skeleton */
     if ((fid = open_skeleton(FILENAME, verbose)) < 0) {
-        HDfprintf(stderr, "Error opening skeleton file!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error opening skeleton file!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Send a message to indicate "H5Fopen" is complete--releasing the file lock */
@@ -386,32 +386,32 @@ main(int argc, char *argv[])
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Adding and removing records\n");
+        fprintf(stderr, "Adding and removing records\n");
 
     /* Grow and shrink datasets */
     if (addrem_records(fid, verbose, (unsigned long)nops, (unsigned long)flush_count) < 0) {
-        HDfprintf(stderr, "Error adding and removing records from datasets!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error adding and removing records from datasets!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Releasing symbols\n");
+        fprintf(stderr, "Releasing symbols\n");
 
     /* Clean up the symbols */
     if (shutdown_symbols() < 0) {
-        HDfprintf(stderr, "Error releasing symbols!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error releasing symbols!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Closing objects\n");
+        fprintf(stderr, "Closing objects\n");
 
     /* Close objects opened */
     if (H5Fclose(fid) < 0) {
-        HDfprintf(stderr, "Error closing file!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error closing file!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     return 0;
