@@ -34,16 +34,16 @@
 /* Local Prototypes */
 /********************/
 
-static int check_dataset(hid_t fid, hbool_t verbose, FILE *verbose_file, const char *sym_name,
-                         symbol_t *record, hid_t rec_sid);
-static int read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned random_seed,
+static int check_dataset(hid_t fid, bool verbose, FILE *verbose_file, const char *sym_name, symbol_t *record,
+                         hid_t rec_sid);
+static int read_records(const char *filename, bool verbose, FILE *verbose_file, unsigned random_seed,
                         unsigned long nseconds, unsigned poll_time, unsigned ncommon, unsigned nrandom);
 
 /*******************/
 /* Local Variables */
 /*******************/
 
-static hid_t symbol_tid = -1; /* The type ID for the SWMR datasets */
+static hid_t symbol_tid = H5I_INVALID_HID; /* The type ID for the SWMR datasets */
 
 /*-------------------------------------------------------------------------
  * Function:    check_dataset
@@ -55,7 +55,7 @@ static hid_t symbol_tid = -1; /* The type ID for the SWMR datasets */
  * Parameters:  hid_t fid
  *              The SWMR test file's ID.
  *
- *              hbool_t verbose
+ *              bool verbose
  *              Whether verbose console output is desired.
  *
  *              FILE *verbose_file
@@ -78,7 +78,7 @@ static hid_t symbol_tid = -1; /* The type ID for the SWMR datasets */
  *-------------------------------------------------------------------------
  */
 static int
-check_dataset(hid_t fid, hbool_t verbose, FILE *verbose_file, const char *sym_name, symbol_t *record,
+check_dataset(hid_t fid, bool verbose, FILE *verbose_file, const char *sym_name, symbol_t *record,
               hid_t rec_sid)
 {
     hid_t    dsid;                                 /* Dataset ID */
@@ -86,10 +86,10 @@ check_dataset(hid_t fid, hbool_t verbose, FILE *verbose_file, const char *sym_na
     hssize_t snpoints;                             /* Number of elements in dataset */
     hsize_t  start[2] = {0, 0}, count[2] = {1, 1}; /* Hyperslab selection values */
 
-    HDassert(fid >= 0);
-    HDassert(sym_name);
-    HDassert(record);
-    HDassert(rec_sid >= 0);
+    assert(fid >= 0);
+    assert(sym_name);
+    assert(record);
+    assert(rec_sid >= 0);
 
     /* Open dataset for symbol */
     if ((dsid = H5Dopen2(fid, sym_name, H5P_DEFAULT)) < 0)
@@ -105,7 +105,7 @@ check_dataset(hid_t fid, hbool_t verbose, FILE *verbose_file, const char *sym_na
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Symbol = '%s', # of records = %lld\n", sym_name, (long long)snpoints);
+        fprintf(verbose_file, "Symbol = '%s', # of records = %lld\n", sym_name, (long long)snpoints);
 
     /* Check if there are records for symbol */
     if (snpoints > 0) {
@@ -126,12 +126,12 @@ check_dataset(hid_t fid, hbool_t verbose, FILE *verbose_file, const char *sym_na
             HDgettimeofday(&tv, NULL);
 
             if (verbose) {
-                HDfprintf(verbose_file, "*** ERROR ***\n");
-                HDfprintf(verbose_file, "Incorrect record value!\n");
-                HDfprintf(verbose_file,
-                          "Time = %llu.%llu, Symbol = '%s', # of records = %lld, record->rec_id = %llu\n",
-                          (unsigned long long)tv.tv_sec, (unsigned long long)tv.tv_usec, sym_name,
-                          (long long)snpoints, (unsigned long long)record->rec_id);
+                fprintf(verbose_file, "*** ERROR ***\n");
+                fprintf(verbose_file, "Incorrect record value!\n");
+                fprintf(verbose_file,
+                        "Time = %llu.%llu, Symbol = '%s', # of records = %lld, record->rec_id = %llu\n",
+                        (unsigned long long)tv.tv_sec, (unsigned long long)tv.tv_usec, sym_name,
+                        (long long)snpoints, (unsigned long long)record->rec_id);
             } /* end if */
             return -1;
         } /* end if */
@@ -163,7 +163,7 @@ check_dataset(hid_t fid, hbool_t verbose, FILE *verbose_file, const char *sym_na
  * Parameters:  const char *filename
  *              The SWMR test file's name.
  *
- *              hbool_t verbose
+ *              bool verbose
  *              Whether verbose console output is desired.
  *
  *              FILE *verbose_file
@@ -190,7 +190,7 @@ check_dataset(hid_t fid, hbool_t verbose, FILE *verbose_file, const char *sym_na
  *-------------------------------------------------------------------------
  */
 static int
-read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned random_seed,
+read_records(const char *filename, bool verbose, FILE *verbose_file, unsigned random_seed,
              unsigned long nseconds, unsigned poll_time, unsigned ncommon, unsigned nrandom)
 {
     time_t          start_time;          /* Starting time */
@@ -202,24 +202,24 @@ read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
     hid_t           fapl;                /* file access property list */
     symbol_t        record;              /* The record to read from the dataset */
     unsigned        v;                   /* Local index variable */
-    hbool_t         use_log_vfd = FALSE; /* Use the log VFD (set this manually) */
+    bool            use_log_vfd = false; /* Use the log VFD (set this manually) */
 
-    HDassert(filename);
-    HDassert(nseconds != 0);
-    HDassert(poll_time != 0);
+    assert(filename);
+    assert(nseconds != 0);
+    assert(poll_time != 0);
 
     /* Reset the record */
     /* (record's 'info' field might need to change for each record read, also) */
-    HDmemset(&record, 0, sizeof(record));
+    memset(&record, 0, sizeof(record));
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Choosing datasets\n");
+        fprintf(verbose_file, "Choosing datasets\n");
 
     /* Allocate space for 'common' datasets, if any */
     if (ncommon > 0) {
         /* Allocate array to hold pointers to symbols for common datasets */
-        if (NULL == (sym_com = (symbol_info_t **)HDmalloc(sizeof(symbol_info_t *) * ncommon)))
+        if (NULL == (sym_com = (symbol_info_t **)malloc(sizeof(symbol_info_t *) * ncommon)))
             return -1;
 
         /* Open the common datasets */
@@ -233,14 +233,14 @@ read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
 
             /* Emit informational message */
             if (verbose)
-                HDfprintf(verbose_file, "Common symbol #%u = '%s'\n", v, symbol_info[0][offset].name);
+                fprintf(verbose_file, "Common symbol #%u = '%s'\n", v, symbol_info[0][offset].name);
         } /* end for */
     }     /* end if */
 
     /* Allocate space for 'random' datasets, if any */
     if (nrandom > 0) {
         /* Allocate array to hold pointers to symbols for random datasets */
-        if (NULL == (sym_rand = (symbol_info_t **)HDmalloc(sizeof(symbol_info_t *) * nrandom)))
+        if (NULL == (sym_rand = (symbol_info_t **)malloc(sizeof(symbol_info_t *) * nrandom)))
             return -1;
 
         /* Determine the random datasets */
@@ -254,7 +254,7 @@ read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
 
             /* Emit informational message */
             if (verbose)
-                HDfprintf(verbose_file, "Random symbol #%u = '%s'\n", v, sym->name);
+                fprintf(verbose_file, "Random symbol #%u = '%s'\n", v, sym->name);
         } /* end for */
     }     /* end if */
 
@@ -264,10 +264,10 @@ read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Reading records\n");
+        fprintf(verbose_file, "Reading records\n");
 
     /* Get the starting time */
-    start_time = HDtime(NULL);
+    start_time = time(NULL);
     curr_time  = start_time;
 
     /* Create file access property list */
@@ -278,7 +278,7 @@ read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
     if (use_log_vfd) {
         char verbose_name[1024];
 
-        HDsnprintf(verbose_name, sizeof(verbose_name), "swmr_reader.log.%u", random_seed);
+        snprintf(verbose_name, sizeof(verbose_name), "swmr_reader.log.%u", random_seed);
 
         H5Pset_fapl_log(fapl, verbose_name, H5FD_LOG_ALL, (size_t)(512 * 1024 * 1024));
     } /* end if */
@@ -288,7 +288,7 @@ read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
 
         /* Emit informational message */
         if (verbose)
-            HDfprintf(verbose_file, "Opening file: %s\n", filename);
+            fprintf(verbose_file, "Opening file: %s\n", filename);
 
         /* Open the file */
         if ((fid = H5Fopen(filename, H5F_ACC_RDONLY | H5F_ACC_SWMR_READ, fapl)) < 0)
@@ -298,14 +298,14 @@ read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
         if (ncommon > 0) {
             /* Emit informational message */
             if (verbose)
-                HDfprintf(verbose_file, "Checking common symbols\n");
+                fprintf(verbose_file, "Checking common symbols\n");
 
             /* Iterate over common datasets */
             for (v = 0; v < ncommon; v++) {
                 /* Check common dataset */
                 if (check_dataset(fid, verbose, verbose_file, sym_com[v]->name, &record, mem_sid) < 0)
                     return -1;
-                HDmemset(&record, 0, sizeof(record));
+                memset(&record, 0, sizeof(record));
             } /* end for */
         }     /* end if */
 
@@ -313,20 +313,20 @@ read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
         if (nrandom > 0) {
             /* Emit informational message */
             if (verbose)
-                HDfprintf(verbose_file, "Checking random symbols\n");
+                fprintf(verbose_file, "Checking random symbols\n");
 
             /* Iterate over random datasets */
             for (v = 0; v < nrandom; v++) {
                 /* Check random dataset */
                 if (check_dataset(fid, verbose, verbose_file, sym_rand[v]->name, &record, mem_sid) < 0)
                     return -1;
-                HDmemset(&record, 0, sizeof(record));
+                memset(&record, 0, sizeof(record));
             } /* end for */
         }     /* end if */
 
         /* Emit informational message */
         if (verbose)
-            HDfprintf(verbose_file, "Closing file\n");
+            fprintf(verbose_file, "Closing file\n");
 
         /* Close the file */
         if (H5Fclose(fid) < 0)
@@ -336,7 +336,7 @@ read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
         HDsleep(poll_time);
 
         /* Retrieve the current time */
-        curr_time = HDtime(NULL);
+        curr_time = time(NULL);
     } /* end while */
 
     /* Close the memory dataspace */
@@ -349,18 +349,18 @@ read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Closing datasets\n");
+        fprintf(verbose_file, "Closing datasets\n");
 
     /* Close 'random' datasets, if any */
     if (nrandom > 0) {
         /* Release array holding dataset ID's for random datasets */
-        HDfree(sym_rand);
+        free(sym_rand);
     } /* end if */
 
     /* Close 'common' datasets, if any */
     if (ncommon > 0) {
         /* Release array holding dataset ID's for common datasets */
-        HDfree(sym_com);
+        free(sym_com);
     } /* end if */
 
     return 0;
@@ -369,20 +369,20 @@ read_records(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
 static void
 usage(void)
 {
-    HDprintf("\n");
-    HDprintf("Usage error!\n");
-    HDprintf("\n");
-    HDprintf("Usage: swmr_reader [-q] [-s <# of seconds to sleep between polling>]\n");
-    HDprintf("    [-h <# of common symbols to poll>] [-l <# of random symbols to poll>]\n");
-    HDprintf("    [-r <random seed>] <# of seconds to test>\n");
-    HDprintf("\n");
-    HDprintf("<# of seconds to test> must be specified.\n");
-    HDprintf("\n");
-    HDprintf("Defaults to verbose (no '-q' given), 1 second between polling ('-s 1'),\n");
-    HDprintf("5 common symbols to poll ('-h 5'), 10 random symbols to poll ('-l 10'),\n");
-    HDprintf("and will generate a random seed (no -r given).\n");
-    HDprintf("\n");
-    HDexit(EXIT_FAILURE);
+    printf("\n");
+    printf("Usage error!\n");
+    printf("\n");
+    printf("Usage: swmr_reader [-q] [-s <# of seconds to sleep between polling>]\n");
+    printf("    [-h <# of common symbols to poll>] [-l <# of random symbols to poll>]\n");
+    printf("    [-r <random seed>] <# of seconds to test>\n");
+    printf("\n");
+    printf("<# of seconds to test> must be specified.\n");
+    printf("\n");
+    printf("Defaults to verbose (no '-q' given), 1 second between polling ('-s 1'),\n");
+    printf("5 common symbols to poll ('-h 5'), 10 random symbols to poll ('-l 10'),\n");
+    printf("and will generate a random seed (no -r given).\n");
+    printf("\n");
+    exit(EXIT_FAILURE);
 }
 
 int
@@ -392,9 +392,9 @@ main(int argc, char *argv[])
     int      poll_time    = 1;     /* # of seconds between polling */
     int      ncommon      = 5;     /* # of common symbols to poll */
     int      nrandom      = 10;    /* # of random symbols to poll */
-    hbool_t  verbose      = TRUE;  /* Whether to emit some informational messages */
+    bool     verbose      = true;  /* Whether to emit some informational messages */
     FILE    *verbose_file = NULL;  /* File handle for verbose output */
-    hbool_t  use_seed     = FALSE; /* Set to 1 if a seed was set on the command line */
+    bool     use_seed     = false; /* Set to 1 if a seed was set on the command line */
     unsigned random_seed  = 0;     /* Random # seed */
     unsigned u;                    /* Local index variables */
     int      temp;
@@ -409,7 +409,7 @@ main(int argc, char *argv[])
                 switch (argv[u][1]) {
                     /* # of common symbols to poll */
                     case 'h':
-                        ncommon = HDatoi(argv[u + 1]);
+                        ncommon = atoi(argv[u + 1]);
                         if (ncommon < 0)
                             usage();
                         u += 2;
@@ -417,7 +417,7 @@ main(int argc, char *argv[])
 
                     /* # of random symbols to poll */
                     case 'l':
-                        nrandom = HDatoi(argv[u + 1]);
+                        nrandom = atoi(argv[u + 1]);
                         if (nrandom < 0)
                             usage();
                         u += 2;
@@ -425,14 +425,14 @@ main(int argc, char *argv[])
 
                     /* Be quiet */
                     case 'q':
-                        verbose = FALSE;
+                        verbose = false;
                         u++;
                         break;
 
                     /* Random # seed */
                     case 'r':
-                        use_seed = TRUE;
-                        temp     = HDatoi(argv[u + 1]);
+                        use_seed = true;
+                        temp     = atoi(argv[u + 1]);
                         if (temp < 0)
                             usage();
                         else
@@ -442,7 +442,7 @@ main(int argc, char *argv[])
 
                     /* # of seconds between polling */
                     case 's':
-                        poll_time = HDatoi(argv[u + 1]);
+                        poll_time = atoi(argv[u + 1]);
                         if (poll_time < 0)
                             usage();
                         u += 2;
@@ -455,7 +455,7 @@ main(int argc, char *argv[])
             }     /* end if */
             else {
                 /* Get the number of records to append */
-                nseconds = HDatol(argv[u]);
+                nseconds = atol(argv[u]);
                 if (nseconds <= 0)
                     usage();
 
@@ -481,33 +481,33 @@ main(int argc, char *argv[])
     if (verbose) {
         char verbose_name[1024];
 
-        HDsnprintf(verbose_name, sizeof(verbose_name), "swmr_reader.out.%u", random_seed);
-        if (NULL == (verbose_file = HDfopen(verbose_name, "w"))) {
-            HDfprintf(stderr, "Can't open verbose output file!\n");
-            HDexit(EXIT_FAILURE);
+        snprintf(verbose_name, sizeof(verbose_name), "swmr_reader.out.%u", random_seed);
+        if (NULL == (verbose_file = fopen(verbose_name, "w"))) {
+            fprintf(stderr, "Can't open verbose output file!\n");
+            exit(EXIT_FAILURE);
         }
     } /* end if */
 
     /* Emit informational message */
     if (verbose) {
-        HDfprintf(verbose_file, "Parameters:\n");
-        HDfprintf(verbose_file, "\t# of seconds between polling = %d\n", poll_time);
-        HDfprintf(verbose_file, "\t# of common symbols to poll = %d\n", ncommon);
-        HDfprintf(verbose_file, "\t# of random symbols to poll = %d\n", nrandom);
-        HDfprintf(verbose_file, "\t# of seconds to test = %ld\n", nseconds);
+        fprintf(verbose_file, "Parameters:\n");
+        fprintf(verbose_file, "\t# of seconds between polling = %d\n", poll_time);
+        fprintf(verbose_file, "\t# of common symbols to poll = %d\n", ncommon);
+        fprintf(verbose_file, "\t# of random symbols to poll = %d\n", nrandom);
+        fprintf(verbose_file, "\t# of seconds to test = %ld\n", nseconds);
     } /* end if */
 
     /* ALWAYS emit the random seed for possible debugging */
-    HDfprintf(stdout, "Using reader random seed: %u\n", random_seed);
+    fprintf(stdout, "Using reader random seed: %u\n", random_seed);
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Generating symbol names\n");
+        fprintf(verbose_file, "Generating symbol names\n");
 
     /* Generate dataset names */
     if (generate_symbols() < 0) {
-        HDfprintf(stderr, "Error generating symbol names!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error generating symbol names!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Create datatype for creating datasets */
@@ -517,28 +517,28 @@ main(int argc, char *argv[])
     /* Reading records from datasets */
     if (read_records(FILENAME, verbose, verbose_file, random_seed, (unsigned long)nseconds,
                      (unsigned)poll_time, (unsigned)ncommon, (unsigned)nrandom) < 0) {
-        HDfprintf(stderr, "Error reading records from datasets (random_seed = %u)!\n", random_seed);
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error reading records from datasets (random_seed = %u)!\n", random_seed);
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Releasing symbols\n");
+        fprintf(verbose_file, "Releasing symbols\n");
 
     /* Clean up the symbols */
     if (shutdown_symbols() < 0) {
-        HDfprintf(stderr, "Error releasing symbols!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error releasing symbols!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Closing objects\n");
+        fprintf(verbose_file, "Closing objects\n");
 
     /* Close objects created */
     if (H5Tclose(symbol_tid) < 0) {
-        HDfprintf(stderr, "Error closing symbol datatype!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error closing symbol datatype!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     return 0;
