@@ -33,7 +33,7 @@
 
 /* Data written to the dataset for single block test.  Global variable
  * for convenience. */
-int da_buffer[2][3][6][2];
+static int da_buffer[2][3][6][2];
 
 /***********************************************************
 **
@@ -42,7 +42,7 @@ int da_buffer[2][3][6][2];
 **
 *************************************************************/
 static void
-test_singleEnd_selElements(hid_t file, hbool_t is_chunked)
+test_singleEnd_selElements(hid_t file, bool is_chunked)
 {
     hid_t   sid, plid, did, msid;
     char    dset_name[NAME_LEN]; /* Dataset name */
@@ -86,10 +86,10 @@ test_singleEnd_selElements(hid_t file, hbool_t is_chunked)
     }
 
     /* Construct dataset's name */
-    HDmemset(dset_name, 0, (size_t)NAME_LEN);
-    HDstrcat(dset_name, SINGLE_END_DSET);
+    memset(dset_name, 0, (size_t)NAME_LEN);
+    strcat(dset_name, SINGLE_END_DSET);
     if (is_chunked)
-        HDstrcat(dset_name, "_chunked");
+        strcat(dset_name, "_chunked");
 
     did = H5Dcreate2(file, dset_name, H5T_NATIVE_INT, sid, H5P_DEFAULT, plid, H5P_DEFAULT);
     CHECK(did, FAIL, "H5Dcreate2");
@@ -225,7 +225,7 @@ test_singleEnd_selElements(hid_t file, hbool_t is_chunked)
 **
 *************************************************************/
 static void
-test_singleEnd_selHyperslab(hid_t file, hbool_t is_chunked)
+test_singleEnd_selHyperslab(hid_t file, bool is_chunked)
 {
     hid_t   sid, did, msid;
     char    dset_name[NAME_LEN]; /* Dataset name */
@@ -258,10 +258,10 @@ test_singleEnd_selHyperslab(hid_t file, hbool_t is_chunked)
     hsize_t mem3_block[4]  = {1, 3, 6, 1};
 
     /* Construct dataset's name */
-    HDmemset(dset_name, 0, NAME_LEN);
-    HDstrcat(dset_name, SINGLE_END_DSET);
+    memset(dset_name, 0, NAME_LEN);
+    strcat(dset_name, SINGLE_END_DSET);
     if (is_chunked)
-        HDstrcat(dset_name, "_chunked");
+        strcat(dset_name, "_chunked");
 
     /* Dataspace for the dataset in file */
     sid = H5Screate_simple(4, da_dims, da_dims);
@@ -371,7 +371,7 @@ test_singleEnd_selHyperslab(hid_t file, hbool_t is_chunked)
 **
 *************************************************************/
 static void
-test_multiple_ends(hid_t file, hbool_t is_chunked)
+test_multiple_ends(hid_t file, bool is_chunked)
 {
     hid_t   sid, plid, did, msid;
     char    dset_name[NAME_LEN]; /* Dataset name */
@@ -386,7 +386,7 @@ test_multiple_ends(hid_t file, hbool_t is_chunked)
     /* For testing the full selections in the fastest-growing end and in the middle dimensions */
     struct {
         int arr[1][1][1][4][2][1][6][2];
-    } *mem1_buffer         = NULL;
+    }      *mem1_buffer    = NULL;
     hsize_t mem1_dims[8]   = {1, 1, 1, 4, 2, 1, 6, 2};
     hsize_t mem1_start[8]  = {0, 0, 0, 0, 0, 0, 0, 0};
     hsize_t mem1_count[8]  = {1, 1, 1, 1, 1, 1, 1, 1};
@@ -396,7 +396,7 @@ test_multiple_ends(hid_t file, hbool_t is_chunked)
     /* For testing the full selections in the slowest-growing end and in the middle dimensions */
     struct {
         int arr[4][5][1][4][2][1][1][1];
-    } *mem2_buffer         = NULL;
+    }      *mem2_buffer    = NULL;
     hsize_t mem2_dims[8]   = {4, 5, 1, 4, 2, 1, 1, 1};
     hsize_t mem2_start[8]  = {0, 0, 0, 0, 0, 0, 0, 0};
     hsize_t mem2_count[8]  = {1, 1, 1, 1, 1, 1, 1, 1};
@@ -406,7 +406,7 @@ test_multiple_ends(hid_t file, hbool_t is_chunked)
     /* For testing two unadjacent full selections in the middle dimensions */
     struct {
         int arr[1][5][3][1][1][3][6][1];
-    } *mem3_buffer         = NULL;
+    }      *mem3_buffer    = NULL;
     hsize_t mem3_dims[8]   = {1, 5, 3, 1, 1, 3, 6, 1};
     hsize_t mem3_start[8]  = {0, 0, 0, 0, 0, 0, 0, 0};
     hsize_t mem3_count[8]  = {1, 1, 1, 1, 1, 1, 1, 1};
@@ -416,7 +416,7 @@ test_multiple_ends(hid_t file, hbool_t is_chunked)
     /* For testing the full selections in the fastest-growing end and the slowest-growing end */
     struct {
         int arr[4][5][1][1][1][1][6][2];
-    } *mem4_buffer         = NULL;
+    }      *mem4_buffer    = NULL;
     hsize_t mem4_dims[8]   = {4, 5, 1, 1, 1, 1, 6, 2};
     hsize_t mem4_start[8]  = {0, 0, 0, 0, 0, 0, 0, 0};
     hsize_t mem4_count[8]  = {1, 1, 1, 1, 1, 1, 1, 1};
@@ -427,7 +427,7 @@ test_multiple_ends(hid_t file, hbool_t is_chunked)
      * also in the middle dimensions */
     struct {
         int arr[4][5][1][4][2][1][6][2];
-    } *mem5_buffer         = NULL;
+    }      *mem5_buffer    = NULL;
     hsize_t mem5_dims[8]   = {4, 5, 1, 4, 2, 1, 6, 2};
     hsize_t mem5_start[8]  = {0, 0, 0, 0, 0, 0, 0, 0};
     hsize_t mem5_count[8]  = {1, 1, 1, 1, 1, 1, 1, 1};
@@ -435,18 +435,18 @@ test_multiple_ends(hid_t file, hbool_t is_chunked)
     hsize_t mem5_block[8]  = {4, 5, 1, 4, 2, 1, 6, 2};
 
     /* Initialize dynamic arrays */
-    data_buf = HDcalloc(1, sizeof(*data_buf));
-    CHECK_PTR(data_buf, "HDcalloc");
-    mem1_buffer = HDcalloc(1, sizeof(*mem1_buffer));
-    CHECK_PTR(data_buf, "HDcalloc");
-    mem2_buffer = HDcalloc(1, sizeof(*mem2_buffer));
-    CHECK_PTR(data_buf, "HDcalloc");
-    mem3_buffer = HDcalloc(1, sizeof(*mem3_buffer));
-    CHECK_PTR(data_buf, "HDcalloc");
-    mem4_buffer = HDcalloc(1, sizeof(*mem4_buffer));
-    CHECK_PTR(data_buf, "HDcalloc");
-    mem5_buffer = HDcalloc(1, sizeof(*mem5_buffer));
-    CHECK_PTR(data_buf, "HDcalloc");
+    data_buf = calloc(1, sizeof(*data_buf));
+    CHECK_PTR(data_buf, "calloc");
+    mem1_buffer = calloc(1, sizeof(*mem1_buffer));
+    CHECK_PTR(data_buf, "calloc");
+    mem2_buffer = calloc(1, sizeof(*mem2_buffer));
+    CHECK_PTR(data_buf, "calloc");
+    mem3_buffer = calloc(1, sizeof(*mem3_buffer));
+    CHECK_PTR(data_buf, "calloc");
+    mem4_buffer = calloc(1, sizeof(*mem4_buffer));
+    CHECK_PTR(data_buf, "calloc");
+    mem5_buffer = calloc(1, sizeof(*mem5_buffer));
+    CHECK_PTR(data_buf, "calloc");
 
     /* Create and write the dataset */
     sid = H5Screate_simple(8, da_dims, da_dims);
@@ -461,10 +461,10 @@ test_multiple_ends(hid_t file, hbool_t is_chunked)
     }
 
     /* Construct dataset's name */
-    HDmemset(dset_name, 0, NAME_LEN);
-    HDstrcat(dset_name, MULTI_ENDS_SEL_HYPER_DSET);
+    memset(dset_name, 0, NAME_LEN);
+    strcat(dset_name, MULTI_ENDS_SEL_HYPER_DSET);
     if (is_chunked)
-        HDstrcat(dset_name, "_chunked");
+        strcat(dset_name, "_chunked");
 
     did = H5Dcreate2(file, dset_name, H5T_NATIVE_INT, sid, H5P_DEFAULT, plid, H5P_DEFAULT);
     CHECK(did, FAIL, "H5Dcreate2");
@@ -664,12 +664,12 @@ test_multiple_ends(hid_t file, hbool_t is_chunked)
     ret = H5Pclose(plid);
     CHECK(ret, FAIL, "H5Pclose");
 
-    HDfree(data_buf);
-    HDfree(mem1_buffer);
-    HDfree(mem2_buffer);
-    HDfree(mem3_buffer);
-    HDfree(mem4_buffer);
-    HDfree(mem5_buffer);
+    free(data_buf);
+    free(mem1_buffer);
+    free(mem2_buffer);
+    free(mem3_buffer);
+    free(mem4_buffer);
+    free(mem5_buffer);
 }
 
 /****************************************************************
@@ -680,10 +680,10 @@ test_multiple_ends(hid_t file, hbool_t is_chunked)
 void
 test_coords(void)
 {
-    hid_t   fid;
-    hbool_t is_chunk[2] = {TRUE, FALSE};
-    int     i;
-    herr_t  ret; /* Generic error return */
+    hid_t  fid;
+    bool   is_chunk[2] = {true, false};
+    int    i;
+    herr_t ret; /* Generic error return */
 
     fid = H5Fcreate(FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
@@ -710,15 +710,14 @@ test_coords(void)
  *
  * Return:	none
  *
- * Programmer:	Raymond Lu
- *              20 Dec. 2007
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 void
 cleanup_coords(void)
 {
-    HDremove(FILENAME);
+    H5E_BEGIN_TRY
+    {
+        H5Fdelete(FILENAME, H5P_DEFAULT);
+    }
+    H5E_END_TRY
 }
