@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Quincey Koziol
- *              Tuesday, January  6, 2004
- *
  * Purpose:    Provides support functions for the testing framework.
  *
  */
@@ -44,7 +41,7 @@ static int         num_errs                         = 0;         /* Total number
 int                TestVerbosity                    = VERBO_DEF; /* Default Verbosity is Low */
 static int         Summary                          = 0;         /* Show test summary. Default is no. */
 static int         CleanUp                          = 1;         /* Do cleanup or not. Default is yes. */
-static int         TestExpress                      = -1;   /* Do TestExpress or not. -1 means not set yet. */
+int                TestExpress                      = -1;   /* Do TestExpress or not. -1 means not set yet. */
 static TestStruct *Test                             = NULL; /* Array of tests */
 static unsigned    TestAlloc                        = 0;    /* Size of the Test array */
 static unsigned    Index                            = 0;
@@ -52,6 +49,7 @@ static const void *Test_parameters                  = NULL;
 static const char *TestProgName                     = NULL;
 static void (*TestPrivateUsage)(void)               = NULL;
 static int (*TestPrivateParser)(int ac, char *av[]) = NULL;
+int mpi_rank_framework_g                            = 0;
 
 /*
  * Setup a test function and add it to the list of tests.
@@ -71,14 +69,14 @@ AddTest(const char *TheName, void (*TheCall)(void), void (*Cleanup)(void), const
         const void *Parameters)
 {
     /* Sanity checking */
-    if (HDstrlen(TheDescr) >= MAXTESTDESC) {
-        HDprintf("Test description ('%s') too long, increase MAXTESTDESC(%d).\n", TheDescr, MAXTESTDESC);
-        HDexit(EXIT_FAILURE);
-    } /* end if */
-    if (HDstrlen(TheName) >= MAXTESTNAME) {
-        HDprintf("Test name too long, increase MAXTESTNAME(%d).\n", MAXTESTNAME);
-        HDexit(EXIT_FAILURE);
-    } /* end if */
+    if (strlen(TheDescr) >= MAXTESTDESC) {
+        printf("Test description ('%s') too long, increase MAXTESTDESC(%d).\n", TheDescr, MAXTESTDESC);
+        exit(EXIT_FAILURE);
+    }
+    if (strlen(TheName) >= MAXTESTNAME) {
+        printf("Test name too long, increase MAXTESTNAME(%d).\n", MAXTESTNAME);
+        exit(EXIT_FAILURE);
+    }
 
     /* Check for increasing the Test array size */
     if (Index >= TestAlloc) {
@@ -86,25 +84,25 @@ AddTest(const char *TheName, void (*TheCall)(void), void (*Cleanup)(void), const
         unsigned    newAlloc = MAX(1, TestAlloc * 2); /* New array size */
 
         /* Reallocate array */
-        if (NULL == (newTest = (TestStruct *)HDrealloc(Test, newAlloc * sizeof(TestStruct)))) {
-            HDprintf("Out of memory for tests, Index = %u, TestAlloc = %u, newAlloc = %u\n", Index, TestAlloc,
-                     newAlloc);
-            HDexit(EXIT_FAILURE);
-        } /* end if */
+        if (NULL == (newTest = (TestStruct *)realloc(Test, newAlloc * sizeof(TestStruct)))) {
+            printf("Out of memory for tests, Index = %u, TestAlloc = %u, newAlloc = %u\n", Index, TestAlloc,
+                   newAlloc);
+            exit(EXIT_FAILURE);
+        }
 
         /* Update info */
         Test      = newTest;
         TestAlloc = newAlloc;
-    } /* end if */
+    }
 
     /* Set up test function */
-    HDstrcpy(Test[Index].Description, TheDescr);
+    strcpy(Test[Index].Description, TheDescr);
     if (*TheName != '-') {
-        HDstrcpy(Test[Index].Name, TheName);
+        strcpy(Test[Index].Name, TheName);
         Test[Index].SkipFlag = 0;
     }
     else { /* skip test by default */
-        HDstrcpy(Test[Index].Name, TheName + 1);
+        strcpy(Test[Index].Name, TheName + 1);
         Test[Index].SkipFlag = 1;
     }
     Test[Index].Call       = TheCall;
@@ -126,9 +124,6 @@ AddTest(const char *TheName, void (*TheCall)(void), void (*Cleanup)(void), const
  * private_parser: Optional routine provided by test program to parse the
  *      private options.  Default to NULL which means none is provided.
  *
- * Modifications:
- *         Albert Cheng 2004/08/17
- *         Added the ProgName, private_usage and private_parser arguments.
  */
 void
 TestInit(const char *ProgName, void (*private_usage)(void), int (*private_parser)(int ac, char *av[]))
@@ -154,44 +149,43 @@ TestInit(const char *ProgName, void (*private_usage)(void), int (*private_parser
 /*
  * Print test usage.
  *    First print the common test options, then the extra options if provided.
- *
- * Modification:
- *     2004/08/18 Albert Cheng.  Add TestPrivateUsage feature.
  */
 void
 TestUsage(void)
 {
     unsigned i;
 
-    print_func("Usage: %s [-v[erbose] (l[ow]|m[edium]|h[igh]|0-9)] %s\n", TestProgName,
-               (TestPrivateUsage ? "<extra options>" : ""));
-    print_func("              [-[e]x[clude] name]+ \n");
-    print_func("              [-o[nly] name]+ \n");
-    print_func("              [-b[egin] name] \n");
-    print_func("              [-s[ummary]]  \n");
-    print_func("              [-c[leanoff]]  \n");
-    print_func("              [-h[elp]]  \n");
-    print_func("\n\n");
-    print_func("verbose   controls the amount of information displayed\n");
-    print_func("exclude   to exclude tests by name\n");
-    print_func("only      to name tests which should be run\n");
-    print_func("begin     start at the name of the test givin\n");
-    print_func("summary   prints a summary of test results at the end\n");
-    print_func("cleanoff  does not delete *.hdf files after execution of tests\n");
-    print_func("help      print out this information\n");
-    if (TestPrivateUsage) {
-        print_func("\nExtra options\n");
-        TestPrivateUsage();
+    if (mpi_rank_framework_g == 0) {
+        print_func("Usage: %s [-v[erbose] (l[ow]|m[edium]|h[igh]|0-9)] %s\n", TestProgName,
+                   (TestPrivateUsage ? "<extra options>" : ""));
+        print_func("              [-[e]x[clude] name]+ \n");
+        print_func("              [-o[nly] name]+ \n");
+        print_func("              [-b[egin] name] \n");
+        print_func("              [-s[ummary]]  \n");
+        print_func("              [-c[leanoff]]  \n");
+        print_func("              [-h[elp]]  \n");
+        print_func("\n\n");
+        print_func("verbose   controls the amount of information displayed\n");
+        print_func("exclude   to exclude tests by name\n");
+        print_func("only      to name tests which should be run\n");
+        print_func("begin     start at the name of the test given\n");
+        print_func("summary   prints a summary of test results at the end\n");
+        print_func("cleanoff  does not delete *.hdf files after execution of tests\n");
+        print_func("help      print out this information\n");
+        if (TestPrivateUsage) {
+            print_func("\nExtra options\n");
+            TestPrivateUsage();
+        }
+        print_func("\n\n");
+        print_func("This program currently tests the following: \n\n");
+        print_func("%16s %s\n", "Name", "Description");
+        print_func("%16s %s\n", "----", "-----------");
+
+        for (i = 0; i < Index; i++)
+            print_func("%16s %s\n", Test[i].Name, Test[i].Description);
+
+        print_func("\n\n");
     }
-    print_func("\n\n");
-    print_func("This program currently tests the following: \n\n");
-    print_func("%16s %s\n", "Name", "Description");
-    print_func("%16s %s\n", "----", "-----------");
-
-    for (i = 0; i < Index; i++)
-        print_func("%16s %s\n", Test[i].Name, Test[i].Description);
-
-    print_func("\n\n");
 }
 
 /*
@@ -200,12 +194,14 @@ TestUsage(void)
 void
 TestInfo(const char *ProgName)
 {
-    unsigned major, minor, release;
+    if (mpi_rank_framework_g == 0) {
+        unsigned major, minor, release;
 
-    H5get_libversion(&major, &minor, &release);
+        H5get_libversion(&major, &minor, &release);
 
-    print_func("\nFor help use: %s -help\n", ProgName);
-    print_func("Linked with hdf5 version %u.%u release %u\n", major, minor, release);
+        print_func("\nFor help use: %s -help\n", ProgName);
+        print_func("Linked with hdf5 version %u.%u release %u\n", major, minor, release);
+    }
 }
 
 /*
@@ -214,18 +210,15 @@ TestInfo(const char *ProgName)
  *
  * Return: Void
  *    exit EXIT_FAILURE if error is encountered.
- *
- * Modification:
- *     2004/08/18 Albert Cheng.  Add extra_parse feature.
  */
 void
 TestParseCmdLine(int argc, char *argv[])
 {
-    hbool_t skipped_all = FALSE;
-    int     ret_code;
+    bool skipped_all = false;
+    int  ret_code;
 
-    while (argv++, --argc > 0) {
-        if ((HDstrcmp(*argv, "-verbose") == 0) || (HDstrcmp(*argv, "-v") == 0)) {
+    while ((void)argv++, --argc > 0) {
+        if ((strcmp(*argv, "-verbose") == 0) || (strcmp(*argv, "-v") == 0)) {
             if (argc > 0) {
                 --argc;
                 ++argv;
@@ -233,10 +226,10 @@ TestParseCmdLine(int argc, char *argv[])
             }
             else {
                 TestUsage();
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
         }
-        else if (((HDstrcmp(*argv, "-exclude") == 0) || (HDstrcmp(*argv, "-x") == 0))) {
+        else if (((strcmp(*argv, "-exclude") == 0) || (strcmp(*argv, "-x") == 0))) {
             if (argc > 0) {
                 --argc;
                 ++argv;
@@ -244,10 +237,10 @@ TestParseCmdLine(int argc, char *argv[])
             }
             else {
                 TestUsage();
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
         }
-        else if (((HDstrcmp(*argv, "-begin") == 0) || (HDstrcmp(*argv, "-b") == 0))) {
+        else if (((strcmp(*argv, "-begin") == 0) || (strcmp(*argv, "-b") == 0))) {
             if (argc > 0) {
                 --argc;
                 ++argv;
@@ -255,10 +248,10 @@ TestParseCmdLine(int argc, char *argv[])
             }
             else {
                 TestUsage();
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
         }
-        else if (((HDstrcmp(*argv, "-only") == 0) || (HDstrcmp(*argv, "-o") == 0))) {
+        else if (((strcmp(*argv, "-only") == 0) || (strcmp(*argv, "-o") == 0))) {
             if (argc > 0) {
                 unsigned Loop;
 
@@ -269,24 +262,24 @@ TestParseCmdLine(int argc, char *argv[])
                 if (!skipped_all) {
                     for (Loop = 0; Loop < Index; Loop++)
                         Test[Loop].SkipFlag = 1;
-                    skipped_all = TRUE;
+                    skipped_all = true;
                 } /* end if */
                 SetTest(*argv, ONLYTEST);
             }
             else {
                 TestUsage();
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
         }
-        else if ((HDstrcmp(*argv, "-summary") == 0) || (HDstrcmp(*argv, "-s") == 0))
+        else if ((strcmp(*argv, "-summary") == 0) || (strcmp(*argv, "-s") == 0))
             Summary = 1;
-        else if (HDstrcmp(*argv, "-enable-error-stack") == 0)
+        else if (strcmp(*argv, "-enable-error-stack") == 0)
             enable_error_stack = 1;
-        else if ((HDstrcmp(*argv, "-help") == 0) || (HDstrcmp(*argv, "-h") == 0)) {
+        else if ((strcmp(*argv, "-help") == 0) || (strcmp(*argv, "-h") == 0)) {
             TestUsage();
-            HDexit(EXIT_SUCCESS);
+            exit(EXIT_SUCCESS);
         }
-        else if ((HDstrcmp(*argv, "-cleanoff") == 0) || (HDstrcmp(*argv, "-c") == 0))
+        else if ((strcmp(*argv, "-cleanoff") == 0) || (strcmp(*argv, "-c") == 0))
             SetTestNoCleanup();
         else {
             /* non-standard option.  Break out. */
@@ -298,7 +291,7 @@ TestParseCmdLine(int argc, char *argv[])
     if (NULL != TestPrivateParser) {
         ret_code = TestPrivateParser(argc + 1, argv - 1);
         if (ret_code != 0)
-            HDexit(EXIT_FAILURE);
+            exit(EXIT_FAILURE);
     }
 }
 
@@ -312,28 +305,35 @@ PerformTests(void)
 
     for (Loop = 0; Loop < Index; Loop++)
         if (Test[Loop].SkipFlag) {
-            MESSAGE(2, ("Skipping -- %s (%s) \n", Test[Loop].Description, Test[Loop].Name));
+            if (mpi_rank_framework_g == 0)
+                MESSAGE(2, ("Skipping -- %s (%s) \n", Test[Loop].Description, Test[Loop].Name));
         }
         else {
-            MESSAGE(2, ("Testing  -- %s (%s) \n", Test[Loop].Description, Test[Loop].Name));
-            MESSAGE(5, ("===============================================\n"));
+            if (mpi_rank_framework_g == 0)
+                MESSAGE(2, ("Testing  -- %s (%s) \n", Test[Loop].Description, Test[Loop].Name));
+            if (mpi_rank_framework_g == 0)
+                MESSAGE(5, ("===============================================\n"));
             Test[Loop].NumErrors = num_errs;
             Test_parameters      = Test[Loop].Parameters;
             TestAlarmOn();
             Test[Loop].Call();
             TestAlarmOff();
             Test[Loop].NumErrors = num_errs - Test[Loop].NumErrors;
-            MESSAGE(5, ("===============================================\n"));
-            MESSAGE(5, ("There were %d errors detected.\n\n", (int)Test[Loop].NumErrors));
+            if (mpi_rank_framework_g == 0) {
+                MESSAGE(5, ("===============================================\n"));
+                MESSAGE(5, ("There were %d errors detected.\n\n", (int)Test[Loop].NumErrors));
+            }
         }
 
     Test_parameters = NULL; /* clear it. */
-    MESSAGE(2, ("\n\n"))
 
-    if (num_errs)
-        print_func("!!! %d Error(s) were detected !!!\n\n", (int)num_errs);
-    else
-        print_func("All tests were successful. \n\n");
+    if (mpi_rank_framework_g == 0) {
+        MESSAGE(2, ("\n\n"));
+        if (num_errs)
+            print_func("!!! %d Error(s) were detected !!!\n\n", (int)num_errs);
+        else
+            print_func("All tests were successful. \n\n");
+    }
 }
 
 /*
@@ -366,7 +366,8 @@ TestCleanup(void)
 {
     unsigned Loop;
 
-    MESSAGE(2, ("\nCleaning Up temp files...\n\n"));
+    if (mpi_rank_framework_g == 0)
+        MESSAGE(2, ("\nCleaning Up temp files...\n\n"));
 
     /* call individual cleanup routines in each source module */
     for (Loop = 0; Loop < Index; Loop++)
@@ -381,7 +382,7 @@ void
 TestShutdown(void)
 {
     if (Test)
-        HDfree(Test);
+        free(Test);
 }
 
 /*
@@ -453,13 +454,13 @@ GetTestExpress(void)
 #endif
 
         /* Check if HDF5TestExpress is set to override the default level */
-        env_val = HDgetenv("HDF5TestExpress");
+        env_val = getenv("HDF5TestExpress");
         if (env_val) {
-            if (HDstrcmp(env_val, "0") == 0)
+            if (strcmp(env_val, "0") == 0)
                 express_val = 0;
-            else if (HDstrcmp(env_val, "1") == 0)
+            else if (strcmp(env_val, "1") == 0)
                 express_val = 1;
-            else if (HDstrcmp(env_val, "2") == 0)
+            else if (strcmp(env_val, "2") == 0)
                 express_val = 2;
             else
                 express_val = 3;
@@ -533,7 +534,7 @@ ParseTestVerbosity(char *argv)
     else if (*argv == 'h')
         SetTestVerbosity(VERBO_HI);
     else
-        SetTestVerbosity(HDatoi(argv));
+        SetTestVerbosity(atoi(argv));
 }
 
 /*
@@ -577,9 +578,9 @@ TestErrPrintf(const char *format, ...)
     num_errs++;
 
     /* Print the requested information */
-    HDva_start(arglist, format);
-    ret_value = HDvprintf(format, arglist);
-    HDva_end(arglist);
+    va_start(arglist, format);
+    ret_value = vprintf(format, arglist);
+    va_end(arglist);
 
     /* Return the length of the string produced (like printf() does) */
     return ret_value;
@@ -589,7 +590,7 @@ TestErrPrintf(const char *format, ...)
  * Set (control) which test will be tested.
  * SKIPTEST: skip this test
  * ONLYTEST: do only this test
- * BEGINETEST: skip all tests before this test
+ * BEGINTEST: skip all tests before this test
  *
  */
 void
@@ -600,14 +601,14 @@ SetTest(const char *testname, int action)
     switch (action) {
         case SKIPTEST:
             for (Loop = 0; Loop < Index; Loop++)
-                if (HDstrcmp(testname, Test[Loop].Name) == 0) {
+                if (strcmp(testname, Test[Loop].Name) == 0) {
                     Test[Loop].SkipFlag = 1;
                     break;
                 }
             break;
         case BEGINTEST:
             for (Loop = 0; Loop < Index; Loop++) {
-                if (HDstrcmp(testname, Test[Loop].Name) != 0)
+                if (strcmp(testname, Test[Loop].Name) != 0)
                     Test[Loop].SkipFlag = 1;
                 else {
                     /* Found it. Set it to run.  Done. */
@@ -618,7 +619,7 @@ SetTest(const char *testname, int action)
             break;
         case ONLYTEST:
             for (Loop = 0; Loop < Index; Loop++) {
-                if (HDstrcmp(testname, Test[Loop].Name) == 0) {
+                if (strcmp(testname, Test[Loop].Name) == 0) {
                     /* Found it. Set it to run. Break to skip the rest. */
                     Test[Loop].SkipFlag = 0;
                     break;
@@ -627,7 +628,8 @@ SetTest(const char *testname, int action)
             break;
         default:
             /* error */
-            HDprintf("*** ERROR: Unknown action (%d) for SetTest\n", action);
+            if (mpi_rank_framework_g == 0)
+                printf("*** ERROR: Unknown action (%d) for SetTest\n", action);
             break;
     }
 }
@@ -635,21 +637,22 @@ SetTest(const char *testname, int action)
 /* Enable a test timer that will kill long-running tests, the time is configurable
  * via an environment variable.
  *
- * Only useful on POSIX systems where alarm(2) is present.
+ * Only useful on POSIX systems where alarm(2) is present. This does not include
+ * MinGW builds, which will often incorrectly decide that alarm(2) exists.
  */
 void
 TestAlarmOn(void)
 {
 #ifdef H5_HAVE_ALARM
-    char         *env_val   = HDgetenv("HDF5_ALARM_SECONDS"); /* Alarm environment */
-    unsigned long alarm_sec = H5_ALARM_SEC;                   /* Number of seconds before alarm goes off */
+    char         *env_val   = getenv("HDF5_ALARM_SECONDS"); /* Alarm environment */
+    unsigned long alarm_sec = H5_ALARM_SEC;                 /* Number of seconds before alarm goes off */
 
     /* Get the alarm value from the environment variable, if set */
     if (env_val != NULL)
-        alarm_sec = (unsigned)HDstrtoul(env_val, (char **)NULL, 10);
+        alarm_sec = (unsigned)strtoul(env_val, (char **)NULL, 10);
 
     /* Set the number of seconds before alarm goes off */
-    HDalarm((unsigned)alarm_sec);
+    alarm((unsigned)alarm_sec);
 #endif
 }
 
@@ -659,6 +662,6 @@ TestAlarmOff(void)
 {
 #ifdef H5_HAVE_ALARM
     /* Set the number of seconds to zero */
-    HDalarm(0);
+    alarm(0);
 #endif
 }
