@@ -37,11 +37,21 @@
 int
 main(int argc, char *argv[])
 {
+    hid_t fapl_id = H5I_INVALID_HID;
+
+    fapl_id = H5Pcreate(H5P_FILE_ACCESS);
+    CHECK(fapl_id, H5I_INVALID_HID, "H5Pcreate");
+
+    CHECK(H5Pget_vol_cap_flags(fapl_id, &vol_cap_flags_g), FAIL, "H5Pget_vol_cap_flags");
+
+    H5Pclose(fapl_id);
+
     /* Initialize testing framework */
     TestInit(argv[0], NULL, NULL);
 
     /* Tests are generally arranged from least to most complexity... */
     AddTest("config", test_configure, cleanup_configure, "Configure definitions", NULL);
+    AddTest("h5system", test_h5_system, cleanup_h5_system, "H5system routines", NULL);
     AddTest("metadata", test_metadata, cleanup_metadata, "Encoding/decoding metadata", NULL);
     AddTest("checksum", test_checksum, cleanup_checksum, "Checksum algorithm", NULL);
     AddTest("skiplist", test_skiplist, NULL, "Skip Lists", NULL);
@@ -54,7 +64,8 @@ main(int argc, char *argv[])
     AddTest("attr", test_attr, cleanup_attr, "Attributes", NULL);
     AddTest("select", test_select, cleanup_select, "Selections", NULL);
     AddTest("time", test_time, cleanup_time, "Time Datatypes", NULL);
-    AddTest("reference", test_reference, cleanup_reference, "References", NULL);
+    AddTest("ref_deprec", test_reference_deprec, cleanup_reference_deprec, "Deprecated References", NULL);
+    AddTest("ref", test_reference, cleanup_reference, "References", NULL);
     AddTest("vltypes", test_vltypes, cleanup_vltypes, "Variable-Length Datatypes", NULL);
     AddTest("vlstrings", test_vlstrings, cleanup_vlstrings, "Variable-Length Strings", NULL);
     AddTest("iterate", test_iterate, cleanup_iterate, "Group & Attribute Iteration", NULL);
@@ -78,7 +89,7 @@ main(int argc, char *argv[])
         TestSummary();
 
     /* Clean up test files, if allowed */
-    if (GetTestCleanup() && !HDgetenv("HDF5_NOCLEANUP"))
+    if (GetTestCleanup() && !getenv(HDF5_NOCLEANUP))
         TestCleanup();
 
     /* Release test infrastructure */
@@ -87,7 +98,7 @@ main(int argc, char *argv[])
     /* Exit failure if errors encountered; else exit success. */
     /* No need to print anything since PerformTests() already does. */
     if (GetTestNumErrs() > 0)
-        HDexit(EXIT_FAILURE);
+        exit(EXIT_FAILURE);
     else
-        HDexit(EXIT_SUCCESS);
+        exit(EXIT_SUCCESS);
 } /* end main() */
