@@ -22,12 +22,6 @@
    BUGS/LIMITATIONS
 
    EXPORTED ROUTINES
-
-   AUTHOR
-       Quincey Koziol
-
-   MODIFICATION HISTORY
-       12/17/02 - Started coding
  */
 
 #include "testhdf5.h"
@@ -185,7 +179,7 @@ test_refstr_cmp(void)
     H5RS_str_t *rs1; /* Ref-counted string created */
     H5RS_str_t *rs2; /* Ref-counted string created */
     int         cmp; /* Comparison value */
-    ssize_t     len; /* Length of string */
+    size_t      len; /* Length of string */
     herr_t      ret; /* Generic return value */
 
     /* Output message about test being performed */
@@ -241,7 +235,7 @@ test_refstr_wrap(void)
     MESSAGE(5, ("Testing Wrapping Ref-Counted Strings\n"));
 
     /* Initialize buffer */
-    HDstrcpy(buf, "foo");
+    strcpy(buf, "foo");
 
     /* Wrap ref-counted string around existing buffer */
     rs = H5RS_wrap(buf);
@@ -251,8 +245,8 @@ test_refstr_wrap(void)
     s = H5RS_get_str(rs);
     CHECK_PTR(s, "H5RS_get_str");
     CHECK_PTR_EQ(s, buf, "wrapping");
-    cmp = HDstrcmp(s, buf);
-    VERIFY(cmp, 0, "HDstrcmp");
+    cmp = strcmp(s, buf);
+    VERIFY(cmp, 0, "strcmp");
 
     /* Increment reference count (should duplicate string) */
     ret = H5RS_incr(rs);
@@ -267,7 +261,7 @@ test_refstr_wrap(void)
     if (s == buf)
         TestErrPrintf("%d: Should not have gotten the same pointer from reference-counted string!\n",
                       __LINE__);
-    cmp = HDstrcmp(s, buf);
+    cmp = strcmp(s, buf);
     if (cmp <= 0)
         TestErrPrintf("%d: string comparison incorrect!\n", __LINE__);
 
@@ -281,60 +275,225 @@ test_refstr_wrap(void)
 
 /****************************************************************
 **
-**  test_refstr_own(): Test basic H5RS (ref-counted strings) code.
-**      Tests transferring ownership of dynamically allocated strings
-**      to ref-counted strings.
+**  test_refstr_asprintf_cat(): Test basic H5RS (ref-counted strings) code.
+**      Tests appending printf-formatted output to ref-counted strings.
 **
 ****************************************************************/
 static void
-test_refstr_own(void)
+test_refstr_asprintf_cat(void)
 {
-    H5RS_str_t *rs;  /* Ref-counted string created */
-    char       *s;   /* Pointer to string to transfer */
-    const char *t;   /* Temporary pointers to string */
-    int         cmp; /* Comparison value */
-    herr_t      ret; /* Generic return value */
+    H5RS_str_t *rs;       /* Ref-counted string created */
+    const char *s;        /* Pointer to raw string in ref-counted string */
+    char        buf[256]; /* Buffer to compare against */
+    int         cmp;      /* Comparison value */
+    herr_t      ret;      /* Generic return value */
 
     /* Output message about test being performed */
-    MESSAGE(5, ("Testing Transferring Ref-Counted Strings\n"));
+    MESSAGE(5, ("Testing Printf-formatted Output to Ref-Counted Strings\n"));
 
-    /* Initialize buffer */
-    s = (char *)H5FL_BLK_MALLOC(str_buf, HDstrlen("foo") + 1);
-    CHECK_PTR(s, "H5FL_BLK_MALLOC");
-    HDstrcpy(s, "foo");
+    /* Wrap ref-counted string around existing buffer */
+    rs = H5RS_create(NULL);
+    CHECK_PTR(rs, "H5RS_create");
 
-    /* Transfer ownership of dynamically allocated string to ref-counted string */
-    rs = H5RS_own(s);
-    CHECK_PTR(rs, "H5RS_own");
+    /* Print initial output to ref-counted string */
+    ret = H5RS_asprintf_cat(rs, "%d-%s", (int)10, "foo");
+    CHECK(ret, FAIL, "H5RS_asprintf_cat");
 
     /* Get pointer to raw string in ref-counted string */
-    t = H5RS_get_str(rs);
-    CHECK_PTR(t, "H5RS_get_str");
-    CHECK_PTR_EQ(t, s, "transferring");
-    cmp = HDstrcmp(s, t);
-    VERIFY(cmp, 0, "HDstrcmp");
+    s = H5RS_get_str(rs);
+    CHECK_PTR(s, "H5RS_get_str");
+    snprintf(buf, sizeof(buf), "%d-%s", (int)10, "foo");
+    cmp = strcmp(s, buf);
+    VERIFY(cmp, 0, "strcmp");
 
-    /* Increment reference count (should NOT duplicate string) */
-    ret = H5RS_incr(rs);
-    CHECK(ret, FAIL, "H5RS_incr");
-
-    /* Change the buffer initially wrapped */
-    *s = 'F';
+    /* Append more output to ref-counted string */
+    ret = H5RS_asprintf_cat(rs, "-%f", (double)20.0);
+    CHECK(ret, FAIL, "H5RS_asprintf_cat");
 
     /* Get pointer to raw string in ref-counted string */
-    t = H5RS_get_str(rs);
-    CHECK_PTR(t, "H5RS_get_str");
-    CHECK_PTR_EQ(t, s, "transferring");
-    cmp = HDstrcmp(t, s);
-    VERIFY(cmp, 0, "HDstrcmp");
+    s = H5RS_get_str(rs);
+    CHECK_PTR(s, "H5RS_get_str");
+    snprintf(buf, sizeof(buf), "%d-%s-%f", (int)10, "foo", (double)20.0);
+    cmp = strcmp(s, buf);
+    VERIFY(cmp, 0, "strcmp");
 
     /* Decrement reference count for string */
     ret = H5RS_decr(rs);
     CHECK(ret, FAIL, "H5RS_decr");
+
+} /* end test_refstr_asprintf_cat() */
+
+/****************************************************************
+**
+**  test_refstr_acat(): Test basic H5RS (ref-counted strings) code.
+**      Tests appending strings to ref-counted strings.
+**
+****************************************************************/
+static void
+test_refstr_acat(void)
+{
+    H5RS_str_t *rs;                     /* Ref-counted string created */
+    const char *s;                      /* Pointer to raw string in ref-counted string */
+    char        buf[256];               /* Buffer to compare against */
+    char       *large_str, *large_str2; /* Large strings to append */
+    int         cmp;                    /* Comparison value */
+    herr_t      ret;                    /* Generic return value */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing Appending Strings to Ref-Counted Strings\n"));
+
+    /* Wrap ref-counted string around existing buffer */
+    rs = H5RS_create(NULL);
+    CHECK_PTR(rs, "H5RS_create");
+
+    /* Append first string to ref-counted string */
+    ret = H5RS_acat(rs, "foo");
+    CHECK(ret, FAIL, "H5RS_acat");
+
+    /* Get pointer to raw string in ref-counted string */
+    s = H5RS_get_str(rs);
+    CHECK_PTR(s, "H5RS_get_str");
+    snprintf(buf, sizeof(buf), "%s", "foo");
+    cmp = strcmp(s, buf);
+    VERIFY(cmp, 0, "strcmp");
+
+    /* Append another string to ref-counted string */
+    ret = H5RS_acat(rs, "bar");
+    CHECK(ret, FAIL, "H5RS_acat");
+
+    /* Get pointer to raw string in ref-counted string */
+    s = H5RS_get_str(rs);
+    CHECK_PTR(s, "H5RS_get_str");
+    snprintf(buf, sizeof(buf), "%s", "foobar");
+    cmp = strcmp(s, buf);
+    VERIFY(cmp, 0, "strcmp");
+
+    /* Append a large string to ref-counted string */
+    large_str = malloc(1024);
+    CHECK_PTR(large_str, "malloc");
+    memset(large_str, 'a', 1024);
+    large_str[1023] = '\0';
+    ret             = H5RS_acat(rs, large_str);
+    CHECK(ret, FAIL, "H5RS_acat");
+
+    /* Get pointer to raw string in ref-counted string */
+    s = H5RS_get_str(rs);
+    CHECK_PTR(s, "H5RS_get_str");
+    snprintf(buf, sizeof(buf), "%s", "foobar");
+    large_str2 = malloc(1024 + 6);
+    CHECK_PTR(large_str2, "malloc");
+    strcpy(large_str2, "foobar");
+    memset(&large_str2[6], 'a', 1024);
+    large_str2[1029] = '\0';
+    cmp              = strcmp(s, large_str2);
+    VERIFY(cmp, 0, "strcmp");
+
+    /* Decrement reference count for string */
     ret = H5RS_decr(rs);
     CHECK(ret, FAIL, "H5RS_decr");
 
-} /* end test_refstr_own() */
+    /* Free large strings */
+    free(large_str);
+    free(large_str2);
+} /* end test_refstr_acat() */
+
+/****************************************************************
+**
+**  test_refstr_ancat(): Test basic H5RS (ref-counted strings) code.
+**      Tests appending length-limited strings to ref-counted strings.
+**
+****************************************************************/
+static void
+test_refstr_ancat(void)
+{
+    H5RS_str_t *rs;       /* Ref-counted string created */
+    const char *s;        /* Pointer to raw string in ref-counted string */
+    char        buf[256]; /* Buffer to compare against */
+    int         cmp;      /* Comparison value */
+    herr_t      ret;      /* Generic return value */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing Appending Strings to Ref-Counted Strings\n"));
+
+    /* Wrap ref-counted string around existing buffer */
+    rs = H5RS_create(NULL);
+    CHECK_PTR(rs, "H5RS_create");
+
+    /* Append first string to ref-counted string */
+    ret = H5RS_ancat(rs, "foo", 2);
+    CHECK(ret, FAIL, "H5RS_ancat");
+
+    /* Get pointer to raw string in ref-counted string */
+    s = H5RS_get_str(rs);
+    CHECK_PTR(s, "H5RS_get_str");
+    strcpy(buf, "fo");
+    cmp = strcmp(s, buf);
+    VERIFY(cmp, 0, "strcmp");
+
+    /* Append another string to ref-counted string */
+    ret = H5RS_ancat(rs, "bar", 2);
+    CHECK(ret, FAIL, "H5RS_ancat");
+
+    /* Get pointer to raw string in ref-counted string */
+    s = H5RS_get_str(rs);
+    CHECK_PTR(s, "H5RS_get_str");
+    strcpy(buf, "foba");
+    cmp = strcmp(s, buf);
+    VERIFY(cmp, 0, "strcmp");
+
+    /* Decrement reference count for string */
+    ret = H5RS_decr(rs);
+    CHECK(ret, FAIL, "H5RS_decr");
+} /* end test_refstr_ancat() */
+
+/****************************************************************
+**
+**  test_refstr_aputc(): Test basic H5RS (ref-counted strings) code.
+**      Tests appending characters to ref-counted strings.
+**
+****************************************************************/
+static void
+test_refstr_aputc(void)
+{
+    H5RS_str_t *rs;       /* Ref-counted string created */
+    const char *s;        /* Pointer to raw string in ref-counted string */
+    char        buf[256]; /* Buffer to compare against */
+    int         cmp;      /* Comparison value */
+    herr_t      ret;      /* Generic return value */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing Appending Strings to Ref-Counted Strings\n"));
+
+    /* Wrap ref-counted string around existing buffer */
+    rs = H5RS_create(NULL);
+    CHECK_PTR(rs, "H5RS_create");
+
+    /* Append first character to ref-counted string */
+    ret = H5RS_aputc(rs, 'f');
+    CHECK(ret, FAIL, "H5RS_ancat");
+
+    /* Get pointer to raw string in ref-counted string */
+    s = H5RS_get_str(rs);
+    CHECK_PTR(s, "H5RS_get_str");
+    strcpy(buf, "f");
+    cmp = strcmp(s, buf);
+    VERIFY(cmp, 0, "strcmp");
+
+    /* Append another character to ref-counted string */
+    ret = H5RS_aputc(rs, 'o');
+    CHECK(ret, FAIL, "H5RS_ancat");
+
+    /* Get pointer to raw string in ref-counted string */
+    s = H5RS_get_str(rs);
+    CHECK_PTR(s, "H5RS_get_str");
+    strcpy(buf, "fo");
+    cmp = strcmp(s, buf);
+    VERIFY(cmp, 0, "strcmp");
+
+    /* Decrement reference count for string */
+    ret = H5RS_decr(rs);
+    CHECK(ret, FAIL, "H5RS_decr");
+} /* end test_refstr_aputc() */
 
 /****************************************************************
 **
@@ -362,12 +521,15 @@ test_refstr(void)
     test_refstr_init();
 
     /* Actual ref-counted strings tests */
-    test_refstr_create(); /* Test ref-counted string creation */
-    test_refstr_count();  /* Test ref-counted string counting */
-    test_refstr_dup();    /* Test ref-counted string duplication */
-    test_refstr_cmp();    /* Test ref-counted string comparison */
-    test_refstr_wrap();   /* Test ref-counted string wrapping */
-    test_refstr_own();    /* Test ref-counted string ownership transfer */
+    test_refstr_create();       /* Test ref-counted string creation */
+    test_refstr_count();        /* Test ref-counted string counting */
+    test_refstr_dup();          /* Test ref-counted string duplication */
+    test_refstr_cmp();          /* Test ref-counted string comparison */
+    test_refstr_wrap();         /* Test ref-counted string wrapping */
+    test_refstr_asprintf_cat(); /* Test ref-counted string printf-formatted output */
+    test_refstr_acat();         /* Test ref-counted string appends */
+    test_refstr_ancat();        /* Test ref-counted length-limited string appends */
+    test_refstr_aputc();        /* Test ref-counted character appends */
 
     /* Finalize ref-counted strings testing data */
     test_refstr_finalize();
