@@ -21,11 +21,6 @@
 
    EXPORTED ROUTINES
 
-   AUTHOR
-       Quincey Koziol
-
-   MODIFICATION HISTORY
-       11/15/04 - Started coding
  */
 
 #include "testhdf5.h"
@@ -66,15 +61,15 @@ test_skiplist_init(void)
     size_t   u, v;      /* Local index variables */
 
     /* Allocate arrays */
-    rand_num = (int *)HDmalloc(sizeof(int) * NUM_ELEMS);
-    CHECK_PTR(rand_num, "HDmalloc");
-    sort_rand_num = (int *)HDmalloc(sizeof(int) * NUM_ELEMS);
-    CHECK_PTR(sort_rand_num, "HDmalloc");
-    rev_sort_rand_num = (int *)HDmalloc(sizeof(int) * NUM_ELEMS);
-    CHECK_PTR(rev_sort_rand_num, "HDmalloc");
+    rand_num = (int *)malloc(sizeof(int) * NUM_ELEMS);
+    CHECK_PTR(rand_num, "malloc");
+    sort_rand_num = (int *)malloc(sizeof(int) * NUM_ELEMS);
+    CHECK_PTR(sort_rand_num, "malloc");
+    rev_sort_rand_num = (int *)malloc(sizeof(int) * NUM_ELEMS);
+    CHECK_PTR(rev_sort_rand_num, "malloc");
 
     /* Initialize random number seed */
-    curr_time = HDtime(NULL);
+    curr_time = time(NULL);
     HDsrandom((unsigned)curr_time);
 
     /* Create randomized set of numbers */
@@ -97,16 +92,16 @@ test_skiplist_init(void)
     } /* end for */
 
     /* Copy random values to sorted array */
-    HDmemcpy(sort_rand_num, rand_num, sizeof(int) * NUM_ELEMS);
+    memcpy(sort_rand_num, rand_num, sizeof(int) * NUM_ELEMS);
 
     /* Sort random numbers */
-    HDqsort(sort_rand_num, (size_t)NUM_ELEMS, sizeof(int), tst_sort);
+    qsort(sort_rand_num, (size_t)NUM_ELEMS, sizeof(int), tst_sort);
 
     /* Copy random values to reverse sorted array */
-    HDmemcpy(rev_sort_rand_num, rand_num, sizeof(int) * NUM_ELEMS);
+    memcpy(rev_sort_rand_num, rand_num, sizeof(int) * NUM_ELEMS);
 
     /* Sort random numbers */
-    HDqsort(rev_sort_rand_num, (size_t)NUM_ELEMS, sizeof(int), tst_rev_sort);
+    qsort(rev_sort_rand_num, (size_t)NUM_ELEMS, sizeof(int), tst_rev_sort);
 } /* end test_skiplist_init() */
 
 /****************************************************************
@@ -536,9 +531,9 @@ test_skiplist_string(void)
         const char *s;
     } string_node;
     string_node  data[10]        = {{10, "10"}, {20, "20"}, {15, "15"}, {5, "05"},  {50, "50"},
-                            {30, "30"}, {31, "31"}, {32, "32"}, {80, "80"}, {90, "90"}};
+                                    {30, "30"}, {31, "31"}, {32, "32"}, {80, "80"}, {90, "90"}};
     string_node  hashed_data[10] = {{5, "05"},  {10, "10"}, {15, "15"}, {20, "20"}, {30, "30"},
-                                   {31, "31"}, {32, "32"}, {50, "50"}, {80, "80"}, {90, "90"}};
+                                    {31, "31"}, {32, "32"}, {50, "50"}, {80, "80"}, {90, "90"}};
     string_node *found_item; /* Item found in skip list */
     herr_t       ret;        /* Generic return value */
 
@@ -760,9 +755,9 @@ test_skiplist_obj(void)
     size_t       num;   /* Number of elements in skip list */
     size_t       u;     /* Local index variable */
     H5_obj_t     data[10]        = {{10, 12}, {20, 12}, {10, 32}, {10, 11}, {50, 1},
-                         {8, 12},  {31, 12}, {20, 11}, {31, 11}, {8, 32}};
+                                    {8, 12},  {31, 12}, {20, 11}, {31, 11}, {8, 32}};
     H5_obj_t     sorted_data[10] = {{8, 12},  {8, 32},  {10, 11}, {10, 12}, {10, 32},
-                                {20, 11}, {20, 12}, {31, 11}, {31, 12}, {50, 1}};
+                                    {20, 11}, {20, 12}, {31, 11}, {31, 12}, {50, 1}};
     H5_obj_t    *found_item; /* Item found in skip list */
     herr_t       ret;        /* Generic return value */
 
@@ -841,9 +836,9 @@ test_skiplist_generic(void)
     size_t       num;   /* Number of elements in skip list */
     size_t       u;     /* Local index variable */
     generic_t    data[10]        = {{10, 1},   {20, 13}, {15, 32}, {5, 2},   {50, 37},
-                          {30, 100}, {31, 38}, {32, 34}, {80, 32}, {90, 0}};
+                                    {30, 100}, {31, 38}, {32, 34}, {80, 32}, {90, 0}};
     generic_t    sorted_data[10] = {{30, 100}, {15, 32}, {31, 38}, {32, 34}, {5, 2},
-                                 {20, 13},  {10, 1},  {50, 37}, {80, 32}, {90, 0}};
+                                    {20, 13},  {10, 1},  {50, 37}, {80, 32}, {90, 0}};
     generic_t   *found_item; /* Item found in skip list */
     herr_t       ret;        /* Generic return value */
 
@@ -1162,213 +1157,6 @@ test_skiplist_free(void)
 
 } /* end test_skiplist_free() */
 
-/****************************************************************
-**
-**  test_skiplist_try_free_safe(): Test H5SL (skip list) code.
-**      Tests 'try_free_safe' operation in skip lists.
-**
-****************************************************************/
-/* Macro definitions */
-#define TEST_TFS_MAX_NOBJS 100
-#define TEST_TFS_MIN_NOBJS 5
-#define TEST_TFS_NITER     50
-
-/* Structure to hold the list of objects */
-typedef struct {
-    H5SL_t                *slist;     /* Skiplist holding the objects */
-    struct test_tfs_obj_t *list;      /* Linear list of objects */
-    int                    nobjs;     /* Number of objects in list */
-    int                    nobjs_rem; /* Number of objects in list that have not been freed */
-} test_tfs_list_t;
-
-/* Structure for an object */
-typedef struct test_tfs_obj_t {
-    int idx;    /* Index (key) for this object */
-    int nfrees; /* Number of times this object has been freed */
-} test_tfs_obj_t;
-
-/* op_data struct for H5SL_iterate() */
-typedef struct test_tfs_it_ud_t {
-    test_tfs_list_t *obj_list; /* List of objects */
-    int              last_idx; /* Index of last object visited in iteration */
-    int              ncalls;   /* Number of times this callback was called */
-} test_tfs_it_ud_t;
-
-/* iterate callback */
-static herr_t
-test_tfs_iter(void *_obj, void *key, void *_udata)
-{
-    test_tfs_obj_t   *obj   = (test_tfs_obj_t *)_obj;
-    test_tfs_it_ud_t *udata = (test_tfs_it_ud_t *)_udata;
-
-    /* Check consistency */
-    CHECK_PTR_EQ((void *)&obj->idx, key, "obj->idx");
-    CHECK_PTR_EQ(obj, &udata->obj_list->list[obj->idx], "obj_list->list[obj->idx]");
-
-    /* Increment number of calls */
-    udata->ncalls++;
-
-    /* Verify we were given the correct object */
-    do {
-        udata->last_idx++;
-    } while (udata->obj_list->list[udata->last_idx].nfrees != 0);
-    VERIFY(udata->last_idx, obj->idx, "H5SL_iterate");
-
-    return 0;
-} /* end test_tfs_iter() */
-
-/* try_free_safe callback */
-static htri_t
-test_tfs_free(void *_obj, void *key, void *_obj_list)
-{
-    test_tfs_obj_t  *obj      = (test_tfs_obj_t *)_obj;
-    test_tfs_list_t *obj_list = (test_tfs_list_t *)_obj_list;
-    test_tfs_it_ud_t iter_ud;
-    int              nrems, rem_idx, i, j;
-    test_tfs_obj_t  *obj_ret;
-    herr_t           ret; /* return value */
-    htri_t           ret_value;
-
-    /* Check consistency */
-    CHECK_PTR_EQ((void *)&obj->idx, key, "obj->idx");
-    CHECK_PTR_EQ(obj, &obj_list->list[obj->idx], "obj_list->list[obj->idx]");
-
-    /* Mark this object as freed (to make sure it isn't recursively freed, that
-     * is not something we support, we will undo this if we decide later not to
-     * free the object) */
-    obj->nfrees++;
-    obj_list->nobjs_rem--;
-
-    /* Decide how many objects to remove */
-    nrems = (int)(HDrandom() % (long)3);
-
-    /* Remove objects */
-    for (i = 0; i < nrems; i++)
-        /* Check nobjs_rem */
-        if (obj_list->nobjs_rem > 0) {
-            /* Remove a random object from the list */
-            rem_idx = (int)(HDrandom() % (long)obj_list->nobjs_rem);
-
-            /* Scan the list, finding the rem_idx'th object that has not been
-             * freed */
-            for (j = 0; j < obj_list->nobjs; j++)
-                if (obj_list->list[j].nfrees == 0) {
-                    if (rem_idx == 0)
-                        break;
-                    else
-                        rem_idx--;
-                } /* end if */
-            if (j == obj_list->nobjs)
-                ERROR("invalid obj_list");
-            else {
-                /* Remove the object */
-                obj_ret = (test_tfs_obj_t *)H5SL_remove(obj_list->slist, &j);
-                CHECK_PTR(obj_ret, "H5SL_remove");
-                obj_ret->nfrees++;
-                obj_list->nobjs_rem--;
-            } /* end else */
-        }     /* end if */
-
-    /* Mark this object as not freed so we know to expect it in the iterate call
-     */
-    obj->nfrees--;
-    obj_list->nobjs_rem++;
-
-    /* Iterate over skip list (maybe) */
-    if (HDrandom() % (long)5) {
-        iter_ud.obj_list = obj_list;
-        iter_ud.last_idx = -1;
-        iter_ud.ncalls   = 0;
-        ret              = H5SL_iterate(obj_list->slist, test_tfs_iter, &iter_ud);
-        CHECK(ret, FAIL, "H5SL_iterate");
-        VERIFY(iter_ud.ncalls, obj_list->nobjs_rem, "H5SL_iterate");
-    } /* end if */
-
-    /* Verify nobjs_rem is non-negative */
-    if (obj_list->nobjs_rem < 0)
-        ERROR("invalid nobjs_rem");
-
-    /* Decide whether this object should be freed */
-    if (HDrandom() % (long)2) {
-        /* Free the object */
-        ret_value = TRUE;
-        obj->nfrees++;
-        obj_list->nobjs_rem--;
-    } /* end if */
-    else
-        /* Do not free the object */
-        ret_value = FALSE;
-
-    return ret_value;
-} /* end test_tfs_free() */
-
-/* Test function */
-static void
-test_skiplist_try_free_safe(void)
-{
-    test_tfs_list_t obj_list;
-    test_tfs_obj_t  list[TEST_TFS_MAX_NOBJS];
-    int             i, j;
-    int             nobjs_found;
-    hsize_t         count;
-    herr_t          ret; /* Generic return value */
-
-    /* Output message about test being performed */
-    MESSAGE(7, ("Testing Skip List 'Try Free Safe' Operation\n"));
-
-    /* Create a skip list */
-    obj_list.slist = H5SL_create(H5SL_TYPE_INT, NULL);
-    CHECK_PTR(obj_list.slist, "H5SL_create");
-
-    /* Init obj_list.list */
-    obj_list.list = list;
-    for (j = 0; j < TEST_TFS_MAX_NOBJS; j++)
-        list[j].idx = j;
-
-    for (i = 0; i < TEST_TFS_NITER; i++) {
-        /* Build object list */
-        obj_list.nobjs = obj_list.nobjs_rem =
-            (int)(TEST_TFS_MIN_NOBJS + (HDrandom() % (long)(TEST_TFS_MAX_NOBJS - TEST_TFS_MIN_NOBJS + 1)));
-        for (j = 0; j < obj_list.nobjs; j++) {
-            list[j].nfrees = 0;
-            ret            = H5SL_insert(obj_list.slist, &list[j], &list[j].idx);
-            CHECK(ret, FAIL, "H5SL_insert");
-        } /* end for */
-
-        /* Call H5S_try_free_safe() - free most of the items in the skip list in
-         * a safe manner */
-        ret = H5SL_try_free_safe(obj_list.slist, test_tfs_free, &obj_list);
-        CHECK(ret, FAIL, "H5SL_try_free_safe");
-
-        /* Verify list */
-        nobjs_found = 0;
-        for (j = 0; j < obj_list.nobjs; j++)
-            if (list[j].nfrees == 0)
-                nobjs_found++;
-            else
-                VERIFY(list[j].nfrees, (long)1, "list[j].nfrees");
-
-        /* Verify number of objects */
-        VERIFY(obj_list.nobjs_rem, nobjs_found, "obj_list.nobjs_rem");
-        count = H5SL_count(obj_list.slist);
-        VERIFY(count, (size_t)nobjs_found, "H5SL_count");
-
-        /* Release the skip list, forcibly freeing all nodes (will not make
-         * callbacks) */
-        ret = H5SL_release(obj_list.slist);
-        CHECK(ret, FAIL, "H5SL_release");
-
-        /* Verify number of objects is 0 */
-        count = H5SL_count(obj_list.slist);
-        VERIFY(count, (size_t)0, "H5SL_count");
-    } /* end for */
-
-    /* Close the skip list */
-    ret = H5SL_close(obj_list.slist);
-    CHECK(ret, FAIL, "H5SL_close");
-
-} /* end test_skiplist_try_free_safe() */
-
 /****************************************************************
 **
 **  test_skiplist_less(): Test H5SL (skip list) code.
@@ -1731,7 +1519,7 @@ test_skiplist_remove_first_many(void)
     /* Remove objects from the skip list */
     for (u = 0; u < NUM_ELEMS; u++) {
         found_item = (int *)H5SL_remove_first(slist);
-        VERIFY(*found_item > prev_item, TRUE, "H5SL_remove_first");
+        VERIFY(*found_item > prev_item, true, "H5SL_remove_first");
         prev_item = *found_item;
     } /* end for */
 
@@ -1756,11 +1544,11 @@ test_skiplist_term(void)
 {
     /* Release arrays */
     if (rand_num)
-        HDfree(rand_num);
+        free(rand_num);
     if (sort_rand_num)
-        HDfree(sort_rand_num);
+        free(sort_rand_num);
     if (rev_sort_rand_num)
-        HDfree(rev_sort_rand_num);
+        free(rev_sort_rand_num);
 } /* end test_skiplist_term() */
 
 /****************************************************************
@@ -1795,7 +1583,6 @@ test_skiplist(void)
     test_skiplist_add();               /* Test 'add' operation */
     test_skiplist_destroy();           /* Test 'destroy' operation */
     test_skiplist_free();              /* Test 'free' operation */
-    test_skiplist_try_free_safe();     /* Test 'try_free_safe' operation */
     test_skiplist_less();              /* Test 'less' operation */
     test_skiplist_greater();           /* Test 'greater' operation */
     test_skiplist_below();             /* Test 'below' operation */
