@@ -150,7 +150,7 @@ test_time_io(void)
     CHECK(dsid, FAIL, "H5Dcreate2");
 
     /* Initialize time data value */
-    timenow = HDtime(NULL);
+    timenow = time(NULL);
 
     /* Write time to dataset */
     status = H5Dwrite(dsid, H5T_UNIX_D32LE, H5S_ALL, H5S_ALL, H5P_DEFAULT, &timenow);
@@ -176,13 +176,13 @@ test_time_io(void)
     tid = H5Dget_type(dsid);
     CHECK(tid, FAIL, "H5Dget_type");
     if (H5Tget_class(tid) == H5T_TIME)
-        HDfprintf(stderr, "datatype class is H5T_TIME\n");
+        fprintf(stderr, "datatype class is H5T_TIME\n");
     status = H5Tclose(tid);
     CHECK(status, FAIL, "H5Tclose");
 
     status = H5Dread(dsid, H5T_UNIX_D32LE, H5S_ALL, H5S_ALL, H5P_DEFAULT, &timethen);
     CHECK(status, FAIL, "H5Dread");
-    HDfprintf(stderr, "time written was: %s\n", HDctime(&timethen));
+    fprintf(stderr, "time written was: %s\n", ctime(&timethen));
 
     status = H5Dclose(dsid);
     CHECK(status, FAIL, "H5Dclose");
@@ -217,15 +217,14 @@ test_time(void)
  *
  * Return:    none
  *
- * Programmer:    Quincey Koziol
- *              October 19, 2000
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 void
 cleanup_time(void)
 {
-    HDremove(DATAFILE);
+    H5E_BEGIN_TRY
+    {
+        H5Fdelete(DATAFILE, H5P_DEFAULT);
+    }
+    H5E_END_TRY
 }
