@@ -33,7 +33,7 @@
 #define RANK            1
 #define COMP_INT_VAL    7
 #define COMP_FLOAT_VAL  (-42.0F)
-#define COMP_DOUBLE_VAL 42.0F
+#define COMP_DOUBLE_VAL 42.0
 
 /* Test function prototypes */
 void test_fl_string(hid_t fid, const char *string);
@@ -94,7 +94,7 @@ test_fl_string(hid_t fid, const char *string)
     ret = H5Dread(dset_id, dtype_id, H5S_ALL, H5S_ALL, H5P_DEFAULT, read_buf);
     CHECK(ret, FAIL, "H5Dread");
 
-    VERIFY(HDstrcmp(string, read_buf), 0, "strcmp");
+    VERIFY(strcmp(string, read_buf), 0, "strcmp");
 
     /* Close all */
     ret = H5Dclose(dset_id);
@@ -137,14 +137,14 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
      * the right number of bytes (even or odd, depending on the test).
      * We create a 'new_string' whose length is convenient by prepending
      * an 'x' to 'string' when necessary. */
-    length = HDstrlen(string);
+    length = strlen(string);
     if (length % 2 != 1) {
-        HDstrcpy(new_string, "x");
-        HDstrcat(new_string, string);
+        strcpy(new_string, "x");
+        strcat(new_string, string);
         length++;
     }
     else {
-        HDstrcpy(new_string, string);
+        strcpy(new_string, string);
     }
 
     /* Convert a null-terminated string to a shorter and longer null
@@ -152,7 +152,7 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
 
     /* Create a src_type that holds the UTF-8 string and its final NULL */
     big_len = length + 1; /* +1 byte for final NULL */
-    HDassert((2 * big_len) <= sizeof(cmpbuf));
+    assert((2 * big_len) <= sizeof(cmpbuf));
     src_type = mkstr(big_len, H5T_STR_NULLTERM);
     CHECK(src_type, FAIL, "mkstr");
     /* Create a dst_type that holds half of the UTF-8 string and a final
@@ -163,8 +163,8 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
 
     /* Fill the buffer with two copies of the UTF-8 string, each with a
      * terminating NULL.  It will look like "abcdefg\0abcdefg\0". */
-    HDstrncpy(buf, new_string, big_len);
-    HDstrncpy(&buf[big_len], new_string, big_len);
+    strncpy(buf, new_string, big_len);
+    strncpy(&buf[big_len], new_string, big_len);
 
     ret = H5Tconvert(src_type, dst_type, (size_t)2, buf, NULL, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Tconvert");
@@ -174,13 +174,13 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
      * like; UTF-8 characters may well have been truncated.
      * To check that the conversion worked properly, we'll build this
      * string manually. */
-    HDstrncpy(cmpbuf, new_string, small_len - 1);
+    strncpy(cmpbuf, new_string, small_len - 1);
     cmpbuf[small_len - 1] = '\0';
-    HDstrncpy(&cmpbuf[small_len], new_string, small_len - 1);
+    strncpy(&cmpbuf[small_len], new_string, small_len - 1);
     cmpbuf[2 * small_len - 1] = '\0';
-    HDstrcpy(&cmpbuf[2 * small_len], new_string);
+    strcpy(&cmpbuf[2 * small_len], new_string);
 
-    VERIFY(HDmemcmp(buf, cmpbuf, 2 * big_len), 0, "HDmemcmp");
+    VERIFY(memcmp(buf, cmpbuf, 2 * big_len), 0, "memcmp");
 
     /* Now convert from smaller datatype to bigger datatype.  This should
      * leave our buffer looking like: "abc\0\0\0\0\0abc\0\0\0\0\0" */
@@ -188,12 +188,12 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
     CHECK(ret, FAIL, "H5Tconvert");
 
     /* First fill the buffer with NULLs */
-    HDmemset(cmpbuf, '\0', (size_t)LONG_BUF_SIZE);
+    memset(cmpbuf, '\0', (size_t)LONG_BUF_SIZE);
     /* Copy in the characters */
-    HDstrncpy(cmpbuf, new_string, small_len - 1);
-    HDstrncpy(&cmpbuf[big_len], new_string, small_len - 1);
+    strncpy(cmpbuf, new_string, small_len - 1);
+    strncpy(&cmpbuf[big_len], new_string, small_len - 1);
 
-    VERIFY(HDmemcmp(buf, cmpbuf, 2 * big_len), 0, "HDmemcmp");
+    VERIFY(memcmp(buf, cmpbuf, 2 * big_len), 0, "memcmp");
 
     ret = H5Tclose(src_type);
     CHECK(ret, FAIL, "H5Tclose");
@@ -203,19 +203,19 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
     /* Now test null padding.  Null-padded strings do *not* need
      * terminating NULLs, so the sizes of the datatypes are slightly
      * different and we want a string with an even number of characters. */
-    length = HDstrlen(string);
+    length = strlen(string);
     if (length % 2 != 0) {
-        HDstrcpy(new_string, "x");
-        HDstrcat(new_string, string);
+        strcpy(new_string, "x");
+        strcat(new_string, string);
         length++;
     }
     else {
-        HDstrcpy(new_string, string);
+        strcpy(new_string, string);
     }
 
     /* Create a src_type that holds the UTF-8 string */
     big_len = length;
-    HDassert((2 * big_len) <= sizeof(cmpbuf));
+    assert((2 * big_len) <= sizeof(cmpbuf));
     src_type = mkstr(big_len, H5T_STR_NULLPAD);
     CHECK(src_type, FAIL, "mkstr");
     /* Create a dst_type that holds half of the UTF-8 string */
@@ -225,8 +225,8 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
 
     /* Fill the buffer with two copies of the UTF-8 string.
      * It will look like "abcdefghabcdefgh". */
-    HDstrncpy(buf, new_string, big_len);
-    HDstrncpy(&buf[big_len], new_string, big_len);
+    strncpy(buf, new_string, big_len);
+    strncpy(&buf[big_len], new_string, big_len);
 
     ret = H5Tconvert(src_type, dst_type, (size_t)2, buf, NULL, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Tconvert");
@@ -236,11 +236,11 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
      * like; UTF-8 characters may well have been truncated.
      * To check that the conversion worked properly, we'll build this
      * string manually. */
-    HDstrncpy(cmpbuf, new_string, small_len);
-    HDstrncpy(&cmpbuf[small_len], new_string, small_len);
-    HDstrncpy(&cmpbuf[2 * small_len], new_string, big_len);
+    strncpy(cmpbuf, new_string, small_len);
+    strncpy(&cmpbuf[small_len], new_string, small_len);
+    strncpy(&cmpbuf[2 * small_len], new_string, big_len);
 
-    VERIFY(HDmemcmp(buf, cmpbuf, 2 * big_len), 0, "HDmemcmp");
+    VERIFY(memcmp(buf, cmpbuf, 2 * big_len), 0, "memcmp");
 
     /* Now convert from smaller datatype to bigger datatype.  This should
      * leave our buffer looking like: "abcd\0\0\0\0abcd\0\0\0\0" */
@@ -248,12 +248,12 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
     CHECK(ret, FAIL, "H5Tconvert");
 
     /* First fill the buffer with NULLs */
-    HDmemset(cmpbuf, '\0', (size_t)LONG_BUF_SIZE);
+    memset(cmpbuf, '\0', (size_t)LONG_BUF_SIZE);
     /* Copy in the characters */
-    HDstrncpy(cmpbuf, new_string, small_len);
-    HDstrncpy(&cmpbuf[big_len], new_string, small_len);
+    strncpy(cmpbuf, new_string, small_len);
+    strncpy(&cmpbuf[big_len], new_string, small_len);
 
-    VERIFY(HDmemcmp(buf, cmpbuf, 2 * big_len), 0, "HDmemcmp");
+    VERIFY(memcmp(buf, cmpbuf, 2 * big_len), 0, "memcmp");
 
     ret = H5Tclose(src_type);
     CHECK(ret, FAIL, "H5Tclose");
@@ -270,8 +270,8 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
 
     /* Fill the buffer with two copies of the UTF-8 string.
      * It will look like "abcdefghabcdefgh". */
-    HDstrcpy(buf, new_string);
-    HDstrcpy(&buf[big_len], new_string);
+    strcpy(buf, new_string);
+    strcpy(&buf[big_len], new_string);
 
     ret = H5Tconvert(src_type, dst_type, (size_t)2, buf, NULL, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Tconvert");
@@ -281,11 +281,11 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
      * like; UTF-8 characters may have been truncated.
      * To check that the conversion worked properly, we'll build this
      * string manually. */
-    HDstrncpy(cmpbuf, new_string, small_len);
-    HDstrncpy(&cmpbuf[small_len], new_string, small_len);
-    HDstrncpy(&cmpbuf[2 * small_len], new_string, big_len);
+    strncpy(cmpbuf, new_string, small_len);
+    strncpy(&cmpbuf[small_len], new_string, small_len);
+    strncpy(&cmpbuf[2 * small_len], new_string, big_len);
 
-    VERIFY(HDmemcmp(buf, cmpbuf, 2 * big_len), 0, "HDmemcmp");
+    VERIFY(memcmp(buf, cmpbuf, 2 * big_len), 0, "memcmp");
 
     /* Now convert from smaller datatype to bigger datatype.  This should
      * leave our buffer looking like: "abcd    abcd    " */
@@ -293,12 +293,12 @@ test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
     CHECK(ret, FAIL, "H5Tconvert");
 
     /* First fill the buffer with spaces */
-    HDmemset(cmpbuf, ' ', (size_t)LONG_BUF_SIZE);
+    memset(cmpbuf, ' ', (size_t)LONG_BUF_SIZE);
     /* Copy in the characters */
-    HDstrncpy(cmpbuf, new_string, small_len);
-    HDstrncpy(&cmpbuf[big_len], new_string, small_len);
+    strncpy(cmpbuf, new_string, small_len);
+    strncpy(&cmpbuf[big_len], new_string, small_len);
 
-    VERIFY(HDmemcmp(buf, cmpbuf, 2 * big_len), 0, "HDmemcmp");
+    VERIFY(memcmp(buf, cmpbuf, 2 * big_len), 0, "memcmp");
 
     ret = H5Tclose(src_type);
     CHECK(ret, FAIL, "H5Tclose");
@@ -340,18 +340,18 @@ test_vl_string(hid_t fid, const char *string)
     /* Make certain the correct amount of memory will be used */
     ret = H5Dvlen_get_buf_size(dset_id, type_id, space_id, &size);
     CHECK(ret, FAIL, "H5Dvlen_get_buf_size");
-    VERIFY(size, (hsize_t)HDstrlen(string) + 1, "H5Dvlen_get_buf_size");
+    VERIFY(size, (hsize_t)strlen(string) + 1, "H5Dvlen_get_buf_size");
 
     /* Read dataset from disk */
     ret = H5Dread(dset_id, type_id, H5S_ALL, H5S_ALL, H5P_DEFAULT, read_buf);
     CHECK(ret, FAIL, "H5Dread");
 
     /* Compare data read in */
-    VERIFY(HDstrcmp(string, read_buf[0]), 0, "strcmp");
+    VERIFY(strcmp(string, read_buf[0]), 0, "strcmp");
 
     /* Reclaim the read VL data */
-    ret = H5Dvlen_reclaim(type_id, space_id, H5P_DEFAULT, read_buf);
-    CHECK(ret, FAIL, "H5Dvlen_reclaim");
+    ret = H5Treclaim(type_id, space_id, H5P_DEFAULT, read_buf);
+    CHECK(ret, FAIL, "H5Treclaim");
 
     /* Close all */
     ret = H5Dclose(dset_id);
@@ -382,25 +382,31 @@ test_objnames(hid_t fid, const char *string)
     hsize_t    dims = 1;
     hobj_ref_t obj_ref;
     ssize_t    size;
+    bool       vol_is_native;
     herr_t     ret;
 
+    /* Check if native VOL is being used */
+    CHECK(h5_using_native_vol(H5P_DEFAULT, fid, &vol_is_native), FAIL, "h5_using_native_vol");
+
     /* Create a group with a UTF-8 name */
     grp_id = H5Gcreate2(fid, string, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(grp_id, FAIL, "H5Gcreate2");
 
-    /* Set a comment on the group to test that we can access the group
-     * Also test that UTF-8 comments can be read.
-     */
-    ret = H5Oset_comment_by_name(fid, string, string, H5P_DEFAULT);
-    CHECK(ret, FAIL, "H5Oset_comment_by_name");
-    size = H5Oget_comment_by_name(fid, string, read_buf, (size_t)MAX_STRING_LENGTH, H5P_DEFAULT);
-    CHECK(size, FAIL, "H5Oget_comment_by_name");
+    if (vol_is_native) {
+        /* Set a comment on the group to test that we can access the group
+         * Also test that UTF-8 comments can be read.
+         */
+        ret = H5Oset_comment_by_name(fid, string, string, H5P_DEFAULT);
+        CHECK(ret, FAIL, "H5Oset_comment_by_name");
+        size = H5Oget_comment_by_name(fid, string, read_buf, (size_t)MAX_STRING_LENGTH, H5P_DEFAULT);
+        CHECK(size, FAIL, "H5Oget_comment_by_name");
+
+        VERIFY(strcmp(string, read_buf), 0, "strcmp");
+    }
 
     ret = H5Gclose(grp_id);
     CHECK(ret, FAIL, "H5Gclose");
 
-    VERIFY(HDstrcmp(string, read_buf), 0, "strcmp");
-
     /* Create a new dataset with a UTF-8 name */
     grp1_id = H5Gcreate2(fid, GROUP1_NAME, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(grp1_id, FAIL, "H5Gcreate2");
@@ -441,34 +447,35 @@ test_objnames(hid_t fid, const char *string)
 
     /* Don't close the group -- use it to test that object references
      * can refer to objects named in UTF-8 */
+    if (vol_is_native) {
+        space_id = H5Screate_simple(RANK, &dims, NULL);
+        CHECK(space_id, FAIL, "H5Screate_simple");
+        dset_id =
+            H5Dcreate2(grp2_id, DSET3_NAME, H5T_STD_REF_OBJ, space_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+        CHECK(ret, FAIL, "H5Dcreate2");
 
-    space_id = H5Screate_simple(RANK, &dims, NULL);
-    CHECK(space_id, FAIL, "H5Screate_simple");
-    dset_id =
-        H5Dcreate2(grp2_id, DSET3_NAME, H5T_STD_REF_OBJ, space_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
-    CHECK(ret, FAIL, "H5Dcreate2");
+        /* Create reference to named datatype */
+        ret = H5Rcreate(&obj_ref, grp2_id, string, H5R_OBJECT, (hid_t)-1);
+        CHECK(ret, FAIL, "H5Rcreate");
+        /* Write selection and read it back*/
+        ret = H5Dwrite(dset_id, H5T_STD_REF_OBJ, H5S_ALL, H5S_ALL, H5P_DEFAULT, &obj_ref);
+        CHECK(ret, FAIL, "H5Dwrite");
+        ret = H5Dread(dset_id, H5T_STD_REF_OBJ, H5S_ALL, H5S_ALL, H5P_DEFAULT, &obj_ref);
+        CHECK(ret, FAIL, "H5Dread");
 
-    /* Create reference to named datatype */
-    ret = H5Rcreate(&obj_ref, grp2_id, string, H5R_OBJECT, (hid_t)-1);
-    CHECK(ret, FAIL, "H5Rcreate");
-    /* Write selection and read it back*/
-    ret = H5Dwrite(dset_id, H5T_STD_REF_OBJ, H5S_ALL, H5S_ALL, H5P_DEFAULT, &obj_ref);
-    CHECK(ret, FAIL, "H5Dwrite");
-    ret = H5Dread(dset_id, H5T_STD_REF_OBJ, H5S_ALL, H5S_ALL, H5P_DEFAULT, &obj_ref);
-    CHECK(ret, FAIL, "H5Dread");
+        /* Ensure that we can open named datatype using object reference */
+        type_id = H5Rdereference2(dset_id, H5P_DEFAULT, H5R_OBJECT, &obj_ref);
+        CHECK(type_id, FAIL, "H5Rdereference2");
+        ret = H5Tcommitted(type_id);
+        VERIFY(ret, 1, "H5Tcommitted");
 
-    /* Ensure that we can open named datatype using object reference */
-    type_id = H5Rdereference2(dset_id, H5P_DEFAULT, H5R_OBJECT, &obj_ref);
-    CHECK(type_id, FAIL, "H5Rdereference2");
-    ret = H5Tcommitted(type_id);
-    VERIFY(ret, 1, "H5Tcommitted");
-
-    ret = H5Tclose(type_id);
-    CHECK(type_id, FAIL, "H5Tclose");
-    ret = H5Dclose(dset_id);
-    CHECK(ret, FAIL, "H5Dclose");
-    ret = H5Sclose(space_id);
-    CHECK(ret, FAIL, "H5Sclose");
+        ret = H5Tclose(type_id);
+        CHECK(type_id, FAIL, "H5Tclose");
+        ret = H5Dclose(dset_id);
+        CHECK(ret, FAIL, "H5Dclose");
+        ret = H5Sclose(space_id);
+        CHECK(ret, FAIL, "H5Sclose");
+    }
 
     ret = H5Gclose(grp2_id);
     CHECK(ret, FAIL, "H5Gclose");
@@ -483,9 +490,9 @@ test_objnames(hid_t fid, const char *string)
 
     ret = H5Lcreate_hard(fid, GROUP2_NAME, grp3_id, GROUP2_NAME, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Lcreate_hard");
-    HDstrcpy(path_buf, GROUP2_NAME);
-    HDstrcat(path_buf, "/");
-    HDstrcat(path_buf, string);
+    strcpy(path_buf, GROUP2_NAME);
+    strcat(path_buf, "/");
+    strcat(path_buf, string);
     ret = H5Lcreate_hard(grp3_id, path_buf, H5L_SAME_LOC, string, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Lcreate_hard");
 
@@ -531,7 +538,7 @@ test_attrname(hid_t fid, const char *string)
     CHECK(attr_id, FAIL, "H5Acreate2");
     size = H5Aget_name(attr_id, (size_t)MAX_STRING_LENGTH, read_buf);
     CHECK(size, FAIL, "H5Aget_name");
-    ret = HDstrcmp(read_buf, string);
+    ret = strcmp(read_buf, string);
     VERIFY(ret, 0, "strcmp");
     read_buf[0] = '\0';
 
@@ -540,7 +547,7 @@ test_attrname(hid_t fid, const char *string)
     CHECK(ret, FAIL, "H5Awrite");
     ret = H5Aread(attr_id, dtype_id, read_buf);
     CHECK(ret, FAIL, "H5Aread");
-    ret = HDstrcmp(read_buf, string);
+    ret = strcmp(read_buf, string);
     VERIFY(ret, 0, "strcmp");
 
     /* Clean up */
@@ -585,7 +592,7 @@ test_compound(hid_t fid, const char *string)
     herr_t  ret;
 
     /* Initialize compound data */
-    HDmemset(&s1, 0, sizeof(s1_t)); /* To make purify happy */
+    memset(&s1, 0, sizeof(s1_t)); /* To make purify happy */
     s1.a = COMP_INT_VAL;
     s1.c = COMP_DOUBLE_VAL;
     s1.b = COMP_FLOAT_VAL;
@@ -598,7 +605,7 @@ test_compound(hid_t fid, const char *string)
 
     /* Check that the field name was stored correctly */
     readbuf = H5Tget_member_name(s1_tid, 0);
-    ret     = HDstrcmp(readbuf, string);
+    ret     = strcmp(readbuf, string);
     VERIFY(ret, 0, "strcmp");
     H5free_memory(readbuf);
 
@@ -681,7 +688,7 @@ test_enum(hid_t H5_ATTR_UNUSED fid, const char *string)
     VERIFY(val, E1_WHITE, "H5Tenum_valueof");
     ret = H5Tenum_nameof(type_id, &val, readbuf, (size_t)MAX_STRING_LENGTH);
     CHECK(ret, FAIL, "H5Tenum_nameof");
-    ret = HDstrcmp(readbuf, string);
+    ret = strcmp(readbuf, string);
     VERIFY(ret, 0, "strcmp");
 
     /* Close the datatype */
@@ -708,7 +715,7 @@ test_opaque(hid_t H5_ATTR_UNUSED fid, const char *string)
 
     /* Read the tag back. */
     read_buf = H5Tget_tag(type_id);
-    ret      = HDstrcmp(read_buf, string);
+    ret      = strcmp(read_buf, string);
     VERIFY(ret, 0, "H5Tget_tag");
     H5free_memory(read_buf);
 
@@ -779,15 +786,15 @@ dump_string(const char *string)
     size_t length;
     size_t x;
 
-    HDprintf("The string was:\n %s", string);
-    HDprintf("Or in hex:\n");
+    printf("The string was:\n %s", string);
+    printf("Or in hex:\n");
 
-    length = HDstrlen(string);
+    length = strlen(string);
 
     for (x = 0; x < length; x++)
-        HDprintf("%x ", string[x] & (0x000000FF));
+        printf("%x ", string[x] & (0x000000FF));
 
-    HDprintf("\n");
+    printf("\n");
 }
 
 /* Main test.
@@ -808,9 +815,9 @@ test_unicode(void)
     MESSAGE(5, ("Testing UTF-8 Encoding\n"));
 
     /* Create a random string with length NUM_CHARS */
-    HDsrandom((unsigned)HDtime(NULL));
+    HDsrandom((unsigned)time(NULL));
 
-    HDmemset(test_string, 0, sizeof(test_string));
+    memset(test_string, 0, sizeof(test_string));
     for (x = 0; x < NUM_CHARS; x++) {
         /* We need to avoid unprintable characters (codes 0-31) and the
          * . and / characters, since they aren't allowed in path names.
@@ -859,5 +866,9 @@ test_unicode(void)
 void
 cleanup_unicode(void)
 {
-    HDremove(FILENAME);
+    H5E_BEGIN_TRY
+    {
+        H5Fdelete(FILENAME, H5P_DEFAULT);
+    }
+    H5E_END_TRY
 }
