@@ -38,11 +38,11 @@ print_dimensions(int rank, hsize_t *dims)
         else {
             parallel_print("[");
             for (i = 0; i < rank - 1; i++) {
-                parallel_print(HSIZE_T_FORMAT, dims[i]);
+                parallel_print("%" PRIuHSIZE, dims[i]);
                 parallel_print("x");
             }
 
-            parallel_print(HSIZE_T_FORMAT, dims[rank - 1]);
+            parallel_print("%" PRIuHSIZE, dims[rank - 1]);
             parallel_print("]");
         }
     }
@@ -120,7 +120,11 @@ print_type(hid_t type)
             break;
 
         case H5T_FLOAT:
-            if (H5Tequal(type, H5T_IEEE_F32BE))
+            if (H5Tequal(type, H5T_IEEE_F16BE))
+                parallel_print("H5T_IEEE_F16BE");
+            else if (H5Tequal(type, H5T_IEEE_F16LE))
+                parallel_print("H5T_IEEE_F16LE");
+            else if (H5Tequal(type, H5T_IEEE_F32BE))
                 parallel_print("H5T_IEEE_F32BE");
             else if (H5Tequal(type, H5T_IEEE_F32LE))
                 parallel_print("H5T_IEEE_F32LE");
@@ -128,14 +132,16 @@ print_type(hid_t type)
                 parallel_print("H5T_IEEE_F64BE");
             else if (H5Tequal(type, H5T_IEEE_F64LE))
                 parallel_print("H5T_IEEE_F64LE");
+#ifdef H5_HAVE__FLOAT16
+            else if (H5Tequal(type, H5T_NATIVE_FLOAT16))
+                parallel_print("H5T_NATIVE_FLOAT16");
+#endif
             else if (H5Tequal(type, H5T_NATIVE_FLOAT))
                 parallel_print("H5T_NATIVE_FLOAT");
             else if (H5Tequal(type, H5T_NATIVE_DOUBLE))
                 parallel_print("H5T_NATIVE_DOUBLE");
-#if H5_SIZEOF_LONG_DOUBLE != 0
             else if (H5Tequal(type, H5T_NATIVE_LDOUBLE))
                 parallel_print("H5T_NATIVE_LDOUBLE");
-#endif
             else
                 parallel_print("undefined float");
             break;
@@ -192,7 +198,7 @@ diff_basename(const char *name)
         return NULL;
 
     /* Find the end of the base name */
-    i = HDstrlen(name);
+    i = strlen(name);
     while (i > 0 && '/' == name[i - 1])
         --i;
 
@@ -323,7 +329,7 @@ print_found(hsize_t nfound)
     if (g_Parallel)
         parallel_print("%" PRIuHSIZE " differences found\n", nfound);
     else
-        HDfprintf(stdout, "%" PRIuHSIZE " differences found\n", nfound);
+        fprintf(stdout, "%" PRIuHSIZE " differences found\n", nfound);
 }
 
 /*-----------------------------------------------------------------
