@@ -55,7 +55,9 @@ h5tools_get_little_endian_type(hid_t tid)
             break;
 
         case H5T_FLOAT:
-            if (size == 4)
+            if (size == 2)
+                p_type = H5Tcopy(H5T_IEEE_F16LE);
+            else if (size == 4)
                 p_type = H5Tcopy(H5T_IEEE_F32LE);
             else if (size == 8)
                 p_type = H5Tcopy(H5T_IEEE_F64LE);
@@ -134,7 +136,9 @@ h5tools_get_big_endian_type(hid_t tid)
             break;
 
         case H5T_FLOAT:
-            if (size == 4)
+            if (size == 2)
+                p_type = H5Tcopy(H5T_IEEE_F16BE);
+            else if (size == 4)
                 p_type = H5Tcopy(H5T_IEEE_F32BE);
             else if (size == 8)
                 p_type = H5Tcopy(H5T_IEEE_F64BE);
