@@ -28,18 +28,18 @@
         else {                                                                                               \
             PRINTSTREAM(rawoutstream, "%s %s", (obj), (begin));                                              \
         }                                                                                                    \
-    } while (0);
+    } while (0)
 
 #define end_obj(obj, end)                                                                                    \
     do {                                                                                                     \
-        if (HDstrlen(end)) {                                                                                 \
+        if (strlen(end)) {                                                                                   \
             PRINTSTREAM(rawoutstream, "%s", end);                                                            \
-            if (HDstrlen(obj))                                                                               \
+            if (strlen(obj))                                                                                 \
                 PRINTVALSTREAM(rawoutstream, " ");                                                           \
         }                                                                                                    \
-        if (HDstrlen(obj))                                                                                   \
+        if (strlen(obj))                                                                                     \
             PRINTSTREAM(rawoutstream, "%s", obj);                                                            \
-    } while (0);
+    } while (0)
 
 /* 3 private values: can't be set, but can be read.
    Note: these are defined in H5Zprivate, they are
