@@ -67,12 +67,12 @@
 /* report 0.0 in case t is zero too */
 #define MB_PER_SEC(bytes, t) (H5_DBL_ABS_EQUAL(t, 0.0) ? 0.0 : ((((double)(bytes)) / (double)ONE_MB) / (t)))
 
-#ifndef TRUE
-#define TRUE 1
-#endif /* TRUE */
-#ifndef FALSE
-#define FALSE (!TRUE)
-#endif /* FALSE */
+#ifndef true
+#define true 1
+#endif /* true */
+#ifndef false
+#define false (!true)
+#endif /* false */
 
 /* global variables */
 FILE *output;              /* output file                          */
@@ -97,35 +97,35 @@ static const char *progname = "h5perf_serial";
  * It seems that only the options that accept additional information
  * such as dataset size (-e) require the colon next to it.
  */
-static const char         *s_opts   = "a:A:B:c:Cd:D:e:F:ghi:Imno:p:P:r:stT:v:wx:X:";
-static struct long_options l_opts[] = {{"align", require_arg, 'a'},
-                                       {"api", require_arg, 'A'},
+static const char            *s_opts   = "a:A:B:c:Cd:D:e:F:ghi:Imno:p:P:r:stT:v:wx:X:";
+static struct h5_long_options l_opts[] = {{"align", require_arg, 'a'},
+                                          {"api", require_arg, 'A'},
 #if 0
     /* a sighting of the elusive binary option */
     { "binary", no_arg, 'b' },
 #endif /* 0 */
-                                       {"block-size", require_arg, 'B'},
-                                       {"chunk", no_arg, 'c'},
-                                       {"collective", no_arg, 'C'},
-                                       {"debug", require_arg, 'D'},
-                                       {"file-driver", require_arg, 'v'},
-                                       {"geometry", no_arg, 'g'},
-                                       {"help", no_arg, 'h'},
-                                       {"interleaved", require_arg, 'I'},
-                                       {"max-num-processes", require_arg, 'P'},
-                                       {"min-num-processes", require_arg, 'p'},
-                                       {"max-xfer-size", require_arg, 'X'},
-                                       {"min-xfer-size", require_arg, 'x'},
-                                       {"num-bytes", require_arg, 'e'},
-                                       {"num-dsets", require_arg, 'd'},
-                                       {"num-files", require_arg, 'F'},
-                                       {"num-iterations", require_arg, 'i'},
-                                       {"order", require_arg, 'r'},
-                                       {"output", require_arg, 'o'},
-                                       {"extendable", no_arg, 't'},
-                                       {"threshold", require_arg, 'T'},
-                                       {"write-only", require_arg, 'w'},
-                                       {NULL, 0, '\0'}};
+                                          {"block-size", require_arg, 'B'},
+                                          {"chunk", no_arg, 'c'},
+                                          {"collective", no_arg, 'C'},
+                                          {"debug", require_arg, 'D'},
+                                          {"file-driver", require_arg, 'v'},
+                                          {"geometry", no_arg, 'g'},
+                                          {"help", no_arg, 'h'},
+                                          {"interleaved", require_arg, 'I'},
+                                          {"max-num-processes", require_arg, 'P'},
+                                          {"min-num-processes", require_arg, 'p'},
+                                          {"max-xfer-size", require_arg, 'X'},
+                                          {"min-xfer-size", require_arg, 'x'},
+                                          {"num-bytes", require_arg, 'e'},
+                                          {"num-dsets", require_arg, 'd'},
+                                          {"num-files", require_arg, 'F'},
+                                          {"num-iterations", require_arg, 'i'},
+                                          {"order", require_arg, 'r'},
+                                          {"output", require_arg, 'o'},
+                                          {"extendable", no_arg, 't'},
+                                          {"threshold", require_arg, 'T'},
+                                          {"write-only", require_arg, 'w'},
+                                          {NULL, 0, '\0'}};
 
 struct options {
     long        io_types;            /* bitmask of which I/O types to test   */
@@ -181,8 +181,6 @@ static void report_parameters(struct options *opts);
  * Function:    main
  * Purpose:     Start things up.
  * Return:      EXIT_SUCCESS or EXIT_FAILURE
- * Programmer:  Bill Wendling, 30. October 2001
- * Modifications:
  */
 int
 main(int argc, char *argv[])
@@ -203,9 +201,9 @@ main(int argc, char *argv[])
     }
 
     if (opts->output_file) {
-        if ((output = HDfopen(opts->output_file, "w")) == NULL) {
-            HDfprintf(stderr, "%s: cannot open output file\n", progname);
-            HDperror(opts->output_file);
+        if ((output = fopen(opts->output_file, "w")) == NULL) {
+            fprintf(stderr, "%s: cannot open output file\n", progname);
+            perror(opts->output_file);
             goto finish;
         }
     }
@@ -215,7 +213,7 @@ main(int argc, char *argv[])
     run_test_loop(opts);
 
 finish:
-    HDfree(opts);
+    free(opts);
     return exit_value;
 }
 
@@ -236,9 +234,6 @@ finish:
  *              this out.
  *
  * Return:      Nothing
- * Programmer:  Bill Wendling, 30. October 2001
- * Modifications:
- *    Added multidimensional testing (Christian Chilan, April, 2008)
  */
 static void
 run_test_loop(struct options *opts)
@@ -291,8 +286,6 @@ run_test_loop(struct options *opts)
  * Function:    run_test
  * Purpose:     Inner loop call to actually run the I/O test.
  * Return:      Nothing
- * Programmer:  Bill Wendling, 18. December 2001
- * Modifications:
  */
 static int
 run_test(iotype iot, parameters parms, struct options *opts)
@@ -331,8 +324,8 @@ run_test(iotype iot, parameters parms, struct options *opts)
             break;
         default:
             /* unknown request */
-            HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)iot);
-            HDassert(0 && "Unknown IO tpe");
+            fprintf(stderr, "Unknown IO type request (%d)\n", (int)iot);
+            assert(0 && "Unknown IO tpe");
             break;
     }
 
@@ -504,16 +497,16 @@ run_test(iotype iot, parameters parms, struct options *opts)
     }
 
     /* clean up our mess */
-    HDfree(write_sys_mm_table);
-    HDfree(write_mm_table);
-    HDfree(write_gross_mm_table);
-    HDfree(write_raw_mm_table);
+    free(write_sys_mm_table);
+    free(write_mm_table);
+    free(write_gross_mm_table);
+    free(write_raw_mm_table);
 
     if (!parms.h5_write_only) {
-        HDfree(read_sys_mm_table);
-        HDfree(read_mm_table);
-        HDfree(read_gross_mm_table);
-        HDfree(read_raw_mm_table);
+        free(read_sys_mm_table);
+        free(read_mm_table);
+        free(read_gross_mm_table);
+        free(read_raw_mm_table);
     }
 
     return ret_value;
@@ -523,8 +516,6 @@ run_test(iotype iot, parameters parms, struct options *opts)
  * Function:    output_all_info
  * Purpose:
  * Return:      Nothing
- * Programmer:  Bill Wendling, 29. January 2002
- * Modifications:
  */
 static void
 output_all_info(minmax *mm, int count, int indent_level)
@@ -545,9 +536,6 @@ output_all_info(minmax *mm, int count, int indent_level)
  * Function:    get_minmax
  * Purpose:     Gather all the min, max and total of val.
  * Return:      Nothing
- * Programmer:  Bill Wendling, 21. December 2001
- * Modifications:
- *    Use MPI_Allreduce to do it. -akc, 2002/01/11
  */
 
 static void
@@ -563,9 +551,6 @@ get_minmax(minmax *mm, double val)
  * Purpose:     Accumulate the minimum, maximum, and average of the times
  *              across all processes.
  * Return:      TOTAL_MM - the total of all of these.
- * Programmer:  Bill Wendling, 21. December 2001
- * Modifications:
- *              Changed to use seconds instead of MB/s - QAK, 5/9/02
  */
 static void
 accumulate_minmax_stuff(const minmax *mm, int count, minmax *total_mm)
@@ -595,8 +580,6 @@ accumulate_minmax_stuff(const minmax *mm, int count, minmax *total_mm)
  * Purpose:     Print information about the time & bandwidth for a given
  *                  minmax & # of iterations.
  * Return:      Nothing
- * Programmer:  Quincey Koziol, 9. May 2002
- * Modifications:
  */
 static void
 output_results(const struct options *opts, const char *name, minmax *table, int table_size, off_t data_size)
@@ -636,19 +619,17 @@ output_results(const struct options *opts, const char *name, minmax *table, int
  * Function:    output_report
  * Purpose:     Print a line of the report. Only do so if I'm the 0 process.
  * Return:      Nothing
- * Programmer:  Bill Wendling, 19. December 2001
- * Modifications:
  */
 static void
 output_report(const char *fmt, ...)
 {
     va_list ap;
 
-    HDva_start(ap, fmt);
+    va_start(ap, fmt);
     H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
-    HDvfprintf(output, fmt, ap);
+    vfprintf(output, fmt, ap);
     H5_GCC_CLANG_DIAG_ON("format-nonliteral")
-    HDva_end(ap);
+    va_end(ap);
 }
 
 /*
@@ -656,7 +637,6 @@ output_report(const char *fmt, ...)
  * Purpose:     Print spaces to indent a new line of text for pretty printing
  *              things.
  * Return:      Nothing
- * Programmer:  Bill Wendling, 29. October 2001
  */
 static void
 print_indent(int indent)
@@ -664,7 +644,7 @@ print_indent(int indent)
     indent *= TAB_SPACE;
 
     for (; indent > 0; --indent)
-        HDfputc(' ', output);
+        fputc(' ', output);
 }
 
 static void
@@ -673,28 +653,28 @@ recover_size_and_print(long long val, const char *end)
     if (val >= ONE_KB && (val % ONE_KB) == 0) {
         if (val >= ONE_MB && (val % ONE_MB) == 0) {
             if (val >= ONE_GB && (val % ONE_GB) == 0)
-                HDfprintf(output,
-                          "%lld"
-                          "GB%s",
-                          val / ONE_GB, end);
+                fprintf(output,
+                        "%lld"
+                        "GB%s",
+                        val / ONE_GB, end);
             else
-                HDfprintf(output,
-                          "%lld"
-                          "MB%s",
-                          val / ONE_MB, end);
+                fprintf(output,
+                        "%lld"
+                        "MB%s",
+                        val / ONE_MB, end);
         }
         else {
-            HDfprintf(output,
-                      "%lld"
-                      "KB%s",
-                      val / ONE_KB, end);
+            fprintf(output,
+                    "%lld"
+                    "KB%s",
+                    val / ONE_KB, end);
         }
     }
     else {
-        HDfprintf(output,
-                  "%lld"
-                  "%s",
-                  val, end);
+        fprintf(output,
+                "%lld"
+                "%s",
+                val, end);
     }
 }
 
@@ -702,10 +682,10 @@ static void
 print_io_api(long io_types)
 {
     if (io_types & SIO_POSIX)
-        HDfprintf(output, "posix ");
+        fprintf(output, "posix ");
     if (io_types & SIO_HDF5)
-        HDfprintf(output, "hdf5 ");
-    HDfprintf(output, "\n");
+        fprintf(output, "hdf5 ");
+    fprintf(output, "\n");
 }
 
 static void
@@ -715,95 +695,95 @@ report_parameters(struct options *opts)
     rank = opts->dset_rank;
 
     print_version("HDF5 Library"); /* print library version */
-    HDfprintf(output, "==== Parameters ====\n");
+    fprintf(output, "==== Parameters ====\n");
 
-    HDfprintf(output, "IO API=");
+    fprintf(output, "IO API=");
     print_io_api(opts->io_types);
 
-    HDfprintf(output, "Number of iterations=%d\n", opts->num_iters);
+    fprintf(output, "Number of iterations=%d\n", opts->num_iters);
 
-    HDfprintf(output, "Dataset size=");
+    fprintf(output, "Dataset size=");
 
     for (i = 0; i < rank; i++)
         recover_size_and_print((long long)opts->dset_size[i], " ");
-    HDfprintf(output, "\n");
+    fprintf(output, "\n");
 
-    HDfprintf(output, "Transfer buffer size=");
+    fprintf(output, "Transfer buffer size=");
     for (i = 0; i < rank; i++)
         recover_size_and_print((long long)opts->buf_size[i], " ");
-    HDfprintf(output, "\n");
+    fprintf(output, "\n");
 
     if (opts->page_size) {
-        HDfprintf(output, "Page Aggregation Enabled. Page size = %zu\n", opts->page_size);
+        fprintf(output, "Page Aggregation Enabled. Page size = %zu\n", opts->page_size);
         if (opts->page_buffer_size)
-            HDfprintf(output, "Page Buffering Enabled. Page Buffer size = %zu\n", opts->page_buffer_size);
+            fprintf(output, "Page Buffering Enabled. Page Buffer size = %zu\n", opts->page_buffer_size);
         else
-            HDfprintf(output, "Page Buffering Disabled\n");
+            fprintf(output, "Page Buffering Disabled\n");
     }
     else
-        HDfprintf(output, "Page Aggregation Disabled\n");
+        fprintf(output, "Page Aggregation Disabled\n");
 
-    HDfprintf(output, "Dimension access order=");
+    fprintf(output, "Dimension access order=");
     for (i = 0; i < rank; i++)
         recover_size_and_print((long long)opts->order[i], " ");
-    HDfprintf(output, "\n");
+    fprintf(output, "\n");
 
     if (opts->io_types & SIO_HDF5) {
 
-        HDfprintf(output, "HDF5 data storage method=");
+        fprintf(output, "HDF5 data storage method=");
 
         if (opts->h5_use_chunks) {
 
-            HDfprintf(output, "Chunked\n");
-            HDfprintf(output, "HDF5 chunk size=");
+            fprintf(output, "Chunked\n");
+            fprintf(output, "HDF5 chunk size=");
             for (i = 0; i < rank; i++)
                 recover_size_and_print((long long)opts->chk_size[i], " ");
-            HDfprintf(output, "\n");
+            fprintf(output, "\n");
 
-            HDfprintf(output, "HDF5 dataset dimensions=");
+            fprintf(output, "HDF5 dataset dimensions=");
             if (opts->h5_extendable) {
-                HDfprintf(output, "Extendable\n");
+                fprintf(output, "Extendable\n");
             }
             else {
-                HDfprintf(output, "Fixed\n");
+                fprintf(output, "Fixed\n");
             }
         }
         else {
-            HDfprintf(output, "Contiguous\n");
+            fprintf(output, "Contiguous\n");
         }
 
-        HDfprintf(output, "HDF5 file driver=");
+        fprintf(output, "HDF5 file driver=");
         if (opts->vfd == sec2) {
-            HDfprintf(output, "sec2\n");
+            fprintf(output, "sec2\n");
         }
         else if (opts->vfd == stdio) {
-            HDfprintf(output, "stdio\n");
+            fprintf(output, "stdio\n");
         }
         else if (opts->vfd == core) {
-            HDfprintf(output, "core\n");
+            fprintf(output, "core\n");
         }
         else if (opts->vfd == split) {
-            HDfprintf(output, "split\n");
+            fprintf(output, "split\n");
         }
         else if (opts->vfd == multi) {
-            HDfprintf(output, "multi\n");
+            fprintf(output, "multi\n");
         }
         else if (opts->vfd == family) {
-            HDfprintf(output, "family\n");
+            fprintf(output, "family\n");
         }
         else if (opts->vfd == direct) {
-            HDfprintf(output, "direct\n");
+            fprintf(output, "direct\n");
         }
     }
 
     {
-        char *prefix = HDgetenv("HDF5_PREFIX");
+        char *prefix = getenv("HDF5_PREFIX");
 
-        HDfprintf(output, "Env HDF5_PREFIX=%s\n", (prefix ? prefix : "not set"));
+        fprintf(output, "Env HDF5_PREFIX=%s\n", (prefix ? prefix : "not set"));
     }
 
-    HDfprintf(output, "==== End of Parameters ====\n");
-    HDfprintf(output, "\n");
+    fprintf(output, "==== End of Parameters ====\n");
+    fprintf(output, "\n");
 }
 
 /*
@@ -811,9 +791,6 @@ report_parameters(struct options *opts)
  * Purpose:     Parse the command line options and return a STRUCT OPTIONS
  *              structure which will need to be freed by the calling function.
  * Return:      Pointer to an OPTIONS structure
- * Programmer:  Bill Wendling, 31. October 2001
- * Modifications:
- *    Added multidimensional testing (Christian Chilan, April, 2008)
  */
 static struct options *
 parse_command_line(int argc, const char *const *argv)
@@ -822,7 +799,7 @@ parse_command_line(int argc, const char *const *argv)
     struct options *cl_opts;
     int             i, default_rank, actual_rank, ranks[4];
 
-    cl_opts = (struct options *)HDmalloc(sizeof(struct options));
+    cl_opts = (struct options *)malloc(sizeof(struct options));
 
     cl_opts->page_buffer_size = 0;
     cl_opts->page_size        = 0;
@@ -847,35 +824,35 @@ parse_command_line(int argc, const char *const *argv)
 
     cl_opts->vfd = sec2;
 
-    cl_opts->print_times   = FALSE; /* Printing times is off by default */
-    cl_opts->print_raw     = FALSE; /* Printing raw data throughput is off by default */
+    cl_opts->print_times   = false; /* Printing times is off by default */
+    cl_opts->print_raw     = false; /* Printing raw data throughput is off by default */
     cl_opts->h5_alignment  = 1;     /* No alignment for HDF5 objects by default */
     cl_opts->h5_threshold  = 1;     /* No threshold for aligning HDF5 objects by default */
-    cl_opts->h5_use_chunks = FALSE; /* Don't chunk the HDF5 dataset by default */
-    cl_opts->h5_write_only = FALSE; /* Do both read and write by default */
-    cl_opts->h5_extendable = FALSE; /* Use extendable dataset */
-    cl_opts->verify        = FALSE; /* No Verify data correctness by default */
+    cl_opts->h5_use_chunks = false; /* Don't chunk the HDF5 dataset by default */
+    cl_opts->h5_write_only = false; /* Do both read and write by default */
+    cl_opts->h5_extendable = false; /* Use extendable dataset */
+    cl_opts->verify        = false; /* No Verify data correctness by default */
 
-    while ((opt = get_option(argc, argv, s_opts, l_opts)) != EOF) {
+    while ((opt = H5_get_option(argc, argv, s_opts, l_opts)) != EOF) {
         switch ((char)opt) {
             case 'a':
-                cl_opts->h5_alignment = parse_size_directive(opt_arg);
+                cl_opts->h5_alignment = parse_size_directive(H5_optarg);
                 break;
             case 'G':
-                cl_opts->page_size = parse_size_directive(opt_arg);
+                cl_opts->page_size = parse_size_directive(H5_optarg);
                 break;
             case 'b':
-                cl_opts->page_buffer_size = parse_size_directive(opt_arg);
+                cl_opts->page_buffer_size = parse_size_directive(H5_optarg);
                 break;
             case 'A': {
-                const char *end = opt_arg;
+                const char *end = H5_optarg;
                 while (end && *end != '\0') {
                     char buf[10];
 
-                    HDmemset(buf, '\0', sizeof(buf));
+                    memset(buf, '\0', sizeof(buf));
 
                     for (i = 0; *end != '\0' && *end != ','; ++end)
-                        if (HDisalnum(*end) && i < 10)
+                        if (isalnum(*end) && i < 10)
                             buf[i++] = *end;
 
                     if (!HDstrcasecmp(buf, "hdf5")) {
@@ -885,8 +862,8 @@ parse_command_line(int argc, const char *const *argv)
                         cl_opts->io_types |= SIO_POSIX;
                     }
                     else {
-                        HDfprintf(stderr, "sio_perf: invalid --api option %s\n", buf);
-                        HDexit(EXIT_FAILURE);
+                        fprintf(stderr, "sio_perf: invalid --api option %s\n", buf);
+                        exit(EXIT_FAILURE);
                     }
 
                     if (*end == '\0')
@@ -906,16 +883,16 @@ parse_command_line(int argc, const char *const *argv)
                 /* Turn on chunked HDF5 dataset creation */
                 cl_opts->h5_use_chunks = 1;
                 {
-                    const char *end = opt_arg;
+                    const char *end = H5_optarg;
                     int         j   = 0;
 
                     while (end && *end != '\0') {
                         char buf[10];
 
-                        HDmemset(buf, '\0', sizeof(buf));
+                        memset(buf, '\0', sizeof(buf));
 
                         for (i = 0; *end != '\0' && *end != ','; ++end)
-                            if (HDisalnum(*end) && i < 10)
+                            if (isalnum(*end) && i < 10)
                                 buf[i++] = *end;
 
                         cl_opts->chk_size[j] = parse_size_directive(buf);
@@ -933,24 +910,24 @@ parse_command_line(int argc, const char *const *argv)
                 break;
 
             case 'D': {
-                const char *end = opt_arg;
+                const char *end = H5_optarg;
 
                 while (end && *end != '\0') {
                     char buf[10];
 
-                    HDmemset(buf, '\0', sizeof(buf));
+                    memset(buf, '\0', sizeof(buf));
 
                     for (i = 0; *end != '\0' && *end != ','; ++end)
-                        if (HDisalnum(*end) && i < 10)
+                        if (isalnum(*end) && i < 10)
                             buf[i++] = *end;
 
-                    if (HDstrlen(buf) > 1 || HDisdigit(buf[0])) {
+                    if (strlen(buf) > 1 || isdigit(buf[0])) {
                         size_t j;
 
                         for (j = 0; j < 10 && buf[j] != '\0'; ++j)
-                            if (!HDisdigit(buf[j])) {
-                                HDfprintf(stderr, "sio_perf: invalid --debug option %s\n", buf);
-                                HDexit(EXIT_FAILURE);
+                            if (!isdigit(buf[j])) {
+                                fprintf(stderr, "sio_perf: invalid --debug option %s\n", buf);
+                                exit(EXIT_FAILURE);
                             }
 
                         sio_debug_level = atoi(buf);
@@ -964,19 +941,19 @@ parse_command_line(int argc, const char *const *argv)
                         switch (*buf) {
                             case 'r':
                                 /* Turn on raw data throughput info */
-                                cl_opts->print_raw = TRUE;
+                                cl_opts->print_raw = true;
                                 break;
                             case 't':
                                 /* Turn on time printing */
-                                cl_opts->print_times = TRUE;
+                                cl_opts->print_times = true;
                                 break;
                             case 'v':
                                 /* Turn on verify data correctness*/
-                                cl_opts->verify = TRUE;
+                                cl_opts->verify = true;
                                 break;
                             default:
-                                HDfprintf(stderr, "sio_perf: invalid --debug option %s\n", buf);
-                                HDexit(EXIT_FAILURE);
+                                fprintf(stderr, "sio_perf: invalid --debug option %s\n", buf);
+                                exit(EXIT_FAILURE);
                         }
                     }
 
@@ -989,16 +966,16 @@ parse_command_line(int argc, const char *const *argv)
 
             break;
             case 'e': {
-                const char *end = opt_arg;
+                const char *end = H5_optarg;
                 int         j   = 0;
 
                 while (end && *end != '\0') {
                     char buf[10];
 
-                    HDmemset(buf, '\0', sizeof(buf));
+                    memset(buf, '\0', sizeof(buf));
 
                     for (i = 0; *end != '\0' && *end != ','; ++end)
-                        if (HDisalnum(*end) && i < 10)
+                        if (isalnum(*end) && i < 10)
                             buf[i++] = *end;
 
                     cl_opts->dset_size[j] = parse_size_directive(buf);
@@ -1016,58 +993,58 @@ parse_command_line(int argc, const char *const *argv)
             break;
 
             case 'i':
-                cl_opts->num_iters = HDatoi(opt_arg);
+                cl_opts->num_iters = atoi(H5_optarg);
                 break;
             case 'o':
-                cl_opts->output_file = opt_arg;
+                cl_opts->output_file = H5_optarg;
                 break;
             case 'T':
-                cl_opts->h5_threshold = parse_size_directive(opt_arg);
+                cl_opts->h5_threshold = parse_size_directive(H5_optarg);
                 break;
             case 'v':
-                if (!HDstrcasecmp(opt_arg, "sec2")) {
+                if (!HDstrcasecmp(H5_optarg, "sec2")) {
                     cl_opts->vfd = sec2;
                 }
-                else if (!HDstrcasecmp(opt_arg, "stdio")) {
+                else if (!HDstrcasecmp(H5_optarg, "stdio")) {
                     cl_opts->vfd = stdio;
                 }
-                else if (!HDstrcasecmp(opt_arg, "core")) {
+                else if (!HDstrcasecmp(H5_optarg, "core")) {
                     cl_opts->vfd = core;
                 }
-                else if (!HDstrcasecmp(opt_arg, "split")) {
+                else if (!HDstrcasecmp(H5_optarg, "split")) {
                     cl_opts->vfd = split;
                 }
-                else if (!HDstrcasecmp(opt_arg, "multi")) {
+                else if (!HDstrcasecmp(H5_optarg, "multi")) {
                     cl_opts->vfd = multi;
                 }
-                else if (!HDstrcasecmp(opt_arg, "family")) {
+                else if (!HDstrcasecmp(H5_optarg, "family")) {
                     cl_opts->vfd = family;
                 }
-                else if (!HDstrcasecmp(opt_arg, "direct")) {
+                else if (!HDstrcasecmp(H5_optarg, "direct")) {
                     cl_opts->vfd = direct;
                 }
                 else {
-                    HDfprintf(stderr, "sio_perf: invalid --api option %s\n", opt_arg);
-                    HDexit(EXIT_FAILURE);
+                    fprintf(stderr, "sio_perf: invalid --api option %s\n", H5_optarg);
+                    exit(EXIT_FAILURE);
                 }
                 break;
             case 'w':
-                cl_opts->h5_write_only = TRUE;
+                cl_opts->h5_write_only = true;
                 break;
             case 't':
-                cl_opts->h5_extendable = TRUE;
+                cl_opts->h5_extendable = true;
                 break;
             case 'x': {
-                const char *end = opt_arg;
+                const char *end = H5_optarg;
                 int         j   = 0;
 
                 while (end && *end != '\0') {
                     char buf[10];
 
-                    HDmemset(buf, '\0', sizeof(buf));
+                    memset(buf, '\0', sizeof(buf));
 
                     for (i = 0; *end != '\0' && *end != ','; ++end)
-                        if (HDisalnum(*end) && i < 10)
+                        if (isalnum(*end) && i < 10)
                             buf[i++] = *end;
 
                     cl_opts->buf_size[j] = parse_size_directive(buf);
@@ -1085,16 +1062,16 @@ parse_command_line(int argc, const char *const *argv)
             break;
 
             case 'r': {
-                const char *end = opt_arg;
+                const char *end = H5_optarg;
                 int         j   = 0;
 
                 while (end && *end != '\0') {
                     char buf[10];
 
-                    HDmemset(buf, '\0', sizeof(buf));
+                    memset(buf, '\0', sizeof(buf));
 
                     for (i = 0; *end != '\0' && *end != ','; ++end)
-                        if (HDisalnum(*end) && i < 10)
+                        if (isalnum(*end) && i < 10)
                             buf[i++] = *end;
 
                     cl_opts->order[j] = (int)parse_size_directive(buf);
@@ -1116,7 +1093,7 @@ parse_command_line(int argc, const char *const *argv)
             case '?':
             default:
                 usage(progname);
-                HDfree(cl_opts);
+                free(cl_opts);
                 return NULL;
         }
     }
@@ -1179,8 +1156,6 @@ parse_command_line(int argc, const char *const *argv)
  * Return:      The size as a off_t because this is related to file size.
  *              If an unknown size indicator is used, then the program will
  *              exit with EXIT_FAILURE as the return value.
- * Programmer:  Bill Wendling, 18. December 2001
- * Modifications:
  */
 
 static hsize_t
@@ -1189,7 +1164,7 @@ parse_size_directive(const char *size)
     hsize_t s;
     char   *endptr;
 
-    s = HDstrtoull(size, &endptr, 10);
+    s = strtoull(size, &endptr, 10);
 
     if (endptr && *endptr) {
         while (*endptr != '\0' && (*endptr == ' ' || *endptr == '\t'))
@@ -1212,8 +1187,8 @@ parse_size_directive(const char *size)
                 break;
 
             default:
-                HDfprintf(stderr, "Illegal size specifier '%c'\n", *endptr);
-                HDexit(EXIT_FAILURE);
+                fprintf(stderr, "Illegal size specifier '%c'\n", *endptr);
+                exit(EXIT_FAILURE);
         }
     }
 
@@ -1224,77 +1199,75 @@ parse_size_directive(const char *size)
  * Function:    usage
  * Purpose:     Print a usage message and then exit.
  * Return:      Nothing
- * Programmer:  Bill Wendling, 31. October 2001
- * Modifications:
  */
 static void
 usage(const char *prog)
 {
     print_version(prog);
-    HDprintf("usage: %s [OPTIONS]\n", prog);
-    HDprintf("  OPTIONS\n");
-    HDprintf("     -h                Print an usage message and exit\n");
-    HDprintf("     -A AL             Which APIs to test\n");
-    HDprintf("                       [default: all of them]\n");
-    HDprintf("     -c SL             Selects chunked storage and defines chunks dimensions\n");
-    HDprintf("                       and sizes\n");
-    HDprintf("                       [default: Off]\n");
-    HDprintf("     -e SL             Dimensions and sizes of dataset\n");
-    HDprintf("                       [default: 100,200]\n");
-    HDprintf("     -i N              Number of iterations to perform\n");
-    HDprintf("                       [default: 1]\n");
-    HDprintf("     -r NL             Dimension access order (see below for description)\n");
-    HDprintf("                       [default: 1,2]\n");
-    HDprintf("     -t                Selects extendable dimensions for HDF5 dataset\n");
-    HDprintf("                       [default: Off]\n");
-    HDprintf("     -v VFD            Selects file driver for HDF5 access\n");
-    HDprintf("                       [default: sec2]\n");
-    HDprintf("     -w                Perform write tests, not the read tests\n");
-    HDprintf("                       [default: Off]\n");
-    HDprintf("     -x SL             Dimensions and sizes of the transfer buffer\n");
-    HDprintf("                       [default: 10,20]\n");
-    HDprintf("\n");
-    HDprintf("  N  - is an integer > 0.\n");
-    HDprintf("\n");
-    HDprintf("  S  - is a size specifier, an integer > 0 followed by a size indicator:\n");
-    HDprintf("          K - Kilobyte (%d)\n", ONE_KB);
-    HDprintf("          M - Megabyte (%d)\n", ONE_MB);
-    HDprintf("          G - Gigabyte (%d)\n", ONE_GB);
-    HDprintf("\n");
-    HDprintf("      Example: '37M' is 37 megabytes or %d bytes\n", 37 * ONE_MB);
-    HDprintf("\n");
-    HDprintf("  AL - is an API list. Valid values are:\n");
-    HDprintf("          hdf5 - HDF5\n");
-    HDprintf("          posix - POSIX\n");
-    HDprintf("\n");
-    HDprintf("      Example: -A posix,hdf5\n");
-    HDprintf("\n");
-    HDprintf("  NL - is list of integers (N) separated by commas.\n");
-    HDprintf("\n");
-    HDprintf("      Example: 1,2,3\n");
-    HDprintf("\n");
-    HDprintf("  SL - is list of size specifiers (S) separated by commas.\n");
-    HDprintf("\n");
-    HDprintf("      Example: 2K,2K,3K\n");
-    HDprintf("\n");
-    HDprintf("      The example defines an object (dataset, transfer buffer) with three\n");
-    HDprintf("      dimensions. Be aware that as the number of dimensions increases, the\n");
-    HDprintf("      the total size of the object increases exponentially.\n");
-    HDprintf("\n");
-    HDprintf("  VFD  - is an HDF5 file driver specifier. Valid values are:\n");
-    HDprintf("          sec2, stdio, core, split, multi, family, direct\n");
-    HDprintf("\n");
-    HDprintf("  Dimension access order:\n");
-    HDprintf("      Data access starts at the cardinal origin of the dataset using the\n");
-    HDprintf("      transfer buffer. The next access occurs on a dataset region next to\n");
-    HDprintf("      the previous one. For a multidimensional dataset, there are several\n");
-    HDprintf("      directions as to where to proceed. This can be specified in the dimension\n");
-    HDprintf("      access order. For example, -r 1,2 states that the tool should traverse\n");
-    HDprintf("      dimension 1 first, and then dimension 2.\n");
-    HDprintf("\n");
-    HDprintf("  Environment variables:\n");
-    HDprintf("      HDF5_NOCLEANUP   Do not remove data files if set [default remove]\n");
-    HDprintf("      HDF5_PREFIX      Data file prefix\n");
-    HDprintf("\n");
-    HDfflush(stdout);
+    printf("usage: %s [OPTIONS]\n", prog);
+    printf("  OPTIONS\n");
+    printf("     -h                Print an usage message and exit\n");
+    printf("     -A AL             Which APIs to test\n");
+    printf("                       [default: all of them]\n");
+    printf("     -c SL             Selects chunked storage and defines chunks dimensions\n");
+    printf("                       and sizes\n");
+    printf("                       [default: Off]\n");
+    printf("     -e SL             Dimensions and sizes of dataset\n");
+    printf("                       [default: 100,200]\n");
+    printf("     -i N              Number of iterations to perform\n");
+    printf("                       [default: 1]\n");
+    printf("     -r NL             Dimension access order (see below for description)\n");
+    printf("                       [default: 1,2]\n");
+    printf("     -t                Selects extendable dimensions for HDF5 dataset\n");
+    printf("                       [default: Off]\n");
+    printf("     -v VFD            Selects file driver for HDF5 access\n");
+    printf("                       [default: sec2]\n");
+    printf("     -w                Perform write tests, not the read tests\n");
+    printf("                       [default: Off]\n");
+    printf("     -x SL             Dimensions and sizes of the transfer buffer\n");
+    printf("                       [default: 10,20]\n");
+    printf("\n");
+    printf("  N  - is an integer > 0.\n");
+    printf("\n");
+    printf("  S  - is a size specifier, an integer > 0 followed by a size indicator:\n");
+    printf("          K - Kilobyte (%d)\n", ONE_KB);
+    printf("          M - Megabyte (%d)\n", ONE_MB);
+    printf("          G - Gigabyte (%d)\n", ONE_GB);
+    printf("\n");
+    printf("      Example: '37M' is 37 megabytes or %d bytes\n", 37 * ONE_MB);
+    printf("\n");
+    printf("  AL - is an API list. Valid values are:\n");
+    printf("          hdf5 - HDF5\n");
+    printf("          posix - POSIX\n");
+    printf("\n");
+    printf("      Example: -A posix,hdf5\n");
+    printf("\n");
+    printf("  NL - is list of integers (N) separated by commas.\n");
+    printf("\n");
+    printf("      Example: 1,2,3\n");
+    printf("\n");
+    printf("  SL - is list of size specifiers (S) separated by commas.\n");
+    printf("\n");
+    printf("      Example: 2K,2K,3K\n");
+    printf("\n");
+    printf("      The example defines an object (dataset, transfer buffer) with three\n");
+    printf("      dimensions. Be aware that as the number of dimensions increases, the\n");
+    printf("      the total size of the object increases exponentially.\n");
+    printf("\n");
+    printf("  VFD  - is an HDF5 file driver specifier. Valid values are:\n");
+    printf("          sec2, stdio, core, split, multi, family, direct\n");
+    printf("\n");
+    printf("  Dimension access order:\n");
+    printf("      Data access starts at the cardinal origin of the dataset using the\n");
+    printf("      transfer buffer. The next access occurs on a dataset region next to\n");
+    printf("      the previous one. For a multidimensional dataset, there are several\n");
+    printf("      directions as to where to proceed. This can be specified in the dimension\n");
+    printf("      access order. For example, -r 1,2 states that the tool should traverse\n");
+    printf("      dimension 1 first, and then dimension 2.\n");
+    printf("\n");
+    printf("  Environment variables:\n");
+    printf("      HDF5_NOCLEANUP   Do not remove data files if set [default remove]\n");
+    printf("      HDF5_PREFIX      Data file prefix\n");
+    printf("\n");
+    fflush(stdout);
 } /* end usage() */
