@@ -49,7 +49,7 @@ h5repack_verify(const char *in_fname, const char *out_fname, pack_opt_t *options
     hid_t                 fcpl_in  = H5I_INVALID_HID;  /* file creation property for input file */
     hid_t                 fcpl_out = H5I_INVALID_HID;  /* file creation property for output file */
     H5F_fspace_strategy_t in_strategy, out_strategy;   /* file space handling strategy for in/output file */
-    hbool_t               in_persist, out_persist;     /* free-space persist status for in/output file */
+    bool                  in_persist, out_persist;     /* free-space persist status for in/output file */
     hsize_t               in_threshold, out_threshold; /* free-space section threshold for in/output file */
     hsize_t               in_pagesize, out_pagesize;   /* file space page size for input/output file */
     int                   ret_value = 0;
@@ -112,7 +112,7 @@ h5repack_verify(const char *in_fname, const char *out_fname, pack_opt_t *options
         /* Initialize indexing options */
         h5trav_set_index(sort_by, sort_order);
         /* init table */
-        trav_table_init(&travt);
+        trav_table_init(fidout, &travt);
 
         /* get the list of objects in the file */
         if (h5trav_gettable(fidout, travt) < 0)
@@ -234,7 +234,7 @@ h5repack_verify(const char *in_fname, const char *out_fname, pack_opt_t *options
      * the same as the input file's free-space persist status
      */
     if (options->fs_persist) {
-        if (out_persist != (hbool_t)(options->fs_persist == (-1) ? FALSE : options->fs_persist))
+        if (out_persist != (bool)(options->fs_persist == (-1) ? false : options->fs_persist))
             H5TOOLS_GOTO_ERROR((-1), "free-space persist status not set as unexpected");
     }
     else {
@@ -286,7 +286,7 @@ done:
         if (travt)
             trav_table_free(travt);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return ret_value;
 } /* h5repack_verify() */
@@ -356,7 +356,7 @@ verify_layout(hid_t pid, pack_info_t *obj)
  */
 
 int
-h5repack_cmp_pl(const char *fname1, hid_t fname1_fapl, const char *fname2, hid_t fname2_fapl)
+h5repack_cmp_pl(const char *fname1, const char *fname2, pack_opt_t *options)
 {
     hid_t         fid1   = H5I_INVALID_HID; /* file ID */
     hid_t         fid2   = H5I_INVALID_HID; /* file ID */
@@ -377,11 +377,11 @@ h5repack_cmp_pl(const char *fname1, hid_t fname1_fapl, const char *fname2, hid_t
      *-------------------------------------------------------------------------
      */
     /* Open the files */
-    if ((fid1 = h5tools_fopen(fname1, H5F_ACC_RDONLY, fname1_fapl,
-                              (fname1_fapl == H5P_DEFAULT) ? FALSE : TRUE, NULL, 0)) < 0)
+    if ((fid1 = h5tools_fopen(fname1, H5F_ACC_RDONLY, options->fin_fapl,
+                              (options->fin_vol || options->fin_vfd), NULL, 0)) < 0)
         H5TOOLS_GOTO_ERROR((-1), "h5tools_fopen failed <%s>: %s", fname1, H5FOPENERROR);
-    if ((fid2 = h5tools_fopen(fname2, H5F_ACC_RDONLY, fname2_fapl,
-                              (fname2_fapl == H5P_DEFAULT) ? FALSE : TRUE, NULL, 0)) < 0)
+    if ((fid2 = h5tools_fopen(fname2, H5F_ACC_RDONLY, options->fout_fapl,
+                              (options->fout_vol || options->fout_vfd), NULL, 0)) < 0)
         H5TOOLS_GOTO_ERROR((-1), "h5tools_fopen failed <%s>: %s", fname2, H5FOPENERROR);
 
     /*-------------------------------------------------------------------------
@@ -391,7 +391,7 @@ h5repack_cmp_pl(const char *fname1, hid_t fname1_fapl, const char *fname2, hid_t
     /* Initialize indexing options */
     h5trav_set_index(sort_by, sort_order);
     /* init table */
-    trav_table_init(&trav);
+    trav_table_init(fid1, &trav);
     if (h5trav_gettable(fid1, trav) < 0)
         H5TOOLS_GOTO_ERROR((-1), "h5trav_gettable failed");
 
@@ -475,7 +475,7 @@ done:
         if (trav)
             trav_table_free(trav);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return ret_value;
 }
