@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:             debug.c
- *                      Jul 18 1997
- *                      Robb Matzke
  *
  * Purpose:             Debugs an existing HDF5 file at a low level.
  *
@@ -65,9 +63,6 @@
  *
  * Return:  Non-NULL on success/NULL on failure
  *
- * Programmer:  Quincey Koziol
- *    Sep 11 2008
- *
  *-------------------------------------------------------------------------
  */
 static const H5B2_class_t *
@@ -131,7 +126,7 @@ get_H5B2_class(const uint8_t *sig)
 
         case H5B2_NUM_BTREE_ID:
         default:
-            HDfprintf(stderr, "Unknown v2 B-tree subtype %u\n", (unsigned)(subtype));
+            fprintf(stderr, "Unknown v2 B-tree subtype %u\n", (unsigned)(subtype));
     } /* end switch */
 
     return (cls);
@@ -146,9 +141,6 @@ get_H5B2_class(const uint8_t *sig)
  *
  * Return:  Non-NULL on success/NULL on failure
  *
- * Programmer:  Quincey Koziol
- *    Sep 11 2008
- *
  *-------------------------------------------------------------------------
  */
 static const H5EA_class_t *
@@ -172,7 +164,7 @@ get_H5EA_class(const uint8_t *sig)
 
         case H5EA_NUM_CLS_ID:
         default:
-            HDfprintf(stderr, "Unknown extensible array class %u\n", (unsigned)(clsid));
+            fprintf(stderr, "Unknown extensible array class %u\n", (unsigned)(clsid));
     } /* end switch */
 
     return (cls);
@@ -187,9 +179,6 @@ get_H5EA_class(const uint8_t *sig)
  *
  * Return:  Non-NULL on success/NULL on failure
  *
- * Programmer:  Quincey Koziol
- *    Sep 11 2008
- *
  *-------------------------------------------------------------------------
  */
 static const H5FA_class_t *
@@ -213,7 +202,7 @@ get_H5FA_class(const uint8_t *sig)
 
         case H5FA_NUM_CLS_ID:
         default:
-            HDfprintf(stderr, "Unknown fixed array class %u\n", (unsigned)(clsid));
+            fprintf(stderr, "Unknown fixed array class %u\n", (unsigned)(clsid));
     } /* end switch */
 
     return (cls);
@@ -228,37 +217,35 @@ get_H5FA_class(const uint8_t *sig)
  *
  *              Failure:        exit (non-zero)
  *
- * Programmer:  Robb Matzke
- *              Jul 18 1997
- *
  *-------------------------------------------------------------------------
  */
 int
 main(int argc, char *argv[])
 {
-    hid_t       fid  = H5I_INVALID_HID;
-    hid_t       fapl = H5I_INVALID_HID;
-    H5F_t      *f;
-    haddr_t     addr        = 0;
-    int         extra_count = 0; /* Number of extra arguments */
-    haddr_t     extra[10];
-    uint8_t     sig[H5F_SIGNATURE_LEN];
-    size_t      u;
-    H5E_auto2_t func           = NULL;
-    void       *edata          = NULL;
-    hbool_t     api_ctx_pushed = FALSE; /* Whether API context pushed */
-    herr_t      status         = SUCCEED;
-    int         exit_value     = 0;
+    hid_t          fid  = H5I_INVALID_HID;
+    hid_t          fapl = H5I_INVALID_HID;
+    H5VL_object_t *vol_obj;
+    H5F_t         *f;
+    haddr_t        addr        = 0;
+    int            extra_count = 0; /* Number of extra arguments */
+    haddr_t        extra[10];
+    uint8_t        sig[H5F_SIGNATURE_LEN];
+    size_t         u;
+    H5E_auto2_t    func           = NULL;
+    void          *edata          = NULL;
+    bool           api_ctx_pushed = false; /* Whether API context pushed */
+    herr_t         status         = SUCCEED;
+    int            exit_value     = 0;
 
     if (argc == 1) {
-        HDfprintf(stderr, "Usage: %s filename [signature-addr [extra]*]\n", argv[0]);
+        fprintf(stderr, "Usage: %s filename [signature-addr [extra]*]\n", argv[0]);
         exit_value = 1;
         goto done;
     } /* end if */
 
     /* Initialize the library */
     if (H5open() < 0) {
-        HDfprintf(stderr, "cannot initialize the library\n");
+        fprintf(stderr, "cannot initialize the library\n");
         exit_value = 1;
         goto done;
     } /* end if */
@@ -271,39 +258,45 @@ main(int argc, char *argv[])
      * Open the file and get the file descriptor.
      */
     if ((fapl = H5Pcreate(H5P_FILE_ACCESS)) < 0) {
-        HDfprintf(stderr, "cannot create file access property list\n");
+        fprintf(stderr, "cannot create file access property list\n");
         exit_value = 1;
         goto done;
     } /* end if */
-    if (HDstrchr(argv[1], '%'))
+    if (strchr(argv[1], '%'))
         if (H5Pset_fapl_family(fapl, (hsize_t)0, H5P_DEFAULT) < 0) {
-            HDfprintf(stderr, "cannot set file access property list\n");
+            fprintf(stderr, "cannot set file access property list\n");
             exit_value = 1;
             goto done;
         }
     if ((fid = H5Fopen(argv[1], H5F_ACC_RDONLY, fapl)) < 0) {
-        HDfprintf(stderr, "cannot open file\n");
+        fprintf(stderr, "cannot open file\n");
         exit_value = 1;
         goto done;
     } /* end if */
 
     /* Push API context */
     if (H5CX_push() < 0) {
-        HDfprintf(stderr, "cannot set API context\n");
+        fprintf(stderr, "cannot set API context\n");
         exit_value = 1;
         goto done;
     }
-    api_ctx_pushed = TRUE;
+    api_ctx_pushed = true;
 
-    if (NULL == (f = (H5F_t *)H5I_object(fid))) {
-        HDfprintf(stderr, "cannot obtain H5F_t pointer\n");
+    if (NULL == (vol_obj = (H5VL_object_t *)H5VL_vol_object(fid))) {
+        fprintf(stderr, "cannot obtain vol_obj pointer\n");
+        exit_value = 2;
+        goto done;
+    } /* end if */
+
+    if (NULL == (f = (H5F_t *)H5VL_object_data(vol_obj))) {
+        fprintf(stderr, "cannot obtain H5F_t pointer\n");
         exit_value = 2;
         goto done;
     } /* end if */
 
     /* Ignore metadata tags while using h5debug */
     if (H5AC_ignore_tags(f) < 0) {
-        HDfprintf(stderr, "cannot ignore metadata tags\n");
+        fprintf(stderr, "cannot ignore metadata tags\n");
         exit_value = 1;
         goto done;
     }
@@ -314,68 +307,68 @@ main(int argc, char *argv[])
 
     /* Primary data structure to dump */
     if (argc > 2)
-        addr = (haddr_t)HDstrtoll(argv[2], NULL, 0);
+        addr = (haddr_t)strtoll(argv[2], NULL, 0);
 
     /* Extra arguments for primary data structure */
-    HDmemset(extra, 0, sizeof(extra));
+    memset(extra, 0, sizeof(extra));
     if (argc > 3) {
         /* Number of extra arguments */
         extra_count = argc - 3;
 
         /* Range check against 'extra' array size */
         if (extra_count > (int)(sizeof(extra) / sizeof(haddr_t))) {
-            HDfprintf(stderr, "\nWARNING: Only using first %d extra parameters\n\n",
-                      (int)(sizeof(extra) / sizeof(haddr_t)));
+            fprintf(stderr, "\nWARNING: Only using first %d extra parameters\n\n",
+                    (int)(sizeof(extra) / sizeof(haddr_t)));
             extra_count = (int)(sizeof(extra) / sizeof(haddr_t));
         } /* end if */
 
         for (u = 0; u < (size_t)extra_count; u++)
-            extra[u] = (haddr_t)HDstrtoll(argv[u + 3], NULL, 0);
+            extra[u] = (haddr_t)strtoll(argv[u + 3], NULL, 0);
     } /* end if */
 
     /*
      * Read the signature at the specified file position.
      */
-    HDfprintf(stdout, "Reading signature at address %" PRIuHADDR " (rel)\n", addr);
+    fprintf(stdout, "Reading signature at address %" PRIuHADDR " (rel)\n", addr);
     if (H5F_block_read(f, H5FD_MEM_SUPER, addr, sizeof(sig), sig) < 0) {
-        HDfprintf(stderr, "cannot read signature\n");
+        fprintf(stderr, "cannot read signature\n");
         exit_value = 3;
         goto done;
     }
-    if (!HDmemcmp(sig, H5F_SIGNATURE, (size_t)H5F_SIGNATURE_LEN)) {
+    if (!memcmp(sig, H5F_SIGNATURE, (size_t)H5F_SIGNATURE_LEN)) {
         /*
          * Debug the file's super block.
          */
         status = H5F_debug(f, stdout, 0, VCOL);
     }
-    else if (!HDmemcmp(sig, H5HL_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5HL_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a local heap.
          */
         status = H5HL_debug(f, addr, stdout, 0, VCOL);
     }
-    else if (!HDmemcmp(sig, H5HG_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5HG_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a global heap collection.
          */
         status = H5HG_debug(f, addr, stdout, 0, VCOL);
     }
-    else if (!HDmemcmp(sig, H5G_NODE_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5G_NODE_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a symbol table node.
          */
 
         /* Check for extra parameters */
         if (extra_count == 0 || extra[0] == 0) {
-            HDfprintf(stderr,
-                      "\nWarning: Providing the group's local heap address will give more information\n");
-            HDfprintf(stderr, "Symbol table node usage:\n");
-            HDfprintf(stderr, "\th5debug <filename> <Symbol table node address> <address of local heap>\n\n");
+            fprintf(stderr,
+                    "\nWarning: Providing the group's local heap address will give more information\n");
+            fprintf(stderr, "Symbol table node usage:\n");
+            fprintf(stderr, "\th5debug <filename> <Symbol table node address> <address of local heap>\n\n");
         } /* end if */
 
         status = H5G_node_debug(f, addr, stdout, 0, VCOL, extra[0]);
     }
-    else if (!HDmemcmp(sig, H5B_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5B_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a B-tree.  B-trees are debugged through the B-tree
          * subclass.  The subclass identifier is the byte immediately
@@ -389,12 +382,11 @@ main(int argc, char *argv[])
             case H5B_SNODE_ID:
                 /* Check for extra parameters */
                 if (extra_count == 0 || extra[0] == 0) {
-                    HDfprintf(
+                    fprintf(
                         stderr,
                         "\nWarning: Providing the group's local heap address will give more information\n");
-                    HDfprintf(stderr, "B-tree symbol table node usage:\n");
-                    HDfprintf(stderr,
-                              "\th5debug <filename> <B-tree node address> <address of local heap>\n\n");
+                    fprintf(stderr, "B-tree symbol table node usage:\n");
+                    fprintf(stderr, "\th5debug <filename> <B-tree node address> <address of local heap>\n\n");
                     exit_value = 4;
                     goto done;
                 } /* end if */
@@ -405,12 +397,11 @@ main(int argc, char *argv[])
             case H5B_CHUNK_ID:
                 /* Check for extra parameters */
                 if (extra_count == 0 || extra[0] == 0) {
-                    HDfprintf(
-                        stderr,
-                        "ERROR: Need number of dimensions of chunk in order to dump chunk B-tree node\n");
-                    HDfprintf(stderr, "B-tree chunked storage node usage:\n");
-                    HDfprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> <slowest "
-                                      "chunk dim>...<fastest chunk dim>\n");
+                    fprintf(stderr,
+                            "ERROR: Need number of dimensions of chunk in order to dump chunk B-tree node\n");
+                    fprintf(stderr, "B-tree chunked storage node usage:\n");
+                    fprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> <slowest "
+                                    "chunk dim>...<fastest chunk dim>\n");
                     exit_value = 4;
                     goto done;
                 } /* end if */
@@ -420,10 +411,10 @@ main(int argc, char *argv[])
 
                 /* Check for dimension error */
                 if (ndims > 9) {
-                    HDfprintf(stderr, "ERROR: Only 9 dimensions support currently (fix h5debug)\n");
-                    HDfprintf(stderr, "B-tree chunked storage node usage:\n");
-                    HDfprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> <slowest "
-                                      "chunk dim>...<fastest chunk dim>\n");
+                    fprintf(stderr, "ERROR: Only 9 dimensions support currently (fix h5debug)\n");
+                    fprintf(stderr, "B-tree chunked storage node usage:\n");
+                    fprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> <slowest "
+                                    "chunk dim>...<fastest chunk dim>\n");
                     exit_value = 4;
                     goto done;
                 } /* end for */
@@ -435,10 +426,10 @@ main(int argc, char *argv[])
                 /* Check for dimension error */
                 for (u = 0; u < ndims; u++)
                     if (0 == dim[u]) {
-                        HDfprintf(stderr, "ERROR: Chunk dimensions should be >0\n");
-                        HDfprintf(stderr, "B-tree chunked storage node usage:\n");
-                        HDfprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> "
-                                          "<slowest chunk dim>...<fastest chunk dim>\n");
+                        fprintf(stderr, "ERROR: Chunk dimensions should be >0\n");
+                        fprintf(stderr, "B-tree chunked storage node usage:\n");
+                        fprintf(stderr, "\th5debug <filename> <B-tree node address> <# of dimensions> "
+                                        "<slowest chunk dim>...<fastest chunk dim>\n");
                         exit_value = 4;
                         goto done;
                     } /* end if */
@@ -451,58 +442,58 @@ main(int argc, char *argv[])
 
             case H5B_NUM_BTREE_ID:
             default:
-                HDfprintf(stderr, "Unknown v1 B-tree subtype %u\n", (unsigned)(subtype));
+                fprintf(stderr, "Unknown v1 B-tree subtype %u\n", (unsigned)(subtype));
                 exit_value = 4;
                 goto done;
         }
     }
-    else if (!HDmemcmp(sig, H5B2_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5B2_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a v2 B-tree header.
          */
         const H5B2_class_t *cls = get_H5B2_class(sig);
-        HDassert(cls);
+        assert(cls);
 
         if ((cls == H5D_BT2 || cls == H5D_BT2_FILT) && (extra_count == 0 || extra[0] == 0)) {
-            HDfprintf(stderr, "ERROR: Need v2 B-tree header address and object header address containing the "
-                              "layout message in order to dump header\n");
-            HDfprintf(stderr, "v2 B-tree hdr usage:\n");
-            HDfprintf(stderr, "\th5debug <filename> <v2 B-tree header address> <object header address>\n");
+            fprintf(stderr, "ERROR: Need v2 B-tree header address and object header address containing the "
+                            "layout message in order to dump header\n");
+            fprintf(stderr, "v2 B-tree hdr usage:\n");
+            fprintf(stderr, "\th5debug <filename> <v2 B-tree header address> <object header address>\n");
             exit_value = 4;
             goto done;
         } /* end if */
 
         status = H5B2__hdr_debug(f, addr, stdout, 0, VCOL, cls, (haddr_t)extra[0]);
     }
-    else if (!HDmemcmp(sig, H5B2_INT_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5B2_INT_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a v2 B-tree internal node.
          */
         const H5B2_class_t *cls = get_H5B2_class(sig);
-        HDassert(cls);
+        assert(cls);
 
         /* Check for enough valid parameters */
         if ((cls == H5D_BT2 || cls == H5D_BT2_FILT) &&
             (extra_count == 0 || extra[0] == 0 || extra[1] == 0 || extra[2] == 0 || extra[3] == 0)) {
-            HDfprintf(stderr,
-                      "ERROR: Need v2 B-tree header address, the node's number of records, depth, and object "
-                      "header address containing the layout message in order to dump internal node\n");
-            HDfprintf(stderr,
-                      "NOTE: Leaf nodes are depth 0, the internal nodes above them are depth 1, etc.\n");
-            HDfprintf(stderr, "v2 B-tree internal node usage:\n");
-            HDfprintf(stderr, "\th5debug <filename> <internal node address> <v2 B-tree header address> "
-                              "<number of records> <depth> <object header address>\n");
+            fprintf(stderr,
+                    "ERROR: Need v2 B-tree header address, the node's number of records, depth, and object "
+                    "header address containing the layout message in order to dump internal node\n");
+            fprintf(stderr,
+                    "NOTE: Leaf nodes are depth 0, the internal nodes above them are depth 1, etc.\n");
+            fprintf(stderr, "v2 B-tree internal node usage:\n");
+            fprintf(stderr, "\th5debug <filename> <internal node address> <v2 B-tree header address> "
+                            "<number of records> <depth> <object header address>\n");
             exit_value = 4;
             goto done;
         }
         else if (extra_count == 0 || extra[0] == 0 || extra[1] == 0 || extra[2] == 0) {
-            HDfprintf(stderr, "ERROR: Need v2 B-tree header address and the node's number of records and "
-                              "depth in order to dump internal node\n");
-            HDfprintf(stderr,
-                      "NOTE: Leaf nodes are depth 0, the internal nodes above them are depth 1, etc.\n");
-            HDfprintf(stderr, "v2 B-tree internal node usage:\n");
-            HDfprintf(stderr, "\th5debug <filename> <internal node address> <v2 B-tree header address> "
-                              "<number of records> <depth>\n");
+            fprintf(stderr, "ERROR: Need v2 B-tree header address and the node's number of records and "
+                            "depth in order to dump internal node\n");
+            fprintf(stderr,
+                    "NOTE: Leaf nodes are depth 0, the internal nodes above them are depth 1, etc.\n");
+            fprintf(stderr, "v2 B-tree internal node usage:\n");
+            fprintf(stderr, "\th5debug <filename> <internal node address> <v2 B-tree header address> "
+                            "<number of records> <depth>\n");
             exit_value = 4;
             goto done;
         } /* end if */
@@ -510,31 +501,31 @@ main(int argc, char *argv[])
         status = H5B2__int_debug(f, addr, stdout, 0, VCOL, cls, extra[0], (unsigned)extra[1],
                                  (unsigned)extra[2], (haddr_t)extra[3]);
     }
-    else if (!HDmemcmp(sig, H5B2_LEAF_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5B2_LEAF_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a v2 B-tree leaf node.
          */
         const H5B2_class_t *cls = get_H5B2_class(sig);
-        HDassert(cls);
+        assert(cls);
 
         /* Check for enough valid parameters */
         if ((cls == H5D_BT2 || cls == H5D_BT2_FILT) &&
             (extra_count == 0 || extra[0] == 0 || extra[1] == 0 || extra[2] == 0)) {
 
-            HDfprintf(stderr, "ERROR: Need v2 B-tree header address, number of records, and object header "
-                              "address containing the layout message in order to dump leaf node\n");
-            HDfprintf(stderr, "v2 B-tree leaf node usage:\n");
-            HDfprintf(stderr, "\th5debug <filename> <leaf node address> <v2 B-tree header address> <number "
-                              "of records> <object header address>\n");
+            fprintf(stderr, "ERROR: Need v2 B-tree header address, number of records, and object header "
+                            "address containing the layout message in order to dump leaf node\n");
+            fprintf(stderr, "v2 B-tree leaf node usage:\n");
+            fprintf(stderr, "\th5debug <filename> <leaf node address> <v2 B-tree header address> <number "
+                            "of records> <object header address>\n");
             exit_value = 4;
             goto done;
         }
         else if (extra_count == 0 || extra[0] == 0 || extra[1] == 0) {
-            HDfprintf(
+            fprintf(
                 stderr,
                 "ERROR: Need v2 B-tree header address and number of records in order to dump leaf node\n");
-            HDfprintf(stderr, "v2 B-tree leaf node usage:\n");
-            HDfprintf(
+            fprintf(stderr, "v2 B-tree leaf node usage:\n");
+            fprintf(
                 stderr,
                 "\th5debug <filename> <leaf node address> <v2 B-tree header address> <number of records>\n");
             exit_value = 4;
@@ -544,23 +535,23 @@ main(int argc, char *argv[])
         status =
             H5B2__leaf_debug(f, addr, stdout, 0, VCOL, cls, extra[0], (unsigned)extra[1], (haddr_t)extra[2]);
     }
-    else if (!HDmemcmp(sig, H5HF_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5HF_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a fractal heap header.
          */
         status = H5HF_hdr_debug(f, addr, stdout, 0, VCOL);
     }
-    else if (!HDmemcmp(sig, H5HF_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5HF_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a fractal heap direct block.
          */
 
         /* Check for enough valid parameters */
         if (extra_count == 0 || extra[0] == 0 || extra[1] == 0) {
-            HDfprintf(stderr, "ERROR: Need fractal heap header address and size of direct block in order to "
-                              "dump direct block\n");
-            HDfprintf(stderr, "Fractal heap direct block usage:\n");
-            HDfprintf(
+            fprintf(stderr, "ERROR: Need fractal heap header address and size of direct block in order to "
+                            "dump direct block\n");
+            fprintf(stderr, "Fractal heap direct block usage:\n");
+            fprintf(
                 stderr,
                 "\th5debug <filename> <direct block address> <heap header address> <size of direct block>\n");
             exit_value = 4;
@@ -569,108 +560,107 @@ main(int argc, char *argv[])
 
         status = H5HF_dblock_debug(f, addr, stdout, 0, VCOL, extra[0], (size_t)extra[1]);
     }
-    else if (!HDmemcmp(sig, H5HF_IBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5HF_IBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a fractal heap indirect block.
          */
 
         /* Check for enough valid parameters */
         if (extra_count == 0 || extra[0] == 0 || extra[1] == 0) {
-            HDfprintf(stderr, "ERROR: Need fractal heap header address and number of rows in order to dump "
-                              "indirect block\n");
-            HDfprintf(stderr, "Fractal heap indirect block usage:\n");
-            HDfprintf(
-                stderr,
-                "\th5debug <filename> <indirect block address> <heap header address> <number of rows>\n");
+            fprintf(stderr, "ERROR: Need fractal heap header address and number of rows in order to dump "
+                            "indirect block\n");
+            fprintf(stderr, "Fractal heap indirect block usage:\n");
+            fprintf(stderr,
+                    "\th5debug <filename> <indirect block address> <heap header address> <number of rows>\n");
             exit_value = 4;
             goto done;
         } /* end if */
 
         status = H5HF_iblock_debug(f, addr, stdout, 0, VCOL, extra[0], (unsigned)extra[1]);
     }
-    else if (!HDmemcmp(sig, H5FS_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5FS_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a free space header.
          */
 
         status = H5FS_debug(f, addr, stdout, 0, VCOL);
     }
-    else if (!HDmemcmp(sig, H5FS_SINFO_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5FS_SINFO_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug free space serialized sections.
          */
 
         /* Check for enough valid parameters */
         if (extra_count == 0 || extra[0] == 0 || extra[1] == 0) {
-            HDfprintf(stderr, "ERROR: Need free space header address and client address in order to dump "
-                              "serialized sections\n");
-            HDfprintf(stderr, "Free space serialized sections usage:\n");
-            HDfprintf(stderr, "\th5debug <filename> <serialized sections address> <free space header "
-                              "address> <client address>\n");
+            fprintf(stderr, "ERROR: Need free space header address and client address in order to dump "
+                            "serialized sections\n");
+            fprintf(stderr, "Free space serialized sections usage:\n");
+            fprintf(stderr, "\th5debug <filename> <serialized sections address> <free space header "
+                            "address> <client address>\n");
             exit_value = 4;
             goto done;
         } /* end if */
 
         status = H5FS_sects_debug(f, addr, stdout, 0, VCOL, extra[0], extra[1]);
     }
-    else if (!HDmemcmp(sig, H5SM_TABLE_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5SM_TABLE_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug shared message master table.
          */
 
         status = H5SM_table_debug(f, addr, stdout, 0, VCOL, UINT_MAX, UINT_MAX);
     }
-    else if (!HDmemcmp(sig, H5SM_LIST_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5SM_LIST_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug shared message list index.
          */
 
         /* Check for enough valid parameters */
         if (extra_count == 0 || extra[0] == 0) {
-            HDfprintf(stderr, "ERROR: Need shared message header address in order to shared message list\n");
-            HDfprintf(stderr, "Shared message list usage:\n");
-            HDfprintf(stderr,
-                      "\th5debug <filename> <shared message list address> <shared message header address>\n");
+            fprintf(stderr, "ERROR: Need shared message header address in order to shared message list\n");
+            fprintf(stderr, "Shared message list usage:\n");
+            fprintf(stderr,
+                    "\th5debug <filename> <shared message list address> <shared message header address>\n");
             exit_value = 4;
             goto done;
         } /* end if */
 
         status = H5SM_list_debug(f, addr, stdout, 0, VCOL, (haddr_t)extra[0]);
     }
-    else if (!HDmemcmp(sig, H5EA_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5EA_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug an extensible array header.
          */
         const H5EA_class_t *cls = get_H5EA_class(sig);
-        HDassert(cls);
+        assert(cls);
 
         /* Check for enough valid parameters */
         if (extra_count == 0 || extra[0] == 0) {
-            HDfprintf(
+            fprintf(
                 stderr,
                 "ERROR: Need object header address containing the layout message in order to dump header\n");
-            HDfprintf(stderr, "Extensible array header block usage:\n");
-            HDfprintf(stderr,
-                      "\th5debug <filename> <Extensible Array header address> <object header address>\n");
+            fprintf(stderr, "Extensible array header block usage:\n");
+            fprintf(stderr,
+                    "\th5debug <filename> <Extensible Array header address> <object header address>\n");
             exit_value = 4;
             goto done;
         } /* end if */
 
         status = H5EA__hdr_debug(f, addr, stdout, 0, VCOL, cls, extra[0]);
     }
-    else if (!HDmemcmp(sig, H5EA_IBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5EA_IBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug an extensible array index block.
          */
         const H5EA_class_t *cls = get_H5EA_class(sig);
-        HDassert(cls);
+        assert(cls);
 
         /* Check for enough valid parameters */
         if (extra_count == 0 || extra[0] == 0 || extra[1] == 0) {
-            HDfprintf(stderr, "ERROR: Need extensible array header address and object header address "
-                              "containing the layout message in order to dump index block\n");
-            HDfprintf(stderr, "Extensible array index block usage:\n");
-            HDfprintf(
+            fprintf(stderr, "ERROR: Need extensible array header address and object header address "
+                            "containing the layout message in order to dump index block\n");
+            fprintf(stderr, "Extensible array index block usage:\n");
+            fprintf(
                 stderr,
                 "\th5debug <filename> <index block address> <array header address> <object header address\n");
             exit_value = 4;
@@ -679,80 +669,80 @@ main(int argc, char *argv[])
 
         status = H5EA__iblock_debug(f, addr, stdout, 0, VCOL, cls, extra[0], extra[1]);
     }
-    else if (!HDmemcmp(sig, H5EA_SBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5EA_SBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug an extensible array super block.
          */
         const H5EA_class_t *cls = get_H5EA_class(sig);
-        HDassert(cls);
+        assert(cls);
 
         /* Check for enough valid parameters */
         if (extra_count == 0 || extra[0] == 0 || extra[1] == 0 || extra[2] == 0) {
-            HDfprintf(stderr, "ERROR: Need extensible array header address, super block index and object "
-                              "header address containing the layout message in order to dump super block\n");
-            HDfprintf(stderr, "Extensible array super block usage:\n");
-            HDfprintf(stderr, "\th5debug <filename> <super block address> <array header address> <super "
-                              "block index> <object header address>\n");
+            fprintf(stderr, "ERROR: Need extensible array header address, super block index and object "
+                            "header address containing the layout message in order to dump super block\n");
+            fprintf(stderr, "Extensible array super block usage:\n");
+            fprintf(stderr, "\th5debug <filename> <super block address> <array header address> <super "
+                            "block index> <object header address>\n");
             exit_value = 4;
             goto done;
         } /* end if */
 
         status = H5EA__sblock_debug(f, addr, stdout, 0, VCOL, cls, extra[0], (unsigned)extra[1], extra[2]);
     }
-    else if (!HDmemcmp(sig, H5EA_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5EA_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug an extensible array data block.
          */
         const H5EA_class_t *cls = get_H5EA_class(sig);
-        HDassert(cls);
+        assert(cls);
 
         /* Check for enough valid parameters */
         if (extra_count == 0 || extra[0] == 0 || extra[1] == 0 || extra[2] == 0) {
-            HDfprintf(stderr,
-                      "ERROR: Need extensible array header address, # of elements in data block and object "
-                      "header address containing the layout message in order to dump data block\n");
-            HDfprintf(stderr, "Extensible array data block usage:\n");
-            HDfprintf(stderr, "\th5debug <filename> <data block address> <array header address> <# of "
-                              "elements in data block> <object header address\n");
+            fprintf(stderr,
+                    "ERROR: Need extensible array header address, # of elements in data block and object "
+                    "header address containing the layout message in order to dump data block\n");
+            fprintf(stderr, "Extensible array data block usage:\n");
+            fprintf(stderr, "\th5debug <filename> <data block address> <array header address> <# of "
+                            "elements in data block> <object header address\n");
             exit_value = 4;
             goto done;
         } /* end if */
 
         status = H5EA__dblock_debug(f, addr, stdout, 0, VCOL, cls, extra[0], (size_t)extra[1], extra[2]);
     }
-    else if (!HDmemcmp(sig, H5FA_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5FA_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a fixed array header.
          */
         const H5FA_class_t *cls = get_H5FA_class(sig);
-        HDassert(cls);
+        assert(cls);
 
         /* Check for enough valid parameters */
         if (extra_count == 0 || extra[0] == 0) {
-            HDfprintf(
+            fprintf(
                 stderr,
                 "ERROR: Need object header address containing the layout message in order to dump header\n");
-            HDfprintf(stderr, "Fixed array header block usage:\n");
-            HDfprintf(stderr, "\th5debug <filename> <Fixed Array header address> <object header address>\n");
+            fprintf(stderr, "Fixed array header block usage:\n");
+            fprintf(stderr, "\th5debug <filename> <Fixed Array header address> <object header address>\n");
             exit_value = 4;
             goto done;
         } /* end if */
 
         status = H5FA__hdr_debug(f, addr, stdout, 0, VCOL, cls, extra[0]);
     }
-    else if (!HDmemcmp(sig, H5FA_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5FA_DBLOCK_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug a fixed array data block.
          */
         const H5FA_class_t *cls = get_H5FA_class(sig);
-        HDassert(cls);
+        assert(cls);
 
         /* Check for enough valid parameters */
         if (extra_count == 0 || extra[0] == 0 || extra[1] == 0) {
-            HDfprintf(stderr, "ERROR: Need fixed array header address and object header address containing "
-                              "the layout message in order to dump data block\n");
-            HDfprintf(stderr, "fixed array data block usage:\n");
-            HDfprintf(
+            fprintf(stderr, "ERROR: Need fixed array header address and object header address containing "
+                            "the layout message in order to dump data block\n");
+            fprintf(stderr, "fixed array data block usage:\n");
+            fprintf(
                 stderr,
                 "\th5debug <filename> <data block address> <array header address> <object header address>\n");
             exit_value = 4;
@@ -761,7 +751,7 @@ main(int argc, char *argv[])
 
         status = H5FA__dblock_debug(f, addr, stdout, 0, VCOL, cls, extra[0], extra[1]);
     }
-    else if (!HDmemcmp(sig, H5O_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
+    else if (!memcmp(sig, H5O_HDR_MAGIC, (size_t)H5_SIZEOF_MAGIC)) {
         /*
          * Debug v2 object header (which have signatures).
          */
@@ -779,27 +769,27 @@ main(int argc, char *argv[])
         /*
          * Got some other unrecognized signature.
          */
-        HDprintf("%-*s ", VCOL, "Signature:");
+        printf("%-*s ", VCOL, "Signature:");
         for (u = 0; u < sizeof(sig); u++) {
             if (sig[u] > ' ' && sig[u] <= '~' && '\\' != sig[u])
-                HDputchar(sig[u]);
+                putchar(sig[u]);
             else if ('\\' == sig[u]) {
-                HDputchar('\\');
-                HDputchar('\\');
+                putchar('\\');
+                putchar('\\');
             }
             else
-                HDprintf("\\%03o", sig[u]);
+                printf("\\%03o", sig[u]);
         }
-        HDputchar('\n');
+        putchar('\n');
 
-        HDfprintf(stderr, "unknown signature\n");
+        fprintf(stderr, "unknown signature\n");
         exit_value = 4;
         goto done;
     } /* end else */
 
     /* Check for an error when dumping information */
     if (status < 0) {
-        HDfprintf(stderr, "An error occurred!\n");
+        fprintf(stderr, "An error occurred!\n");
         H5Eprint2(H5E_DEFAULT, stderr);
         exit_value = 5;
         goto done;
@@ -808,12 +798,16 @@ main(int argc, char *argv[])
 done:
     if (fapl > 0)
         H5Pclose(fapl);
-    if (fid > 0)
-        H5Fclose(fid);
+    if (fid > 0) {
+        if (H5Fclose(fid) < 0) {
+            fprintf(stderr, "Error in closing file!\n");
+            exit_value = 1;
+        }
+    }
 
     /* Pop API context */
     if (api_ctx_pushed)
-        H5CX_pop();
+        H5CX_pop(false);
 
     H5Eset_auto2(H5E_DEFAULT, func, edata);
 
