@@ -238,10 +238,10 @@ gent_named_vl(hid_t loc_id)
 
     /* allocate and initialize VL dataset to write */
     buf[0].len           = 1;
-    buf[0].p             = HDmalloc(1 * sizeof(int));
+    buf[0].p             = malloc(1 * sizeof(int));
     ((int *)buf[0].p)[0] = 1;
     buf[1].len           = 2;
-    buf[1].p             = HDmalloc(2 * sizeof(int));
+    buf[1].p             = malloc(2 * sizeof(int));
     ((int *)buf[1].p)[0] = 2;
     ((int *)buf[1].p)[1] = 3;
 
@@ -261,7 +261,7 @@ gent_named_vl(hid_t loc_id)
     H5Dwrite(did, tid, H5S_ALL, H5S_ALL, H5P_DEFAULT, buf);
 
     /* close */
-    H5Dvlen_reclaim(tid, sid, H5P_DEFAULT, buf);
+    H5Treclaim(tid, sid, H5P_DEFAULT, buf);
     H5Sclose(sid);
     H5Dclose(did);
     H5Tclose(tid);
@@ -284,16 +284,16 @@ gent_nested_vl(hid_t loc_id)
 
     /* allocate and initialize VL dataset to write */
     buf[0].len         = 1;
-    buf[0].p           = HDmalloc(1 * sizeof(hvl_t));
+    buf[0].p           = malloc(1 * sizeof(hvl_t));
     tvl                = (hvl_t *)buf[0].p;
-    tvl->p             = HDmalloc(1 * sizeof(int));
+    tvl->p             = malloc(1 * sizeof(int));
     tvl->len           = 1;
     ((int *)tvl->p)[0] = 1;
 
     buf[1].len         = 1;
-    buf[1].p           = HDmalloc(1 * sizeof(hvl_t));
+    buf[1].p           = malloc(1 * sizeof(hvl_t));
     tvl                = (hvl_t *)buf[1].p;
-    tvl->p             = HDmalloc(2 * sizeof(int));
+    tvl->p             = malloc(2 * sizeof(int));
     tvl->len           = 2;
     ((int *)tvl->p)[0] = 2;
     ((int *)tvl->p)[1] = 3;
@@ -314,7 +314,7 @@ gent_nested_vl(hid_t loc_id)
     H5Dwrite(did, tid2, H5S_ALL, H5S_ALL, H5P_DEFAULT, buf);
 
     /* close */
-    H5Dvlen_reclaim(tid2, sid, H5P_DEFAULT, buf);
+    H5Treclaim(tid2, sid, H5P_DEFAULT, buf);
     H5Sclose(sid);
     H5Dclose(did);
     H5Tclose(tid1);
@@ -491,7 +491,6 @@ gent_nested_group(hid_t loc_id)
  *
  * Purpose: Generate object references to dataset and group
  *
- * Programmer: Jonathan Kim (Feb 23, 2010)
  *------------------------------------------------------------------------*/
 static herr_t
 gen_obj_ref(hid_t loc_id)
@@ -512,21 +511,21 @@ gen_obj_ref(hid_t loc_id)
      * add dataset */
     sid = H5Screate_simple(1, dims1, NULL);
     if (sid < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Screate_simple failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Screate_simple failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
 
     oid = H5Dcreate2(loc_id, OBJ_REF_DS, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     if (oid < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Dcreate2 failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Dcreate2 failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
 
     status = H5Dwrite(oid, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, data);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Dwrite failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Dwrite failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -538,7 +537,7 @@ gen_obj_ref(hid_t loc_id)
      * add group  */
     oid = H5Gcreate2(loc_id, OBJ_REF_GRP, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     if (oid < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Gcreate2 failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Gcreate2 failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -546,34 +545,34 @@ gen_obj_ref(hid_t loc_id)
 
     status = H5Rcreate(&or_data[0], loc_id, OBJ_REF_DS, H5R_OBJECT, (hid_t)-1);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Rcreate failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Rcreate failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
     status = H5Rcreate(&or_data[1], loc_id, OBJ_REF_GRP, H5R_OBJECT, (hid_t)-1);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Rcreate failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Rcreate failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
 
     sid = H5Screate_simple(1, dims2, NULL);
     if (sid < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Screate_simple failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Screate_simple failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
 
     oid = H5Dcreate2(loc_id, "Dset_OBJREF", H5T_STD_REF_OBJ, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     if (oid < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Dcreate2 failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Dcreate2 failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
 
     status = H5Dwrite(oid, H5T_STD_REF_OBJ, H5S_ALL, H5S_ALL, H5P_DEFAULT, or_data);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Dwrite failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Dwrite failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -592,7 +591,6 @@ out:
  *
  * Purpose: Generate dataset region references
  *
- * Programmer: Jonathan Kim (Feb 23, 2010)
  *------------------------------------------------------------------------*/
 static herr_t
 gen_region_ref(hid_t loc_id)
@@ -612,7 +610,7 @@ gen_region_ref(hid_t loc_id)
 
     sid = H5Screate_simple(2, dims2, NULL);
     if (sid < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Screate_simple failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Screate_simple failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -620,7 +618,7 @@ gen_region_ref(hid_t loc_id)
     /* create normal dataset which is referred */
     oid2 = H5Dcreate2(loc_id, REG_REF_DS2, H5T_STD_I8LE, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     if (oid2 < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Dcreate2 failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Dcreate2 failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -628,7 +626,7 @@ gen_region_ref(hid_t loc_id)
     /* write values to dataset */
     status = H5Dwrite(oid2, H5T_NATIVE_CHAR, H5S_ALL, H5S_ALL, H5P_DEFAULT, data);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Dwrite failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Dwrite failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -636,7 +634,7 @@ gen_region_ref(hid_t loc_id)
     /* select elements space for reference */
     status = H5Sselect_elements(sid, H5S_SELECT_SET, 4, coords[0]);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Sselect_elements failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Sselect_elements failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -644,7 +642,7 @@ gen_region_ref(hid_t loc_id)
     /* create region reference from elements space */
     status = H5Rcreate(&rr_data[0], loc_id, REG_REF_DS2, H5R_DATASET_REGION, sid);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Rcreate failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Rcreate failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -652,7 +650,7 @@ gen_region_ref(hid_t loc_id)
     /* select hyperslab space for reference */
     status = H5Sselect_hyperslab(sid, H5S_SELECT_SET, start, stride, count, block);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Sselect_hyperslab failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Sselect_hyperslab failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -660,7 +658,7 @@ gen_region_ref(hid_t loc_id)
     /* create region reference from hyperslab space */
     status = H5Rcreate(&rr_data[1], loc_id, REG_REF_DS2, H5R_DATASET_REGION, sid);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Rcreate failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Rcreate failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -670,7 +668,7 @@ gen_region_ref(hid_t loc_id)
     /* Create dataspace. */
     sid = H5Screate_simple(1, dims1, NULL);
     if (sid < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Screate_simple failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Screate_simple failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -678,7 +676,7 @@ gen_region_ref(hid_t loc_id)
     /* create region reference dataset */
     oid1 = H5Dcreate2(loc_id, REG_REF_DS1, H5T_STD_REF_DSETREG, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     if (oid1 < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Dcreate2 failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Dcreate2 failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -686,7 +684,7 @@ gen_region_ref(hid_t loc_id)
     /* write data as region references */
     status = H5Dwrite(oid1, H5T_STD_REF_DSETREG, H5S_ALL, H5S_ALL, H5P_DEFAULT, rr_data);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Dwrite failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Dwrite failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -716,16 +714,16 @@ Test_Obj_Copy(void)
     unsigned new_format;                 /* New format or old format */
 
     if ((fapl_new = H5Pcreate(H5P_FILE_ACCESS)) < 0) {
-        HDfprintf(stderr, "Error: H5Pcreate failed.\n");
+        fprintf(stderr, "Error: H5Pcreate failed.\n");
         goto out;
     }
     if (H5Pset_libver_bounds(fapl_new, H5F_LIBVER_LATEST, H5F_LIBVER_LATEST) < 0) {
-        HDfprintf(stderr, "Error: H5Pset_libver_bounds failed.\n");
+        fprintf(stderr, "Error: H5Pset_libver_bounds failed.\n");
         goto out;
     }
 
     /* Test with old & new format groups */
-    for (new_format = FALSE; new_format <= TRUE; new_format++) {
+    for (new_format = false; new_format <= true; new_format++) {
 
         /* Set the FAPL for the type of format */
         /* Create source file */
@@ -734,7 +732,7 @@ Test_Obj_Copy(void)
         else
             fid = H5Fcreate(HDF_FILE1_NEW, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
         if (fid < 0) {
-            HDfprintf(stderr, "Error: H5Fcreate failed.\n");
+            fprintf(stderr, "Error: H5Fcreate failed.\n");
             goto out;
         }
 
@@ -772,19 +770,19 @@ Test_Ref_Copy(void)
 
     fid = H5Fcreate(HDF_FILE2, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     if (fid < 0) {
-        HDfprintf(stderr, "Error: %s> H5Fcreate failed.\n", HDF_FILE2);
+        fprintf(stderr, "Error: %s> H5Fcreate failed.\n", HDF_FILE2);
         goto out;
     }
 
     /* add object reference */
     status = gen_obj_ref(fid);
     if (status < 0)
-        HDfprintf(stderr, "Failed to generate object reference.\n");
+        fprintf(stderr, "Failed to generate object reference.\n");
 
     /* add region reference */
     status = gen_region_ref(fid);
     if (status < 0)
-        HDfprintf(stderr, "Failed to generate region reference.\n");
+        fprintf(stderr, "Failed to generate region reference.\n");
 
 out:
     /*-----------------------------------------------------------------------
@@ -799,7 +797,6 @@ out:
  *
  * Purpose: generate target external link objs
  *
- * Programmer: Jonathan Kim (March 03, 2010)
  *------------------------------------------------------------------------*/
 static herr_t
 gen_extlink_trg(hid_t loc_id)
@@ -815,7 +812,7 @@ gen_extlink_trg(hid_t loc_id)
      * target file */
     gid = H5Gcreate2(loc_id, "group", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     if (gid < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Gcreate2 failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Gcreate2 failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -830,7 +827,7 @@ gen_extlink_trg(hid_t loc_id)
     tid    = H5Tcopy(H5T_NATIVE_INT);
     status = H5Tcommit2(loc_id, "datatype", tid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Tcommit2 failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Tcommit2 failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -849,7 +846,6 @@ out:
  *
  * Purpose: generate source external link objs
  *
- * Programmer: Jonathan Kim (March 03, 2010)
  *------------------------------------------------------------------------*/
 static herr_t
 gen_extlink_src(hid_t loc_id)
@@ -863,7 +859,7 @@ gen_extlink_src(hid_t loc_id)
      *------------------------------------------------------------------------*/
     gid = H5Gcreate2(loc_id, "/group_ext", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     if (gid < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Gcreate2 failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Gcreate2 failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -874,7 +870,7 @@ gen_extlink_src(hid_t loc_id)
     /* link to dataset */
     status = H5Lcreate_external(HDF_EXT_TRG_FILE, "/simple", gid, "extlink_dset", H5P_DEFAULT, H5P_DEFAULT);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Lcreate_external failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Lcreate_external failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -882,7 +878,7 @@ gen_extlink_src(hid_t loc_id)
     /* link to group */
     status = H5Lcreate_external(HDF_EXT_TRG_FILE, "/group", gid, "extlink_grp", H5P_DEFAULT, H5P_DEFAULT);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Lcreate_external failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Lcreate_external failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -891,7 +887,7 @@ gen_extlink_src(hid_t loc_id)
     status =
         H5Lcreate_external(HDF_EXT_TRG_FILE, "/datatype", gid, "extlink_datatype", H5P_DEFAULT, H5P_DEFAULT);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Lcreate_external failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Lcreate_external failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -899,7 +895,7 @@ gen_extlink_src(hid_t loc_id)
     /* dangling link - no obj*/
     status = H5Lcreate_external(HDF_EXT_TRG_FILE, "notyet", gid, "extlink_notyet1", H5P_DEFAULT, H5P_DEFAULT);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Lcreate_external failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Lcreate_external failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -907,7 +903,7 @@ gen_extlink_src(hid_t loc_id)
     /* dangling link - no file */
     status = H5Lcreate_external("notyet_file.h5", "notyet", gid, "extlink_notyet2", H5P_DEFAULT, H5P_DEFAULT);
     if (status < 0) {
-        HDfprintf(stderr, "Error: %s %d> H5Lcreate_external failed.\n", FUNC, __LINE__);
+        fprintf(stderr, "Error: %s %d> H5Lcreate_external failed.\n", __func__, __LINE__);
         ret = FAIL;
         goto out;
     }
@@ -934,25 +930,25 @@ Test_Extlink_Copy(void)
 
     fid1 = H5Fcreate(HDF_EXT_SRC_FILE, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     if (fid1 < 0) {
-        HDfprintf(stderr, "Error: %s> H5Fcreate failed.\n", HDF_EXT_SRC_FILE);
+        fprintf(stderr, "Error: %s> H5Fcreate failed.\n", HDF_EXT_SRC_FILE);
         goto out;
     }
 
     fid2 = H5Fcreate(HDF_EXT_TRG_FILE, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     if (fid2 < 0) {
-        HDfprintf(stderr, "Error: %s> H5Fcreate failed.\n", HDF_EXT_TRG_FILE);
+        fprintf(stderr, "Error: %s> H5Fcreate failed.\n", HDF_EXT_TRG_FILE);
         goto out;
     }
 
     /* add links to source external link file */
     status = gen_extlink_src(fid1);
     if (status < 0)
-        HDfprintf(stderr, "Error: %s> gen_extlink_src failed.\n", HDF_EXT_SRC_FILE);
+        fprintf(stderr, "Error: %s> gen_extlink_src failed.\n", HDF_EXT_SRC_FILE);
 
     /* add objs to target external link file */
     status = gen_extlink_trg(fid2);
     if (status < 0)
-        HDfprintf(stderr, "Error: %s> gen_extlink_trg failed.\n", HDF_EXT_TRG_FILE);
+        fprintf(stderr, "Error: %s> gen_extlink_trg failed.\n", HDF_EXT_TRG_FILE);
 
 out:
     /*-----------------------------------------------------------------------
