@@ -25,7 +25,7 @@ static void usage(void);
 static void
 usage(void)
 {
-    HDfprintf(stdout, "Usage: h5fc_chk_idx file_name dataset_pathname\n");
+    fprintf(stdout, "Usage: h5fc_chk_idx file_name dataset_pathname\n");
 } /* usage() */
 
 /*-------------------------------------------------------------------------
@@ -51,49 +51,57 @@ main(int argc, char *argv[])
     /* h5fc_chk_idx fname dname */
     if (argc != 3) {
         usage();
-        HDexit(EXIT_FAILURE);
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Duplicate the file name  & dataset name */
-    fname = HDstrdup(argv[1]);
-    dname = HDstrdup(argv[2]);
+    fname = strdup(argv[1]);
+    dname = strdup(argv[2]);
 
     /* Try opening the file */
-    if ((fid = h5tools_fopen(fname, H5F_ACC_RDONLY, H5P_DEFAULT, FALSE, NULL, (size_t)0)) < 0) {
-        HDfprintf(stderr, "h5fc_chk_idx: unable to open the file\n");
-        HDexit(EXIT_FAILURE);
+    if ((fid = h5tools_fopen(fname, H5F_ACC_RDONLY, H5P_DEFAULT, false, NULL, (size_t)0)) < 0) {
+        fprintf(stderr, "h5fc_chk_idx: unable to open the file\n");
+        goto error;
     } /* end if */
 
     /* Open the dataset */
     if ((did = H5Dopen2(fid, dname, H5P_DEFAULT)) < 0) {
-        HDfprintf(stderr, "h5fc_chk_idx: unable to open the dataset\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "h5fc_chk_idx: unable to open the dataset\n");
+        goto error;
     } /* end if */
 
     /* Get the dataset's chunk indexing type */
     if (H5Dget_chunk_index_type(did, &idx_type) < 0) {
-        HDfprintf(stderr, "h5fc_chk_idx: unable to get chunk index type for the dataset\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "h5fc_chk_idx: unable to get chunk index type for the dataset\n");
+        goto error;
     } /* end if */
 
     /* Close the dataset */
     if (H5Dclose(did) < 0) {
-        HDfprintf(stderr, "h5fc_chk_idx: unable to close the dataset\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "h5fc_chk_idx: unable to close the dataset\n");
+        goto error;
     } /* end if */
 
     /* Close the file */
     if (H5Fclose(fid) < 0) {
-        HDfprintf(stderr, "h5fc_chk_idx_type: cannot close the file\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "h5fc_chk_idx_type: cannot close the file\n");
+        goto error;
     } /* end if */
 
     /* Return success when the chunk indexing type is version 1 B-tree */
-    if (idx_type == H5D_CHUNK_IDX_BTREE)
-        HDexit(EXIT_SUCCESS);
-    else {
-        HDfprintf(stderr, "Error: chunk indexing type is %d\n", idx_type);
-        HDexit(EXIT_FAILURE);
+    if (idx_type != H5D_CHUNK_IDX_BTREE) {
+        fprintf(stderr, "Error: chunk indexing type is %d\n", idx_type);
+        goto error;
     } /* end if */
 
+    free(fname);
+    free(dname);
+
+    exit(EXIT_SUCCESS);
+
+error:
+    free(fname);
+    free(dname);
+
+    exit(EXIT_FAILURE);
 } /* main() */
