@@ -45,11 +45,9 @@ main(void)
     int rowo4i = 11, colo4i = 21, plno4i = 51;
     int rowi4i = 1, coli4i = 2, plni4i = 5;
 
-#ifdef H5_SIZEOF_LONG_LONG
     long long row4i64[3], col4i64[4], pln4i64[5];
     long long rowo4i64 = (long long)11, colo4i64 = (long long)21, plno4i64 = (long long)51;
     long long rowi4i64 = (long long)1, coli4i64 = (long long)2, plni4i64 = (long long)5;
-#endif
 
     short b16i3[5][3][4];
     short row4i16[3], col4i16[4], pln4i16[5];
@@ -70,9 +68,9 @@ main(void)
     volatile uint32_t ibyte = 0x01234567;
     /* 0 for big endian, 1 for little endian. */
     if ((*((volatile uint8_t *)(&ibyte))) == 0x67)
-        HDstrcpy(machine_order, "LE");
+        strcpy(machine_order, "LE");
     else
-        HDstrcpy(machine_order, "BE");
+        strcpy(machine_order, "BE");
 
     /*
      * initialize the row, column, and plane vectors
@@ -100,11 +98,9 @@ main(void)
     col4i[0] = colo4i;
     pln4i[0] = plno4i;
 
-#ifdef H5_SIZEOF_LONG_LONG
     row4i64[0] = rowo4i64;
     col4i64[0] = colo4i64;
     pln4i64[0] = plno4i64;
-#endif
 
     row4i16[0] = rowo4i16;
     col4i16[0] = colo4i16;
@@ -115,33 +111,27 @@ main(void)
     pln4i8[0] = plno4i8;
 
     for (i = 1; i < nrow; i++) {
-        row4[i]  = row4[i - 1] + rowi4;
-        row8[i]  = row8[i - 1] + rowi8;
-        row4i[i] = row4i[i - 1] + rowi4i;
-#ifdef H5_SIZEOF_LONG_LONG
+        row4[i]    = row4[i - 1] + rowi4;
+        row8[i]    = row8[i - 1] + rowi8;
+        row4i[i]   = row4i[i - 1] + rowi4i;
         row4i64[i] = row4i64[i - 1] + rowi4i64;
-#endif
         row4i16[i] = (short)(row4i16[i - 1] + rowi4i16);
         row4i8[i]  = (char)(row4i8[i - 1] + rowi4i8);
     }
 
     for (j = 1; j < ncol; j++) {
-        col4[j]  = col4[j - 1] + coli4;
-        col8[j]  = col8[j - 1] + coli8;
-        col4i[j] = col4i[j - 1] + coli4i;
-#ifdef H5_SIZEOF_LONG_LONG
+        col4[j]    = col4[j - 1] + coli4;
+        col8[j]    = col8[j - 1] + coli8;
+        col4i[j]   = col4i[j - 1] + coli4i;
         col4i64[j] = col4i64[j - 1] + coli4i64;
-#endif
         col4i16[j] = (short)(col4i16[j - 1] + coli4i16);
         col4i8[j]  = (char)(col4i8[j - 1] + coli4i8);
     }
     for (k = 1; k < npln; k++) {
-        pln4[k]  = pln4[k - 1] + plni4;
-        pln8[k]  = pln8[k - 1] + plni8;
-        pln4i[k] = pln4i[k - 1] + plni4i;
-#ifdef H5_SIZEOF_LONG_LONG
+        pln4[k]    = pln4[k - 1] + plni4;
+        pln8[k]    = pln8[k - 1] + plni8;
+        pln4i[k]   = pln4i[k - 1] + plni4i;
         pln4i64[k] = pln4i64[k - 1] + plni4i64;
-#endif
         pln4i16[k] = (short)(pln4i16[k - 1] + plni4i16);
         pln4i8[k]  = (char)(pln4i8[k - 1] + plni4i8);
     }
@@ -169,45 +159,45 @@ main(void)
      *-------------------------------------------------------------------------
      */
 
-    sp = HDfopen("txtin8.txt", "w");
+    sp = fopen("txtin8.txt", "w");
     for (k = 0; k < npln; k++) {
         for (i = 0; i < nrow; i++) {
             for (j = 0; j < ncol; j++)
-                (void)HDfprintf(sp, "%10u", b8i3[k][i][j]);
-            (void)HDfprintf(sp, "\n");
+                (void)fprintf(sp, "%10u", b8i3[k][i][j]);
+            (void)fprintf(sp, "\n");
         }
     }
-    (void)HDfclose(sp);
+    (void)fclose(sp);
 
     /*-------------------------------------------------------------------------
      * TOOLTEST txtin16.txt -c $srcdir/testfiles/txtin16.conf -o txtin16.h5
      *-------------------------------------------------------------------------
      */
 
-    sp = HDfopen("txtin16.txt", "w");
+    sp = fopen("txtin16.txt", "w");
     for (k = 0; k < npln; k++) {
         for (i = 0; i < nrow; i++) {
             for (j = 0; j < ncol; j++)
-                (void)HDfprintf(sp, "%10u", b16i3[k][i][j]);
-            (void)HDfprintf(sp, "\n");
+                (void)fprintf(sp, "%10u", b16i3[k][i][j]);
+            (void)fprintf(sp, "\n");
         }
     }
-    (void)HDfclose(sp);
+    (void)fclose(sp);
 
     /*-------------------------------------------------------------------------
      * TOOLTEST txtin32.txt -c $srcdir/testfiles/textin32.conf -o textin32.h5
      *-------------------------------------------------------------------------
      */
 
-    sp = HDfopen("txtin32.txt", "w");
+    sp = fopen("txtin32.txt", "w");
     for (k = 0; k < npln; k++) {
         for (i = 0; i < nrow; i++) {
             for (j = 0; j < ncol; j++)
-                (void)HDfprintf(sp, "%10d", b32i3[k][i][j]);
-            (void)HDfprintf(sp, "\n");
+                (void)fprintf(sp, "%10d", b32i3[k][i][j]);
+            (void)fprintf(sp, "\n");
         }
     }
-    (void)HDfclose(sp);
+    (void)fclose(sp);
 #endif
 
     /*-------------------------------------------------------------------------
@@ -215,144 +205,144 @@ main(void)
      *-------------------------------------------------------------------------
      */
 
-    sp = HDfopen("binin32.bin", OPEN_FLAGS);
+    sp = fopen("binin32.bin", OPEN_FLAGS);
     for (k = 0; k < npln; k++) {
         for (i = 0; i < nrow; i++) {
             for (j = 0; j < ncol; j++) {
-                (void)HDfwrite((char *)&b32i3[k][i][j], sizeof(int), 1, sp);
+                (void)fwrite((char *)&b32i3[k][i][j], sizeof(int), 1, sp);
             }
         }
     }
-    (void)HDfclose(sp);
+    (void)fclose(sp);
 
-    sp = HDfopen("binin32.conf", "w");
-    (void)HDfprintf(sp, "PATH /int/bin/32-bit\n");
-    (void)HDfprintf(sp, "INPUT-CLASS IN\n");
-    (void)HDfprintf(sp, "INPUT-SIZE    32\n");
-    (void)HDfprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
-    (void)HDfprintf(sp, "RANK 3\n");
-    (void)HDfprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
-    (void)HDfprintf(sp, "OUTPUT-BYTE-ORDER BE\n");
-    (void)HDfprintf(sp, "DIMENSION-SIZES 5 3 4\n");
-    (void)HDfprintf(sp, "CHUNKED-DIMENSION-SIZES 1 2 1\n");
-    (void)HDfprintf(sp, "\n");
-    (void)HDfclose(sp);
+    sp = fopen("binin32.conf", "w");
+    (void)fprintf(sp, "PATH /int/bin/32-bit\n");
+    (void)fprintf(sp, "INPUT-CLASS IN\n");
+    (void)fprintf(sp, "INPUT-SIZE    32\n");
+    (void)fprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
+    (void)fprintf(sp, "RANK 3\n");
+    (void)fprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
+    (void)fprintf(sp, "OUTPUT-BYTE-ORDER BE\n");
+    (void)fprintf(sp, "DIMENSION-SIZES 5 3 4\n");
+    (void)fprintf(sp, "CHUNKED-DIMENSION-SIZES 1 2 1\n");
+    (void)fprintf(sp, "\n");
+    (void)fclose(sp);
 
     /*-------------------------------------------------------------------------
      * TOOLTEST binuin32.bin -c binuin32.conf -o binuin32.h5
      *-------------------------------------------------------------------------
      */
 
-    sp = HDfopen("binuin32.bin", OPEN_FLAGS);
+    sp = fopen("binuin32.bin", OPEN_FLAGS);
     for (k = 0; k < npln; k++) {
         for (i = 0; i < nrow; i++) {
             for (j = 0; j < ncol; j++) {
-                (void)HDfwrite((char *)&b32i3[k][i][j], sizeof(unsigned int), 1, sp);
+                (void)fwrite((char *)&b32i3[k][i][j], sizeof(unsigned int), 1, sp);
             }
         }
     }
-    (void)HDfclose(sp);
+    (void)fclose(sp);
 
-    sp = HDfopen("binuin32.conf", "w");
-    (void)HDfprintf(sp, "PATH /int/buin/32-bit\n");
-    (void)HDfprintf(sp, "INPUT-CLASS UIN\n");
-    (void)HDfprintf(sp, "INPUT-SIZE    32\n");
-    (void)HDfprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
-    (void)HDfprintf(sp, "RANK 3\n");
-    (void)HDfprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
-    (void)HDfprintf(sp, "OUTPUT-BYTE-ORDER LE\n");
-    (void)HDfprintf(sp, "DIMENSION-SIZES 5 3 4\n");
-    (void)HDfprintf(sp, "\n");
-    (void)HDfclose(sp);
+    sp = fopen("binuin32.conf", "w");
+    (void)fprintf(sp, "PATH /int/buin/32-bit\n");
+    (void)fprintf(sp, "INPUT-CLASS UIN\n");
+    (void)fprintf(sp, "INPUT-SIZE    32\n");
+    (void)fprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
+    (void)fprintf(sp, "RANK 3\n");
+    (void)fprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
+    (void)fprintf(sp, "OUTPUT-BYTE-ORDER LE\n");
+    (void)fprintf(sp, "DIMENSION-SIZES 5 3 4\n");
+    (void)fprintf(sp, "\n");
+    (void)fclose(sp);
 
     /*-------------------------------------------------------------------------
      * TOOLTEST binin16.bin -c binin16.conf -o binin16.h5
      *-------------------------------------------------------------------------
      */
 
-    sp = HDfopen("binin16.bin", OPEN_FLAGS);
+    sp = fopen("binin16.bin", OPEN_FLAGS);
     for (k = 0; k < npln; k++) {
         for (i = 0; i < nrow; i++) {
             for (j = 0; j < ncol; j++) {
-                (void)HDfwrite((char *)&b16i3[k][i][j], sizeof(short), 1, sp);
+                (void)fwrite((char *)&b16i3[k][i][j], sizeof(short), 1, sp);
             }
         }
     }
-    (void)HDfclose(sp);
+    (void)fclose(sp);
 
-    sp = HDfopen("binin16.conf", "w");
-    (void)HDfprintf(sp, "PATH /int/bin/16-bit\n");
-    (void)HDfprintf(sp, "INPUT-CLASS IN\n");
-    (void)HDfprintf(sp, "INPUT-SIZE    16\n");
-    (void)HDfprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
-    (void)HDfprintf(sp, "RANK 3\n");
-    (void)HDfprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
-    (void)HDfprintf(sp, "OUTPUT-BYTE-ORDER LE\n");
-    (void)HDfprintf(sp, "DIMENSION-SIZES 2 3 4\n");
-    (void)HDfprintf(sp, "CHUNKED-DIMENSION-SIZES 2 2 2\n");
-    (void)HDfprintf(sp, "MAXIMUM-DIMENSIONS -1 -1 8\n");
-    (void)HDfprintf(sp, "\n");
-    (void)HDfclose(sp);
+    sp = fopen("binin16.conf", "w");
+    (void)fprintf(sp, "PATH /int/bin/16-bit\n");
+    (void)fprintf(sp, "INPUT-CLASS IN\n");
+    (void)fprintf(sp, "INPUT-SIZE    16\n");
+    (void)fprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
+    (void)fprintf(sp, "RANK 3\n");
+    (void)fprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
+    (void)fprintf(sp, "OUTPUT-BYTE-ORDER LE\n");
+    (void)fprintf(sp, "DIMENSION-SIZES 2 3 4\n");
+    (void)fprintf(sp, "CHUNKED-DIMENSION-SIZES 2 2 2\n");
+    (void)fprintf(sp, "MAXIMUM-DIMENSIONS -1 -1 8\n");
+    (void)fprintf(sp, "\n");
+    (void)fclose(sp);
 
     /*-------------------------------------------------------------------------
      * TOOLTEST binuin16.bin -c binuin16.conf -o binuin16.h5
      *-------------------------------------------------------------------------
      */
-    sp = HDfopen("binuin16.bin", OPEN_FLAGS);
+    sp = fopen("binuin16.bin", OPEN_FLAGS);
     for (k = 0; k < npln; k++) {
         for (i = 0; i < nrow; i++) {
             for (j = 0; j < ncol; j++) {
-                (void)HDfwrite((char *)&b16i3[k][i][j], sizeof(unsigned short), 1, sp);
+                (void)fwrite((char *)&b16i3[k][i][j], sizeof(unsigned short), 1, sp);
             }
         }
     }
-    (void)HDfclose(sp);
+    (void)fclose(sp);
 
-    sp = HDfopen("binuin16.conf", "w");
-    (void)HDfprintf(sp, "PATH /int/buin/16-bit\n");
-    (void)HDfprintf(sp, "INPUT-CLASS UIN\n");
-    (void)HDfprintf(sp, "INPUT-SIZE    16\n");
-    (void)HDfprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
-    (void)HDfprintf(sp, "RANK 3\n");
-    (void)HDfprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
-    (void)HDfprintf(sp, "OUTPUT-BYTE-ORDER BE\n");
-    (void)HDfprintf(sp, "DIMENSION-SIZES 2 3 4\n");
-    (void)HDfprintf(sp, "CHUNKED-DIMENSION-SIZES 2 2 2\n");
-    (void)HDfprintf(sp, "MAXIMUM-DIMENSIONS -1 -1 8\n");
-    (void)HDfprintf(sp, "\n");
-    (void)HDfclose(sp);
+    sp = fopen("binuin16.conf", "w");
+    (void)fprintf(sp, "PATH /int/buin/16-bit\n");
+    (void)fprintf(sp, "INPUT-CLASS UIN\n");
+    (void)fprintf(sp, "INPUT-SIZE    16\n");
+    (void)fprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
+    (void)fprintf(sp, "RANK 3\n");
+    (void)fprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
+    (void)fprintf(sp, "OUTPUT-BYTE-ORDER BE\n");
+    (void)fprintf(sp, "DIMENSION-SIZES 2 3 4\n");
+    (void)fprintf(sp, "CHUNKED-DIMENSION-SIZES 2 2 2\n");
+    (void)fprintf(sp, "MAXIMUM-DIMENSIONS -1 -1 8\n");
+    (void)fprintf(sp, "\n");
+    (void)fclose(sp);
 
     /*-------------------------------------------------------------------------
      * TOOLTEST binin8.bin -c binin8.conf  -o binin8.h5
      *-------------------------------------------------------------------------
      */
 
-    sp = HDfopen("binin8.bin", OPEN_FLAGS);
+    sp = fopen("binin8.bin", OPEN_FLAGS);
     for (k = 0; k < npln; k++) {
         for (i = 0; i < nrow; i++) {
             for (j = 0; j < ncol; j++) {
-                (void)HDfwrite((char *)&b8i3[k][i][j], sizeof(char), 1, sp);
+                (void)fwrite((char *)&b8i3[k][i][j], sizeof(char), 1, sp);
             }
         }
     }
-    (void)HDfclose(sp);
+    (void)fclose(sp);
 
-    sp = HDfopen("binin8.conf", "w");
-    (void)HDfprintf(sp, "PATH /int/bin/8-bit\n");
-    (void)HDfprintf(sp, "INPUT-CLASS IN\n");
-    (void)HDfprintf(sp, "INPUT-SIZE    8\n");
-    (void)HDfprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
-    (void)HDfprintf(sp, "RANK 3\n");
-    (void)HDfprintf(sp, "OUTPUT-CLASS IN\n");
-    (void)HDfprintf(sp, "OUTPUT-SIZE    16\n");
-    (void)HDfprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
-    (void)HDfprintf(sp, "OUTPUT-BYTE-ORDER LE\n");
-    (void)HDfprintf(sp, "DIMENSION-SIZES 5 3 4\n");
-    (void)HDfprintf(sp, "CHUNKED-DIMENSION-SIZES 2 2 2\n");
-    (void)HDfprintf(sp, "MAXIMUM-DIMENSIONS -1 -1 -1\n");
-    (void)HDfprintf(sp, "COMPRESSION-PARAM 3\n");
-    (void)HDfprintf(sp, "\n");
-    (void)HDfclose(sp);
+    sp = fopen("binin8.conf", "w");
+    (void)fprintf(sp, "PATH /int/bin/8-bit\n");
+    (void)fprintf(sp, "INPUT-CLASS IN\n");
+    (void)fprintf(sp, "INPUT-SIZE    8\n");
+    (void)fprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
+    (void)fprintf(sp, "RANK 3\n");
+    (void)fprintf(sp, "OUTPUT-CLASS IN\n");
+    (void)fprintf(sp, "OUTPUT-SIZE    16\n");
+    (void)fprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
+    (void)fprintf(sp, "OUTPUT-BYTE-ORDER LE\n");
+    (void)fprintf(sp, "DIMENSION-SIZES 5 3 4\n");
+    (void)fprintf(sp, "CHUNKED-DIMENSION-SIZES 2 2 2\n");
+    (void)fprintf(sp, "MAXIMUM-DIMENSIONS -1 -1 -1\n");
+    (void)fprintf(sp, "COMPRESSION-PARAM 3\n");
+    (void)fprintf(sp, "\n");
+    (void)fclose(sp);
 
 #endif /* UNICOS */
 
@@ -365,30 +355,30 @@ main(void)
      * binary 64-bit file - rank 2 & 3
      */
 
-    sp = HDfopen("binfp64.bin", OPEN_FLAGS);
+    sp = fopen("binfp64.bin", OPEN_FLAGS);
     for (k = 0; k < npln; k++) {
         for (i = 0; i < nrow; i++) {
             for (j = 0; j < ncol; j++) {
-                (void)HDfwrite((char *)&b64r3[k][i][j], sizeof(double), 1, sp);
+                (void)fwrite((char *)&b64r3[k][i][j], sizeof(double), 1, sp);
             }
         }
     }
-    (void)HDfclose(sp);
+    (void)fclose(sp);
 
-    sp = HDfopen("binfp64.conf", "w");
-    (void)HDfprintf(sp, "PATH /fp/bin/64-bit\n");
-    (void)HDfprintf(sp, "INPUT-CLASS FP\n");
-    (void)HDfprintf(sp, "INPUT-SIZE    64\n");
-    (void)HDfprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
-    (void)HDfprintf(sp, "RANK 3\n");
-    (void)HDfprintf(sp, "OUTPUT-ARCHITECTURE IEEE\n");
-    (void)HDfprintf(sp, "OUTPUT-BYTE-ORDER LE\n");
-    (void)HDfprintf(sp, "DIMENSION-SIZES 5 3 4\n");
-    (void)HDfprintf(sp, "CHUNKED-DIMENSION-SIZES 2 2 2\n");
-    (void)HDfprintf(sp, "MAXIMUM-DIMENSIONS -1 6 7\n");
-    (void)HDfprintf(sp, "COMPRESSION-PARAM 8\n");
-    (void)HDfprintf(sp, "\n");
-    (void)HDfclose(sp);
+    sp = fopen("binfp64.conf", "w");
+    (void)fprintf(sp, "PATH /fp/bin/64-bit\n");
+    (void)fprintf(sp, "INPUT-CLASS FP\n");
+    (void)fprintf(sp, "INPUT-SIZE    64\n");
+    (void)fprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
+    (void)fprintf(sp, "RANK 3\n");
+    (void)fprintf(sp, "OUTPUT-ARCHITECTURE IEEE\n");
+    (void)fprintf(sp, "OUTPUT-BYTE-ORDER LE\n");
+    (void)fprintf(sp, "DIMENSION-SIZES 5 3 4\n");
+    (void)fprintf(sp, "CHUNKED-DIMENSION-SIZES 2 2 2\n");
+    (void)fprintf(sp, "MAXIMUM-DIMENSIONS -1 6 7\n");
+    (void)fprintf(sp, "COMPRESSION-PARAM 8\n");
+    (void)fprintf(sp, "\n");
+    (void)fclose(sp);
 
     /*-------------------------------------------------------------------------
      * TOOLTEST binin8w.bin -c binin8w.conf -o binin8w.h5
@@ -399,26 +389,26 @@ main(void)
         /* test CR+LF (13,10) and EOF (26) in windows */
         char bin8w[4] = {13, 10, 26, 0};
 
-        sp = HDfopen("binin8w.bin", OPEN_FLAGS);
+        sp = fopen("binin8w.bin", OPEN_FLAGS);
         for (i = 0; i < 4; i++) {
             char c = bin8w[i];
-            if (HDfwrite(&c, sizeof(char), 1, sp) != 1)
-                HDprintf("error writing file\n");
+            if (fwrite(&c, sizeof(char), 1, sp) != 1)
+                printf("error writing file\n");
         }
-        HDfclose(sp);
+        fclose(sp);
 
-        sp = HDfopen("binin8w.conf", "w");
-        (void)HDfprintf(sp, "INPUT-CLASS IN\n");
-        (void)HDfprintf(sp, "INPUT-SIZE    8\n");
-        (void)HDfprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
-        (void)HDfprintf(sp, "RANK 1\n");
-        (void)HDfprintf(sp, "OUTPUT-CLASS IN\n");
-        (void)HDfprintf(sp, "OUTPUT-SIZE    8\n");
-        (void)HDfprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
-        (void)HDfprintf(sp, "OUTPUT-BYTE-ORDER LE\n");
-        (void)HDfprintf(sp, "DIMENSION-SIZES 4\n");
-        (void)HDfprintf(sp, "\n");
-        (void)HDfclose(sp);
+        sp = fopen("binin8w.conf", "w");
+        (void)fprintf(sp, "INPUT-CLASS IN\n");
+        (void)fprintf(sp, "INPUT-SIZE    8\n");
+        (void)fprintf(sp, "INPUT-BYTE-ORDER %s\n", machine_order);
+        (void)fprintf(sp, "RANK 1\n");
+        (void)fprintf(sp, "OUTPUT-CLASS IN\n");
+        (void)fprintf(sp, "OUTPUT-SIZE    8\n");
+        (void)fprintf(sp, "OUTPUT-ARCHITECTURE STD\n");
+        (void)fprintf(sp, "OUTPUT-BYTE-ORDER LE\n");
+        (void)fprintf(sp, "DIMENSION-SIZES 4\n");
+        (void)fprintf(sp, "\n");
+        (void)fclose(sp);
     }
     return (EXIT_SUCCESS);
 }
