@@ -18,11 +18,11 @@ void parse_command_line(int argc, const char *const *argv);
 
 /* Name of tool */
 #define PROGRAM_NAME "getub"
-char *nbytes = NULL;
+static char *nbytes = NULL;
 
-static const char         *s_opts   = "c:";                     /* add more later ? */
-static struct long_options l_opts[] = {{"c", require_arg, 'c'}, /* input file */
-                                       {NULL, 0, '\0'}};
+static const char            *s_opts   = "c:";                     /* add more later ? */
+static struct h5_long_options l_opts[] = {{"c", require_arg, 'c'}, /* input file */
+                                          {NULL, 0, '\0'}};
 
 /*-------------------------------------------------------------------------
  * Function:    usage
@@ -35,9 +35,9 @@ static struct long_options l_opts[] = {{"c", require_arg, 'c'}, /* input file */
 static void
 usage(const char *prog)
 {
-    HDfflush(stdout);
-    HDfprintf(stdout, "usage: %s -c nb file] \n", prog);
-    HDfprintf(stdout, "           print first 'nb' byts of file to stdoug.\n");
+    fflush(stdout);
+    fprintf(stdout, "usage: %s -c nb file] \n", prog);
+    fprintf(stdout, "           print first 'nb' byts of file to stdoug.\n");
 }
 
 /*-------------------------------------------------------------------------
@@ -56,22 +56,22 @@ parse_command_line(int argc, const char *const *argv)
     int opt;
 
     /* parse command line options */
-    while ((opt = get_option(argc, argv, s_opts, l_opts)) != EOF) {
+    while ((opt = H5_get_option(argc, argv, s_opts, l_opts)) != EOF) {
         switch ((char)opt) {
             case 'c':
-                nbytes = HDstrdup(opt_arg);
+                nbytes = strdup(H5_optarg);
                 break;
             case '?':
             default:
                 usage(h5tools_getprogname());
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
         } /* end switch */
     }     /* end while */
 
-    if (argc <= opt_ind) {
+    if (argc <= H5_optind) {
         error_msg("missing file name\n");
         usage(h5tools_getprogname());
-        HDexit(EXIT_FAILURE);
+        exit(EXIT_FAILURE);
     } /* end if */
 } /* end parse_command_line() */
 
@@ -99,16 +99,16 @@ main(int argc, char *argv[])
         goto error;
     } /* end if */
 
-    if (argc <= (opt_ind)) {
+    if (argc <= (H5_optind)) {
         error_msg("missing file name\n");
         usage(h5tools_getprogname());
         goto error;
     } /* end if */
 
-    filename = HDstrdup(argv[opt_ind]);
+    filename = strdup(argv[H5_optind]);
 
     size = 0;
-    if (EOF == (res = HDsscanf(nbytes, "%u", &size))) {
+    if (EOF == (res = sscanf(nbytes, "%u", &size))) {
         /* fail */
         error_msg("missing file name\n");
         usage(h5tools_getprogname());
@@ -120,7 +120,7 @@ main(int argc, char *argv[])
         goto error;
     } /* end if */
 
-    if (NULL == (buf = (char *)HDmalloc((unsigned)(size + 1)))) {
+    if (NULL == (buf = (char *)malloc((unsigned)(size + 1)))) {
         error_msg("can't allocate buffer \n");
         goto error;
     } /* end if */
@@ -137,15 +137,15 @@ main(int argc, char *argv[])
     } /* end if */
 
     /* close things and exit */
-    HDfree(filename);
-    HDfree(buf);
+    free(filename);
+    free(buf);
     HDclose(fd);
 
     return EXIT_SUCCESS;
 
 error:
-    HDfree(filename);
-    HDfree(buf);
+    free(filename);
+    free(buf);
     if (fd >= 0)
         HDclose(fd);
     return EXIT_FAILURE;
