@@ -53,7 +53,7 @@ static size_t counter(unsigned flags, size_t cd_nelmts, const unsigned *cd_value
                       size_t *buf_size, void **buf);
 
 /* This message derives from H5Z */
-const H5Z_class2_t H5Z_COUNTER[1] = {{
+static const H5Z_class2_t H5Z_COUNTER[1] = {{
     H5Z_CLASS_T_VERS, /* H5Z_class_t version          */
     FILTER_COUNTER,   /* Filter id number             */
     1, 1,             /* Encoding and decoding enabled */
@@ -80,7 +80,7 @@ counter(unsigned H5_ATTR_UNUSED flags, size_t H5_ATTR_UNUSED cd_nelmts,
 static void
 cleanup(void)
 {
-    if (!getenv("HDF5_NOCLEANUP")) {
+    if (!getenv(HDF5_NOCLEANUP)) {
         remove(FILENAME);
     }
 }
@@ -97,7 +97,9 @@ create_dset1(hid_t file)
     hid_t   dcpl             = H5I_INVALID_HID;
     hsize_t dims[RANK]       = {DSET1_DIM1, DSET1_DIM2};
     hsize_t chunk_dims[RANK] = {CHUNK1_DIM1, CHUNK1_DIM2};
-    int   **data             = NULL; /* data for writing */
+    struct {
+        int arr[DSET1_DIM1][DSET1_DIM2];
+    } *data = malloc(sizeof(*data));
 
     /* Create the data space. */
     if ((dataspace = H5Screate_simple(RANK, dims, NULL)) < 0)
@@ -121,9 +123,8 @@ create_dset1(hid_t file)
         0)
         goto error;
 
-    /* Create & fill array */
-    H5TEST_ALLOCATE_2D_ARRAY(data, int, DSET1_DIM1, DSET1_DIM2);
-    H5TEST_FILL_2D_ARRAY(data, int, DSET1_DIM1, DSET1_DIM2);
+    /* Fill array */
+    H5TEST_FILL_2D_HEAP_ARRAY(data, int);
 
     /* Write data to dataset */
     if (H5Dwrite(dataset, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, data) < 0)
@@ -133,7 +134,7 @@ create_dset1(hid_t file)
     H5Dclose(dataset);
     H5Pclose(dcpl);
     H5Sclose(dataspace);
-    HDfree(data);
+    free(data);
     return 0;
 
 error:
@@ -143,8 +144,8 @@ error:
         H5Pclose(dcpl);
         H5Sclose(dataspace);
     }
-    H5E_END_TRY;
-    HDfree(data);
+    H5E_END_TRY
+    free(data);
 
     return 1;
 }
@@ -161,7 +162,9 @@ create_dset2(hid_t file)
     hid_t   dcpl             = H5I_INVALID_HID;
     hsize_t dims[RANK]       = {DSET2_DIM1, DSET2_DIM2};
     hsize_t chunk_dims[RANK] = {CHUNK2_DIM1, CHUNK2_DIM2};
-    int   **data             = NULL; /* data for writing */
+    struct {
+        int arr[DSET2_DIM1][DSET2_DIM2];
+    } *data = malloc(sizeof(*data));
 
     /* Create the data space. */
     if ((dataspace = H5Screate_simple(RANK, dims, NULL)) < 0)
@@ -184,9 +187,8 @@ create_dset2(hid_t file)
         0)
         goto error;
 
-    /* Create & fill array */
-    H5TEST_ALLOCATE_2D_ARRAY(data, int, DSET2_DIM1, DSET2_DIM2);
-    H5TEST_FILL_2D_ARRAY(data, int, DSET2_DIM1, DSET2_DIM2);
+    /* Fill array */
+    H5TEST_FILL_2D_HEAP_ARRAY(data, int);
 
     /* Write data to dataset */
     if (H5Dwrite(dataset, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, data) < 0)
@@ -196,7 +198,7 @@ create_dset2(hid_t file)
     H5Dclose(dataset);
     H5Pclose(dcpl);
     H5Sclose(dataspace);
-    HDfree(data);
+    free(data);
 
     return 0;
 
@@ -207,8 +209,8 @@ error:
         H5Pclose(dcpl);
         H5Sclose(dataspace);
     }
-    H5E_END_TRY;
-    HDfree(data);
+    H5E_END_TRY
+    free(data);
 
     return 1;
 }
@@ -262,13 +264,12 @@ check_partial_chunks_perf(hid_t file)
     end_t = H5_get_time();
 
     if ((end_t - start_t) > 0.0)
-        HDprintf("1. Partial chunks: total read time is %lf; number of bytes being read from file is %zu\n",
-                 (end_t - start_t), nbytes_global);
+        printf("1. Partial chunks: total read time is %lf; number of bytes being read from file is %zu\n",
+               (end_t - start_t), nbytes_global);
     else
-        HDprintf(
-            "1. Partial chunks: no total read time because timer is not available; number of bytes being "
-            "read from file is %zu\n",
-            nbytes_global);
+        printf("1. Partial chunks: no total read time because timer is not available; number of bytes being "
+               "read from file is %zu\n",
+               nbytes_global);
 
     H5Dclose(dataset);
     H5Sclose(filespace);
@@ -284,7 +285,7 @@ error:
         H5Sclose(memspace);
         H5Pclose(dapl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 }
 
@@ -341,13 +342,12 @@ check_hash_value_perf(hid_t file)
     end_t = H5_get_time();
 
     if ((end_t - start_t) > 0.0)
-        HDprintf("2. Hash value: total read time is %lf; number of bytes being read from file is %zu\n",
-                 (end_t - start_t), nbytes_global);
+        printf("2. Hash value: total read time is %lf; number of bytes being read from file is %zu\n",
+               (end_t - start_t), nbytes_global);
     else
-        HDprintf(
-            "2. Hash value: no total read time because timer is not available; number of bytes being read "
-            "from file is %zu\n",
-            nbytes_global);
+        printf("2. Hash value: no total read time because timer is not available; number of bytes being read "
+               "from file is %zu\n",
+               nbytes_global);
 
     H5Dclose(dataset);
     H5Sclose(filespace);
@@ -363,7 +363,7 @@ error:
         H5Sclose(memspace);
         H5Pclose(dapl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 }
 
@@ -405,6 +405,6 @@ main(void)
     return 0;
 
 error:
-    HDfprintf(stderr, "*** ERRORS DETECTED ***\n");
+    fprintf(stderr, "*** ERRORS DETECTED ***\n");
     return 1;
 }
