@@ -10,11 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/*
- * Programmer:  Robb Matzke
- *              Thursday, March 12, 1998
- */
-
 /* See H5private.h for how to include headers */
 #include "hdf5.h"
 
@@ -46,9 +41,6 @@
  *
  * Return:  void
  *
- * Programmer:  Robb Matzke
- *              Thursday, March 12, 1998
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -70,12 +62,12 @@ print_stats(const char *prefix,
              ((double)(r_start->ru_stime.tv_sec) + (double)(r_start->ru_stime.tv_usec) / 1000000.0);
 #endif
     e_time = t_stop - t_start;
-    H5_bandwidth(bw, (double)nbytes, e_time);
+    H5_bandwidth(bw, sizeof(bw), (double)nbytes, e_time);
 
 #ifdef H5_HAVE_GETRUSAGE
-    HDprintf(HEADING "%1.2fuser %1.2fsystem %1.2felapsed %s\n", prefix, u_time, s_time, e_time, bw);
+    printf(HEADING "%1.2fuser %1.2fsystem %1.2felapsed %s\n", prefix, u_time, s_time, e_time, bw);
 #else
-    HDprintf(HEADING "%1.2felapsed %s\n", prefix, e_time, bw);
+    printf(HEADING "%1.2felapsed %s\n", prefix, e_time, bw);
 #endif
 }
 
@@ -86,9 +78,6 @@ print_stats(const char *prefix,
  *
  * Return:  void
  *
- * Programmer:  Robb Matzke
- *              Thursday, March 12, 1998
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -99,11 +88,11 @@ synchronize(void)
 #else
     int H5_ATTR_NDEBUG_UNUSED status;
 
-    status = HDsystem("sync");
-    HDassert(status >= 0);
+    status = system("sync");
+    assert(status >= 0);
 
-    status = HDsystem("df >/dev/null");
-    HDassert(status >= 0);
+    status = system("df >/dev/null");
+    assert(status >= 0);
 #endif
 }
 
@@ -116,9 +105,6 @@ synchronize(void)
  *
  *    Failure:
  *
- * Programmer:  Robb Matzke
- *              Thursday, March 12, 1998
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -137,7 +123,7 @@ main(void)
     unsigned                       u;
     herr_t H5_ATTR_NDEBUG_UNUSED   status;
     hssize_t H5_ATTR_NDEBUG_UNUSED n;
-    off_t H5_ATTR_NDEBUG_UNUSED    offset;
+    HDoff_t H5_ATTR_NDEBUG_UNUSED  offset;
     hsize_t                        start[2];
     hsize_t                        count[2];
 
@@ -146,41 +132,41 @@ main(void)
      * Win32 version 5.0 compiler.
      * 1998-11-06 ptl
      */
-    HDprintf("I/O request size is %1.1fMB\n", (double)(hssize_t)(size[0] * size[1]) / 1024.0 * 1024.0);
+    printf("I/O request size is %1.1fMB\n", (double)(hssize_t)(size[0] * size[1]) / 1024.0 * 1024.0);
 
     /* Open the files */
     file = H5Fcreate(HDF5_FILE_NAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
-    HDassert(file >= 0);
+    assert(file >= 0);
     fd = HDopen(RAW_FILE_NAME, O_RDWR | O_CREAT | O_TRUNC, 0666);
-    HDassert(fd >= 0);
+    assert(fd >= 0);
 
     /* Create the dataset */
     file_space = H5Screate_simple(2, size, size);
-    HDassert(file_space >= 0);
+    assert(file_space >= 0);
     dset = H5Dcreate2(file, "dset", H5T_NATIVE_UCHAR, file_space, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
-    HDassert(dset >= 0);
-    the_data = (unsigned char *)HDmalloc((size_t)(size[0] * size[1]));
+    assert(dset >= 0);
+    the_data = (unsigned char *)malloc((size_t)(size[0] * size[1]));
 
     /* initial fill for lazy malloc */
-    HDmemset(the_data, 0xAA, (size_t)(size[0] * size[1]));
+    memset(the_data, 0xAA, (size_t)(size[0] * size[1]));
 
     /* Fill raw */
     synchronize();
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_start);
+    getrusage(RUSAGE_SELF, &r_start);
 #endif
     t_start = H5_get_time();
-    HDfprintf(stderr, HEADING, "fill raw");
+    fprintf(stderr, HEADING, "fill raw");
     for (u = 0; u < nwrite; u++) {
-        HDputc(PROGRESS, stderr);
-        HDfflush(stderr);
-        HDmemset(the_data, 0xAA, (size_t)(size[0] * size[1]));
+        putc(PROGRESS, stderr);
+        fflush(stderr);
+        memset(the_data, 0xAA, (size_t)(size[0] * size[1]));
     }
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_stop);
+    getrusage(RUSAGE_SELF, &r_stop);
 #endif
     t_stop = H5_get_time();
-    HDputc('\n', stderr);
+    putc('\n', stderr);
     print_stats("fill raw",
 #ifdef H5_HAVE_GETRUSAGE
                 &r_start, &r_stop,
@@ -190,21 +176,21 @@ main(void)
     /* Fill hdf5 */
     synchronize();
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_start);
+    getrusage(RUSAGE_SELF, &r_start);
 #endif
     t_start = H5_get_time();
-    HDfprintf(stderr, HEADING, "fill hdf5");
+    fprintf(stderr, HEADING, "fill hdf5");
     for (u = 0; u < nread; u++) {
-        HDputc(PROGRESS, stderr);
-        HDfflush(stderr);
+        putc(PROGRESS, stderr);
+        fflush(stderr);
         status = H5Dread(dset, H5T_NATIVE_UCHAR, file_space, file_space, H5P_DEFAULT, the_data);
-        HDassert(status >= 0);
+        assert(status >= 0);
     }
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_stop);
+    getrusage(RUSAGE_SELF, &r_stop);
 #endif
     t_stop = H5_get_time();
-    HDputc('\n', stderr);
+    putc('\n', stderr);
     print_stats("fill hdf5",
 #ifdef H5_HAVE_GETRUSAGE
                 &r_start, &r_stop,
@@ -214,23 +200,23 @@ main(void)
     /* Write the raw dataset */
     synchronize();
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_start);
+    getrusage(RUSAGE_SELF, &r_start);
 #endif
     t_start = H5_get_time();
-    HDfprintf(stderr, HEADING, "out raw");
+    fprintf(stderr, HEADING, "out raw");
     for (u = 0; u < nwrite; u++) {
-        HDputc(PROGRESS, stderr);
-        HDfflush(stderr);
-        offset = HDlseek(fd, (off_t)0, SEEK_SET);
-        HDassert(0 == offset);
+        putc(PROGRESS, stderr);
+        fflush(stderr);
+        offset = HDlseek(fd, 0, SEEK_SET);
+        assert(0 == offset);
         n = HDwrite(fd, the_data, (size_t)(size[0] * size[1]));
-        HDassert(n >= 0 && (size_t)n == (size[0] * size[1]));
+        assert(n >= 0 && (size_t)n == (size[0] * size[1]));
     }
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_stop);
+    getrusage(RUSAGE_SELF, &r_stop);
 #endif
     t_stop = H5_get_time();
-    HDputc('\n', stderr);
+    putc('\n', stderr);
     print_stats("out raw",
 #ifdef H5_HAVE_GETRUSAGE
                 &r_start, &r_stop,
@@ -240,21 +226,21 @@ main(void)
     /* Write the hdf5 dataset */
     synchronize();
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_start);
+    getrusage(RUSAGE_SELF, &r_start);
 #endif
     t_start = H5_get_time();
-    HDfprintf(stderr, HEADING, "out hdf5");
+    fprintf(stderr, HEADING, "out hdf5");
     for (u = 0; u < nwrite; u++) {
-        HDputc(PROGRESS, stderr);
-        HDfflush(stderr);
+        putc(PROGRESS, stderr);
+        fflush(stderr);
         status = H5Dwrite(dset, H5T_NATIVE_UCHAR, H5S_ALL, H5S_ALL, H5P_DEFAULT, the_data);
-        HDassert(status >= 0);
+        assert(status >= 0);
     }
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_stop);
+    getrusage(RUSAGE_SELF, &r_stop);
 #endif
     t_stop = H5_get_time();
-    HDputc('\n', stderr);
+    putc('\n', stderr);
     print_stats("out hdf5",
 #ifdef H5_HAVE_GETRUSAGE
                 &r_start, &r_stop,
@@ -264,23 +250,23 @@ main(void)
     /* Read the raw dataset */
     synchronize();
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_start);
+    getrusage(RUSAGE_SELF, &r_start);
 #endif
     t_start = H5_get_time();
-    HDfprintf(stderr, HEADING, "in raw");
+    fprintf(stderr, HEADING, "in raw");
     for (u = 0; u < nread; u++) {
-        HDputc(PROGRESS, stderr);
-        HDfflush(stderr);
-        offset = HDlseek(fd, (off_t)0, SEEK_SET);
-        HDassert(0 == offset);
+        putc(PROGRESS, stderr);
+        fflush(stderr);
+        offset = HDlseek(fd, 0, SEEK_SET);
+        assert(0 == offset);
         n = HDread(fd, the_data, (size_t)(size[0] * size[1]));
-        HDassert(n >= 0 && (size_t)n == (size[0] * size[1]));
+        assert(n >= 0 && (size_t)n == (size[0] * size[1]));
     }
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_stop);
+    getrusage(RUSAGE_SELF, &r_stop);
 #endif
     t_stop = H5_get_time();
-    HDputc('\n', stderr);
+    putc('\n', stderr);
     print_stats("in raw",
 #ifdef H5_HAVE_GETRUSAGE
                 &r_start, &r_stop,
@@ -290,21 +276,21 @@ main(void)
     /* Read the hdf5 dataset */
     synchronize();
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_start);
+    getrusage(RUSAGE_SELF, &r_start);
 #endif
     t_start = H5_get_time();
-    HDfprintf(stderr, HEADING, "in hdf5");
+    fprintf(stderr, HEADING, "in hdf5");
     for (u = 0; u < nread; u++) {
-        HDputc(PROGRESS, stderr);
-        HDfflush(stderr);
+        putc(PROGRESS, stderr);
+        fflush(stderr);
         status = H5Dread(dset, H5T_NATIVE_UCHAR, file_space, file_space, H5P_DEFAULT, the_data);
-        HDassert(status >= 0);
+        assert(status >= 0);
     }
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_stop);
+    getrusage(RUSAGE_SELF, &r_stop);
 #endif
     t_stop = H5_get_time();
-    HDputc('\n', stderr);
+    putc('\n', stderr);
     print_stats("in hdf5",
 #ifdef H5_HAVE_GETRUSAGE
                 &r_start, &r_stop,
@@ -312,28 +298,28 @@ main(void)
                 t_start, t_stop, (size_t)(nread * size[0] * size[1]));
 
     /* Read hyperslab */
-    HDassert(size[0] > 20 && size[1] > 20);
+    assert(size[0] > 20 && size[1] > 20);
     start[0] = start[1] = 10;
     count[0] = count[1] = size[0] - 20;
     status              = H5Sselect_hyperslab(file_space, H5S_SELECT_SET, start, NULL, count, NULL);
-    HDassert(status >= 0);
+    assert(status >= 0);
     synchronize();
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_start);
+    getrusage(RUSAGE_SELF, &r_start);
 #endif
     t_start = H5_get_time();
-    HDfprintf(stderr, HEADING, "in hdf5 partial");
+    fprintf(stderr, HEADING, "in hdf5 partial");
     for (u = 0; u < nread; u++) {
-        HDputc(PROGRESS, stderr);
-        HDfflush(stderr);
+        putc(PROGRESS, stderr);
+        fflush(stderr);
         status = H5Dread(dset, H5T_NATIVE_UCHAR, file_space, file_space, H5P_DEFAULT, the_data);
-        HDassert(status >= 0);
+        assert(status >= 0);
     }
 #ifdef H5_HAVE_GETRUSAGE
-    HDgetrusage(RUSAGE_SELF, &r_stop);
+    getrusage(RUSAGE_SELF, &r_stop);
 #endif
     t_stop = H5_get_time();
-    HDputc('\n', stderr);
+    putc('\n', stderr);
     print_stats("in hdf5 partial",
 #ifdef H5_HAVE_GETRUSAGE
                 &r_start, &r_stop,
@@ -347,7 +333,7 @@ main(void)
     H5Sclose(file_space);
     H5Fclose(file);
 
-    HDfree(the_data);
+    free(the_data);
 
     return 0;
 }
