@@ -29,7 +29,6 @@
                             /* in detailed logging  */
 #define HEXDUMP_WRITEDATA 0 /* Toggle whether to print bytes to write */
                             /* in detailed logging  */
-#define LISTENQ 80          /* max pending Driver requests */
 
 #define MW_SESSION_MAGIC   0x88F36B32u
 #define MW_SOCK_COMM_MAGIC 0xDF10A157u
@@ -57,7 +56,7 @@
  *      guard against commands from the wrong entity.
  *
  * xmit_count (uint32_t)
- *      Record of trasmissions received from the Driver. While the transmission
+ *      Record of transmissions received from the Driver. While the transmission
  *      protocol should be trustworthy, this serves as an additional guard.
  *      Starts a 0 and should be incremented for each one-way transmission.
  *
@@ -154,31 +153,8 @@ struct mirror_writer_opts {
     char    *logpath;
 };
 
-static void mybzero(void *dest, size_t size);
-
 static int do_open(struct mirror_session *session, const H5FD_mirror_xmit_open_t *xmit_open);
 
-/* ---------------------------------------------------------------------------
- * Function:   mybzero
- *
- * Purpose:    Introduce bzero without neededing it on the system.
- *
- * Programmer: Jacob Smith
- *             2020-03-30
- * ---------------------------------------------------------------------------
- */
-static void
-mybzero(void *dest, size_t size)
-{
-    size_t i = 0;
-    char  *s = NULL;
-    HDassert(dest);
-    s = (char *)dest;
-    for (i = 0; i < size; i++) {
-        *(s + i) = 0;
-    }
-} /* end mybzero() */
-
 /* ---------------------------------------------------------------------------
  * Function:    session_init
  *
@@ -201,7 +177,7 @@ session_init(struct mirror_writer_opts *opts)
         goto error;
     }
 
-    session = (struct mirror_session *)HDmalloc(sizeof(struct mirror_session));
+    session = (struct mirror_session *)malloc(sizeof(struct mirror_session));
     if (session == NULL) {
         mirror_log(NULL, V_ERR, "can't allocate session structure");
         goto error;
@@ -217,10 +193,9 @@ session_init(struct mirror_writer_opts *opts)
     session->reply.pub.version       = H5FD_MIRROR_XMIT_CURR_VERSION;
     session->reply.pub.op            = H5FD_MIRROR_OP_REPLY;
     session->reply.pub.session_token = 0;
-    mybzero(session->reply.message, H5FD_MIRROR_STATUS_MESSAGE_MAX);
+    memset(session->reply.message, 0, H5FD_MIRROR_STATUS_MESSAGE_MAX);
 
-    /* Options-derived population
-     */
+    /* Options-derived population */
 
     session->loginfo = mirror_log_init(opts->logpath, "W- ", MIRROR_LOG_DEFAULT_VERBOSITY);
 
@@ -228,7 +203,7 @@ session_init(struct mirror_writer_opts *opts)
 
 error:
     if (session) {
-        HDfree(session);
+        free(session);
     }
     return NULL;
 } /* end session_init() */
@@ -247,7 +222,7 @@ session_stop(struct mirror_session *session)
 {
     int ret_value = 0;
 
-    HDassert(session && (session->magic == MW_SESSION_MAGIC));
+    assert(session && (session->magic == MW_SESSION_MAGIC));
 
     mirror_log(session->loginfo, V_INFO, "session_stop()");
 
@@ -271,7 +246,7 @@ session_stop(struct mirror_session *session)
 
     /* Invalidate and release structure */
     session->magic++;
-    HDfree(session);
+    free(session);
 
     return ret_value;
 } /* end session_stop() */
@@ -291,25 +266,16 @@ session_start(int socketfd, const H5FD_mirror_xmit_open_t *xmit_open)
 {
     struct mirror_session    *session = NULL;
     struct mirror_writer_opts opts;
-#if 0 /* TODO: behavior option */
-    char logpath[H5FD_MIRROR_XMIT_FILEPATH_MAX] = "";
-#endif
 
     mirror_log(NULL, V_INFO, "session_start()");
 
-    if (FALSE == H5FD_mirror_xmit_is_open(xmit_open)) {
+    if (false == H5FD_mirror_xmit_is_open(xmit_open)) {
         mirror_log(NULL, V_ERR, "invalid OPEN xmit");
         return NULL;
     }
 
-    opts.magic = MW_OPTS_MAGIC;
-#if 0 /* TODO: behavior option */
-    HDsnprintf(logpath, H5FD_MIRROR_XMIT_FILEPATH_MAX, "%s.log",
-            xmit_open->filename);
-    opts.logpath = logpath;
-#else
+    opts.magic   = MW_OPTS_MAGIC;
     opts.logpath = NULL;
-#endif
 
     session = session_init(&opts);
     if (NULL == session) {
@@ -350,7 +316,7 @@ _xmit_reply(struct mirror_session *session)
     unsigned char             xmit_buf[H5FD_MIRROR_XMIT_REPLY_SIZE];
     H5FD_mirror_xmit_reply_t *reply = &(session->reply);
 
-    HDassert(session && (session->magic == MW_SESSION_MAGIC));
+    assert(session && (session->magic == MW_SESSION_MAGIC));
 
     mirror_log(session->loginfo, V_ALL, "_xmit_reply()");
 
@@ -386,12 +352,12 @@ reply_ok(struct mirror_session *session)
 {
     H5FD_mirror_xmit_reply_t *reply = &(session->reply);
 
-    HDassert(session && (session->magic == MW_SESSION_MAGIC));
+    assert(session && (session->magic == MW_SESSION_MAGIC));
 
     mirror_log(session->loginfo, V_ALL, "reply_ok()");
 
     reply->status = H5FD_MIRROR_STATUS_OK;
-    mybzero(reply->message, H5FD_MIRROR_STATUS_MESSAGE_MAX);
+    memset(reply->message, 0, H5FD_MIRROR_STATUS_MESSAGE_MAX);
     return _xmit_reply(session);
 } /* end reply_ok() */
 
@@ -410,12 +376,12 @@ reply_error(struct mirror_session *session, const char *msg)
 {
     H5FD_mirror_xmit_reply_t *reply = &(session->reply);
 
-    HDassert(session && (session->magic == MW_SESSION_MAGIC));
+    assert(session && (session->magic == MW_SESSION_MAGIC));
 
     mirror_log(session->loginfo, V_ALL, "reply_error(%s)", msg);
 
     reply->status = H5FD_MIRROR_STATUS_ERROR;
-    HDsnprintf(reply->message, H5FD_MIRROR_STATUS_MESSAGE_MAX - 1, "%s", msg);
+    snprintf(reply->message, H5FD_MIRROR_STATUS_MESSAGE_MAX - 1, "%s", msg);
     return _xmit_reply(session);
 } /* end reply_error() */
 
@@ -431,7 +397,7 @@ static int
 do_close(struct mirror_session *session)
 {
 
-    HDassert(session && (session->magic == MW_SESSION_MAGIC));
+    assert(session && (session->magic == MW_SESSION_MAGIC));
 
     mirror_log(session->loginfo, V_INFO, "do_close()");
 
@@ -471,7 +437,7 @@ do_lock(struct mirror_session *session, const unsigned char *xmit_buf)
     size_t                  decode_ret = 0;
     H5FD_mirror_xmit_lock_t xmit_lock;
 
-    HDassert(session && (session->magic == MW_SESSION_MAGIC) && xmit_buf);
+    assert(session && (session->magic == MW_SESSION_MAGIC) && xmit_buf);
 
     mirror_log(session->loginfo, V_INFO, "do_lock()");
 
@@ -489,7 +455,7 @@ do_lock(struct mirror_session *session, const unsigned char *xmit_buf)
     }
     mirror_log(session->loginfo, V_INFO, "lock rw: (%d)", xmit_lock.rw);
 
-    if (H5FDlock(session->file, (hbool_t)xmit_lock.rw) < 0) {
+    if (H5FDlock(session->file, (bool)xmit_lock.rw) < 0) {
         mirror_log(session->loginfo, V_ERR, "H5FDlock()");
         reply_error(session, "remote H5FDlock() failure");
         return -1;
@@ -519,8 +485,8 @@ do_open(struct mirror_session *session, const H5FD_mirror_xmit_open_t *xmit_open
     unsigned _flags   = 0;
     haddr_t  _maxaddr = HADDR_UNDEF;
 
-    HDassert(session && (session->magic == MW_SESSION_MAGIC) && xmit_open &&
-             TRUE == H5FD_mirror_xmit_is_open(xmit_open));
+    assert(session && (session->magic == MW_SESSION_MAGIC) && xmit_open &&
+           true == H5FD_mirror_xmit_is_open(xmit_open));
 
     mirror_log(session->loginfo, V_INFO, "do_open()");
 
@@ -595,7 +561,7 @@ error:
         {
             (void)H5Pclose(fapl_id);
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     }
     return -1;
 } /* end do_open() */
@@ -614,7 +580,7 @@ do_set_eoa(struct mirror_session *session, const unsigned char *xmit_buf)
     size_t                 decode_ret = 0;
     H5FD_mirror_xmit_eoa_t xmit_seoa;
 
-    HDassert(session && (session->magic == MW_SESSION_MAGIC) && xmit_buf);
+    assert(session && (session->magic == MW_SESSION_MAGIC) && xmit_buf);
 
     mirror_log(session->loginfo, V_INFO, "do_set_eoa()");
 
@@ -660,11 +626,11 @@ static int
 do_truncate(struct mirror_session *session)
 {
 
-    HDassert(session && (session->magic == MW_SESSION_MAGIC));
+    assert(session && (session->magic == MW_SESSION_MAGIC));
 
     mirror_log(session->loginfo, V_INFO, "do_truncate()");
 
-    /* default DXPL ID (0), 0 for "FALSE" closing -- both probably unused */
+    /* default DXPL ID (0), 0 for "false" closing -- both probably unused */
     if (H5FDtruncate(session->file, 0, 0) < 0) {
         mirror_log(session->loginfo, V_ERR, "H5FDtruncate()");
         reply_error(session, "remote H5FDtruncate() failure");
@@ -691,7 +657,7 @@ do_truncate(struct mirror_session *session)
 static int
 do_unlock(struct mirror_session *session)
 {
-    HDassert(session && (session->magic == MW_SESSION_MAGIC));
+    assert(session && (session->magic == MW_SESSION_MAGIC));
 
     mirror_log(session->loginfo, V_INFO, "do_unlock()");
 
@@ -735,7 +701,7 @@ do_write(struct mirror_session *session, const unsigned char *xmit_buf)
     ssize_t                  nbytes_in_packet  = 0;
     H5FD_mirror_xmit_write_t xmit_write;
 
-    HDassert(session && (session->magic == MW_SESSION_MAGIC) && xmit_buf);
+    assert(session && (session->magic == MW_SESSION_MAGIC) && xmit_buf);
 
     mirror_log(session->loginfo, V_INFO, "do_write()");
 
@@ -761,9 +727,9 @@ do_write(struct mirror_session *session, const unsigned char *xmit_buf)
     addr = (haddr_t)xmit_write.offset;
     type = (H5FD_mem_t)xmit_write.type;
 
-    /* Allocate the buffer once -- re-use between loops.
+    /* Allocate the buffer once -- reuse between loops.
      */
-    buf = (char *)HDmalloc(sizeof(char) * H5FD_MIRROR_DATA_BUFFER_MAX);
+    buf = (char *)malloc(sizeof(char) * H5FD_MIRROR_DATA_BUFFER_MAX);
     if (NULL == buf) {
         mirror_log(session->loginfo, V_ERR, "can't allocate databuffer");
         reply_error(session, "can't allocate buffer for receiving data");
@@ -815,7 +781,7 @@ do_write(struct mirror_session *session, const unsigned char *xmit_buf)
 
     } while (sum_bytes_written < xmit_write.size); /* end while ingesting */
 
-    HDfree(buf);
+    free(buf);
 
     /* signal that we're done here and a-ok */
     if (reply_ok(session) < 0) {
@@ -847,13 +813,13 @@ receive_communique(struct mirror_session *session, struct sock_comm *comm)
     size_t              decode_ret;
     H5FD_mirror_xmit_t *X = comm->xmit_recd;
 
-    HDassert((session != NULL) && (session->magic == MW_SESSION_MAGIC) && (comm != NULL) &&
-             (comm->magic == MW_SOCK_COMM_MAGIC) && (comm->xmit_recd != NULL) && (comm->raw != NULL) &&
-             (comm->raw_size >= H5FD_MIRROR_XMIT_BUFFER_MAX));
+    assert((session != NULL) && (session->magic == MW_SESSION_MAGIC) && (comm != NULL) &&
+           (comm->magic == MW_SOCK_COMM_MAGIC) && (comm->xmit_recd != NULL) && (comm->raw != NULL) &&
+           (comm->raw_size >= H5FD_MIRROR_XMIT_BUFFER_MAX));
 
     mirror_log(session->loginfo, V_INFO, "receive_communique()");
 
-    mybzero(comm->raw, comm->raw_size);
+    memset(comm->raw, 0, comm->raw_size);
     comm->recd_die = 0;
 
     mirror_log(session->loginfo, V_INFO, "ready to receive"); /* TODO */
@@ -871,7 +837,7 @@ receive_communique(struct mirror_session *session, struct sock_comm *comm)
     } /* end if hexdump transmissions received */
 
     /* old-fashioned manual kill (for debugging) */
-    if (!HDstrncmp("GOODBYE", comm->raw, 7)) {
+    if (!strncmp("GOODBYE", comm->raw, 7)) {
         mirror_log(session->loginfo, V_INFO, "received GOODBYE");
         comm->recd_die = 1;
         goto done;
@@ -933,13 +899,13 @@ process_instructions(struct mirror_session *session)
     size_t             buf_size;
     H5FD_mirror_xmit_t xmit_recd; /* for decoded xmit header */
 
-    HDassert(session && (session->magic == MW_SESSION_MAGIC));
+    assert(session && (session->magic == MW_SESSION_MAGIC));
 
     mirror_log(session->loginfo, V_INFO, "process_instructions()");
 
     buf_size = H5FD_MIRROR_XMIT_BUFFER_MAX * sizeof(char);
 
-    if (NULL == (xmit_buf = HDmalloc(buf_size))) {
+    if (NULL == (xmit_buf = malloc(buf_size))) {
         mirror_log(session->loginfo, V_ERR, "out of memory");
         goto error;
     }
@@ -1008,11 +974,11 @@ process_instructions(struct mirror_session *session)
 done:
     comm.magic      = 0; /* invalidate structure, on principle */
     xmit_recd.magic = 0; /* invalidate structure, on principle */
-    HDfree(xmit_buf);
+    free(xmit_buf);
     return 0;
 
 error:
-    HDfree(xmit_buf);
+    free(xmit_buf);
     return -1;
 } /* end process_instructions() */
 
